@@ -48,21 +48,14 @@
 # define N_HBLK_FLS ((HUGE_THRESHOLD - UNIQUE_THRESHOLD) / FL_COMPRESSION \
                      + UNIQUE_THRESHOLD)
 
-#ifndef GC_GCJ_SUPPORT
-  STATIC
-#endif
-  struct hblk * GC_hblkfreelist[N_HBLK_FLS+1] = { 0 };
+STATIC struct hblk * GC_hblkfreelist[N_HBLK_FLS+1] = { 0 };
                                 /* List of completely empty heap blocks */
                                 /* Linked through hb_next field of      */
                                 /* header structure associated with     */
-                                /* block.  Remains externally visible   */
-                                /* as used by GNU GCJ currently.        */
+                                /* block.                               */
 
-#ifndef GC_GCJ_SUPPORT
-  STATIC
-#endif
-  word GC_free_bytes[N_HBLK_FLS+1] = { 0 };
-        /* Number of free bytes on each list.  Remains visible to GCJ.  */
+STATIC word GC_free_bytes[N_HBLK_FLS+1] = { 0 };
+        /* Number of free bytes on each list.   */
 
 /* Return the largest n such that the number of free bytes on lists     */
 /* n .. N_HBLK_FLS is greater or equal to GC_max_large_allocd_bytes     */
@@ -751,12 +744,11 @@ GC_allochblk_nth(size_t sz, int kind, unsigned flags, int n, int may_split)
                       GC_bytes_dropped += total_size;
                       GC_remove_from_fl_at(hhdr, n);
                       for (h = hbp; (word)h < (word)limit; h++) {
-                        if (h != hbp) {
-                          hhdr = GC_install_header(h);
-                        }
-                        if (NULL != hhdr) {
-                          (void)setup_header(hhdr, h, HBLKSIZE, PTRFREE, 0);
-                                                    /* Can't fail. */
+                        if (h == hbp || 0 != (hhdr = GC_install_header(h))) {
+                          (void) setup_header(
+                                  hhdr, h,
+                                  HBLKSIZE,
+                                  PTRFREE, 0); /* Can't fail */
                           if (GC_debugging_started) {
                             BZERO(h, HBLKSIZE);
                           }
@@ -845,8 +837,10 @@ GC_INNER void GC_freehblk(struct hblk *hbp)
 
     /* Check for duplicate deallocation in the easy case */
       if (HBLK_IS_FREE(hhdr)) {
-        ABORT_ARG1("Duplicate large block deallocation",
-                   " of %p", (void *)hbp);
+        if (GC_print_stats)
+          GC_log_printf("Duplicate large block deallocation of %p\n",
+                        (void *)hbp);
+        ABORT("Duplicate large block deallocation");
       }
 
     GC_ASSERT(IS_MAPPED(hhdr));
