@@ -3,7 +3,7 @@
 ;*    -------------------------------------------------------------    */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Sun Nov 15 06:58:27 1998                          */
-;*    Last change :  Wed Jun  7 06:25:09 2000 (serrano)                */
+;*    Last change :  Tue Jan 28 11:02:05 2003 (serrano)                */
 ;*    -------------------------------------------------------------    */
 ;*    The connexion to bdb (via dbg).                                  */
 ;*=====================================================================*/
@@ -12,12 +12,15 @@
 ;*    The module                                                       */
 ;*---------------------------------------------------------------------*/
 (provide 'bee-bdb)
+(require (if (featurep 'xemacs) 'bmacs-xemacs 'bmacs-gnu-emacs))
 (require 'bee-config)
 (require 'bee-autoload)
+(require 'bee-keymap)
 (require 'dbg-autoload)
 (require 'dbg-config)
 (require 'ude-autoload)
 (require 'ude-config)
+(require 'ude-balloon)
 (require 'cee-gdb)
  
 ;*---------------------------------------------------------------------*/
@@ -336,13 +339,6 @@ reported by `info breakpoint'."
 			file
 			line)
 		  t)
-	  "-"
-	  (vector "(bdb) footprint"
-		  (list 'bdb-remote-set-breakpoint
-			(concat bee-dbg-footprint-command " ")
-			file
-			line)
-		  t)
 	  "--:shadowDoubleEtchedOut")))
 
 ;*---------------------------------------------------------------------*/
@@ -352,19 +348,17 @@ reported by `info breakpoint'."
   ;; we start balloon
   (ude-balloon-start)
   ;; the action on breakpoint (margin balloon)
-  (ude-add-balloon-action
+  '(ude-add-balloon-action
    'bee-bdb
-   '(lambda (mouse-pos)
-      (let ((win (car mouse-pos))
-	    (x   (car (cdr mouse-pos))))
-	(and (windowp win)
-	     (numberp x)
-	     (> (window-left-margin-pixel-width win) x))))
-   '(lambda ()
+   #'(lambda (x win)
+       (and (windowp win)
+	    (numberp x)
+	    (> (window-left-margin-pixel-width win) x)))
+   #'(lambda ()
       (let* ((buffer (ude-balloon-get-buffer))
 	     (pos    (ude-balloon-get-point)))
 	(if (and (bufferp buffer) (numberp pos))
-	    (let* ((ex  (extent-at pos buffer 'dbg-breakpoint))
+	    (let* ((ex  (find-text-property pos 'dbg-breakpoint buffer))
 		   (msg (dbg-breakpoint-balloon-message ex)))
 	      (if (stringp msg)
 		  (display-message 'no-log msg))))))))
@@ -380,7 +374,7 @@ reported by `info breakpoint'."
 ;*---------------------------------------------------------------------*/
 (defun bee-connect-buffer-hook ()
   ;; we set dbg mouse bindings
-  (ude-add-menu '(lambda (event)
+  '(ude-add-menu #'(lambda (event)
 		   (and (> (window-left-margin-pixel-width
 			    (event-window event))
 			   (event-x-pixel event))))
