@@ -1,41 +1,9 @@
-;*---------------------------------------------------------------------*/
-;*   A pratical implementation for the Scheme programming language     */
-;*                                                                     */
-;*                                    ,--^,                            */
-;*                              _ ___/ /|/                             */
-;*                          ,;'( )__, ) '                              */
-;*                         ;;  //   L__.                               */
-;*                         '   \\   /  '                               */
-;*                              ^   ^                                  */
-;*                                                                     */
-;*   Copyright (c) 1992-1999 Manuel Serrano                            */
-;*                                                                     */
-;*     Bug descriptions, use reports, comments or suggestions are      */
-;*     welcome. Send them to                                           */
-;*       bigloo-request@kaolin.unice.fr                                */
-;*       http://kaolin.unice.fr/bigloo                                 */
-;*                                                                     */
-;*   This program is free software; you can redistribute it            */
-;*   and/or modify it under the terms of the GNU General Public        */
-;*   License as published by the Free Software Foundation; either      */
-;*   version 2 of the License, or (at your option) any later version.  */
-;*                                                                     */
-;*   This program is distributed in the hope that it will be useful,   */
-;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
-;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
-;*   GNU General Public License for more details.                      */
-;*                                                                     */
-;*   You should have received a copy of the GNU General Public         */
-;*   License along with this program; if not, write to the Free        */
-;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
-;*   MA 02111-1307, USA.                                               */
-;*---------------------------------------------------------------------*/
 ;*=====================================================================*/
 ;*    serrano/prgm/project/bigloo/cigloo/Parser/cpp.scm                */
 ;*    -------------------------------------------------------------    */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Wed Nov 29 09:46:19 1995                          */
-;*    Last change :  Fri Dec 11 08:27:05 1998 (serrano)                */
+;*    Last change :  Sun Aug 31 16:05:42 2008 (serrano)                */
 ;*    -------------------------------------------------------------    */
 ;*    The cpp parsing                                                  */
 ;*=====================================================================*/
@@ -70,7 +38,8 @@
    (regular-grammar ((nonzero-digit   (in ("19")))
 		     (odigit          (in ("07")))
 		     (long-suffix     (or #\l #\L))
-		     (unsigned-suffix (or #\u #\U)))
+		     (unsigned-suffix (or #\u #\U))
+		     ctx)
 
       ;; blank
       ((+ (in #\space #\Newline #\tab #a012 #\\))
@@ -85,21 +54,24 @@
 		   (* #\space)
 		   (: (or #\_ alpha) (* (or #\_ alpha #\_ digit)))
 		 #\())
-       (rgc-context 'define-fun)
-       (cons 'define-fun (the-string)))
+       (cell-set! ctx 'define-fun)
+       (cons 'DEFINE-FUN (the-string)))
 
       ;; ending of `define toto( ...'
-      ((context define-fun #\))
-       (rgc-context)
-       'EOA)
+      (#\)
+       (if (eq? (cell-ref ctx) 'define-fun)
+	   (begin
+	      (cell-set! ctx 'noctx)
+	      'EOA)
+	   (list 'STRING ")")))
 
       ;; define
       ((bol (: #\# (* #\space) "define"))
-       'define-var)
+       'DEFINE-VAR)
 
       ;; include
       ((bol (: #\# (* #\space) "include"))
-       'include)
+       'INCLUDE)
 
       ;; identifier
       ((: (or #\_ alpha) (* (or alpha #\_ digit)))
@@ -110,7 +82,7 @@
        (list '<STRING> (the-substring 1 (-fx (the-length) 1))))
 
       ;; strings
-      ((: #\" (+ (out #\")) #\")
+      ((: #\" (* (out #\")) #\")
        (list 'STRING (the-substring 1 (-fx (the-length) 1))))
 
       ;; integer constant
@@ -227,14 +199,16 @@
 				"Unknown type expression -- "
 				"Using `" *default-type* "' type"))
 		   (bind-macro! m-id)
-		   (fprint *oport*
-			   "   (macro " m-id "::" *default-type*
-			   " \"" m-id "\")"))
+                   (if (or (not *omit-underscore*) (not (eq? (string-ref m-id 0) #\_)))
+		     (fprint *oport*
+		  	   "   (macro " m-id "::" *default-type*
+		  	   " \"" m-id "\")")))
 		  (else
 		   (bind-macro! m-id)
-		   (fprint *oport*
-			   "   (macro " m-id "::" (cdr cell) " \"" m-id
-			   "\")")))))
+                   (if (or (not *omit-underscore*) (not (eq? (string-ref m-id 0) #\_)))
+		     (fprint *oport*
+		  	   "   (macro " m-id "::" (cdr cell) " \"" m-id
+		  	   "\")"))))))
 	'done)
        ((DEFINE-FUN args)
 	(if *define-fun*
@@ -278,10 +252,11 @@
 			 'done)
 		      (begin
 			 (bind-macro! m-id)
-			 (fprint *oport*
-				 "   (macro " m-id "::" *default-type*
-				 " " (map (lambda (x) *default-type*) args)
-				 " \"" m-id "\")"))))))))
+                         (if (or (not *omit-underscore*) (not (eq? (string-ref m-id 0) #\_)))
+			   (fprint *oport*
+			  	 "   (macro " m-id "::" *default-type*
+			  	 " " (map (lambda (x) *default-type*) args)
+			  	 " \"" m-id "\")")))))))))
       (args
        ((EOA)
 	'())
