@@ -3,7 +3,7 @@
 ;*    -------------------------------------------------------------    */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Fri May 31 14:00:21 1996                          */
-;*    Last change :  Tue Jul  3 16:20:58 2001 (serrano)                */
+;*    Last change :  Tue Apr 19 14:18:41 2016 (serrano)                */
 ;*    -------------------------------------------------------------    */
 ;*    From the code definition, we build the Ast                       */
 ;*=====================================================================*/
@@ -25,9 +25,16 @@
 	    tools_location
 	    tools_error
 	    tools_shape)
-   (export  (build-ast             ::obj)
+   (export  (append-ast::pair-nil ::pair-nil ::pair-nil)
+	    (build-ast ::obj)
 	    (build-ast-sans-remove ::obj)))
 
+;*---------------------------------------------------------------------*/
+;*    append-ast ...                                                   */
+;*---------------------------------------------------------------------*/
+(define (append-ast a1 a2)
+   (append a1 a2))
+
 ;*---------------------------------------------------------------------*/
 ;*    build-ast ...                                                    */
 ;*    -------------------------------------------------------------    */
@@ -46,29 +53,31 @@
    ;; there are two separate `map' because we can't build
    ;; node of the ast _until_ all the units have been processed
    ;; (otherwise some global variables could be unbound).
-   (let ((defs (apply append (map unit->defs units))))
-      ;; we can now check if all declared global variables are defined.
-      (check-to-be-define)
-      ;; and build the regular ast
-      (let ((ast (map sfun-def->ast defs)))
-	 ;; and we return the constructed ast
-	 (pass-postlude ast))))
+   (let* ((nberr *nb-error-on-pass*)
+	  (defs (apply append (map unit->defs units))))
+      (if (=fx nberr *nb-error-on-pass*)
+	  (begin
+	     ;; we can now check if all declared global variables are defined.
+	     (check-to-be-define)
+	     ;; and build the regular ast
+	     (let ((ast (map sfun-def->ast defs)))
+		;; and we return the constructed ast
+		(pass-postlude ast)))
+	  (pass-postlude '()))))
 
 ;*---------------------------------------------------------------------*/
 ;*    sfun-def->ast ...                                                */
 ;*---------------------------------------------------------------------*/
 (define (sfun-def->ast::global def::global)
    (enter-function (global-id def))
-   (let* ((sfun          (global-value def))
-	  (sfun-args     (sfun-args sfun))
-	  (sfun-body-exp (sfun-body sfun))
-	  (def-loc       (find-location (global-src def)))
-	  (body          (sexp->node sfun-body-exp
-				     sfun-args
-				     (find-location/loc sfun-body-exp
-							def-loc)
-				     'value)))
-      (sfun-body-set! sfun body)
-      (leave-function)
-      def))
+   (unwind-protect
+      (let* ((sfun (global-value def))
+	     (sfun-args (sfun-args sfun))
+	     (sfun-body-exp (sfun-body sfun))
+	     (def-loc (find-location (global-src def)))
+	     (loc (find-location/loc sfun-body-exp def-loc))
+	     (body (sexp->node sfun-body-exp sfun-args loc 'value)))
+	 (sfun-body-set! sfun body))
+      (leave-function))
+   def)
 
