@@ -1,9 +1,9 @@
 /*===========================================================================*/
 /*   (Ast/init.scm)                                                          */
-/*   Bigloo (4.5b)                                                           */
-/*   Inria -- Sophia Antipolis (c)       Fri Dec 22 05:17:06 PM CET 2023     */
+/*   Bigloo (4.6a)                                                           */
+/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
 /*===========================================================================*/
-/* COMPILATION: (/home/serrano/prgm/project/bigloo/bigloo/bin/bigloo -ldopt -L/home/serrano/prgm/project/bigloo/bigloo/libbacktrace/home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b  -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Ast/init.scm) */
+/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Ast/init.scm) */
 /* GC selection */
 #define THE_GC BOEHM_GC
 
@@ -38,6 +38,7 @@ extern "C"
 		obj_t BgL_parentsz00;
 		bool_t BgL_initzf3zf3;
 		bool_t BgL_magiczf3zf3;
+		obj_t BgL_nullz00;
 		obj_t BgL_z42z42;
 		obj_t BgL_aliasz00;
 		obj_t BgL_pointedzd2tozd2byz00;
@@ -90,7 +91,7 @@ extern "C"
 		obj_t BgL_libraryz00;
 		obj_t BgL_pragmaz00;
 		obj_t BgL_srcz00;
-		obj_t BgL_jvmzd2typezd2namez00;
+		obj_t BgL_qualifiedzd2typezd2namez00;
 		obj_t BgL_initz00;
 		obj_t BgL_aliasz00;
 	}                *BgL_globalz00_bglt;
@@ -207,12 +208,12 @@ extern "C"
 	   
 		 
 		DEFINE_EXPORT_BGL_PROCEDURE(BGl_astzd2initializa7erszd2envza7zzast_initz00,
-		BgL_bgl_za762astza7d2initial1576z00,
+		BgL_bgl_za762astza7d2initial1401z00,
 		BGl_z62astzd2initializa7ersz17zzast_initz00, 0L, BUNSPEC, 0);
-	      DEFINE_STRING(BGl_string1570z00zzast_initz00,
-		BgL_bgl_string1570za700za7za7a1577za7, "ast_init", 8);
-	      DEFINE_STRING(BGl_string1571z00zzast_initz00,
-		BgL_bgl_string1571za700za7za7a1578za7, "imported (ld distrib) unit ", 27);
+	      DEFINE_STRING(BGl_string1393z00zzast_initz00,
+		BgL_bgl_string1393za700za7za7a1402za7, "ast_init", 8);
+	      DEFINE_STRING(BGl_string1394z00zzast_initz00,
+		BgL_bgl_string1394za700za7za7a1403za7, "imported (ld distrib) unit ", 27);
 
 /* GC roots registration */
 	static obj_t bgl_gc_roots_register()
@@ -232,7 +233,7 @@ extern "C"
 
 /* module-initialization */
 	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zzast_initz00(long
-		BgL_checksumz00_1886, char *BgL_fromz00_1887)
+		BgL_checksumz00_1891, char *BgL_fromz00_1892)
 	{
 		{
 			if (CBOOL(BGl_requirezd2initializa7ationz75zzast_initz00))
@@ -277,71 +278,71 @@ extern "C"
 	{
 		{	/* Ast/init.scm 15 */
 			{	/* Ast/init.scm 15 */
-				obj_t BgL_cportz00_1875;
+				obj_t BgL_cportz00_1880;
 
 				{	/* Ast/init.scm 15 */
-					obj_t BgL_stringz00_1882;
+					obj_t BgL_stringz00_1887;
 
-					BgL_stringz00_1882 = BGl_string1571z00zzast_initz00;
+					BgL_stringz00_1887 = BGl_string1394z00zzast_initz00;
 					{	/* Ast/init.scm 15 */
-						obj_t BgL_startz00_1883;
+						obj_t BgL_startz00_1888;
 
-						BgL_startz00_1883 = BINT(0L);
+						BgL_startz00_1888 = BINT(0L);
 						{	/* Ast/init.scm 15 */
-							obj_t BgL_endz00_1884;
+							obj_t BgL_endz00_1889;
 
-							BgL_endz00_1884 =
-								BINT(STRING_LENGTH(((obj_t) BgL_stringz00_1882)));
+							BgL_endz00_1889 =
+								BINT(STRING_LENGTH(((obj_t) BgL_stringz00_1887)));
 							{	/* Ast/init.scm 15 */
 
-								BgL_cportz00_1875 =
+								BgL_cportz00_1880 =
 									BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00
-									(BgL_stringz00_1882, BgL_startz00_1883, BgL_endz00_1884);
+									(BgL_stringz00_1887, BgL_startz00_1888, BgL_endz00_1889);
 				}}}}
 				{
-					long BgL_iz00_1876;
+					long BgL_iz00_1881;
 
-					BgL_iz00_1876 = 2L;
-				BgL_loopz00_1877:
-					if ((BgL_iz00_1876 == -1L))
+					BgL_iz00_1881 = 2L;
+				BgL_loopz00_1882:
+					if ((BgL_iz00_1881 == (-1L)))
 						{	/* Ast/init.scm 15 */
 							return BUNSPEC;
 						}
 					else
 						{	/* Ast/init.scm 15 */
 							{	/* Ast/init.scm 15 */
-								obj_t BgL_arg1575z00_1878;
+								obj_t BgL_arg1400z00_1883;
 
 								{	/* Ast/init.scm 15 */
 
 									{	/* Ast/init.scm 15 */
-										obj_t BgL_locationz00_1880;
+										obj_t BgL_locationz00_1885;
 
-										BgL_locationz00_1880 = BBOOL(((bool_t) 0));
+										BgL_locationz00_1885 = BBOOL(((bool_t) 0));
 										{	/* Ast/init.scm 15 */
 
-											BgL_arg1575z00_1878 =
-												BGl_readz00zz__readerz00(BgL_cportz00_1875,
-												BgL_locationz00_1880);
+											BgL_arg1400z00_1883 =
+												BGl_readz00zz__readerz00(BgL_cportz00_1880,
+												BgL_locationz00_1885);
 										}
 									}
 								}
 								{	/* Ast/init.scm 15 */
-									int BgL_tmpz00_1911;
+									int BgL_tmpz00_1916;
 
-									BgL_tmpz00_1911 = (int) (BgL_iz00_1876);
-									CNST_TABLE_SET(BgL_tmpz00_1911, BgL_arg1575z00_1878);
+									BgL_tmpz00_1916 = (int) (BgL_iz00_1881);
+									CNST_TABLE_SET(BgL_tmpz00_1916, BgL_arg1400z00_1883);
 							}}
 							{	/* Ast/init.scm 15 */
-								int BgL_auxz00_1881;
+								int BgL_auxz00_1886;
 
-								BgL_auxz00_1881 = (int) ((BgL_iz00_1876 - 1L));
+								BgL_auxz00_1886 = (int) ((BgL_iz00_1881 - 1L));
 								{
-									long BgL_iz00_1916;
+									long BgL_iz00_1921;
 
-									BgL_iz00_1916 = (long) (BgL_auxz00_1881);
-									BgL_iz00_1876 = BgL_iz00_1916;
-									goto BgL_loopz00_1877;
+									BgL_iz00_1921 = (long) (BgL_auxz00_1886);
+									BgL_iz00_1881 = BgL_iz00_1921;
+									goto BgL_loopz00_1882;
 								}
 							}
 						}
@@ -380,78 +381,79 @@ extern "C"
 	{
 		{	/* Ast/init.scm 54 */
 			{	/* Ast/init.scm 55 */
-				obj_t BgL_libzd2unitzd2_1655;
+				obj_t BgL_libzd2unitzd2_1660;
 
-				BgL_libzd2unitzd2_1655 =
+				BgL_libzd2unitzd2_1660 =
 					BGl_libraryzd2finaliza7erz75zzmodule_libraryz00();
 				{	/* Ast/init.scm 55 */
-					obj_t BgL_libzd2initzd2_1656;
+					obj_t BgL_libzd2initzd2_1661;
 
 					{	/* Ast/init.scm 56 */
-						bool_t BgL_test1581z00_1920;
+						bool_t BgL_test1407z00_1925;
 
-						if (STRUCTP(BgL_libzd2unitzd2_1655))
+						if (STRUCTP(BgL_libzd2unitzd2_1660))
 							{	/* Ast/init.scm 56 */
-								BgL_test1581z00_1920 =
-									(STRUCT_KEY(BgL_libzd2unitzd2_1655) == CNST_TABLE_REF(0L));
+								BgL_test1407z00_1925 =
+									(STRUCT_KEY(BgL_libzd2unitzd2_1660) ==
+									((obj_t) CNST_TABLE_REF(0)));
 							}
 						else
 							{	/* Ast/init.scm 56 */
-								BgL_test1581z00_1920 = ((bool_t) 0);
+								BgL_test1407z00_1925 = ((bool_t) 0);
 							}
-						if (BgL_test1581z00_1920)
+						if (BgL_test1407z00_1925)
 							{	/* Ast/init.scm 57 */
-								obj_t BgL_varsz00_1664;
+								obj_t BgL_varsz00_1669;
 
 								{	/* Ast/init.scm 57 */
-									obj_t BgL_arg1292z00_1674;
+									obj_t BgL_arg1281z00_1679;
 
 									{	/* Ast/init.scm 57 */
-										obj_t BgL_list1293z00_1675;
+										obj_t BgL_list1282z00_1680;
 
-										BgL_list1293z00_1675 =
-											MAKE_YOUNG_PAIR(BgL_libzd2unitzd2_1655, BNIL);
-										BgL_arg1292z00_1674 = BgL_list1293z00_1675;
+										BgL_list1282z00_1680 =
+											MAKE_YOUNG_PAIR(BgL_libzd2unitzd2_1660, BNIL);
+										BgL_arg1281z00_1679 = BgL_list1282z00_1680;
 									}
-									BgL_varsz00_1664 =
+									BgL_varsz00_1669 =
 										BGl_buildzd2astzd2sanszd2removezd2zzast_buildz00
-										(BgL_arg1292z00_1674);
+										(BgL_arg1281z00_1679);
 								}
 								{
-									obj_t BgL_l1250z00_1666;
+									obj_t BgL_l1249z00_1671;
 
-									BgL_l1250z00_1666 = BgL_varsz00_1664;
-								BgL_zc3z04anonymousza31287ze3z87_1667:
-									if (PAIRP(BgL_l1250z00_1666))
+									BgL_l1249z00_1671 = BgL_varsz00_1669;
+								BgL_zc3z04anonymousza31277ze3z87_1672:
+									if (PAIRP(BgL_l1249z00_1671))
 										{	/* Ast/init.scm 58 */
 											{	/* Ast/init.scm 59 */
-												obj_t BgL_gz00_1669;
+												obj_t BgL_gz00_1674;
 
-												BgL_gz00_1669 = CAR(BgL_l1250z00_1666);
+												BgL_gz00_1674 = CAR(BgL_l1249z00_1671);
 												{	/* Ast/init.scm 59 */
-													obj_t BgL_nz00_1670;
+													obj_t BgL_nz00_1675;
 
-													BgL_nz00_1670 =
+													BgL_nz00_1675 =
 														(((BgL_sfunz00_bglt) COBJECT(
 																((BgL_sfunz00_bglt)
 																	(((BgL_variablez00_bglt) COBJECT(
 																				((BgL_variablez00_bglt)
 																					((BgL_globalz00_bglt)
-																						BgL_gz00_1669))))->
+																						BgL_gz00_1674))))->
 																		BgL_valuez00))))->BgL_bodyz00);
 													BGl_occurzd2nodezd2inz12z12zzast_occurz00((
-															(BgL_nodez00_bglt) BgL_nz00_1670),
-														((BgL_globalz00_bglt) BgL_gz00_1669));
+															(BgL_nodez00_bglt) BgL_nz00_1675),
+														((BgL_globalz00_bglt) BgL_gz00_1674));
 													BGl_lvtypezd2nodez12zc0zzast_lvtypez00((
-															(BgL_nodez00_bglt) BgL_nz00_1670));
+															(BgL_nodez00_bglt) BgL_nz00_1675));
 												}
 											}
 											{
-												obj_t BgL_l1250z00_1941;
+												obj_t BgL_l1249z00_1947;
 
-												BgL_l1250z00_1941 = CDR(BgL_l1250z00_1666);
-												BgL_l1250z00_1666 = BgL_l1250z00_1941;
-												goto BgL_zc3z04anonymousza31287ze3z87_1667;
+												BgL_l1249z00_1947 = CDR(BgL_l1249z00_1671);
+												BgL_l1249z00_1671 = BgL_l1249z00_1947;
+												goto BgL_zc3z04anonymousza31277ze3z87_1672;
 											}
 										}
 									else
@@ -459,72 +461,72 @@ extern "C"
 											((bool_t) 1);
 										}
 								}
-								BgL_libzd2initzd2_1656 = BgL_varsz00_1664;
+								BgL_libzd2initzd2_1661 = BgL_varsz00_1669;
 							}
 						else
 							{	/* Ast/init.scm 56 */
-								BgL_libzd2initzd2_1656 = BNIL;
+								BgL_libzd2initzd2_1661 = BNIL;
 							}
 					}
 					{	/* Ast/init.scm 56 */
-						obj_t BgL_modzd2initzd2_1657;
+						obj_t BgL_modzd2initzd2_1662;
 
-						BgL_modzd2initzd2_1657 =
+						BgL_modzd2initzd2_1662 =
 							BGl_getzd2modulezd2initz00zzbackend_initz00();
 						{	/* Ast/init.scm 65 */
 
 							{	/* Ast/init.scm 67 */
-								obj_t BgL_arg1282z00_1658;
+								obj_t BgL_arg1272z00_1663;
 
 								{	/* Ast/init.scm 67 */
-									bool_t BgL_test1584z00_1944;
+									bool_t BgL_test1411z00_1950;
 
 									{	/* Ast/init.scm 67 */
-										bool_t BgL_test1585z00_1945;
+										bool_t BgL_test1420z00_1951;
 
 										if (CBOOL(BGl_za2mainza2z00zzmodule_modulez00))
 											{	/* Ast/init.scm 67 */
-												BgL_test1585z00_1945 = ((bool_t) 1);
+												BgL_test1420z00_1951 = ((bool_t) 1);
 											}
 										else
 											{	/* Ast/init.scm 67 */
-												BgL_test1585z00_1945 =
+												BgL_test1420z00_1951 =
 													CBOOL(BGl_memqz00zz__r4_pairs_and_lists_6_3z00
 													(BGl_za2passza2z00zzengine_paramz00,
-														CNST_TABLE_REF(1L)));
+														((obj_t) CNST_TABLE_REF(1))));
 											}
-										if (BgL_test1585z00_1945)
+										if (BgL_test1420z00_1951)
 											{	/* Ast/init.scm 67 */
 												if (
 													(BGl_za2mainza2z00zzmodule_modulez00 ==
-														CNST_TABLE_REF(2L)))
+														((obj_t) CNST_TABLE_REF(2))))
 													{	/* Ast/init.scm 68 */
-														BgL_test1584z00_1944 = ((bool_t) 0);
+														BgL_test1411z00_1950 = ((bool_t) 0);
 													}
 												else
 													{	/* Ast/init.scm 68 */
-														BgL_test1584z00_1944 = ((bool_t) 1);
+														BgL_test1411z00_1950 = ((bool_t) 1);
 													}
 											}
 										else
 											{	/* Ast/init.scm 67 */
-												BgL_test1584z00_1944 = ((bool_t) 0);
+												BgL_test1411z00_1950 = ((bool_t) 0);
 											}
 									}
-									if (BgL_test1584z00_1944)
+									if (BgL_test1411z00_1950)
 										{	/* Ast/init.scm 67 */
-											BgL_arg1282z00_1658 =
+											BgL_arg1272z00_1663 =
 												MAKE_YOUNG_PAIR
 												(BGl_makezd2bigloozd2mainz00zzbackend_c_mainz00(),
-												BgL_libzd2initzd2_1656);
+												BgL_libzd2initzd2_1661);
 										}
 									else
 										{	/* Ast/init.scm 67 */
-											BgL_arg1282z00_1658 = BgL_libzd2initzd2_1656;
+											BgL_arg1272z00_1663 = BgL_libzd2initzd2_1661;
 										}
 								}
 								return
-									MAKE_YOUNG_PAIR(BgL_modzd2initzd2_1657, BgL_arg1282z00_1658);
+									MAKE_YOUNG_PAIR(BgL_modzd2initzd2_1662, BgL_arg1272z00_1663);
 							}
 						}
 					}
@@ -537,7 +539,7 @@ extern "C"
 
 
 /* &ast-initializers */
-	obj_t BGl_z62astzd2initializa7ersz17zzast_initz00(obj_t BgL_envz00_1873)
+	obj_t BGl_z62astzd2initializa7ersz17zzast_initz00(obj_t BgL_envz00_1878)
 	{
 		{	/* Ast/init.scm 54 */
 			return BGl_astzd2initializa7ersz75zzast_initz00();
@@ -585,56 +587,56 @@ extern "C"
 	{
 		{	/* Ast/init.scm 15 */
 			BGl_modulezd2initializa7ationz75zztools_speekz00(61247943L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 			BGl_modulezd2initializa7ationz75zztools_errorz00(300504031L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 			BGl_modulezd2initializa7ationz75zzengine_passz00(373082237L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 			BGl_modulezd2initializa7ationz75zztools_tracez00(54713316L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 			BGl_modulezd2initializa7ationz75zztools_shapez00(365925558L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
-			BGl_modulezd2initializa7ationz75zzengine_paramz00(517137079L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
+			BGl_modulezd2initializa7ationz75zzengine_paramz00(161876678L,
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 			BGl_modulezd2initializa7ationz75zzengine_configurez00(272817175L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 			BGl_modulezd2initializa7ationz75zzmodule_modulez00(158397907L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 			BGl_modulezd2initializa7ationz75zzmodule_libraryz00(292140514L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 			BGl_modulezd2initializa7ationz75zztype_typez00(515343395L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
-			BGl_modulezd2initializa7ationz75zztype_cachez00(346491734L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
+			BGl_modulezd2initializa7ationz75zztype_cachez00(489890788L,
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 			BGl_modulezd2initializa7ationz75zzobject_classz00(502007119L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 			BGl_modulezd2initializa7ationz75zzobject_slotsz00(151271251L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 			BGl_modulezd2initializa7ationz75zzast_varz00(90839984L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 			BGl_modulezd2initializa7ationz75zzast_nodez00(469732712L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 			BGl_modulezd2initializa7ationz75zzast_occurz00(282085879L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 			BGl_modulezd2initializa7ationz75zzast_buildz00(428035925L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 			BGl_modulezd2initializa7ationz75zzast_envz00(146730773L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 			BGl_modulezd2initializa7ationz75zzast_lvtypez00(189769752L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 			BGl_modulezd2initializa7ationz75zzbdb_emitz00(182920176L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 			BGl_modulezd2initializa7ationz75zzprof_emitz00(522750846L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 			BGl_modulezd2initializa7ationz75zzbackend_initz00(517592975L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
-			BGl_modulezd2initializa7ationz75zzbackend_c_emitz00(14466025L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
+			BGl_modulezd2initializa7ationz75zzbackend_c_emitz00(474089076L,
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 			BGl_modulezd2initializa7ationz75zzbackend_c_prototypez00(364917963L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 			return
 				BGl_modulezd2initializa7ationz75zzbackend_c_mainz00(65542503L,
-				BSTRING_TO_STRING(BGl_string1570z00zzast_initz00));
+				BSTRING_TO_STRING(BGl_string1393z00zzast_initz00));
 		}
 
 	}
