@@ -1,9 +1,9 @@
 /*===========================================================================*/
 /*   (Ast/local.scm)                                                         */
-/*   Bigloo (4.5b)                                                           */
-/*   Inria -- Sophia Antipolis (c)       Fri Dec 22 05:17:06 PM CET 2023     */
+/*   Bigloo (4.6a)                                                           */
+/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
 /*===========================================================================*/
-/* COMPILATION: (/home/serrano/prgm/project/bigloo/bigloo/bin/bigloo -ldopt -L/home/serrano/prgm/project/bigloo/bigloo/libbacktrace/home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b  -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Ast/local.scm) */
+/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Ast/local.scm) */
 /* GC selection */
 #define THE_GC BOEHM_GC
 
@@ -38,6 +38,7 @@ extern "C"
 		obj_t BgL_parentsz00;
 		bool_t BgL_initzf3zf3;
 		bool_t BgL_magiczf3zf3;
+		obj_t BgL_nullz00;
 		obj_t BgL_z42z42;
 		obj_t BgL_aliasz00;
 		obj_t BgL_pointedzd2tozd2byz00;
@@ -186,7 +187,7 @@ extern "C"
 		long);
 	static BgL_localz00_bglt
 		BGl_z62makezd2userzd2localzd2svarzb0zzast_localz00(obj_t, obj_t, obj_t);
-	static long BGl_za2localzd2keyza2zd2zzast_localz00;
+	static long BGl_za2localzd2keyza2zd2zzast_localz00 = 0L;
 	extern obj_t BGl_localz00zzast_varz00;
 	static BgL_localz00_bglt BGl_z62makezd2localzd2sexitz62zzast_localz00(obj_t,
 		obj_t, obj_t, obj_t);
@@ -206,36 +207,35 @@ extern "C"
 
 	   
 		 
-		DEFINE_STRING(BGl_string1158z00zzast_localz00,
-		BgL_bgl_string1158za700za7za7a1162za7, "_", 1);
-	      DEFINE_STRING(BGl_string1159z00zzast_localz00,
-		BgL_bgl_string1159za700za7za7a1163za7, "ast_local", 9);
-	      DEFINE_STRING(BGl_string1160z00zzast_localz00,
-		BgL_bgl_string1160za700za7za7a1164za7, "now read ", 9);
-	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_makezd2userzd2localzd2svarzd2envz00zzast_localz00,
-		BgL_bgl_za762makeza7d2userza7d1165za7,
+		BgL_bgl_za762makeza7d2userza7d1179za7,
 		BGl_z62makezd2userzd2localzd2svarzb0zzast_localz00, 0L, BUNSPEC, 2);
+	      DEFINE_STRING(BGl_string1175z00zzast_localz00,
+		BgL_bgl_string1175za700za7za7a1180za7, "_", 1);
+	      DEFINE_STRING(BGl_string1176z00zzast_localz00,
+		BgL_bgl_string1176za700za7za7a1181za7, "ast_local", 9);
+	      DEFINE_STRING(BGl_string1177z00zzast_localz00,
+		BgL_bgl_string1177za700za7za7a1182za7, "now read ", 9);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE(BGl_makezd2localzd2sfunzd2envzd2zzast_localz00,
-		BgL_bgl_za762makeza7d2localza71166za7,
+		BgL_bgl_za762makeza7d2localza71183za7,
 		BGl_z62makezd2localzd2sfunz62zzast_localz00, 0L, BUNSPEC, 3);
 	      DEFINE_EXPORT_BGL_PROCEDURE(BGl_clonezd2localzd2envz00zzast_localz00,
-		BgL_bgl_za762cloneza7d2local1167z00, BGl_z62clonezd2localzb0zzast_localz00,
+		BgL_bgl_za762cloneza7d2local1184z00, BGl_z62clonezd2localzb0zzast_localz00,
 		0L, BUNSPEC, 2);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE(BGl_makezd2localzd2sexitzd2envzd2zzast_localz00,
-		BgL_bgl_za762makeza7d2localza71168za7,
+		BgL_bgl_za762makeza7d2localza71185za7,
 		BGl_z62makezd2localzd2sexitz62zzast_localz00, 0L, BUNSPEC, 3);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE(BGl_makezd2localzd2svarzd2envzd2zzast_localz00,
-		BgL_bgl_za762makeza7d2localza71169za7,
+		BgL_bgl_za762makeza7d2localza71186za7,
 		BGl_z62makezd2localzd2svarz62zzast_localz00, 0L, BUNSPEC, 2);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_makezd2userzd2localzd2sfunzd2envz00zzast_localz00,
-		BgL_bgl_za762makeza7d2userza7d1170za7,
+		BgL_bgl_za762makeza7d2userza7d1187za7,
 		BGl_z62makezd2userzd2localzd2sfunzb0zzast_localz00, 0L, BUNSPEC, 3);
 
 /* GC roots registration */
@@ -256,7 +256,7 @@ extern "C"
 
 /* module-initialization */
 	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zzast_localz00(long
-		BgL_checksumz00_578, char *BgL_fromz00_579)
+		BgL_checksumz00_583, char *BgL_fromz00_584)
 	{
 		{
 			if (CBOOL(BGl_requirezd2initializa7ationz75zzast_localz00))
@@ -300,70 +300,70 @@ extern "C"
 	{
 		{	/* Ast/local.scm 14 */
 			{	/* Ast/local.scm 14 */
-				obj_t BgL_cportz00_567;
+				obj_t BgL_cportz00_572;
 
 				{	/* Ast/local.scm 14 */
-					obj_t BgL_stringz00_574;
+					obj_t BgL_stringz00_579;
 
-					BgL_stringz00_574 = BGl_string1160z00zzast_localz00;
+					BgL_stringz00_579 = BGl_string1177z00zzast_localz00;
 					{	/* Ast/local.scm 14 */
-						obj_t BgL_startz00_575;
+						obj_t BgL_startz00_580;
 
-						BgL_startz00_575 = BINT(0L);
+						BgL_startz00_580 = BINT(0L);
 						{	/* Ast/local.scm 14 */
-							obj_t BgL_endz00_576;
+							obj_t BgL_endz00_581;
 
-							BgL_endz00_576 = BINT(STRING_LENGTH(((obj_t) BgL_stringz00_574)));
+							BgL_endz00_581 = BINT(STRING_LENGTH(((obj_t) BgL_stringz00_579)));
 							{	/* Ast/local.scm 14 */
 
-								BgL_cportz00_567 =
+								BgL_cportz00_572 =
 									BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00
-									(BgL_stringz00_574, BgL_startz00_575, BgL_endz00_576);
+									(BgL_stringz00_579, BgL_startz00_580, BgL_endz00_581);
 				}}}}
 				{
-					long BgL_iz00_568;
+					long BgL_iz00_573;
 
-					BgL_iz00_568 = 1L;
-				BgL_loopz00_569:
-					if ((BgL_iz00_568 == -1L))
+					BgL_iz00_573 = 1L;
+				BgL_loopz00_574:
+					if ((BgL_iz00_573 == (-1L)))
 						{	/* Ast/local.scm 14 */
 							return BUNSPEC;
 						}
 					else
 						{	/* Ast/local.scm 14 */
 							{	/* Ast/local.scm 14 */
-								obj_t BgL_arg1161z00_570;
+								obj_t BgL_arg1178z00_575;
 
 								{	/* Ast/local.scm 14 */
 
 									{	/* Ast/local.scm 14 */
-										obj_t BgL_locationz00_572;
+										obj_t BgL_locationz00_577;
 
-										BgL_locationz00_572 = BBOOL(((bool_t) 0));
+										BgL_locationz00_577 = BBOOL(((bool_t) 0));
 										{	/* Ast/local.scm 14 */
 
-											BgL_arg1161z00_570 =
-												BGl_readz00zz__readerz00(BgL_cportz00_567,
-												BgL_locationz00_572);
+											BgL_arg1178z00_575 =
+												BGl_readz00zz__readerz00(BgL_cportz00_572,
+												BgL_locationz00_577);
 										}
 									}
 								}
 								{	/* Ast/local.scm 14 */
-									int BgL_tmpz00_602;
+									int BgL_tmpz00_607;
 
-									BgL_tmpz00_602 = (int) (BgL_iz00_568);
-									CNST_TABLE_SET(BgL_tmpz00_602, BgL_arg1161z00_570);
+									BgL_tmpz00_607 = (int) (BgL_iz00_573);
+									CNST_TABLE_SET(BgL_tmpz00_607, BgL_arg1178z00_575);
 							}}
 							{	/* Ast/local.scm 14 */
-								int BgL_auxz00_573;
+								int BgL_auxz00_578;
 
-								BgL_auxz00_573 = (int) ((BgL_iz00_568 - 1L));
+								BgL_auxz00_578 = (int) ((BgL_iz00_573 - 1L));
 								{
-									long BgL_iz00_607;
+									long BgL_iz00_612;
 
-									BgL_iz00_607 = (long) (BgL_auxz00_573);
-									BgL_iz00_568 = BgL_iz00_607;
-									goto BgL_loopz00_569;
+									BgL_iz00_612 = (long) (BgL_auxz00_578);
+									BgL_iz00_573 = BgL_iz00_612;
+									goto BgL_loopz00_574;
 								}
 							}
 						}
@@ -417,91 +417,91 @@ extern "C"
 	{
 		{	/* Ast/local.scm 44 */
 			{	/* Ast/local.scm 45 */
-				long BgL_keyz00_461;
+				long BgL_keyz00_466;
 
-				BgL_keyz00_461 = BGl_getzd2newzd2keyz00zzast_localz00();
+				BgL_keyz00_466 = BGl_getzd2newzd2keyz00zzast_localz00();
 				{	/* Ast/local.scm 46 */
-					BgL_localz00_bglt BgL_new1062z00_462;
+					BgL_localz00_bglt BgL_new1062z00_467;
 
 					{	/* Ast/local.scm 48 */
-						BgL_localz00_bglt BgL_new1060z00_467;
+						BgL_localz00_bglt BgL_new1060z00_472;
 
-						BgL_new1060z00_467 =
+						BgL_new1060z00_472 =
 							((BgL_localz00_bglt) BOBJECT(GC_MALLOC(sizeof(struct
 										BgL_localz00_bgl))));
 						{	/* Ast/local.scm 48 */
-							long BgL_arg1124z00_468;
+							long BgL_arg1111z00_473;
 
-							BgL_arg1124z00_468 = BGL_CLASS_NUM(BGl_localz00zzast_varz00);
+							BgL_arg1111z00_473 = BGL_CLASS_NUM(BGl_localz00zzast_varz00);
 							BGL_OBJECT_CLASS_NUM_SET(
-								((BgL_objectz00_bglt) BgL_new1060z00_467), BgL_arg1124z00_468);
+								((BgL_objectz00_bglt) BgL_new1060z00_472), BgL_arg1111z00_473);
 						}
 						{	/* Ast/local.scm 48 */
-							BgL_objectz00_bglt BgL_tmpz00_616;
+							BgL_objectz00_bglt BgL_tmpz00_621;
 
-							BgL_tmpz00_616 = ((BgL_objectz00_bglt) BgL_new1060z00_467);
-							BGL_OBJECT_WIDENING_SET(BgL_tmpz00_616, BFALSE);
+							BgL_tmpz00_621 = ((BgL_objectz00_bglt) BgL_new1060z00_472);
+							BGL_OBJECT_WIDENING_SET(BgL_tmpz00_621, BFALSE);
 						}
-						((BgL_objectz00_bglt) BgL_new1060z00_467);
-						BgL_new1062z00_462 = BgL_new1060z00_467;
+						((BgL_objectz00_bglt) BgL_new1060z00_472);
+						BgL_new1062z00_467 = BgL_new1060z00_472;
 					}
 					((((BgL_variablez00_bglt) COBJECT(
-									((BgL_variablez00_bglt) BgL_new1062z00_462)))->BgL_idz00) =
+									((BgL_variablez00_bglt) BgL_new1062z00_467)))->BgL_idz00) =
 						((obj_t) BgL_idz00_3), BUNSPEC);
 					{
-						obj_t BgL_auxz00_622;
+						obj_t BgL_auxz00_627;
 
 						{	/* Ast/local.scm 49 */
-							obj_t BgL_arg1122z00_463;
-							obj_t BgL_arg1123z00_464;
+							obj_t BgL_arg1105z00_468;
+							obj_t BgL_arg1110z00_469;
 
-							BgL_arg1122z00_463 =
+							BgL_arg1105z00_468 =
 								BGl_localzd2idzd2ze3nameze3zzast_identz00(BgL_idz00_3);
 							{	/* Ast/local.scm 49 */
 
-								BgL_arg1123z00_464 =
+								BgL_arg1110z00_469 =
 									BGl_integerzd2ze3stringz31zz__r4_numbers_6_5_fixnumz00
-									(BgL_keyz00_461, 10L);
+									(BgL_keyz00_466, 10L);
 							}
-							BgL_auxz00_622 =
-								string_append_3(BgL_arg1122z00_463,
-								BGl_string1158z00zzast_localz00, BgL_arg1123z00_464);
+							BgL_auxz00_627 =
+								string_append_3(BgL_arg1105z00_468,
+								BGl_string1175z00zzast_localz00, BgL_arg1110z00_469);
 						}
 						((((BgL_variablez00_bglt) COBJECT(
-										((BgL_variablez00_bglt) BgL_new1062z00_462)))->
-								BgL_namez00) = ((obj_t) BgL_auxz00_622), BUNSPEC);
+										((BgL_variablez00_bglt) BgL_new1062z00_467)))->
+								BgL_namez00) = ((obj_t) BgL_auxz00_627), BUNSPEC);
 					}
 					((((BgL_variablez00_bglt) COBJECT(
-									((BgL_variablez00_bglt) BgL_new1062z00_462)))->BgL_typez00) =
+									((BgL_variablez00_bglt) BgL_new1062z00_467)))->BgL_typez00) =
 						((BgL_typez00_bglt) BgL_typez00_4), BUNSPEC);
 					((((BgL_variablez00_bglt) COBJECT(((BgL_variablez00_bglt)
-										BgL_new1062z00_462)))->BgL_valuez00) =
+										BgL_new1062z00_467)))->BgL_valuez00) =
 						((BgL_valuez00_bglt) BgL_valuez00_5), BUNSPEC);
 					((((BgL_variablez00_bglt) COBJECT(((BgL_variablez00_bglt)
-										BgL_new1062z00_462)))->BgL_accessz00) =
-						((obj_t) CNST_TABLE_REF(0L)), BUNSPEC);
+										BgL_new1062z00_467)))->BgL_accessz00) =
+						((obj_t) ((obj_t) CNST_TABLE_REF(0))), BUNSPEC);
 					((((BgL_variablez00_bglt) COBJECT(((BgL_variablez00_bglt)
-										BgL_new1062z00_462)))->BgL_fastzd2alphazd2) =
+										BgL_new1062z00_467)))->BgL_fastzd2alphazd2) =
 						((obj_t) BUNSPEC), BUNSPEC);
 					((((BgL_variablez00_bglt) COBJECT(((BgL_variablez00_bglt)
-										BgL_new1062z00_462)))->BgL_removablez00) =
-						((obj_t) CNST_TABLE_REF(1L)), BUNSPEC);
+										BgL_new1062z00_467)))->BgL_removablez00) =
+						((obj_t) ((obj_t) CNST_TABLE_REF(1))), BUNSPEC);
 					((((BgL_variablez00_bglt) COBJECT(((BgL_variablez00_bglt)
-										BgL_new1062z00_462)))->BgL_occurrencez00) =
+										BgL_new1062z00_467)))->BgL_occurrencez00) =
 						((long) 0L), BUNSPEC);
 					((((BgL_variablez00_bglt) COBJECT(((BgL_variablez00_bglt)
-										BgL_new1062z00_462)))->BgL_occurrencewz00) =
+										BgL_new1062z00_467)))->BgL_occurrencewz00) =
 						((long) 0L), BUNSPEC);
 					((((BgL_variablez00_bglt) COBJECT(((BgL_variablez00_bglt)
-										BgL_new1062z00_462)))->BgL_userzf3zf3) =
+										BgL_new1062z00_467)))->BgL_userzf3zf3) =
 						((bool_t) BgL_userzf3zf3_6), BUNSPEC);
-					((((BgL_localz00_bglt) COBJECT(BgL_new1062z00_462))->BgL_keyz00) =
-						((long) BgL_keyz00_461), BUNSPEC);
-					((((BgL_localz00_bglt) COBJECT(BgL_new1062z00_462))->
+					((((BgL_localz00_bglt) COBJECT(BgL_new1062z00_467))->BgL_keyz00) =
+						((long) BgL_keyz00_466), BUNSPEC);
+					((((BgL_localz00_bglt) COBJECT(BgL_new1062z00_467))->
 							BgL_valzd2noescapezd2) = ((obj_t) BTRUE), BUNSPEC);
-					((((BgL_localz00_bglt) COBJECT(BgL_new1062z00_462))->
+					((((BgL_localz00_bglt) COBJECT(BgL_new1062z00_467))->
 							BgL_volatilez00) = ((bool_t) ((bool_t) 0)), BUNSPEC);
-					return BgL_new1062z00_462;
+					return BgL_new1062z00_467;
 				}
 			}
 		}
@@ -517,113 +517,113 @@ extern "C"
 	{
 		{	/* Ast/local.scm 57 */
 			{	/* Ast/local.scm 58 */
-				long BgL_keyz00_469;
+				long BgL_keyz00_474;
 
-				BgL_keyz00_469 = BGl_getzd2newzd2keyz00zzast_localz00();
+				BgL_keyz00_474 = BGl_getzd2newzd2keyz00zzast_localz00();
 				{	/* Ast/local.scm 60 */
-					BgL_localz00_bglt BgL_new1064z00_472;
+					BgL_localz00_bglt BgL_new1064z00_477;
 
 					{	/* Ast/local.scm 60 */
-						BgL_localz00_bglt BgL_new1069z00_480;
+						BgL_localz00_bglt BgL_new1069z00_485;
 
-						BgL_new1069z00_480 =
+						BgL_new1069z00_485 =
 							((BgL_localz00_bglt) BOBJECT(GC_MALLOC(sizeof(struct
 										BgL_localz00_bgl))));
 						{	/* Ast/local.scm 60 */
-							long BgL_arg1128z00_481;
+							long BgL_arg1127z00_486;
 
-							BgL_arg1128z00_481 = BGL_CLASS_NUM(BGl_localz00zzast_varz00);
+							BgL_arg1127z00_486 = BGL_CLASS_NUM(BGl_localz00zzast_varz00);
 							BGL_OBJECT_CLASS_NUM_SET(
-								((BgL_objectz00_bglt) BgL_new1069z00_480), BgL_arg1128z00_481);
+								((BgL_objectz00_bglt) BgL_new1069z00_485), BgL_arg1127z00_486);
 						}
 						{	/* Ast/local.scm 60 */
-							BgL_objectz00_bglt BgL_tmpz00_654;
+							BgL_objectz00_bglt BgL_tmpz00_661;
 
-							BgL_tmpz00_654 = ((BgL_objectz00_bglt) BgL_new1069z00_480);
-							BGL_OBJECT_WIDENING_SET(BgL_tmpz00_654, BFALSE);
+							BgL_tmpz00_661 = ((BgL_objectz00_bglt) BgL_new1069z00_485);
+							BGL_OBJECT_WIDENING_SET(BgL_tmpz00_661, BFALSE);
 						}
-						((BgL_objectz00_bglt) BgL_new1069z00_480);
-						BgL_new1064z00_472 = BgL_new1069z00_480;
+						((BgL_objectz00_bglt) BgL_new1069z00_485);
+						BgL_new1064z00_477 = BgL_new1069z00_485;
 					}
 					((((BgL_variablez00_bglt) COBJECT(
-									((BgL_variablez00_bglt) BgL_new1064z00_472)))->BgL_idz00) =
+									((BgL_variablez00_bglt) BgL_new1064z00_477)))->BgL_idz00) =
 						((obj_t) (((BgL_variablez00_bglt) COBJECT(((BgL_variablez00_bglt)
 											BgL_localz00_7)))->BgL_idz00)), BUNSPEC);
 					{
-						obj_t BgL_auxz00_662;
+						obj_t BgL_auxz00_669;
 
 						{	/* Ast/local.scm 62 */
-							obj_t BgL_arg1125z00_473;
-							obj_t BgL_arg1126z00_474;
+							obj_t BgL_arg1113z00_478;
+							obj_t BgL_arg1114z00_479;
 
 							{	/* Ast/local.scm 62 */
-								obj_t BgL_arg1127z00_475;
+								obj_t BgL_arg1115z00_480;
 
-								BgL_arg1127z00_475 =
+								BgL_arg1115z00_480 =
 									(((BgL_variablez00_bglt) COBJECT(
 											((BgL_variablez00_bglt) BgL_localz00_7)))->BgL_idz00);
-								BgL_arg1125z00_473 =
-									BGl_idzd2ze3namez31zzast_identz00(BgL_arg1127z00_475);
+								BgL_arg1113z00_478 =
+									BGl_idzd2ze3namez31zzast_identz00(BgL_arg1115z00_480);
 							}
 							{	/* Ast/local.scm 62 */
 
-								BgL_arg1126z00_474 =
+								BgL_arg1114z00_479 =
 									BGl_integerzd2ze3stringz31zz__r4_numbers_6_5_fixnumz00
-									(BgL_keyz00_469, 10L);
+									(BgL_keyz00_474, 10L);
 							}
-							BgL_auxz00_662 =
-								string_append_3(BgL_arg1125z00_473,
-								BGl_string1158z00zzast_localz00, BgL_arg1126z00_474);
+							BgL_auxz00_669 =
+								string_append_3(BgL_arg1113z00_478,
+								BGl_string1175z00zzast_localz00, BgL_arg1114z00_479);
 						}
 						((((BgL_variablez00_bglt) COBJECT(
-										((BgL_variablez00_bglt) BgL_new1064z00_472)))->
-								BgL_namez00) = ((obj_t) BgL_auxz00_662), BUNSPEC);
+										((BgL_variablez00_bglt) BgL_new1064z00_477)))->
+								BgL_namez00) = ((obj_t) BgL_auxz00_669), BUNSPEC);
 					}
 					((((BgL_variablez00_bglt) COBJECT(
-									((BgL_variablez00_bglt) BgL_new1064z00_472)))->BgL_typez00) =
+									((BgL_variablez00_bglt) BgL_new1064z00_477)))->BgL_typez00) =
 						((BgL_typez00_bglt) (((BgL_variablez00_bglt)
 									COBJECT(((BgL_variablez00_bglt) BgL_localz00_7)))->
 								BgL_typez00)), BUNSPEC);
 					((((BgL_variablez00_bglt) COBJECT(((BgL_variablez00_bglt)
-										BgL_new1064z00_472)))->BgL_valuez00) =
+										BgL_new1064z00_477)))->BgL_valuez00) =
 						((BgL_valuez00_bglt) BgL_valuez00_8), BUNSPEC);
 					((((BgL_variablez00_bglt) COBJECT(((BgL_variablez00_bglt)
-										BgL_new1064z00_472)))->BgL_accessz00) =
+										BgL_new1064z00_477)))->BgL_accessz00) =
 						((obj_t) (((BgL_variablez00_bglt) COBJECT(((BgL_variablez00_bglt)
 											BgL_localz00_7)))->BgL_accessz00)), BUNSPEC);
 					((((BgL_variablez00_bglt) COBJECT(((BgL_variablez00_bglt)
-										BgL_new1064z00_472)))->BgL_fastzd2alphazd2) =
+										BgL_new1064z00_477)))->BgL_fastzd2alphazd2) =
 						((obj_t) (((BgL_variablez00_bglt) COBJECT(((BgL_variablez00_bglt)
 											BgL_localz00_7)))->BgL_fastzd2alphazd2)), BUNSPEC);
 					((((BgL_variablez00_bglt) COBJECT(((BgL_variablez00_bglt)
-										BgL_new1064z00_472)))->BgL_removablez00) =
+										BgL_new1064z00_477)))->BgL_removablez00) =
 						((obj_t) (((BgL_variablez00_bglt) COBJECT(((BgL_variablez00_bglt)
 											BgL_localz00_7)))->BgL_removablez00)), BUNSPEC);
 					((((BgL_variablez00_bglt) COBJECT(((BgL_variablez00_bglt)
-										BgL_new1064z00_472)))->BgL_occurrencez00) =
+										BgL_new1064z00_477)))->BgL_occurrencez00) =
 						((long) (((BgL_variablez00_bglt) COBJECT(((BgL_variablez00_bglt)
 											BgL_localz00_7)))->BgL_occurrencez00)), BUNSPEC);
 					((((BgL_variablez00_bglt) COBJECT(((BgL_variablez00_bglt)
-										BgL_new1064z00_472)))->BgL_occurrencewz00) =
+										BgL_new1064z00_477)))->BgL_occurrencewz00) =
 						((long) (((BgL_variablez00_bglt) COBJECT(((BgL_variablez00_bglt)
 											BgL_localz00_7)))->BgL_occurrencewz00)), BUNSPEC);
 					((((BgL_variablez00_bglt) COBJECT(((BgL_variablez00_bglt)
-										BgL_new1064z00_472)))->BgL_userzf3zf3) =
+										BgL_new1064z00_477)))->BgL_userzf3zf3) =
 						((bool_t) (((BgL_variablez00_bglt) COBJECT(((BgL_variablez00_bglt)
 											BgL_localz00_7)))->BgL_userzf3zf3)), BUNSPEC);
-					((((BgL_localz00_bglt) COBJECT(BgL_new1064z00_472))->BgL_keyz00) =
-						((long) BgL_keyz00_469), BUNSPEC);
-					((((BgL_localz00_bglt) COBJECT(BgL_new1064z00_472))->
+					((((BgL_localz00_bglt) COBJECT(BgL_new1064z00_477))->BgL_keyz00) =
+						((long) BgL_keyz00_474), BUNSPEC);
+					((((BgL_localz00_bglt) COBJECT(BgL_new1064z00_477))->
 							BgL_valzd2noescapezd2) =
 						((obj_t) (((BgL_localz00_bglt)
 									COBJECT(((BgL_localz00_bglt) ((BgL_variablez00_bglt)
 												BgL_localz00_7))))->BgL_valzd2noescapezd2)), BUNSPEC);
-					((((BgL_localz00_bglt) COBJECT(BgL_new1064z00_472))->
+					((((BgL_localz00_bglt) COBJECT(BgL_new1064z00_477))->
 							BgL_volatilez00) =
 						((bool_t) (((BgL_localz00_bglt)
 									COBJECT(((BgL_localz00_bglt) ((BgL_variablez00_bglt)
 												BgL_localz00_7))))->BgL_volatilez00)), BUNSPEC);
-					return BgL_new1064z00_472;
+					return BgL_new1064z00_477;
 				}
 			}
 		}
@@ -633,14 +633,14 @@ extern "C"
 
 
 /* &clone-local */
-	BgL_localz00_bglt BGl_z62clonezd2localzb0zzast_localz00(obj_t BgL_envz00_546,
-		obj_t BgL_localz00_547, obj_t BgL_valuez00_548)
+	BgL_localz00_bglt BGl_z62clonezd2localzb0zzast_localz00(obj_t BgL_envz00_551,
+		obj_t BgL_localz00_552, obj_t BgL_valuez00_553)
 	{
 		{	/* Ast/local.scm 57 */
 			return
 				BGl_clonezd2localzd2zzast_localz00(
-				((BgL_localz00_bglt) BgL_localz00_547),
-				((BgL_valuez00_bglt) BgL_valuez00_548));
+				((BgL_localz00_bglt) BgL_localz00_552),
+				((BgL_valuez00_bglt) BgL_valuez00_553));
 		}
 
 	}
@@ -654,40 +654,40 @@ extern "C"
 	{
 		{	/* Ast/local.scm 68 */
 			{	/* Ast/local.scm 69 */
-				BgL_svarz00_bglt BgL_arg1134z00_482;
+				BgL_svarz00_bglt BgL_arg1128z00_487;
 
 				{	/* Ast/local.scm 69 */
-					BgL_svarz00_bglt BgL_new1071z00_483;
+					BgL_svarz00_bglt BgL_new1071z00_488;
 
 					{	/* Ast/local.scm 69 */
-						BgL_svarz00_bglt BgL_new1070z00_484;
+						BgL_svarz00_bglt BgL_new1070z00_489;
 
-						BgL_new1070z00_484 =
+						BgL_new1070z00_489 =
 							((BgL_svarz00_bglt) BOBJECT(GC_MALLOC(sizeof(struct
 										BgL_svarz00_bgl))));
 						{	/* Ast/local.scm 69 */
-							long BgL_arg1135z00_485;
+							long BgL_arg1129z00_490;
 
-							BgL_arg1135z00_485 = BGL_CLASS_NUM(BGl_svarz00zzast_varz00);
+							BgL_arg1129z00_490 = BGL_CLASS_NUM(BGl_svarz00zzast_varz00);
 							BGL_OBJECT_CLASS_NUM_SET(
-								((BgL_objectz00_bglt) BgL_new1070z00_484), BgL_arg1135z00_485);
+								((BgL_objectz00_bglt) BgL_new1070z00_489), BgL_arg1129z00_490);
 						}
 						{	/* Ast/local.scm 69 */
-							BgL_objectz00_bglt BgL_tmpz00_716;
+							BgL_objectz00_bglt BgL_tmpz00_723;
 
-							BgL_tmpz00_716 = ((BgL_objectz00_bglt) BgL_new1070z00_484);
-							BGL_OBJECT_WIDENING_SET(BgL_tmpz00_716, BFALSE);
+							BgL_tmpz00_723 = ((BgL_objectz00_bglt) BgL_new1070z00_489);
+							BGL_OBJECT_WIDENING_SET(BgL_tmpz00_723, BFALSE);
 						}
-						((BgL_objectz00_bglt) BgL_new1070z00_484);
-						BgL_new1071z00_483 = BgL_new1070z00_484;
+						((BgL_objectz00_bglt) BgL_new1070z00_489);
+						BgL_new1071z00_488 = BgL_new1070z00_489;
 					}
-					((((BgL_svarz00_bglt) COBJECT(BgL_new1071z00_483))->BgL_locz00) =
+					((((BgL_svarz00_bglt) COBJECT(BgL_new1071z00_488))->BgL_locz00) =
 						((obj_t) BUNSPEC), BUNSPEC);
-					BgL_arg1134z00_482 = BgL_new1071z00_483;
+					BgL_arg1128z00_487 = BgL_new1071z00_488;
 				}
 				return
 					BGl_makezd2newzd2localz00zzast_localz00(BgL_idz00_9, BgL_typez00_10,
-					((BgL_valuez00_bglt) BgL_arg1134z00_482), ((bool_t) 0));
+					((BgL_valuez00_bglt) BgL_arg1128z00_487), ((bool_t) 0));
 			}
 		}
 
@@ -697,12 +697,12 @@ extern "C"
 
 /* &make-local-svar */
 	BgL_localz00_bglt BGl_z62makezd2localzd2svarz62zzast_localz00(obj_t
-		BgL_envz00_549, obj_t BgL_idz00_550, obj_t BgL_typez00_551)
+		BgL_envz00_554, obj_t BgL_idz00_555, obj_t BgL_typez00_556)
 	{
 		{	/* Ast/local.scm 68 */
 			return
-				BGl_makezd2localzd2svarz00zzast_localz00(BgL_idz00_550,
-				((BgL_typez00_bglt) BgL_typez00_551));
+				BGl_makezd2localzd2svarz00zzast_localz00(BgL_idz00_555,
+				((BgL_typez00_bglt) BgL_typez00_556));
 		}
 
 	}
@@ -716,40 +716,40 @@ extern "C"
 	{
 		{	/* Ast/local.scm 74 */
 			{	/* Ast/local.scm 75 */
-				BgL_svarz00_bglt BgL_arg1137z00_486;
+				BgL_svarz00_bglt BgL_arg1131z00_491;
 
 				{	/* Ast/local.scm 75 */
-					BgL_svarz00_bglt BgL_new1073z00_487;
+					BgL_svarz00_bglt BgL_new1073z00_492;
 
 					{	/* Ast/local.scm 75 */
-						BgL_svarz00_bglt BgL_new1072z00_488;
+						BgL_svarz00_bglt BgL_new1072z00_493;
 
-						BgL_new1072z00_488 =
+						BgL_new1072z00_493 =
 							((BgL_svarz00_bglt) BOBJECT(GC_MALLOC(sizeof(struct
 										BgL_svarz00_bgl))));
 						{	/* Ast/local.scm 75 */
-							long BgL_arg1140z00_489;
+							long BgL_arg1134z00_494;
 
-							BgL_arg1140z00_489 = BGL_CLASS_NUM(BGl_svarz00zzast_varz00);
+							BgL_arg1134z00_494 = BGL_CLASS_NUM(BGl_svarz00zzast_varz00);
 							BGL_OBJECT_CLASS_NUM_SET(
-								((BgL_objectz00_bglt) BgL_new1072z00_488), BgL_arg1140z00_489);
+								((BgL_objectz00_bglt) BgL_new1072z00_493), BgL_arg1134z00_494);
 						}
 						{	/* Ast/local.scm 75 */
-							BgL_objectz00_bglt BgL_tmpz00_729;
+							BgL_objectz00_bglt BgL_tmpz00_736;
 
-							BgL_tmpz00_729 = ((BgL_objectz00_bglt) BgL_new1072z00_488);
-							BGL_OBJECT_WIDENING_SET(BgL_tmpz00_729, BFALSE);
+							BgL_tmpz00_736 = ((BgL_objectz00_bglt) BgL_new1072z00_493);
+							BGL_OBJECT_WIDENING_SET(BgL_tmpz00_736, BFALSE);
 						}
-						((BgL_objectz00_bglt) BgL_new1072z00_488);
-						BgL_new1073z00_487 = BgL_new1072z00_488;
+						((BgL_objectz00_bglt) BgL_new1072z00_493);
+						BgL_new1073z00_492 = BgL_new1072z00_493;
 					}
-					((((BgL_svarz00_bglt) COBJECT(BgL_new1073z00_487))->BgL_locz00) =
+					((((BgL_svarz00_bglt) COBJECT(BgL_new1073z00_492))->BgL_locz00) =
 						((obj_t) BUNSPEC), BUNSPEC);
-					BgL_arg1137z00_486 = BgL_new1073z00_487;
+					BgL_arg1131z00_491 = BgL_new1073z00_492;
 				}
 				return
 					BGl_makezd2newzd2localz00zzast_localz00(BgL_idz00_11, BgL_typez00_12,
-					((BgL_valuez00_bglt) BgL_arg1137z00_486), ((bool_t) 1));
+					((BgL_valuez00_bglt) BgL_arg1131z00_491), ((bool_t) 1));
 			}
 		}
 
@@ -759,12 +759,12 @@ extern "C"
 
 /* &make-user-local-svar */
 	BgL_localz00_bglt BGl_z62makezd2userzd2localzd2svarzb0zzast_localz00(obj_t
-		BgL_envz00_552, obj_t BgL_idz00_553, obj_t BgL_typez00_554)
+		BgL_envz00_557, obj_t BgL_idz00_558, obj_t BgL_typez00_559)
 	{
 		{	/* Ast/local.scm 74 */
 			return
-				BGl_makezd2userzd2localzd2svarzd2zzast_localz00(BgL_idz00_553,
-				((BgL_typez00_bglt) BgL_typez00_554));
+				BGl_makezd2userzd2localzd2svarzd2zzast_localz00(BgL_idz00_558,
+				((BgL_typez00_bglt) BgL_typez00_559));
 		}
 
 	}
@@ -788,14 +788,14 @@ extern "C"
 
 /* &make-local-sexit */
 	BgL_localz00_bglt BGl_z62makezd2localzd2sexitz62zzast_localz00(obj_t
-		BgL_envz00_555, obj_t BgL_idz00_556, obj_t BgL_typez00_557,
-		obj_t BgL_sexitz00_558)
+		BgL_envz00_560, obj_t BgL_idz00_561, obj_t BgL_typez00_562,
+		obj_t BgL_sexitz00_563)
 	{
 		{	/* Ast/local.scm 80 */
 			return
-				BGl_makezd2localzd2sexitz00zzast_localz00(BgL_idz00_556,
-				((BgL_typez00_bglt) BgL_typez00_557),
-				((BgL_sexitz00_bglt) BgL_sexitz00_558));
+				BGl_makezd2localzd2sexitz00zzast_localz00(BgL_idz00_561,
+				((BgL_typez00_bglt) BgL_typez00_562),
+				((BgL_sexitz00_bglt) BgL_sexitz00_563));
 		}
 
 	}
@@ -819,14 +819,14 @@ extern "C"
 
 /* &make-local-sfun */
 	BgL_localz00_bglt BGl_z62makezd2localzd2sfunz62zzast_localz00(obj_t
-		BgL_envz00_559, obj_t BgL_idz00_560, obj_t BgL_typez00_561,
-		obj_t BgL_sfunz00_562)
+		BgL_envz00_564, obj_t BgL_idz00_565, obj_t BgL_typez00_566,
+		obj_t BgL_sfunz00_567)
 	{
 		{	/* Ast/local.scm 88 */
 			return
-				BGl_makezd2localzd2sfunz00zzast_localz00(BgL_idz00_560,
-				((BgL_typez00_bglt) BgL_typez00_561),
-				((BgL_sfunz00_bglt) BgL_sfunz00_562));
+				BGl_makezd2localzd2sfunz00zzast_localz00(BgL_idz00_565,
+				((BgL_typez00_bglt) BgL_typez00_566),
+				((BgL_sfunz00_bglt) BgL_sfunz00_567));
 		}
 
 	}
@@ -850,14 +850,14 @@ extern "C"
 
 /* &make-user-local-sfun */
 	BgL_localz00_bglt BGl_z62makezd2userzd2localzd2sfunzb0zzast_localz00(obj_t
-		BgL_envz00_563, obj_t BgL_idz00_564, obj_t BgL_typez00_565,
-		obj_t BgL_sfunz00_566)
+		BgL_envz00_568, obj_t BgL_idz00_569, obj_t BgL_typez00_570,
+		obj_t BgL_sfunz00_571)
 	{
 		{	/* Ast/local.scm 96 */
 			return
-				BGl_makezd2userzd2localzd2sfunzd2zzast_localz00(BgL_idz00_564,
-				((BgL_typez00_bglt) BgL_typez00_565),
-				((BgL_sfunz00_bglt) BgL_sfunz00_566));
+				BGl_makezd2userzd2localzd2sfunzd2zzast_localz00(BgL_idz00_569,
+				((BgL_typez00_bglt) BgL_typez00_570),
+				((BgL_sfunz00_bglt) BgL_sfunz00_571));
 		}
 
 	}
@@ -902,16 +902,16 @@ extern "C"
 	{
 		{	/* Ast/local.scm 14 */
 			BGl_modulezd2initializa7ationz75zztype_typez00(515343395L,
-				BSTRING_TO_STRING(BGl_string1159z00zzast_localz00));
-			BGl_modulezd2initializa7ationz75zztype_cachez00(346491734L,
-				BSTRING_TO_STRING(BGl_string1159z00zzast_localz00));
-			BGl_modulezd2initializa7ationz75zzengine_paramz00(517137079L,
-				BSTRING_TO_STRING(BGl_string1159z00zzast_localz00));
+				BSTRING_TO_STRING(BGl_string1176z00zzast_localz00));
+			BGl_modulezd2initializa7ationz75zztype_cachez00(489890788L,
+				BSTRING_TO_STRING(BGl_string1176z00zzast_localz00));
+			BGl_modulezd2initializa7ationz75zzengine_paramz00(161876678L,
+				BSTRING_TO_STRING(BGl_string1176z00zzast_localz00));
 			BGl_modulezd2initializa7ationz75zzast_varz00(90839984L,
-				BSTRING_TO_STRING(BGl_string1159z00zzast_localz00));
+				BSTRING_TO_STRING(BGl_string1176z00zzast_localz00));
 			return
 				BGl_modulezd2initializa7ationz75zzast_identz00(174885617L,
-				BSTRING_TO_STRING(BGl_string1159z00zzast_localz00));
+				BSTRING_TO_STRING(BGl_string1176z00zzast_localz00));
 		}
 
 	}
