@@ -1,11 +1,14 @@
 ;*=====================================================================*/
-;*    serrano/prgm/project/bigloo/comptime/Ast/occur.scm               */
+;*    serrano/prgm/project/bigloo/bigloo/comptime/Ast/occur.scm        */
 ;*    -------------------------------------------------------------    */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Fri Jan  6 11:09:14 1995                          */
-;*    Last change :  Sun Dec 24 14:24:49 2000 (serrano)                */
+;*    Last change :  Wed Jun 16 15:53:11 2021 (serrano)                */
 ;*    -------------------------------------------------------------    */
-;*    The substitution tools module                                    */
+;*    Compute the occurrences number and compute the read/write        */
+;*    property of local variables. The read/write property is          */
+;*    recomputed because dead code elimination might remove useless    */
+;*    set!                                                             */
 ;*=====================================================================*/
 
 ;*---------------------------------------------------------------------*/
@@ -17,20 +20,34 @@
 	    tools_shape
 	    ast_sexp
 	    ast_env
-	    ast_local)
+	    ast_local
+	    ast_dump)
    (export  (occur-var globals)
-	    (occur-node-in! ::node ::global)))
+	    (occur-node-sfun! ::sfun ::global)
+	    (occur-node-in! ::node ::global)
+	    (generic occur-node! ::node)))
 
 ;*---------------------------------------------------------------------*/
 ;*    occur-var ...                                                    */
 ;*---------------------------------------------------------------------*/
 (define (occur-var globals)
-   ;; first, we rester the counter.
-   (for-each-global! (lambda (global) (global-occurrence-set! global 0)))
+   ;; first, we reste the counter.
+   (for-each-global! (lambda (global)
+			(global-occurrence-set! global 0)
+			(global-occurrencew-set! global 0)))
    ;; then we recompute the global occurrences.
    (for-each (lambda (global)
-		(occur-node-in! (sfun-body (global-value global)) global))
-	     globals))
+		(occur-node-sfun! (global-value global) global))
+	     globals)
+   globals)
+
+;*---------------------------------------------------------------------*/
+;*    occur-node-sfun! ...                                             */
+;*---------------------------------------------------------------------*/
+(define (occur-node-sfun! f global)
+   (with-access::sfun f (args body)
+      (for-each (lambda (a) (local-occurrence-set! a 0)) args)
+      (occur-node-in! body global)))
 
 ;*---------------------------------------------------------------------*/
 ;*    occur-node-in! ...                                               */
@@ -38,7 +55,7 @@
 (define (occur-node-in! node global)
    (set! *global* global)
    (occur-node! node))
-   
+
 ;*---------------------------------------------------------------------*/
 ;*    *global* ...                                                     */
 ;*---------------------------------------------------------------------*/
@@ -58,8 +75,21 @@
       (let ((value (variable-value v)))
 	 (if (and (scnst? value) (node? (scnst-node value)))
 	     (occur-node! (scnst-node value))))
-      (if (not (eq? v *global*))
-	  (variable-occurrence-set! v (+fx (variable-occurrence v) 1)))))
+      (unless (eq? v *global*)
+	 (variable-occurrence-set! v (+fx (variable-occurrence v) 1)))))
+
+;*---------------------------------------------------------------------*/
+;*    occur-node! ::patch ...                                          */
+;*---------------------------------------------------------------------*/
+(define-method (occur-node! node::patch)
+   (with-access::patch node (ref value)
+      (if (isa? value var)
+	  (let ((v (var-variable value)))
+	     (variable-occurrencew-set! v (+fx (variable-occurrencew v) 1))
+	     (variable-occurrence-set! v (+fx (variable-occurrence v) 1))
+	     (variable-access-set! v 'write))
+	  (occur-node! value))
+      (occur-node! ref)))
 
 ;*---------------------------------------------------------------------*/
 ;*    occur-node! ::sequence ...                                       */
@@ -67,6 +97,14 @@
 (define-method (occur-node! node::sequence)
    (occur-node*! (sequence-nodes node)))
 
+;*---------------------------------------------------------------------*/
+;*    occur-node! ::sync ...                                           */
+;*---------------------------------------------------------------------*/
+(define-method (occur-node! node::sync)
+   (occur-node! (sync-mutex node))
+   (occur-node! (sync-prelock node))
+   (occur-node! (sync-body node)))
+
 ;*---------------------------------------------------------------------*/
 ;*    occur-node! ::app ...                                            */
 ;*---------------------------------------------------------------------*/
@@ -95,7 +133,23 @@
 ;*    occur-node! ::extern ...                                         */
 ;*---------------------------------------------------------------------*/
 (define-method (occur-node! node::extern)
-   (occur-node*! (extern-expr* node)))
+   (with-access::extern node (side-effect)
+      (let ((nodes (extern-expr* node)))
+	 (occur-node*! nodes))))
+
+;*---------------------------------------------------------------------*/
+;*    occur-node! ::pragma ...                                         */
+;*---------------------------------------------------------------------*/
+(define-method (occur-node! node::pragma)
+   (with-access::pragma node (side-effect)
+      (when side-effect
+	 (for-each (lambda (n)
+		      (if (and (var? n) (local? (var-variable n)))
+			  (with-access::local  (var-variable n) (access)
+			     (when (eq? access 'read)
+				(set! access 'write)))))
+		   (extern-expr* node)))
+      (call-next-method)))
 
 ;*---------------------------------------------------------------------*/
 ;*    occur-node! ::cast ...                                           */
@@ -108,6 +162,9 @@
 ;*---------------------------------------------------------------------*/
 (define-method (occur-node! node::setq)
    (with-access::setq node (var value)
+      (with-access::variable (var-variable var) (access occurrencew)
+	 (when (eq? access 'read) (set! access 'write))
+	 (set! occurrencew (+fx 1 occurrencew)))
       (occur-node! var)
       (occur-node! value)))
 
@@ -130,10 +187,10 @@
       (occur-node! obj)))
 
 ;*---------------------------------------------------------------------*/
-;*    occur-node! ::select ...                                         */
+;*    occur-node! ::switch ...                                         */
 ;*---------------------------------------------------------------------*/
-(define-method (occur-node! node::select)
-   (with-access::select node (test clauses)
+(define-method (occur-node! node::switch)
+   (with-access::switch node (test clauses)
       (occur-node! test)
       (for-each (lambda (clause)
 		   (occur-node! (cdr clause)))
@@ -144,16 +201,21 @@
 ;*---------------------------------------------------------------------*/
 (define-method (occur-node! node::let-fun)
    (with-access::let-fun node (body locals)
+      
       (for-each (lambda (local)
-		   (local-occurrence-set! local 0)
-		   (for-each (lambda (a) (local-occurrence-set! a 1))
-			     (sfun-args (local-value local))))
-		locals)
+		   (with-access::local local (occurrence occurrencew access)
+		      (set! occurrence 0)
+		      (set! occurrencew 0)
+		      ;; re-compute the access property of written locals
+		      (when (eq? access 'write) (set! access 'read)))
+		   (for-each (lambda (a) (local-occurrence-set! a 0))
+		      (sfun-args (local-value local))))
+	 locals)
       (for-each (lambda (local)
 		   (let ((old (local-occurrence local)))
 		      (occur-node! (sfun-body (local-value local)))
 		      (local-occurrence-set! local old)))
-		locals)
+	 locals)
       (occur-node! body)))
 
 ;*---------------------------------------------------------------------*/
@@ -162,7 +224,12 @@
 (define-method (occur-node! node::let-var)
    (with-access::let-var node (body bindings)
       (for-each (lambda (binding)
-		   (local-occurrence-set! (car binding) 0)
+		   (with-access::local (car binding) (occurrence occurrencew access)
+		      (set! occurrence 0)
+		      (set! occurrencew 0)
+		      (set! access 'read)))
+		bindings)
+      (for-each (lambda (binding)
 		   (occur-node! (cdr binding)))
 		bindings)
       (occur-node! body)))
@@ -172,7 +239,11 @@
 ;*---------------------------------------------------------------------*/
 (define-method (occur-node! node::set-ex-it)
    (with-access::set-ex-it node (var)
-      (local-occurrence-set! (var-variable var) 0)
+      (with-access::local (var-variable var) (occurrence occurrencew access)
+	 (set! occurrence 0)
+	 (set! occurrencew 0)
+	 (when (eq? access 'write) (set! access 'read)))
+      (occur-node! (set-ex-it-onexit node))
       (occur-node! (set-ex-it-body node))))
 
 ;*---------------------------------------------------------------------*/
@@ -183,6 +254,20 @@
       (occur-node! exit)
       (occur-node! value)))
 
+;*---------------------------------------------------------------------*/
+;*    occur-node! ::retblock ...                                       */
+;*---------------------------------------------------------------------*/
+(define-method (occur-node! node::retblock)
+   (with-access::retblock node (body)
+      (occur-node! body)))
+
+;*---------------------------------------------------------------------*/
+;*    occur-node! ::return ...                                         */
+;*---------------------------------------------------------------------*/
+(define-method (occur-node! node::return)
+   (with-access::return node (value)
+      (occur-node! value)))
+
 ;*---------------------------------------------------------------------*/
 ;*    occur-node! ::make-box ...                                       */
 ;*---------------------------------------------------------------------*/
