@@ -1,9 +1,9 @@
 /*===========================================================================*/
 /*   (Bdb/bdb_initialize.scm)                                                */
-/*   Bigloo (4.5b)                                                           */
-/*   Inria -- Sophia Antipolis (c)       Fri Dec 22 05:17:06 PM CET 2023     */
+/*   Bigloo (4.6a)                                                           */
+/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
 /*===========================================================================*/
-/* COMPILATION: (/home/serrano/prgm/project/bigloo/bigloo/bin/bigloo -ldopt -L/home/serrano/prgm/project/bigloo/bigloo/libbacktrace/home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b  -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Bdb/bdb_initialize.scm) */
+/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Bdb/bdb_initialize.scm) */
 /* GC selection */
 #define THE_GC BOEHM_GC
 
@@ -38,6 +38,7 @@ extern "C"
 		obj_t BgL_parentsz00;
 		bool_t BgL_initzf3zf3;
 		bool_t BgL_magiczf3zf3;
+		obj_t BgL_nullz00;
 		obj_t BgL_z42z42;
 		obj_t BgL_aliasz00;
 		obj_t BgL_pointedzd2tozd2byz00;
@@ -90,7 +91,7 @@ extern "C"
 		obj_t BgL_libraryz00;
 		obj_t BgL_pragmaz00;
 		obj_t BgL_srcz00;
-		obj_t BgL_jvmzd2typezd2namez00;
+		obj_t BgL_qualifiedzd2typezd2namez00;
 		obj_t BgL_initz00;
 		obj_t BgL_aliasz00;
 	}                *BgL_globalz00_bglt;
@@ -188,17 +189,17 @@ extern "C"
 
 	   
 		 
-		DEFINE_STRING(BGl_string1500z00zzbdb_initializa7eza7,
-		BgL_bgl_string1500za700za7za7b1520za7, "bdb_initialize", 14);
-	      DEFINE_STRING(BGl_string1501z00zzbdb_initializa7eza7,
-		BgL_bgl_string1501za700za7za7b1521za7,
+		DEFINE_STRING(BGl_string1363z00zzbdb_initializa7eza7,
+		BgL_bgl_string1363za700za7za7b1368za7, "((obj_t)__bdb_info)", 19);
+	      DEFINE_STRING(BGl_string1364z00zzbdb_initializa7eza7,
+		BgL_bgl_string1364za700za7za7b1369za7, "bdb_initialize", 14);
+	      DEFINE_STRING(BGl_string1365z00zzbdb_initializa7eza7,
+		BgL_bgl_string1365za700za7za7b1370za7,
 		"unit bdb bdb-set-module-info! pragma::obj quote ", 48);
-	      DEFINE_STRING(BGl_string1499z00zzbdb_initializa7eza7,
-		BgL_bgl_string1499za700za7za7b1522za7, "((obj_t)__bdb_info)", 19);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_initializa7ezd2astzd2envza7zzbdb_initializa7eza7,
-		BgL_bgl_za762initializa7a7eza71523za7,
+		BgL_bgl_za762initializa7a7eza71371za7,
 		BGl_z62initializa7ezd2astz17zzbdb_initializa7eza7, 0L, BUNSPEC, 0);
 
 /* GC roots registration */
@@ -222,7 +223,7 @@ extern "C"
 /* module-initialization */
 	BGL_EXPORTED_DEF obj_t
 		BGl_modulezd2initializa7ationz75zzbdb_initializa7eza7(long
-		BgL_checksumz00_1619, char *BgL_fromz00_1620)
+		BgL_checksumz00_1624, char *BgL_fromz00_1625)
 	{
 		{
 			if (CBOOL(BGl_requirezd2initializa7ationz75zzbdb_initializa7eza7))
@@ -270,71 +271,71 @@ extern "C"
 	{
 		{	/* Bdb/bdb_initialize.scm 15 */
 			{	/* Bdb/bdb_initialize.scm 15 */
-				obj_t BgL_cportz00_1608;
+				obj_t BgL_cportz00_1613;
 
 				{	/* Bdb/bdb_initialize.scm 15 */
-					obj_t BgL_stringz00_1615;
+					obj_t BgL_stringz00_1620;
 
-					BgL_stringz00_1615 = BGl_string1501z00zzbdb_initializa7eza7;
+					BgL_stringz00_1620 = BGl_string1365z00zzbdb_initializa7eza7;
 					{	/* Bdb/bdb_initialize.scm 15 */
-						obj_t BgL_startz00_1616;
+						obj_t BgL_startz00_1621;
 
-						BgL_startz00_1616 = BINT(0L);
+						BgL_startz00_1621 = BINT(0L);
 						{	/* Bdb/bdb_initialize.scm 15 */
-							obj_t BgL_endz00_1617;
+							obj_t BgL_endz00_1622;
 
-							BgL_endz00_1617 =
-								BINT(STRING_LENGTH(((obj_t) BgL_stringz00_1615)));
+							BgL_endz00_1622 =
+								BINT(STRING_LENGTH(((obj_t) BgL_stringz00_1620)));
 							{	/* Bdb/bdb_initialize.scm 15 */
 
-								BgL_cportz00_1608 =
+								BgL_cportz00_1613 =
 									BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00
-									(BgL_stringz00_1615, BgL_startz00_1616, BgL_endz00_1617);
+									(BgL_stringz00_1620, BgL_startz00_1621, BgL_endz00_1622);
 				}}}}
 				{
-					long BgL_iz00_1609;
+					long BgL_iz00_1614;
 
-					BgL_iz00_1609 = 4L;
-				BgL_loopz00_1610:
-					if ((BgL_iz00_1609 == -1L))
+					BgL_iz00_1614 = 4L;
+				BgL_loopz00_1615:
+					if ((BgL_iz00_1614 == (-1L)))
 						{	/* Bdb/bdb_initialize.scm 15 */
 							return BUNSPEC;
 						}
 					else
 						{	/* Bdb/bdb_initialize.scm 15 */
 							{	/* Bdb/bdb_initialize.scm 15 */
-								obj_t BgL_arg1519z00_1611;
+								obj_t BgL_arg1367z00_1616;
 
 								{	/* Bdb/bdb_initialize.scm 15 */
 
 									{	/* Bdb/bdb_initialize.scm 15 */
-										obj_t BgL_locationz00_1613;
+										obj_t BgL_locationz00_1618;
 
-										BgL_locationz00_1613 = BBOOL(((bool_t) 0));
+										BgL_locationz00_1618 = BBOOL(((bool_t) 0));
 										{	/* Bdb/bdb_initialize.scm 15 */
 
-											BgL_arg1519z00_1611 =
-												BGl_readz00zz__readerz00(BgL_cportz00_1608,
-												BgL_locationz00_1613);
+											BgL_arg1367z00_1616 =
+												BGl_readz00zz__readerz00(BgL_cportz00_1613,
+												BgL_locationz00_1618);
 										}
 									}
 								}
 								{	/* Bdb/bdb_initialize.scm 15 */
-									int BgL_tmpz00_1644;
+									int BgL_tmpz00_1649;
 
-									BgL_tmpz00_1644 = (int) (BgL_iz00_1609);
-									CNST_TABLE_SET(BgL_tmpz00_1644, BgL_arg1519z00_1611);
+									BgL_tmpz00_1649 = (int) (BgL_iz00_1614);
+									CNST_TABLE_SET(BgL_tmpz00_1649, BgL_arg1367z00_1616);
 							}}
 							{	/* Bdb/bdb_initialize.scm 15 */
-								int BgL_auxz00_1614;
+								int BgL_auxz00_1619;
 
-								BgL_auxz00_1614 = (int) ((BgL_iz00_1609 - 1L));
+								BgL_auxz00_1619 = (int) ((BgL_iz00_1614 - 1L));
 								{
-									long BgL_iz00_1649;
+									long BgL_iz00_1654;
 
-									BgL_iz00_1649 = (long) (BgL_auxz00_1614);
-									BgL_iz00_1609 = BgL_iz00_1649;
-									goto BgL_loopz00_1610;
+									BgL_iz00_1654 = (long) (BgL_auxz00_1619);
+									BgL_iz00_1614 = BgL_iz00_1654;
+									goto BgL_loopz00_1615;
 								}
 							}
 						}
@@ -373,147 +374,150 @@ extern "C"
 	{
 		{	/* Bdb/bdb_initialize.scm 42 */
 			{	/* Bdb/bdb_initialize.scm 44 */
-				obj_t BgL_bodyz00_1397;
+				obj_t BgL_bodyz00_1402;
 
 				{	/* Bdb/bdb_initialize.scm 44 */
-					obj_t BgL_arg1259z00_1412;
+					obj_t BgL_arg1266z00_1417;
 
 					{	/* Bdb/bdb_initialize.scm 44 */
-						obj_t BgL_arg1260z00_1413;
+						obj_t BgL_arg1267z00_1418;
 
 						{	/* Bdb/bdb_initialize.scm 44 */
-							obj_t BgL_arg1265z00_1414;
-							obj_t BgL_arg1275z00_1415;
+							obj_t BgL_arg1268z00_1419;
+							obj_t BgL_arg1271z00_1420;
 
 							{	/* Bdb/bdb_initialize.scm 44 */
-								obj_t BgL_arg1276z00_1416;
+								obj_t BgL_arg1272z00_1421;
 
-								BgL_arg1276z00_1416 =
+								BgL_arg1272z00_1421 =
 									MAKE_YOUNG_PAIR(BGl_za2moduleza2z00zzmodule_modulez00, BNIL);
-								BgL_arg1265z00_1414 =
-									MAKE_YOUNG_PAIR(CNST_TABLE_REF(0L), BgL_arg1276z00_1416);
+								BgL_arg1268z00_1419 =
+									MAKE_YOUNG_PAIR(
+									((obj_t) CNST_TABLE_REF(0)), BgL_arg1272z00_1421);
 							}
 							{	/* Bdb/bdb_initialize.scm 45 */
-								obj_t BgL_arg1277z00_1417;
+								obj_t BgL_arg1273z00_1422;
 
 								{	/* Bdb/bdb_initialize.scm 45 */
-									obj_t BgL_arg1279z00_1418;
+									obj_t BgL_arg1274z00_1423;
 
-									BgL_arg1279z00_1418 =
-										MAKE_YOUNG_PAIR(BGl_string1499z00zzbdb_initializa7eza7,
+									BgL_arg1274z00_1423 =
+										MAKE_YOUNG_PAIR(BGl_string1363z00zzbdb_initializa7eza7,
 										BNIL);
-									BgL_arg1277z00_1417 =
-										MAKE_YOUNG_PAIR(CNST_TABLE_REF(1L), BgL_arg1279z00_1418);
+									BgL_arg1273z00_1422 =
+										MAKE_YOUNG_PAIR(((obj_t) CNST_TABLE_REF(1)),
+										BgL_arg1274z00_1423);
 								}
-								BgL_arg1275z00_1415 =
-									MAKE_YOUNG_PAIR(BgL_arg1277z00_1417, BNIL);
+								BgL_arg1271z00_1420 =
+									MAKE_YOUNG_PAIR(BgL_arg1273z00_1422, BNIL);
 							}
-							BgL_arg1260z00_1413 =
-								MAKE_YOUNG_PAIR(BgL_arg1265z00_1414, BgL_arg1275z00_1415);
+							BgL_arg1267z00_1418 =
+								MAKE_YOUNG_PAIR(BgL_arg1268z00_1419, BgL_arg1271z00_1420);
 						}
-						BgL_arg1259z00_1412 =
-							MAKE_YOUNG_PAIR(CNST_TABLE_REF(2L), BgL_arg1260z00_1413);
+						BgL_arg1266z00_1417 =
+							MAKE_YOUNG_PAIR(((obj_t) CNST_TABLE_REF(2)), BgL_arg1267z00_1418);
 					}
-					BgL_bodyz00_1397 = MAKE_YOUNG_PAIR(BgL_arg1259z00_1412, BNIL);
+					BgL_bodyz00_1402 = MAKE_YOUNG_PAIR(BgL_arg1266z00_1417, BNIL);
 				}
 				{	/* Bdb/bdb_initialize.scm 46 */
-					obj_t BgL_unitz00_1398;
+					obj_t BgL_unitz00_1403;
 
 					{	/* Bdb/bdb_initialize.scm 46 */
-						obj_t BgL_idz00_1593;
+						obj_t BgL_idz00_1598;
 
-						BgL_idz00_1593 = CNST_TABLE_REF(3L);
+						BgL_idz00_1598 = ((obj_t) CNST_TABLE_REF(3));
 						{	/* Bdb/bdb_initialize.scm 46 */
-							obj_t BgL_newz00_1594;
+							obj_t BgL_newz00_1599;
 
-							BgL_newz00_1594 = create_struct(CNST_TABLE_REF(4L), (int) (5L));
+							BgL_newz00_1599 =
+								create_struct(((obj_t) CNST_TABLE_REF(4)), (int) (5L));
 							{	/* Bdb/bdb_initialize.scm 46 */
-								int BgL_tmpz00_1667;
+								int BgL_tmpz00_1677;
 
-								BgL_tmpz00_1667 = (int) (4L);
-								STRUCT_SET(BgL_newz00_1594, BgL_tmpz00_1667, BFALSE);
+								BgL_tmpz00_1677 = (int) (4L);
+								STRUCT_SET(BgL_newz00_1599, BgL_tmpz00_1677, BFALSE);
 							}
 							{	/* Bdb/bdb_initialize.scm 46 */
-								int BgL_tmpz00_1670;
+								int BgL_tmpz00_1680;
 
-								BgL_tmpz00_1670 = (int) (3L);
-								STRUCT_SET(BgL_newz00_1594, BgL_tmpz00_1670, BTRUE);
+								BgL_tmpz00_1680 = (int) (3L);
+								STRUCT_SET(BgL_newz00_1599, BgL_tmpz00_1680, BTRUE);
 							}
 							{	/* Bdb/bdb_initialize.scm 46 */
-								int BgL_tmpz00_1673;
+								int BgL_tmpz00_1683;
 
-								BgL_tmpz00_1673 = (int) (2L);
-								STRUCT_SET(BgL_newz00_1594, BgL_tmpz00_1673, BgL_bodyz00_1397);
+								BgL_tmpz00_1683 = (int) (2L);
+								STRUCT_SET(BgL_newz00_1599, BgL_tmpz00_1683, BgL_bodyz00_1402);
 							}
 							{	/* Bdb/bdb_initialize.scm 46 */
-								obj_t BgL_auxz00_1678;
-								int BgL_tmpz00_1676;
+								obj_t BgL_auxz00_1688;
+								int BgL_tmpz00_1686;
 
-								BgL_auxz00_1678 = BINT(9L);
-								BgL_tmpz00_1676 = (int) (1L);
-								STRUCT_SET(BgL_newz00_1594, BgL_tmpz00_1676, BgL_auxz00_1678);
+								BgL_auxz00_1688 = BINT(9L);
+								BgL_tmpz00_1686 = (int) (1L);
+								STRUCT_SET(BgL_newz00_1599, BgL_tmpz00_1686, BgL_auxz00_1688);
 							}
 							{	/* Bdb/bdb_initialize.scm 46 */
-								int BgL_tmpz00_1681;
+								int BgL_tmpz00_1691;
 
-								BgL_tmpz00_1681 = (int) (0L);
-								STRUCT_SET(BgL_newz00_1594, BgL_tmpz00_1681, BgL_idz00_1593);
+								BgL_tmpz00_1691 = (int) (0L);
+								STRUCT_SET(BgL_newz00_1599, BgL_tmpz00_1691, BgL_idz00_1598);
 							}
-							BgL_unitz00_1398 = BgL_newz00_1594;
+							BgL_unitz00_1403 = BgL_newz00_1599;
 					}}
 					{	/* Bdb/bdb_initialize.scm 47 */
-						obj_t BgL_astz00_1399;
+						obj_t BgL_astz00_1404;
 
 						{	/* Bdb/bdb_initialize.scm 47 */
-							obj_t BgL_arg1257z00_1410;
+							obj_t BgL_arg1262z00_1415;
 
 							{	/* Bdb/bdb_initialize.scm 47 */
-								obj_t BgL_list1258z00_1411;
+								obj_t BgL_list1263z00_1416;
 
-								BgL_list1258z00_1411 = MAKE_YOUNG_PAIR(BgL_unitz00_1398, BNIL);
-								BgL_arg1257z00_1410 = BgL_list1258z00_1411;
+								BgL_list1263z00_1416 = MAKE_YOUNG_PAIR(BgL_unitz00_1403, BNIL);
+								BgL_arg1262z00_1415 = BgL_list1263z00_1416;
 							}
-							BgL_astz00_1399 =
-								BGl_buildzd2astzd2zzast_buildz00(BgL_arg1257z00_1410);
+							BgL_astz00_1404 =
+								BGl_buildzd2astzd2zzast_buildz00(BgL_arg1262z00_1415);
 						}
 						{
-							obj_t BgL_l1227z00_1401;
+							obj_t BgL_l1226z00_1406;
 
-							BgL_l1227z00_1401 = BgL_astz00_1399;
-						BgL_zc3z04anonymousza31250ze3z87_1402:
-							if (PAIRP(BgL_l1227z00_1401))
+							BgL_l1226z00_1406 = BgL_astz00_1404;
+						BgL_zc3z04anonymousza31253ze3z87_1407:
+							if (PAIRP(BgL_l1226z00_1406))
 								{	/* Bdb/bdb_initialize.scm 48 */
 									{	/* Bdb/bdb_initialize.scm 49 */
-										obj_t BgL_globalz00_1404;
+										obj_t BgL_globalz00_1409;
 
-										BgL_globalz00_1404 = CAR(BgL_l1227z00_1401);
+										BgL_globalz00_1409 = CAR(BgL_l1226z00_1406);
 										{	/* Bdb/bdb_initialize.scm 49 */
-											obj_t BgL_arg1252z00_1405;
-											BgL_typez00_bglt BgL_arg1253z00_1406;
+											obj_t BgL_arg1255z00_1410;
+											BgL_typez00_bglt BgL_arg1256z00_1411;
 
-											BgL_arg1252z00_1405 =
+											BgL_arg1255z00_1410 =
 												(((BgL_sfunz00_bglt) COBJECT(
 														((BgL_sfunz00_bglt)
 															(((BgL_variablez00_bglt) COBJECT(
 																		((BgL_variablez00_bglt)
 																			((BgL_globalz00_bglt)
-																				BgL_globalz00_1404))))->
+																				BgL_globalz00_1409))))->
 																BgL_valuez00))))->BgL_bodyz00);
-											BgL_arg1253z00_1406 =
+											BgL_arg1256z00_1411 =
 												(((BgL_variablez00_bglt)
 													COBJECT(((BgL_variablez00_bglt) ((BgL_globalz00_bglt)
-																BgL_globalz00_1404))))->BgL_typez00);
+																BgL_globalz00_1409))))->BgL_typez00);
 											BGl_coercez12z12zzcoerce_coercez00(((BgL_nodez00_bglt)
-													BgL_arg1252z00_1405), BgL_globalz00_1404,
-												BgL_arg1253z00_1406, ((bool_t) 0));
+													BgL_arg1255z00_1410), BgL_globalz00_1409,
+												BgL_arg1256z00_1411, ((bool_t) 0));
 										}
 									}
 									{
-										obj_t BgL_l1227z00_1699;
+										obj_t BgL_l1226z00_1709;
 
-										BgL_l1227z00_1699 = CDR(BgL_l1227z00_1401);
-										BgL_l1227z00_1401 = BgL_l1227z00_1699;
-										goto BgL_zc3z04anonymousza31250ze3z87_1402;
+										BgL_l1226z00_1709 = CDR(BgL_l1226z00_1406);
+										BgL_l1226z00_1406 = BgL_l1226z00_1709;
+										goto BgL_zc3z04anonymousza31253ze3z87_1407;
 									}
 								}
 							else
@@ -521,7 +525,7 @@ extern "C"
 									((bool_t) 1);
 								}
 						}
-						return BgL_astz00_1399;
+						return BgL_astz00_1404;
 					}
 				}
 			}
@@ -532,7 +536,7 @@ extern "C"
 
 
 /* &initialize-ast */
-	obj_t BGl_z62initializa7ezd2astz17zzbdb_initializa7eza7(obj_t BgL_envz00_1606)
+	obj_t BGl_z62initializa7ezd2astz17zzbdb_initializa7eza7(obj_t BgL_envz00_1611)
 	{
 		{	/* Bdb/bdb_initialize.scm 42 */
 			return BGl_initializa7ezd2astz75zzbdb_initializa7eza7();
@@ -580,40 +584,40 @@ extern "C"
 	{
 		{	/* Bdb/bdb_initialize.scm 15 */
 			BGl_modulezd2initializa7ationz75zztools_tracez00(54713316L,
-				BSTRING_TO_STRING(BGl_string1500z00zzbdb_initializa7eza7));
+				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
 			BGl_modulezd2initializa7ationz75zztools_shapez00(365925558L,
-				BSTRING_TO_STRING(BGl_string1500z00zzbdb_initializa7eza7));
+				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
 			BGl_modulezd2initializa7ationz75zztools_speekz00(61247943L,
-				BSTRING_TO_STRING(BGl_string1500z00zzbdb_initializa7eza7));
+				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
 			BGl_modulezd2initializa7ationz75zztools_errorz00(300504031L,
-				BSTRING_TO_STRING(BGl_string1500z00zzbdb_initializa7eza7));
-			BGl_modulezd2initializa7ationz75zzengine_paramz00(517137079L,
-				BSTRING_TO_STRING(BGl_string1500z00zzbdb_initializa7eza7));
+				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
+			BGl_modulezd2initializa7ationz75zzengine_paramz00(161876678L,
+				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
 			BGl_modulezd2initializa7ationz75zzmodule_modulez00(158397907L,
-				BSTRING_TO_STRING(BGl_string1500z00zzbdb_initializa7eza7));
+				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
 			BGl_modulezd2initializa7ationz75zztype_typez00(515343395L,
-				BSTRING_TO_STRING(BGl_string1500z00zzbdb_initializa7eza7));
-			BGl_modulezd2initializa7ationz75zztype_cachez00(346491734L,
-				BSTRING_TO_STRING(BGl_string1500z00zzbdb_initializa7eza7));
+				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
+			BGl_modulezd2initializa7ationz75zztype_cachez00(489890788L,
+				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
 			BGl_modulezd2initializa7ationz75zzast_varz00(90839984L,
-				BSTRING_TO_STRING(BGl_string1500z00zzbdb_initializa7eza7));
+				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
 			BGl_modulezd2initializa7ationz75zzast_nodez00(469732712L,
-				BSTRING_TO_STRING(BGl_string1500z00zzbdb_initializa7eza7));
+				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
 			BGl_modulezd2initializa7ationz75zzast_envz00(146730773L,
-				BSTRING_TO_STRING(BGl_string1500z00zzbdb_initializa7eza7));
+				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
 			BGl_modulezd2initializa7ationz75zzast_buildz00(428035925L,
-				BSTRING_TO_STRING(BGl_string1500z00zzbdb_initializa7eza7));
+				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
 			BGl_modulezd2initializa7ationz75zzast_lvtypez00(189769752L,
-				BSTRING_TO_STRING(BGl_string1500z00zzbdb_initializa7eza7));
+				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
 			BGl_modulezd2initializa7ationz75zzast_glozd2defzd2(44601789L,
-				BSTRING_TO_STRING(BGl_string1500z00zzbdb_initializa7eza7));
+				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
 			BGl_modulezd2initializa7ationz75zzcoerce_coercez00(361167184L,
-				BSTRING_TO_STRING(BGl_string1500z00zzbdb_initializa7eza7));
-			BGl_modulezd2initializa7ationz75zzcnst_allocz00(192699986L,
-				BSTRING_TO_STRING(BGl_string1500z00zzbdb_initializa7eza7));
+				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
+			BGl_modulezd2initializa7ationz75zzcnst_allocz00(117763019L,
+				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
 			return
 				BGl_modulezd2initializa7ationz75zzcnst_nodez00(89013043L,
-				BSTRING_TO_STRING(BGl_string1500z00zzbdb_initializa7eza7));
+				BSTRING_TO_STRING(BGl_string1364z00zzbdb_initializa7eza7));
 		}
 
 	}
