@@ -1,9 +1,9 @@
 /*===========================================================================*/
 /*   (Bdb/walk.scm)                                                          */
-/*   Bigloo (4.5b)                                                           */
-/*   Inria -- Sophia Antipolis (c)       Fri Dec 22 05:17:06 PM CET 2023     */
+/*   Bigloo (4.6a)                                                           */
+/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
 /*===========================================================================*/
-/* COMPILATION: (/home/serrano/prgm/project/bigloo/bigloo/bin/bigloo -ldopt -L/home/serrano/prgm/project/bigloo/bigloo/libbacktrace/home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b  -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Bdb/walk.scm) */
+/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Bdb/walk.scm) */
 /* GC selection */
 #define THE_GC BOEHM_GC
 
@@ -82,28 +82,28 @@ extern "C"
 
 	   
 		 
-		DEFINE_STRING(BGl_string1500z00zzbdb_walkz00,
-		BgL_bgl_string1500za700za7za7b1520za7, " error", 6);
-	      DEFINE_STRING(BGl_string1501z00zzbdb_walkz00,
-		BgL_bgl_string1501za700za7za7b1521za7, "s", 1);
-	      DEFINE_STRING(BGl_string1502z00zzbdb_walkz00,
-		BgL_bgl_string1502za700za7za7b1522za7, "", 0);
-	      DEFINE_STRING(BGl_string1503z00zzbdb_walkz00,
-		BgL_bgl_string1503za700za7za7b1523za7, " occured, ending ...", 20);
-	      DEFINE_STRING(BGl_string1504z00zzbdb_walkz00,
-		BgL_bgl_string1504za700za7za7b1524za7, "failure during postlude hook", 28);
-	      DEFINE_STRING(BGl_string1505z00zzbdb_walkz00,
-		BgL_bgl_string1505za700za7za7b1525za7, "bdb_walk", 8);
-	      DEFINE_STRING(BGl_string1506z00zzbdb_walkz00,
-		BgL_bgl_string1506za700za7za7b1526za7, "pass-started ", 13);
-	      DEFINE_STRING(BGl_string1497z00zzbdb_walkz00,
-		BgL_bgl_string1497za700za7za7b1527za7, "Bdb", 3);
-	      DEFINE_STRING(BGl_string1498z00zzbdb_walkz00,
-		BgL_bgl_string1498za700za7za7b1528za7, "   . ", 5);
-	      DEFINE_STRING(BGl_string1499z00zzbdb_walkz00,
-		BgL_bgl_string1499za700za7za7b1529za7, "failure during prelude hook", 27);
+		DEFINE_STRING(BGl_string1358z00zzbdb_walkz00,
+		BgL_bgl_string1358za700za7za7b1371za7, "Bdb", 3);
+	      DEFINE_STRING(BGl_string1359z00zzbdb_walkz00,
+		BgL_bgl_string1359za700za7za7b1372za7, "   . ", 5);
+	      DEFINE_STRING(BGl_string1360z00zzbdb_walkz00,
+		BgL_bgl_string1360za700za7za7b1373za7, "failure during prelude hook", 27);
+	      DEFINE_STRING(BGl_string1361z00zzbdb_walkz00,
+		BgL_bgl_string1361za700za7za7b1374za7, " error", 6);
+	      DEFINE_STRING(BGl_string1362z00zzbdb_walkz00,
+		BgL_bgl_string1362za700za7za7b1375za7, "s", 1);
+	      DEFINE_STRING(BGl_string1363z00zzbdb_walkz00,
+		BgL_bgl_string1363za700za7za7b1376za7, "", 0);
+	      DEFINE_STRING(BGl_string1364z00zzbdb_walkz00,
+		BgL_bgl_string1364za700za7za7b1377za7, " occured, ending ...", 20);
+	      DEFINE_STRING(BGl_string1365z00zzbdb_walkz00,
+		BgL_bgl_string1365za700za7za7b1378za7, "failure during postlude hook", 28);
+	      DEFINE_STRING(BGl_string1366z00zzbdb_walkz00,
+		BgL_bgl_string1366za700za7za7b1379za7, "bdb_walk", 8);
+	      DEFINE_STRING(BGl_string1367z00zzbdb_walkz00,
+		BgL_bgl_string1367za700za7za7b1380za7, "pass-started ", 13);
 	      DEFINE_EXPORT_BGL_PROCEDURE(BGl_bdbzd2walkz12zd2envz12zzbdb_walkz00,
-		BgL_bgl_za762bdbza7d2walkza7121530za7, BGl_z62bdbzd2walkz12za2zzbdb_walkz00,
+		BgL_bgl_za762bdbza7d2walkza7121381za7, BGl_z62bdbzd2walkz12za2zzbdb_walkz00,
 		0L, BUNSPEC, 1);
 
 /* GC roots registration */
@@ -124,7 +124,7 @@ extern "C"
 
 /* module-initialization */
 	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zzbdb_walkz00(long
-		BgL_checksumz00_1589, char *BgL_fromz00_1590)
+		BgL_checksumz00_1594, char *BgL_fromz00_1595)
 	{
 		{
 			if (CBOOL(BGl_requirezd2initializa7ationz75zzbdb_walkz00))
@@ -172,71 +172,71 @@ extern "C"
 	{
 		{	/* Bdb/walk.scm 15 */
 			{	/* Bdb/walk.scm 15 */
-				obj_t BgL_cportz00_1578;
+				obj_t BgL_cportz00_1583;
 
 				{	/* Bdb/walk.scm 15 */
-					obj_t BgL_stringz00_1585;
+					obj_t BgL_stringz00_1590;
 
-					BgL_stringz00_1585 = BGl_string1506z00zzbdb_walkz00;
+					BgL_stringz00_1590 = BGl_string1367z00zzbdb_walkz00;
 					{	/* Bdb/walk.scm 15 */
-						obj_t BgL_startz00_1586;
+						obj_t BgL_startz00_1591;
 
-						BgL_startz00_1586 = BINT(0L);
+						BgL_startz00_1591 = BINT(0L);
 						{	/* Bdb/walk.scm 15 */
-							obj_t BgL_endz00_1587;
+							obj_t BgL_endz00_1592;
 
-							BgL_endz00_1587 =
-								BINT(STRING_LENGTH(((obj_t) BgL_stringz00_1585)));
+							BgL_endz00_1592 =
+								BINT(STRING_LENGTH(((obj_t) BgL_stringz00_1590)));
 							{	/* Bdb/walk.scm 15 */
 
-								BgL_cportz00_1578 =
+								BgL_cportz00_1583 =
 									BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00
-									(BgL_stringz00_1585, BgL_startz00_1586, BgL_endz00_1587);
+									(BgL_stringz00_1590, BgL_startz00_1591, BgL_endz00_1592);
 				}}}}
 				{
-					long BgL_iz00_1579;
+					long BgL_iz00_1584;
 
-					BgL_iz00_1579 = 0L;
-				BgL_loopz00_1580:
-					if ((BgL_iz00_1579 == -1L))
+					BgL_iz00_1584 = 0L;
+				BgL_loopz00_1585:
+					if ((BgL_iz00_1584 == (-1L)))
 						{	/* Bdb/walk.scm 15 */
 							return BUNSPEC;
 						}
 					else
 						{	/* Bdb/walk.scm 15 */
 							{	/* Bdb/walk.scm 15 */
-								obj_t BgL_arg1519z00_1581;
+								obj_t BgL_arg1370z00_1586;
 
 								{	/* Bdb/walk.scm 15 */
 
 									{	/* Bdb/walk.scm 15 */
-										obj_t BgL_locationz00_1583;
+										obj_t BgL_locationz00_1588;
 
-										BgL_locationz00_1583 = BBOOL(((bool_t) 0));
+										BgL_locationz00_1588 = BBOOL(((bool_t) 0));
 										{	/* Bdb/walk.scm 15 */
 
-											BgL_arg1519z00_1581 =
-												BGl_readz00zz__readerz00(BgL_cportz00_1578,
-												BgL_locationz00_1583);
+											BgL_arg1370z00_1586 =
+												BGl_readz00zz__readerz00(BgL_cportz00_1583,
+												BgL_locationz00_1588);
 										}
 									}
 								}
 								{	/* Bdb/walk.scm 15 */
-									int BgL_tmpz00_1616;
+									int BgL_tmpz00_1621;
 
-									BgL_tmpz00_1616 = (int) (BgL_iz00_1579);
-									CNST_TABLE_SET(BgL_tmpz00_1616, BgL_arg1519z00_1581);
+									BgL_tmpz00_1621 = (int) (BgL_iz00_1584);
+									CNST_TABLE_SET(BgL_tmpz00_1621, BgL_arg1370z00_1586);
 							}}
 							{	/* Bdb/walk.scm 15 */
-								int BgL_auxz00_1584;
+								int BgL_auxz00_1589;
 
-								BgL_auxz00_1584 = (int) ((BgL_iz00_1579 - 1L));
+								BgL_auxz00_1589 = (int) ((BgL_iz00_1584 - 1L));
 								{
-									long BgL_iz00_1621;
+									long BgL_iz00_1626;
 
-									BgL_iz00_1621 = (long) (BgL_auxz00_1584);
-									BgL_iz00_1579 = BgL_iz00_1621;
-									goto BgL_loopz00_1580;
+									BgL_iz00_1626 = (long) (BgL_auxz00_1589);
+									BgL_iz00_1584 = BgL_iz00_1626;
+									goto BgL_loopz00_1585;
 								}
 							}
 						}
@@ -263,42 +263,47 @@ extern "C"
 	obj_t BGl_appendzd221011zd2zzbdb_walkz00(obj_t BgL_l1z00_1, obj_t BgL_l2z00_2)
 	{
 		{
-			{
-				obj_t BgL_headz00_1345;
-
-				BgL_headz00_1345 = MAKE_YOUNG_PAIR(BNIL, BgL_l2z00_2);
+			if (NULLP(BgL_l1z00_1))
 				{
-					obj_t BgL_prevz00_1346;
-					obj_t BgL_tailz00_1347;
+					return BgL_l2z00_2;
+				}
+			else
+				{
+					obj_t BgL_headz00_1350;
 
-					BgL_prevz00_1346 = BgL_headz00_1345;
-					BgL_tailz00_1347 = BgL_l1z00_1;
-				BgL_loopz00_1348:
-					if (PAIRP(BgL_tailz00_1347))
-						{
-							obj_t BgL_newzd2prevzd2_1350;
+					BgL_headz00_1350 = MAKE_YOUNG_PAIR(BNIL, BgL_l2z00_2);
+					{
+						obj_t BgL_prevz00_1351;
+						obj_t BgL_tailz00_1352;
 
-							BgL_newzd2prevzd2_1350 =
-								MAKE_YOUNG_PAIR(CAR(BgL_tailz00_1347), BgL_l2z00_2);
-							SET_CDR(BgL_prevz00_1346, BgL_newzd2prevzd2_1350);
+						BgL_prevz00_1351 = BgL_headz00_1350;
+						BgL_tailz00_1352 = BgL_l1z00_1;
+					BgL_loopz00_1353:
+						if (PAIRP(BgL_tailz00_1352))
 							{
-								obj_t BgL_tailz00_1631;
-								obj_t BgL_prevz00_1630;
+								obj_t BgL_newzd2prevzd2_1355;
 
-								BgL_prevz00_1630 = BgL_newzd2prevzd2_1350;
-								BgL_tailz00_1631 = CDR(BgL_tailz00_1347);
-								BgL_tailz00_1347 = BgL_tailz00_1631;
-								BgL_prevz00_1346 = BgL_prevz00_1630;
-								goto BgL_loopz00_1348;
+								BgL_newzd2prevzd2_1355 =
+									MAKE_YOUNG_PAIR(CAR(BgL_tailz00_1352), BgL_l2z00_2);
+								SET_CDR(BgL_prevz00_1351, BgL_newzd2prevzd2_1355);
+								{
+									obj_t BgL_tailz00_1638;
+									obj_t BgL_prevz00_1637;
+
+									BgL_prevz00_1637 = BgL_newzd2prevzd2_1355;
+									BgL_tailz00_1638 = CDR(BgL_tailz00_1352);
+									BgL_tailz00_1352 = BgL_tailz00_1638;
+									BgL_prevz00_1351 = BgL_prevz00_1637;
+									goto BgL_loopz00_1353;
+								}
+							}
+						else
+							{
+								BNIL;
 							}
-						}
-					else
-						{
-							BNIL;
-						}
-					return CDR(BgL_headz00_1345);
+						return CDR(BgL_headz00_1350);
+					}
 				}
-			}
 		}
 
 	}
@@ -311,121 +316,114 @@ extern "C"
 	{
 		{	/* Bdb/walk.scm 30 */
 			{	/* Bdb/walk.scm 31 */
-				obj_t BgL_list1234z00_1353;
+				obj_t BgL_list1237z00_1358;
 
 				{	/* Bdb/walk.scm 31 */
-					obj_t BgL_arg1237z00_1354;
+					obj_t BgL_arg1240z00_1359;
 
 					{	/* Bdb/walk.scm 31 */
-						obj_t BgL_arg1240z00_1355;
+						obj_t BgL_arg1241z00_1360;
 
-						BgL_arg1240z00_1355 =
+						BgL_arg1241z00_1360 =
 							MAKE_YOUNG_PAIR(BCHAR(((unsigned char) 10)), BNIL);
-						BgL_arg1237z00_1354 =
-							MAKE_YOUNG_PAIR(BGl_string1497z00zzbdb_walkz00,
-							BgL_arg1240z00_1355);
+						BgL_arg1240z00_1359 =
+							MAKE_YOUNG_PAIR(BGl_string1358z00zzbdb_walkz00,
+							BgL_arg1241z00_1360);
 					}
-					BgL_list1234z00_1353 =
-						MAKE_YOUNG_PAIR(BGl_string1498z00zzbdb_walkz00,
-						BgL_arg1237z00_1354);
+					BgL_list1237z00_1358 =
+						MAKE_YOUNG_PAIR(BGl_string1359z00zzbdb_walkz00,
+						BgL_arg1240z00_1359);
 				}
-				BGl_verbosez00zztools_speekz00(BINT(1L), BgL_list1234z00_1353);
+				BGl_verbosez00zztools_speekz00(BINT(1L), BgL_list1237z00_1358);
 			}
 			BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00 = BINT(0L);
 			BGl_za2currentzd2passza2zd2zzengine_passz00 =
-				BGl_string1497z00zzbdb_walkz00;
+				BGl_string1358z00zzbdb_walkz00;
 			{	/* Bdb/walk.scm 31 */
-				obj_t BgL_g1106z00_1356;
+				obj_t BgL_g1106z00_1361;
 
-				BgL_g1106z00_1356 = BNIL;
+				BgL_g1106z00_1361 = BNIL;
 				{
-					obj_t BgL_hooksz00_1359;
-					obj_t BgL_hnamesz00_1360;
+					obj_t BgL_hooksz00_1364;
+					obj_t BgL_hnamesz00_1365;
 
-					BgL_hooksz00_1359 = BgL_g1106z00_1356;
-					BgL_hnamesz00_1360 = BNIL;
-				BgL_zc3z04anonymousza31241ze3z87_1361:
-					if (NULLP(BgL_hooksz00_1359))
+					BgL_hooksz00_1364 = BgL_g1106z00_1361;
+					BgL_hnamesz00_1365 = BNIL;
+				BgL_zc3z04anonymousza31242ze3z87_1366:
+					if (NULLP(BgL_hooksz00_1364))
 						{	/* Bdb/walk.scm 31 */
-							CNST_TABLE_REF(0L);
+							((obj_t) CNST_TABLE_REF(0));
 						}
 					else
 						{	/* Bdb/walk.scm 31 */
-							bool_t BgL_test1536z00_1644;
+							bool_t BgL_test1392z00_1652;
 
 							{	/* Bdb/walk.scm 31 */
-								obj_t BgL_fun1249z00_1368;
+								obj_t BgL_fun1251z00_1373;
 
-								BgL_fun1249z00_1368 = CAR(((obj_t) BgL_hooksz00_1359));
-								BgL_test1536z00_1644 =
-									CBOOL(
-									(VA_PROCEDUREP(BgL_fun1249z00_1368) ? ((obj_t(*)(obj_t,
-													...))
-											PROCEDURE_ENTRY(BgL_fun1249z00_1368))
-										(BgL_fun1249z00_1368,
-											BEOA) : ((obj_t(*)(obj_t))
-											PROCEDURE_ENTRY(BgL_fun1249z00_1368))
-										(BgL_fun1249z00_1368)));
+								BgL_fun1251z00_1373 = CAR(((obj_t) BgL_hooksz00_1364));
+								BgL_test1392z00_1652 =
+									CBOOL(BGL_PROCEDURE_CALL0(BgL_fun1251z00_1373));
 							}
-							if (BgL_test1536z00_1644)
+							if (BgL_test1392z00_1652)
 								{	/* Bdb/walk.scm 31 */
-									obj_t BgL_arg1246z00_1365;
-									obj_t BgL_arg1247z00_1366;
+									obj_t BgL_arg1246z00_1370;
+									obj_t BgL_arg1247z00_1371;
 
-									BgL_arg1246z00_1365 = CDR(((obj_t) BgL_hooksz00_1359));
-									BgL_arg1247z00_1366 = CDR(((obj_t) BgL_hnamesz00_1360));
+									BgL_arg1246z00_1370 = CDR(((obj_t) BgL_hooksz00_1364));
+									BgL_arg1247z00_1371 = CDR(((obj_t) BgL_hnamesz00_1365));
 									{
-										obj_t BgL_hnamesz00_1656;
-										obj_t BgL_hooksz00_1655;
+										obj_t BgL_hnamesz00_1664;
+										obj_t BgL_hooksz00_1663;
 
-										BgL_hooksz00_1655 = BgL_arg1246z00_1365;
-										BgL_hnamesz00_1656 = BgL_arg1247z00_1366;
-										BgL_hnamesz00_1360 = BgL_hnamesz00_1656;
-										BgL_hooksz00_1359 = BgL_hooksz00_1655;
-										goto BgL_zc3z04anonymousza31241ze3z87_1361;
+										BgL_hooksz00_1663 = BgL_arg1246z00_1370;
+										BgL_hnamesz00_1664 = BgL_arg1247z00_1371;
+										BgL_hnamesz00_1365 = BgL_hnamesz00_1664;
+										BgL_hooksz00_1364 = BgL_hooksz00_1663;
+										goto BgL_zc3z04anonymousza31242ze3z87_1366;
 									}
 								}
 							else
 								{	/* Bdb/walk.scm 31 */
-									obj_t BgL_arg1248z00_1367;
+									obj_t BgL_arg1249z00_1372;
 
-									BgL_arg1248z00_1367 = CAR(((obj_t) BgL_hnamesz00_1360));
+									BgL_arg1249z00_1372 = CAR(((obj_t) BgL_hnamesz00_1365));
 									BGl_internalzd2errorzd2zztools_errorz00
-										(BGl_string1497z00zzbdb_walkz00,
-										BGl_string1499z00zzbdb_walkz00, BgL_arg1248z00_1367);
+										(BGl_string1358z00zzbdb_walkz00,
+										BGl_string1360z00zzbdb_walkz00, BgL_arg1249z00_1372);
 								}
 						}
 				}
 			}
 			{	/* Bdb/walk.scm 32 */
-				obj_t BgL_valuez00_1371;
+				obj_t BgL_valuez00_1376;
 
-				BgL_valuez00_1371 =
+				BgL_valuez00_1376 =
 					BGl_appendzd221011zd2zzbdb_walkz00
 					(BGl_initializa7ezd2astz75zzbdb_initializa7eza7(), BgL_globalsz00_3);
 				if (((long) CINT(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00) >
 						0L))
 					{	/* Bdb/walk.scm 32 */
 						{	/* Bdb/walk.scm 32 */
-							obj_t BgL_port1228z00_1373;
+							obj_t BgL_port1227z00_1378;
 
 							{	/* Bdb/walk.scm 32 */
-								obj_t BgL_tmpz00_1665;
+								obj_t BgL_tmpz00_1673;
 
-								BgL_tmpz00_1665 = BGL_CURRENT_DYNAMIC_ENV();
-								BgL_port1228z00_1373 =
-									BGL_ENV_CURRENT_ERROR_PORT(BgL_tmpz00_1665);
+								BgL_tmpz00_1673 = BGL_CURRENT_DYNAMIC_ENV();
+								BgL_port1227z00_1378 =
+									BGL_ENV_CURRENT_ERROR_PORT(BgL_tmpz00_1673);
 							}
 							bgl_display_obj
 								(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00,
-								BgL_port1228z00_1373);
-							bgl_display_string(BGl_string1500z00zzbdb_walkz00,
-								BgL_port1228z00_1373);
+								BgL_port1227z00_1378);
+							bgl_display_string(BGl_string1361z00zzbdb_walkz00,
+								BgL_port1227z00_1378);
 							{	/* Bdb/walk.scm 32 */
-								obj_t BgL_arg1252z00_1374;
+								obj_t BgL_arg1254z00_1379;
 
 								{	/* Bdb/walk.scm 32 */
-									bool_t BgL_test1538z00_1670;
+									bool_t BgL_test1394z00_1678;
 
 									if (BGl_integerzf3zf3zz__r4_numbers_6_5_fixnumz00
 										(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00))
@@ -433,7 +431,7 @@ extern "C"
 											if (INTEGERP
 												(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00))
 												{	/* Bdb/walk.scm 32 */
-													BgL_test1538z00_1670 =
+													BgL_test1394z00_1678 =
 														(
 														(long)
 														CINT
@@ -442,7 +440,7 @@ extern "C"
 												}
 											else
 												{	/* Bdb/walk.scm 32 */
-													BgL_test1538z00_1670 =
+													BgL_test1394z00_1678 =
 														BGl_2ze3ze3zz__r4_numbers_6_5z00
 														(BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00,
 														BINT(1L));
@@ -450,91 +448,84 @@ extern "C"
 										}
 									else
 										{	/* Bdb/walk.scm 32 */
-											BgL_test1538z00_1670 = ((bool_t) 0);
+											BgL_test1394z00_1678 = ((bool_t) 0);
 										}
-									if (BgL_test1538z00_1670)
+									if (BgL_test1394z00_1678)
 										{	/* Bdb/walk.scm 32 */
-											BgL_arg1252z00_1374 = BGl_string1501z00zzbdb_walkz00;
+											BgL_arg1254z00_1379 = BGl_string1362z00zzbdb_walkz00;
 										}
 									else
 										{	/* Bdb/walk.scm 32 */
-											BgL_arg1252z00_1374 = BGl_string1502z00zzbdb_walkz00;
+											BgL_arg1254z00_1379 = BGl_string1363z00zzbdb_walkz00;
 										}
 								}
-								bgl_display_obj(BgL_arg1252z00_1374, BgL_port1228z00_1373);
+								bgl_display_obj(BgL_arg1254z00_1379, BgL_port1227z00_1378);
 							}
-							bgl_display_string(BGl_string1503z00zzbdb_walkz00,
-								BgL_port1228z00_1373);
-							bgl_display_char(((unsigned char) 10), BgL_port1228z00_1373);
+							bgl_display_string(BGl_string1364z00zzbdb_walkz00,
+								BgL_port1227z00_1378);
+							bgl_display_char(((unsigned char) 10), BgL_port1227z00_1378);
 						}
 						{	/* Bdb/walk.scm 32 */
-							obj_t BgL_list1255z00_1378;
+							obj_t BgL_list1257z00_1383;
 
-							BgL_list1255z00_1378 = MAKE_YOUNG_PAIR(BINT(-1L), BNIL);
-							BGL_TAIL return BGl_exitz00zz__errorz00(BgL_list1255z00_1378);
+							BgL_list1257z00_1383 = MAKE_YOUNG_PAIR(BINT((-1L)), BNIL);
+							BGL_TAIL return BGl_exitz00zz__errorz00(BgL_list1257z00_1383);
 						}
 					}
 				else
 					{	/* Bdb/walk.scm 32 */
-						obj_t BgL_g1108z00_1379;
+						obj_t BgL_g1108z00_1384;
 
-						BgL_g1108z00_1379 = BNIL;
+						BgL_g1108z00_1384 = BNIL;
 						{
-							obj_t BgL_hooksz00_1382;
-							obj_t BgL_hnamesz00_1383;
+							obj_t BgL_hooksz00_1387;
+							obj_t BgL_hnamesz00_1388;
 
-							BgL_hooksz00_1382 = BgL_g1108z00_1379;
-							BgL_hnamesz00_1383 = BNIL;
-						BgL_zc3z04anonymousza31256ze3z87_1384:
-							if (NULLP(BgL_hooksz00_1382))
+							BgL_hooksz00_1387 = BgL_g1108z00_1384;
+							BgL_hnamesz00_1388 = BNIL;
+						BgL_zc3z04anonymousza31258ze3z87_1389:
+							if (NULLP(BgL_hooksz00_1387))
 								{	/* Bdb/walk.scm 32 */
-									return BgL_valuez00_1371;
+									return BgL_valuez00_1376;
 								}
 							else
 								{	/* Bdb/walk.scm 32 */
-									bool_t BgL_test1543z00_1687;
+									bool_t BgL_test1398z00_1695;
 
 									{	/* Bdb/walk.scm 32 */
-										obj_t BgL_fun1276z00_1391;
+										obj_t BgL_fun1270z00_1396;
 
-										BgL_fun1276z00_1391 = CAR(((obj_t) BgL_hooksz00_1382));
-										BgL_test1543z00_1687 =
-											CBOOL(
-											(VA_PROCEDUREP(BgL_fun1276z00_1391) ? ((obj_t(*)(obj_t,
-															...))
-													PROCEDURE_ENTRY(BgL_fun1276z00_1391))
-												(BgL_fun1276z00_1391,
-													BEOA) : ((obj_t(*)(obj_t))
-													PROCEDURE_ENTRY(BgL_fun1276z00_1391))
-												(BgL_fun1276z00_1391)));
+										BgL_fun1270z00_1396 = CAR(((obj_t) BgL_hooksz00_1387));
+										BgL_test1398z00_1695 =
+											CBOOL(BGL_PROCEDURE_CALL0(BgL_fun1270z00_1396));
 									}
-									if (BgL_test1543z00_1687)
+									if (BgL_test1398z00_1695)
 										{	/* Bdb/walk.scm 32 */
-											obj_t BgL_arg1260z00_1388;
-											obj_t BgL_arg1265z00_1389;
+											obj_t BgL_arg1262z00_1393;
+											obj_t BgL_arg1266z00_1394;
 
-											BgL_arg1260z00_1388 = CDR(((obj_t) BgL_hooksz00_1382));
-											BgL_arg1265z00_1389 = CDR(((obj_t) BgL_hnamesz00_1383));
+											BgL_arg1262z00_1393 = CDR(((obj_t) BgL_hooksz00_1387));
+											BgL_arg1266z00_1394 = CDR(((obj_t) BgL_hnamesz00_1388));
 											{
-												obj_t BgL_hnamesz00_1699;
-												obj_t BgL_hooksz00_1698;
+												obj_t BgL_hnamesz00_1707;
+												obj_t BgL_hooksz00_1706;
 
-												BgL_hooksz00_1698 = BgL_arg1260z00_1388;
-												BgL_hnamesz00_1699 = BgL_arg1265z00_1389;
-												BgL_hnamesz00_1383 = BgL_hnamesz00_1699;
-												BgL_hooksz00_1382 = BgL_hooksz00_1698;
-												goto BgL_zc3z04anonymousza31256ze3z87_1384;
+												BgL_hooksz00_1706 = BgL_arg1262z00_1393;
+												BgL_hnamesz00_1707 = BgL_arg1266z00_1394;
+												BgL_hnamesz00_1388 = BgL_hnamesz00_1707;
+												BgL_hooksz00_1387 = BgL_hooksz00_1706;
+												goto BgL_zc3z04anonymousza31258ze3z87_1389;
 											}
 										}
 									else
 										{	/* Bdb/walk.scm 32 */
-											obj_t BgL_arg1275z00_1390;
+											obj_t BgL_arg1267z00_1395;
 
-											BgL_arg1275z00_1390 = CAR(((obj_t) BgL_hnamesz00_1383));
+											BgL_arg1267z00_1395 = CAR(((obj_t) BgL_hnamesz00_1388));
 											return
 												BGl_internalzd2errorzd2zztools_errorz00
 												(BGl_za2currentzd2passza2zd2zzengine_passz00,
-												BGl_string1504z00zzbdb_walkz00, BgL_arg1275z00_1390);
+												BGl_string1365z00zzbdb_walkz00, BgL_arg1267z00_1395);
 										}
 								}
 						}
@@ -547,11 +538,11 @@ extern "C"
 
 
 /* &bdb-walk! */
-	obj_t BGl_z62bdbzd2walkz12za2zzbdb_walkz00(obj_t BgL_envz00_1576,
-		obj_t BgL_globalsz00_1577)
+	obj_t BGl_z62bdbzd2walkz12za2zzbdb_walkz00(obj_t BgL_envz00_1581,
+		obj_t BgL_globalsz00_1582)
 	{
 		{	/* Bdb/walk.scm 30 */
-			return BGl_bdbzd2walkz12zc0zzbdb_walkz00(BgL_globalsz00_1577);
+			return BGl_bdbzd2walkz12zc0zzbdb_walkz00(BgL_globalsz00_1582);
 		}
 
 	}
@@ -596,26 +587,26 @@ extern "C"
 	{
 		{	/* Bdb/walk.scm 15 */
 			BGl_modulezd2initializa7ationz75zztools_speekz00(61247943L,
-				BSTRING_TO_STRING(BGl_string1505z00zzbdb_walkz00));
+				BSTRING_TO_STRING(BGl_string1366z00zzbdb_walkz00));
 			BGl_modulezd2initializa7ationz75zztools_errorz00(300504031L,
-				BSTRING_TO_STRING(BGl_string1505z00zzbdb_walkz00));
+				BSTRING_TO_STRING(BGl_string1366z00zzbdb_walkz00));
 			BGl_modulezd2initializa7ationz75zzengine_passz00(373082237L,
-				BSTRING_TO_STRING(BGl_string1505z00zzbdb_walkz00));
+				BSTRING_TO_STRING(BGl_string1366z00zzbdb_walkz00));
 			BGl_modulezd2initializa7ationz75zztools_shapez00(365925558L,
-				BSTRING_TO_STRING(BGl_string1505z00zzbdb_walkz00));
-			BGl_modulezd2initializa7ationz75zzengine_paramz00(517137079L,
-				BSTRING_TO_STRING(BGl_string1505z00zzbdb_walkz00));
+				BSTRING_TO_STRING(BGl_string1366z00zzbdb_walkz00));
+			BGl_modulezd2initializa7ationz75zzengine_paramz00(161876678L,
+				BSTRING_TO_STRING(BGl_string1366z00zzbdb_walkz00));
 			BGl_modulezd2initializa7ationz75zztype_typez00(515343395L,
-				BSTRING_TO_STRING(BGl_string1505z00zzbdb_walkz00));
+				BSTRING_TO_STRING(BGl_string1366z00zzbdb_walkz00));
 			BGl_modulezd2initializa7ationz75zzast_varz00(90839984L,
-				BSTRING_TO_STRING(BGl_string1505z00zzbdb_walkz00));
+				BSTRING_TO_STRING(BGl_string1366z00zzbdb_walkz00));
 			BGl_modulezd2initializa7ationz75zzast_nodez00(469732712L,
-				BSTRING_TO_STRING(BGl_string1505z00zzbdb_walkz00));
+				BSTRING_TO_STRING(BGl_string1366z00zzbdb_walkz00));
 			BGl_modulezd2initializa7ationz75zzast_removez00(383247627L,
-				BSTRING_TO_STRING(BGl_string1505z00zzbdb_walkz00));
+				BSTRING_TO_STRING(BGl_string1366z00zzbdb_walkz00));
 			return
 				BGl_modulezd2initializa7ationz75zzbdb_initializa7eza7(527197336L,
-				BSTRING_TO_STRING(BGl_string1505z00zzbdb_walkz00));
+				BSTRING_TO_STRING(BGl_string1366z00zzbdb_walkz00));
 		}
 
 	}
