@@ -1,9 +1,9 @@
 /*===========================================================================*/
 /*   (Cc/roots.scm)                                                          */
-/*   Bigloo (4.5b)                                                           */
-/*   Inria -- Sophia Antipolis (c)       Fri Dec 22 05:17:06 PM CET 2023     */
+/*   Bigloo (4.6a)                                                           */
+/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
 /*===========================================================================*/
-/* COMPILATION: (/home/serrano/prgm/project/bigloo/bigloo/bin/bigloo -ldopt -L/home/serrano/prgm/project/bigloo/bigloo/libbacktrace/home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b  -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Cc/roots.scm) */
+/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Cc/roots.scm) */
 /* GC selection */
 #define THE_GC BOEHM_GC
 
@@ -59,6 +59,11 @@ extern "C"
 		bool_t BgL_boundzd2checkzd2;
 		bool_t BgL_typezd2checkzd2;
 		bool_t BgL_typedzd2funcallzd2;
+		bool_t BgL_strictzd2typezd2castz00;
+		bool_t BgL_forcezd2registerzd2gczd2rootszd2;
+		bool_t BgL_stringzd2literalzd2supportz00;
+		bool_t BgL_boxedzd2fixnumszd2;
+		bool_t BgL_typedzd2closureszd2;
 	}                 *BgL_backendz00_bglt;
 
 	typedef struct BgL_typez00_bgl
@@ -73,6 +78,7 @@ extern "C"
 		obj_t BgL_parentsz00;
 		bool_t BgL_initzf3zf3;
 		bool_t BgL_magiczf3zf3;
+		obj_t BgL_nullz00;
 		obj_t BgL_z42z42;
 		obj_t BgL_aliasz00;
 		obj_t BgL_pointedzd2tozd2byz00;
@@ -125,7 +131,7 @@ extern "C"
 		obj_t BgL_libraryz00;
 		obj_t BgL_pragmaz00;
 		obj_t BgL_srcz00;
-		obj_t BgL_jvmzd2typezd2namez00;
+		obj_t BgL_qualifiedzd2typezd2namez00;
 		obj_t BgL_initz00;
 		obj_t BgL_aliasz00;
 	}                *BgL_globalz00_bglt;
@@ -134,7 +140,6 @@ extern "C"
 #endif													// BGL_CC_ROOTS_TYPE_DEFINITIONS
 #endif													// BGL_MODULE_TYPE_DEFINITIONS
 
-	static obj_t BGl_z62zc3z04anonymousza31200ze3ze5zzcc_rootsz00(obj_t, obj_t);
 	static obj_t BGl_requirezd2initializa7ationz75zzcc_rootsz00 = BUNSPEC;
 	BGL_IMPORT obj_t bgl_display_obj(obj_t, obj_t);
 	BGL_IMPORT obj_t BGl_za2classesza2z00zz__objectz00;
@@ -147,6 +152,7 @@ extern "C"
 	BGL_EXPORTED_DECL obj_t BGl_gczd2rootszd2emitz00zzcc_rootsz00(obj_t);
 	extern obj_t BGl_thezd2backendzd2zzbackend_backendz00(void);
 	BGL_IMPORT obj_t BGl_readz00zz__readerz00(obj_t, obj_t);
+	static obj_t BGl_z62zc3z04anonymousza31137ze3ze5zzcc_rootsz00(obj_t, obj_t);
 	BGL_IMPORT obj_t BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00(obj_t,
 		obj_t, obj_t);
 	static obj_t BGl_methodzd2initzd2zzcc_rootsz00(void);
@@ -194,50 +200,50 @@ extern "C"
 
 	   
 		 
-		DEFINE_STRING(BGl_string1241z00zzcc_rootsz00,
-		BgL_bgl_string1241za700za7za7c1257za7, "/* GC roots registration */\n", 28);
-	      DEFINE_STRING(BGl_string1242z00zzcc_rootsz00,
-		BgL_bgl_string1242za700za7za7c1258za7,
-		"static obj_t bgl_gc_roots_register() {\n", 39);
-	      DEFINE_STRING(BGl_string1243z00zzcc_rootsz00,
-		BgL_bgl_string1243za700za7za7c1259za7, "#if defined( BGL_GC_ROOTS )\n", 28);
-	      DEFINE_STRING(BGl_string1244z00zzcc_rootsz00,
-		BgL_bgl_string1244za700za7za7c1260za7,
-		"#define ADD_ROOT( addr ) (addr > roots_max ? roots_max = addr : (addr < roots_min ? roots_min = addr : 0))\n",
-		107);
-	      DEFINE_STRING(BGl_string1245z00zzcc_rootsz00,
-		BgL_bgl_string1245za700za7za7c1261za7,
-		"void *roots_min = (void*)ULONG_MAX, *roots_max = 0;\n", 52);
-	      DEFINE_STRING(BGl_string1246z00zzcc_rootsz00,
-		BgL_bgl_string1246za700za7za7c1262za7, "#undef ADD_ROOT\n", 16);
-	      DEFINE_STRING(BGl_string1247z00zzcc_rootsz00,
-		BgL_bgl_string1247za700za7za7c1263za7,
-		"if( roots_max > 0 ) GC_add_roots( roots_min, ((void **)roots_max) + 1 );\n",
-		73);
-	      DEFINE_STRING(BGl_string1248z00zzcc_rootsz00,
-		BgL_bgl_string1248za700za7za7c1264za7, "#endif\n", 7);
-	      DEFINE_STRING(BGl_string1249z00zzcc_rootsz00,
-		BgL_bgl_string1249za700za7za7c1265za7, "return BUNSPEC;\n", 16);
-	      DEFINE_STRING(BGl_string1250z00zzcc_rootsz00,
-		BgL_bgl_string1250za700za7za7c1266za7, "}\n\n", 3);
-	      DEFINE_STRING(BGl_string1251z00zzcc_rootsz00,
-		BgL_bgl_string1251za700za7za7c1267za7, "ADD_ROOT( (void *)(&", 20);
-	      DEFINE_STRING(BGl_string1252z00zzcc_rootsz00,
-		BgL_bgl_string1252za700za7za7c1268za7, ") );\n", 5);
-	      DEFINE_STRING(BGl_string1253z00zzcc_rootsz00,
-		BgL_bgl_string1253za700za7za7c1269za7, "cc_roots", 8);
-	      DEFINE_STRING(BGl_string1254z00zzcc_rootsz00,
-		BgL_bgl_string1254za700za7za7c1270za7,
-		"unit gc-roots begin (begin (pragma::obj \"bgl_gc_roots_register()\")) ",
-		68);
-	      DEFINE_EXPORT_BGL_PROCEDURE(BGl_gczd2rootszd2emitzd2envzd2zzcc_rootsz00,
-		BgL_bgl_za762gcza7d2rootsza7d21271za7,
+		DEFINE_EXPORT_BGL_PROCEDURE(BGl_gczd2rootszd2emitzd2envzd2zzcc_rootsz00,
+		BgL_bgl_za762gcza7d2rootsza7d21227za7,
 		BGl_z62gczd2rootszd2emitz62zzcc_rootsz00, 0L, BUNSPEC, 1);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_makezd2gczd2rootszd2unitzd2envz00zzcc_rootsz00,
-		BgL_bgl_za762makeza7d2gcza7d2r1272za7,
+		BgL_bgl_za762makeza7d2gcza7d2r1228za7,
 		BGl_z62makezd2gczd2rootszd2unitzb0zzcc_rootsz00, 0L, BUNSPEC, 0);
+	      DEFINE_STRING(BGl_string1211z00zzcc_rootsz00,
+		BgL_bgl_string1211za700za7za7c1229za7, "/* GC roots registration */\n", 28);
+	      DEFINE_STRING(BGl_string1212z00zzcc_rootsz00,
+		BgL_bgl_string1212za700za7za7c1230za7,
+		"static obj_t bgl_gc_roots_register() {\n", 39);
+	      DEFINE_STRING(BGl_string1213z00zzcc_rootsz00,
+		BgL_bgl_string1213za700za7za7c1231za7, "#if defined( BGL_GC_ROOTS )\n", 28);
+	      DEFINE_STRING(BGl_string1214z00zzcc_rootsz00,
+		BgL_bgl_string1214za700za7za7c1232za7,
+		"#define ADD_ROOT( addr ) (addr > roots_max ? roots_max = addr : (addr < roots_min ? roots_min = addr : 0))\n",
+		107);
+	      DEFINE_STRING(BGl_string1215z00zzcc_rootsz00,
+		BgL_bgl_string1215za700za7za7c1233za7,
+		"void *roots_min = (void*)ULONG_MAX, *roots_max = 0;\n", 52);
+	      DEFINE_STRING(BGl_string1216z00zzcc_rootsz00,
+		BgL_bgl_string1216za700za7za7c1234za7, "#undef ADD_ROOT\n", 16);
+	      DEFINE_STRING(BGl_string1217z00zzcc_rootsz00,
+		BgL_bgl_string1217za700za7za7c1235za7,
+		"if( roots_max > 0 ) GC_add_roots( roots_min, ((void **)roots_max) + 1 );\n",
+		73);
+	      DEFINE_STRING(BGl_string1218z00zzcc_rootsz00,
+		BgL_bgl_string1218za700za7za7c1236za7, "#endif\n", 7);
+	      DEFINE_STRING(BGl_string1219z00zzcc_rootsz00,
+		BgL_bgl_string1219za700za7za7c1237za7, "return BUNSPEC;\n", 16);
+	      DEFINE_STRING(BGl_string1220z00zzcc_rootsz00,
+		BgL_bgl_string1220za700za7za7c1238za7, "}\n\n", 3);
+	      DEFINE_STRING(BGl_string1221z00zzcc_rootsz00,
+		BgL_bgl_string1221za700za7za7c1239za7, "ADD_ROOT( (void *)(&", 20);
+	      DEFINE_STRING(BGl_string1222z00zzcc_rootsz00,
+		BgL_bgl_string1222za700za7za7c1240za7, ") );\n", 5);
+	      DEFINE_STRING(BGl_string1223z00zzcc_rootsz00,
+		BgL_bgl_string1223za700za7za7c1241za7, "cc_roots", 8);
+	      DEFINE_STRING(BGl_string1224z00zzcc_rootsz00,
+		BgL_bgl_string1224za700za7za7c1242za7,
+		"unit gc-roots begin (begin (pragma::obj :srfi bigloo-c \"bgl_gc_roots_register()\")) ",
+		83);
 
 /* GC roots registration */
 	static obj_t bgl_gc_roots_register()
@@ -257,7 +263,7 @@ extern "C"
 
 /* module-initialization */
 	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zzcc_rootsz00(long
-		BgL_checksumz00_833, char *BgL_fromz00_834)
+		BgL_checksumz00_796, char *BgL_fromz00_797)
 	{
 		{
 			if (CBOOL(BGl_requirezd2initializa7ationz75zzcc_rootsz00))
@@ -306,70 +312,70 @@ extern "C"
 	{
 		{	/* Cc/roots.scm 15 */
 			{	/* Cc/roots.scm 15 */
-				obj_t BgL_cportz00_822;
+				obj_t BgL_cportz00_785;
 
 				{	/* Cc/roots.scm 15 */
-					obj_t BgL_stringz00_829;
+					obj_t BgL_stringz00_792;
 
-					BgL_stringz00_829 = BGl_string1254z00zzcc_rootsz00;
+					BgL_stringz00_792 = BGl_string1224z00zzcc_rootsz00;
 					{	/* Cc/roots.scm 15 */
-						obj_t BgL_startz00_830;
+						obj_t BgL_startz00_793;
 
-						BgL_startz00_830 = BINT(0L);
+						BgL_startz00_793 = BINT(0L);
 						{	/* Cc/roots.scm 15 */
-							obj_t BgL_endz00_831;
+							obj_t BgL_endz00_794;
 
-							BgL_endz00_831 = BINT(STRING_LENGTH(((obj_t) BgL_stringz00_829)));
+							BgL_endz00_794 = BINT(STRING_LENGTH(((obj_t) BgL_stringz00_792)));
 							{	/* Cc/roots.scm 15 */
 
-								BgL_cportz00_822 =
+								BgL_cportz00_785 =
 									BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00
-									(BgL_stringz00_829, BgL_startz00_830, BgL_endz00_831);
+									(BgL_stringz00_792, BgL_startz00_793, BgL_endz00_794);
 				}}}}
 				{
-					long BgL_iz00_823;
+					long BgL_iz00_786;
 
-					BgL_iz00_823 = 3L;
-				BgL_loopz00_824:
-					if ((BgL_iz00_823 == -1L))
+					BgL_iz00_786 = 3L;
+				BgL_loopz00_787:
+					if ((BgL_iz00_786 == (-1L)))
 						{	/* Cc/roots.scm 15 */
 							return BUNSPEC;
 						}
 					else
 						{	/* Cc/roots.scm 15 */
 							{	/* Cc/roots.scm 15 */
-								obj_t BgL_arg1256z00_825;
+								obj_t BgL_arg1226z00_788;
 
 								{	/* Cc/roots.scm 15 */
 
 									{	/* Cc/roots.scm 15 */
-										obj_t BgL_locationz00_827;
+										obj_t BgL_locationz00_790;
 
-										BgL_locationz00_827 = BBOOL(((bool_t) 0));
+										BgL_locationz00_790 = BBOOL(((bool_t) 0));
 										{	/* Cc/roots.scm 15 */
 
-											BgL_arg1256z00_825 =
-												BGl_readz00zz__readerz00(BgL_cportz00_822,
-												BgL_locationz00_827);
+											BgL_arg1226z00_788 =
+												BGl_readz00zz__readerz00(BgL_cportz00_785,
+												BgL_locationz00_790);
 										}
 									}
 								}
 								{	/* Cc/roots.scm 15 */
-									int BgL_tmpz00_862;
+									int BgL_tmpz00_825;
 
-									BgL_tmpz00_862 = (int) (BgL_iz00_823);
-									CNST_TABLE_SET(BgL_tmpz00_862, BgL_arg1256z00_825);
+									BgL_tmpz00_825 = (int) (BgL_iz00_786);
+									CNST_TABLE_SET(BgL_tmpz00_825, BgL_arg1226z00_788);
 							}}
 							{	/* Cc/roots.scm 15 */
-								int BgL_auxz00_828;
+								int BgL_auxz00_791;
 
-								BgL_auxz00_828 = (int) ((BgL_iz00_823 - 1L));
+								BgL_auxz00_791 = (int) ((BgL_iz00_786 - 1L));
 								{
-									long BgL_iz00_867;
+									long BgL_iz00_830;
 
-									BgL_iz00_867 = (long) (BgL_auxz00_828);
-									BgL_iz00_823 = BgL_iz00_867;
-									goto BgL_loopz00_824;
+									BgL_iz00_830 = (long) (BgL_auxz00_791);
+									BgL_iz00_786 = BgL_iz00_830;
+									goto BgL_loopz00_787;
 								}
 							}
 						}
@@ -408,74 +414,76 @@ extern "C"
 	{
 		{	/* Cc/roots.scm 32 */
 			{	/* Cc/roots.scm 35 */
-				obj_t BgL_arg1185z00_579;
+				obj_t BgL_arg1127z00_596;
 
 				{	/* Cc/roots.scm 35 */
-					bool_t BgL_test1280z00_870;
+					bool_t BgL_test1246z00_833;
 
 					{	/* Cc/roots.scm 35 */
-						obj_t BgL_arg1197z00_583;
+						obj_t BgL_arg1134z00_600;
 
-						BgL_arg1197z00_583 = BGl_thezd2backendzd2zzbackend_backendz00();
-						BgL_test1280z00_870 =
+						BgL_arg1134z00_600 = BGl_thezd2backendzd2zzbackend_backendz00();
+						BgL_test1246z00_833 =
 							(((BgL_backendz00_bglt) COBJECT(
-									((BgL_backendz00_bglt) BgL_arg1197z00_583)))->
+									((BgL_backendz00_bglt) BgL_arg1134z00_600)))->
 							BgL_pragmazd2supportzd2);
 					}
-					if (BgL_test1280z00_870)
+					if (BgL_test1246z00_833)
 						{	/* Cc/roots.scm 35 */
-							BgL_arg1185z00_579 = CNST_TABLE_REF(0L);
+							BgL_arg1127z00_596 = ((obj_t) CNST_TABLE_REF(0));
 						}
 					else
 						{	/* Cc/roots.scm 37 */
-							obj_t BgL_arg1196z00_582;
+							obj_t BgL_arg1131z00_599;
 
-							BgL_arg1196z00_582 = MAKE_YOUNG_PAIR(BUNSPEC, BNIL);
-							BgL_arg1185z00_579 =
-								MAKE_YOUNG_PAIR(CNST_TABLE_REF(1L), BgL_arg1196z00_582);
+							BgL_arg1131z00_599 = MAKE_YOUNG_PAIR(BUNSPEC, BNIL);
+							BgL_arg1127z00_596 =
+								MAKE_YOUNG_PAIR(
+								((obj_t) CNST_TABLE_REF(1)), BgL_arg1131z00_599);
 						}
 				}
 				{	/* Cc/roots.scm 33 */
-					obj_t BgL_idz00_718;
+					obj_t BgL_idz00_676;
 
-					BgL_idz00_718 = CNST_TABLE_REF(2L);
+					BgL_idz00_676 = ((obj_t) CNST_TABLE_REF(2));
 					{	/* Cc/roots.scm 33 */
-						obj_t BgL_newz00_719;
+						obj_t BgL_newz00_677;
 
-						BgL_newz00_719 = create_struct(CNST_TABLE_REF(3L), (int) (5L));
+						BgL_newz00_677 =
+							create_struct(((obj_t) CNST_TABLE_REF(3)), (int) (5L));
 						{	/* Cc/roots.scm 33 */
-							int BgL_tmpz00_882;
+							int BgL_tmpz00_849;
 
-							BgL_tmpz00_882 = (int) (4L);
-							STRUCT_SET(BgL_newz00_719, BgL_tmpz00_882, BFALSE);
+							BgL_tmpz00_849 = (int) (4L);
+							STRUCT_SET(BgL_newz00_677, BgL_tmpz00_849, BFALSE);
 						}
 						{	/* Cc/roots.scm 33 */
-							int BgL_tmpz00_885;
+							int BgL_tmpz00_852;
 
-							BgL_tmpz00_885 = (int) (3L);
-							STRUCT_SET(BgL_newz00_719, BgL_tmpz00_885, BTRUE);
+							BgL_tmpz00_852 = (int) (3L);
+							STRUCT_SET(BgL_newz00_677, BgL_tmpz00_852, BTRUE);
 						}
 						{	/* Cc/roots.scm 33 */
-							int BgL_tmpz00_888;
+							int BgL_tmpz00_855;
 
-							BgL_tmpz00_888 = (int) (2L);
-							STRUCT_SET(BgL_newz00_719, BgL_tmpz00_888, BgL_arg1185z00_579);
+							BgL_tmpz00_855 = (int) (2L);
+							STRUCT_SET(BgL_newz00_677, BgL_tmpz00_855, BgL_arg1127z00_596);
 						}
 						{	/* Cc/roots.scm 33 */
-							obj_t BgL_auxz00_893;
-							int BgL_tmpz00_891;
+							obj_t BgL_auxz00_860;
+							int BgL_tmpz00_858;
 
-							BgL_auxz00_893 = BINT(-1L);
-							BgL_tmpz00_891 = (int) (1L);
-							STRUCT_SET(BgL_newz00_719, BgL_tmpz00_891, BgL_auxz00_893);
+							BgL_auxz00_860 = BINT((-1L));
+							BgL_tmpz00_858 = (int) (1L);
+							STRUCT_SET(BgL_newz00_677, BgL_tmpz00_858, BgL_auxz00_860);
 						}
 						{	/* Cc/roots.scm 33 */
-							int BgL_tmpz00_896;
+							int BgL_tmpz00_863;
 
-							BgL_tmpz00_896 = (int) (0L);
-							STRUCT_SET(BgL_newz00_719, BgL_tmpz00_896, BgL_idz00_718);
+							BgL_tmpz00_863 = (int) (0L);
+							STRUCT_SET(BgL_newz00_677, BgL_tmpz00_863, BgL_idz00_676);
 						}
-						return BgL_newz00_719;
+						return BgL_newz00_677;
 					}
 				}
 			}
@@ -486,7 +494,7 @@ extern "C"
 
 
 /* &make-gc-roots-unit */
-	obj_t BGl_z62makezd2gczd2rootszd2unitzb0zzcc_rootsz00(obj_t BgL_envz00_814)
+	obj_t BGl_z62makezd2gczd2rootszd2unitzb0zzcc_rootsz00(obj_t BgL_envz00_777)
 	{
 		{	/* Cc/roots.scm 32 */
 			return BGl_makezd2gczd2rootszd2unitzd2zzcc_rootsz00();
@@ -501,27 +509,27 @@ extern "C"
 		BgL_portz00_25)
 	{
 		{	/* Cc/roots.scm 44 */
-			bgl_display_string(BGl_string1241z00zzcc_rootsz00, BgL_portz00_25);
-			bgl_display_string(BGl_string1242z00zzcc_rootsz00, BgL_portz00_25);
-			bgl_display_string(BGl_string1243z00zzcc_rootsz00, BgL_portz00_25);
-			bgl_display_string(BGl_string1244z00zzcc_rootsz00, BgL_portz00_25);
-			bgl_display_string(BGl_string1245z00zzcc_rootsz00, BgL_portz00_25);
+			bgl_display_string(BGl_string1211z00zzcc_rootsz00, BgL_portz00_25);
+			bgl_display_string(BGl_string1212z00zzcc_rootsz00, BgL_portz00_25);
+			bgl_display_string(BGl_string1213z00zzcc_rootsz00, BgL_portz00_25);
+			bgl_display_string(BGl_string1214z00zzcc_rootsz00, BgL_portz00_25);
+			bgl_display_string(BGl_string1215z00zzcc_rootsz00, BgL_portz00_25);
 			{	/* Cc/roots.scm 52 */
-				obj_t BgL_zc3z04anonymousza31200ze3z87_815;
+				obj_t BgL_zc3z04anonymousza31137ze3z87_778;
 
-				BgL_zc3z04anonymousza31200ze3z87_815 =
-					MAKE_FX_PROCEDURE(BGl_z62zc3z04anonymousza31200ze3ze5zzcc_rootsz00,
+				BgL_zc3z04anonymousza31137ze3z87_778 =
+					MAKE_FX_PROCEDURE(BGl_z62zc3z04anonymousza31137ze3ze5zzcc_rootsz00,
 					(int) (1L), (int) (1L));
-				PROCEDURE_SET(BgL_zc3z04anonymousza31200ze3z87_815,
+				PROCEDURE_SET(BgL_zc3z04anonymousza31137ze3z87_778,
 					(int) (0L), BgL_portz00_25);
 				BGl_forzd2eachzd2globalz12z12zzast_envz00
-					(BgL_zc3z04anonymousza31200ze3z87_815, BNIL);
+					(BgL_zc3z04anonymousza31137ze3z87_778, BNIL);
 			}
-			bgl_display_string(BGl_string1246z00zzcc_rootsz00, BgL_portz00_25);
-			bgl_display_string(BGl_string1247z00zzcc_rootsz00, BgL_portz00_25);
-			bgl_display_string(BGl_string1248z00zzcc_rootsz00, BgL_portz00_25);
-			bgl_display_string(BGl_string1249z00zzcc_rootsz00, BgL_portz00_25);
-			return bgl_display_string(BGl_string1250z00zzcc_rootsz00, BgL_portz00_25);
+			bgl_display_string(BGl_string1216z00zzcc_rootsz00, BgL_portz00_25);
+			bgl_display_string(BGl_string1217z00zzcc_rootsz00, BgL_portz00_25);
+			bgl_display_string(BGl_string1218z00zzcc_rootsz00, BgL_portz00_25);
+			bgl_display_string(BGl_string1219z00zzcc_rootsz00, BgL_portz00_25);
+			return bgl_display_string(BGl_string1220z00zzcc_rootsz00, BgL_portz00_25);
 		}
 
 	}
@@ -529,31 +537,31 @@ extern "C"
 
 
 /* &gc-roots-emit */
-	obj_t BGl_z62gczd2rootszd2emitz62zzcc_rootsz00(obj_t BgL_envz00_816,
-		obj_t BgL_portz00_817)
+	obj_t BGl_z62gczd2rootszd2emitz62zzcc_rootsz00(obj_t BgL_envz00_779,
+		obj_t BgL_portz00_780)
 	{
 		{	/* Cc/roots.scm 44 */
-			return BGl_gczd2rootszd2emitz00zzcc_rootsz00(BgL_portz00_817);
+			return BGl_gczd2rootszd2emitz00zzcc_rootsz00(BgL_portz00_780);
 		}
 
 	}
 
 
 
-/* &<@anonymous:1200> */
-	obj_t BGl_z62zc3z04anonymousza31200ze3ze5zzcc_rootsz00(obj_t BgL_envz00_818,
-		obj_t BgL_globalz00_820)
+/* &<@anonymous:1137> */
+	obj_t BGl_z62zc3z04anonymousza31137ze3ze5zzcc_rootsz00(obj_t BgL_envz00_781,
+		obj_t BgL_globalz00_783)
 	{
 		{	/* Cc/roots.scm 51 */
 			{	/* Cc/roots.scm 52 */
-				obj_t BgL_portz00_819;
+				obj_t BgL_portz00_782;
 
-				BgL_portz00_819 = ((obj_t) PROCEDURE_REF(BgL_envz00_818, (int) (0L)));
-				if (BGl_iszd2localzd2gczd2rootzf3z21zzcc_rootsz00(BgL_globalz00_820))
+				BgL_portz00_782 = ((obj_t) PROCEDURE_REF(BgL_envz00_781, (int) (0L)));
+				if (BGl_iszd2localzd2gczd2rootzf3z21zzcc_rootsz00(BgL_globalz00_783))
 					{	/* Cc/roots.scm 52 */
 						return
 							BGl_emitzd2gczd2registrationz00zzcc_rootsz00(
-							((BgL_variablez00_bglt) BgL_globalz00_820), BgL_portz00_819);
+							((BgL_variablez00_bglt) BgL_globalz00_783), BgL_portz00_782);
 					}
 				else
 					{	/* Cc/roots.scm 52 */
@@ -571,99 +579,111 @@ extern "C"
 	{
 		{	/* Cc/roots.scm 63 */
 			{	/* Cc/roots.scm 64 */
-				bool_t BgL_test1282z00_924;
+				bool_t BgL_test1248z00_891;
 
 				{	/* Cc/roots.scm 64 */
-					BgL_valuez00_bglt BgL_arg1214z00_601;
+					BgL_valuez00_bglt BgL_arg1157z00_618;
 
-					BgL_arg1214z00_601 =
+					BgL_arg1157z00_618 =
 						(((BgL_variablez00_bglt) COBJECT(
 								((BgL_variablez00_bglt)
 									((BgL_globalz00_bglt) BgL_globalz00_26))))->BgL_valuez00);
 					{	/* Cc/roots.scm 64 */
-						obj_t BgL_classz00_746;
+						obj_t BgL_classz00_704;
 
-						BgL_classz00_746 = BGl_svarz00zzast_varz00;
+						BgL_classz00_704 = BGl_svarz00zzast_varz00;
 						{	/* Cc/roots.scm 64 */
-							BgL_objectz00_bglt BgL_arg1801z00_748;
+							BgL_objectz00_bglt BgL_arg1858z00_706;
 
 							{	/* Cc/roots.scm 64 */
-								obj_t BgL_tmpz00_928;
+								obj_t BgL_tmpz00_895;
 
-								BgL_tmpz00_928 =
-									((obj_t) ((BgL_objectz00_bglt) BgL_arg1214z00_601));
-								BgL_arg1801z00_748 = (BgL_objectz00_bglt) (BgL_tmpz00_928);
+								BgL_tmpz00_895 =
+									((obj_t) ((BgL_objectz00_bglt) BgL_arg1157z00_618));
+								BgL_arg1858z00_706 = (BgL_objectz00_bglt) (BgL_tmpz00_895);
 							}
 							if (BGL_CONDEXPAND_ISA_ARCH64())
 								{	/* Cc/roots.scm 64 */
-									long BgL_idxz00_754;
+									long BgL_idxz00_712;
 
-									BgL_idxz00_754 =
-										BGL_OBJECT_INHERITANCE_NUM(BgL_arg1801z00_748);
-									BgL_test1282z00_924 =
+									BgL_idxz00_712 =
+										BGL_OBJECT_INHERITANCE_NUM(BgL_arg1858z00_706);
+									BgL_test1248z00_891 =
 										(VECTOR_REF(BGl_za2inheritancesza2z00zz__objectz00,
-											(BgL_idxz00_754 + 2L)) == BgL_classz00_746);
+											(BgL_idxz00_712 + 2L)) == BgL_classz00_704);
 								}
 							else
 								{	/* Cc/roots.scm 64 */
-									bool_t BgL_res1239z00_776;
+									bool_t BgL_res1209z00_737;
 
 									{	/* Cc/roots.scm 64 */
-										obj_t BgL_oclassz00_762;
+										obj_t BgL_oclassz00_720;
 
 										{	/* Cc/roots.scm 64 */
-											long BgL_arg1808z00_768;
+											obj_t BgL_arg1866z00_728;
+											long BgL_arg1867z00_729;
 
+											BgL_arg1866z00_728 = (BGl_za2classesza2z00zz__objectz00);
 											{	/* Cc/roots.scm 64 */
-												long BgL_arg1809z00_769;
+												long BgL_arg1869z00_730;
 
-												BgL_arg1809z00_769 =
-													BGL_OBJECT_CLASS_NUM(BgL_arg1801z00_748);
-												BgL_arg1808z00_768 = (BgL_arg1809z00_769 - OBJECT_TYPE);
+												BgL_arg1869z00_730 =
+													BGL_OBJECT_CLASS_NUM(BgL_arg1858z00_706);
+												BgL_arg1867z00_729 = (BgL_arg1869z00_730 - OBJECT_TYPE);
 											}
-											BgL_oclassz00_762 =
-												VECTOR_REF(BGl_za2classesza2z00zz__objectz00,
-												BgL_arg1808z00_768);
+											BgL_oclassz00_720 =
+												VECTOR_REF(BgL_arg1866z00_728, BgL_arg1867z00_729);
 										}
 										{	/* Cc/roots.scm 64 */
-											bool_t BgL__ortest_1115z00_763;
+											bool_t BgL__ortest_1115z00_721;
 
-											BgL__ortest_1115z00_763 =
-												(BgL_classz00_746 == BgL_oclassz00_762);
-											if (BgL__ortest_1115z00_763)
+											BgL__ortest_1115z00_721 =
+												(BgL_classz00_704 == BgL_oclassz00_720);
+											if (BgL__ortest_1115z00_721)
 												{	/* Cc/roots.scm 64 */
-													BgL_res1239z00_776 = BgL__ortest_1115z00_763;
+													BgL_res1209z00_737 = BgL__ortest_1115z00_721;
 												}
 											else
 												{	/* Cc/roots.scm 64 */
-													long BgL_odepthz00_764;
+													long BgL_odepthz00_722;
 
-													BgL_odepthz00_764 =
-														BGL_CLASS_DEPTH(BgL_oclassz00_762);
-													if ((2L < BgL_odepthz00_764))
+													{	/* Cc/roots.scm 64 */
+														obj_t BgL_arg1855z00_723;
+
+														BgL_arg1855z00_723 = (BgL_oclassz00_720);
+														BgL_odepthz00_722 =
+															BGL_CLASS_DEPTH(BgL_arg1855z00_723);
+													}
+													if ((2L < BgL_odepthz00_722))
 														{	/* Cc/roots.scm 64 */
-															obj_t BgL_arg1797z00_766;
+															obj_t BgL_arg1853z00_725;
 
-															BgL_arg1797z00_766 =
-																BGL_CLASS_ANCESTORS_REF(BgL_oclassz00_762, 2L);
-															BgL_res1239z00_776 =
-																(BgL_arg1797z00_766 == BgL_classz00_746);
+															{	/* Cc/roots.scm 64 */
+																obj_t BgL_arg1854z00_726;
+
+																BgL_arg1854z00_726 = (BgL_oclassz00_720);
+																BgL_arg1853z00_725 =
+																	BGL_CLASS_ANCESTORS_REF(BgL_arg1854z00_726,
+																	2L);
+															}
+															BgL_res1209z00_737 =
+																(BgL_arg1853z00_725 == BgL_classz00_704);
 														}
 													else
 														{	/* Cc/roots.scm 64 */
-															BgL_res1239z00_776 = ((bool_t) 0);
+															BgL_res1209z00_737 = ((bool_t) 0);
 														}
 												}
 										}
 									}
-									BgL_test1282z00_924 = BgL_res1239z00_776;
+									BgL_test1248z00_891 = BgL_res1209z00_737;
 								}
 						}
 					}
 				}
-				if (BgL_test1282z00_924)
+				if (BgL_test1248z00_891)
 					{	/* Cc/roots.scm 66 */
-						bool_t BgL_test1286z00_948;
+						bool_t BgL_test1252z00_918;
 
 						if (
 							(((BgL_variablez00_bglt) COBJECT(
@@ -675,33 +695,33 @@ extern "C"
 													((BgL_variablez00_bglt) BgL_globalz00_26)))->
 											BgL_namez00)))
 									{	/* Cc/roots.scm 66 */
-										BgL_typez00_bglt BgL_arg1213z00_600;
+										BgL_typez00_bglt BgL_arg1156z00_617;
 
-										BgL_arg1213z00_600 =
+										BgL_arg1156z00_617 =
 											(((BgL_variablez00_bglt) COBJECT(
 													((BgL_variablez00_bglt) BgL_globalz00_26)))->
 											BgL_typez00);
-										BgL_test1286z00_948 =
-											BGl_bigloozd2typezf3z21zztype_typez00(BgL_arg1213z00_600);
+										BgL_test1252z00_918 =
+											BGl_bigloozd2typezf3z21zztype_typez00(BgL_arg1156z00_617);
 									}
 								else
 									{	/* Cc/roots.scm 66 */
-										BgL_test1286z00_948 = ((bool_t) 0);
+										BgL_test1252z00_918 = ((bool_t) 0);
 									}
 							}
 						else
 							{	/* Cc/roots.scm 66 */
-								BgL_test1286z00_948 = ((bool_t) 0);
+								BgL_test1252z00_918 = ((bool_t) 0);
 							}
-						if (BgL_test1286z00_948)
+						if (BgL_test1252z00_918)
 							{	/* Cc/roots.scm 67 */
-								obj_t BgL_arg1211z00_597;
+								obj_t BgL_arg1153z00_614;
 
-								BgL_arg1211z00_597 =
+								BgL_arg1153z00_614 =
 									(((BgL_globalz00_bglt) COBJECT(
 											((BgL_globalz00_bglt) BgL_globalz00_26)))->BgL_modulez00);
 								return
-									(BgL_arg1211z00_597 == BGl_za2moduleza2z00zzmodule_modulez00);
+									(BgL_arg1153z00_614 == BGl_za2moduleza2z00zzmodule_modulez00);
 							}
 						else
 							{	/* Cc/roots.scm 66 */
@@ -724,11 +744,11 @@ extern "C"
 		BgL_globalz00_27, obj_t BgL_portz00_28)
 	{
 		{	/* Cc/roots.scm 72 */
-			bgl_display_string(BGl_string1251z00zzcc_rootsz00, BgL_portz00_28);
+			bgl_display_string(BGl_string1221z00zzcc_rootsz00, BgL_portz00_28);
 			bgl_display_obj(
 				(((BgL_variablez00_bglt) COBJECT(BgL_globalz00_27))->BgL_namez00),
 				BgL_portz00_28);
-			return bgl_display_string(BGl_string1252z00zzcc_rootsz00, BgL_portz00_28);
+			return bgl_display_string(BGl_string1222z00zzcc_rootsz00, BgL_portz00_28);
 		}
 
 	}
@@ -773,18 +793,18 @@ extern "C"
 	{
 		{	/* Cc/roots.scm 15 */
 			BGl_modulezd2initializa7ationz75zzbackend_backendz00(216206620L,
-				BSTRING_TO_STRING(BGl_string1253z00zzcc_rootsz00));
+				BSTRING_TO_STRING(BGl_string1223z00zzcc_rootsz00));
 			BGl_modulezd2initializa7ationz75zzmodule_modulez00(158397907L,
-				BSTRING_TO_STRING(BGl_string1253z00zzcc_rootsz00));
+				BSTRING_TO_STRING(BGl_string1223z00zzcc_rootsz00));
 			BGl_modulezd2initializa7ationz75zztools_shapez00(365925558L,
-				BSTRING_TO_STRING(BGl_string1253z00zzcc_rootsz00));
+				BSTRING_TO_STRING(BGl_string1223z00zzcc_rootsz00));
 			BGl_modulezd2initializa7ationz75zztype_typez00(515343395L,
-				BSTRING_TO_STRING(BGl_string1253z00zzcc_rootsz00));
+				BSTRING_TO_STRING(BGl_string1223z00zzcc_rootsz00));
 			BGl_modulezd2initializa7ationz75zzast_varz00(90839984L,
-				BSTRING_TO_STRING(BGl_string1253z00zzcc_rootsz00));
+				BSTRING_TO_STRING(BGl_string1223z00zzcc_rootsz00));
 			return
 				BGl_modulezd2initializa7ationz75zzast_envz00(146730773L,
-				BSTRING_TO_STRING(BGl_string1253z00zzcc_rootsz00));
+				BSTRING_TO_STRING(BGl_string1223z00zzcc_rootsz00));
 		}
 
 	}
