@@ -1,9 +1,9 @@
 /*===========================================================================*/
 /*   (Effect/effect.scm)                                                     */
-/*   Bigloo (4.5b)                                                           */
-/*   Inria -- Sophia Antipolis (c)       Fri Dec 22 05:17:06 PM CET 2023     */
+/*   Bigloo (4.6a)                                                           */
+/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
 /*===========================================================================*/
-/* COMPILATION: (/home/serrano/prgm/project/bigloo/bigloo/bin/bigloo -ldopt -L/home/serrano/prgm/project/bigloo/bigloo/libbacktrace/home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b  -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Effect/effect.scm) */
+/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Effect/effect.scm) */
 /* GC selection */
 #define THE_GC BOEHM_GC
 
@@ -38,6 +38,7 @@ extern "C"
 		obj_t BgL_parentsz00;
 		bool_t BgL_initzf3zf3;
 		bool_t BgL_magiczf3zf3;
+		obj_t BgL_nullz00;
 		obj_t BgL_z42z42;
 		obj_t BgL_aliasz00;
 		obj_t BgL_pointedzd2tozd2byz00;
@@ -244,75 +245,75 @@ extern "C"
 
 	   
 		 
-		DEFINE_STRING(BGl_string1552z00zzeffect_effectz00,
-		BgL_bgl_string1552za700za7za7e1576za7, "side-effect?1223", 16);
-	      DEFINE_STRING(BGl_string1553z00zzeffect_effectz00,
-		BgL_bgl_string1553za700za7za7e1577za7, "No method for this object", 25);
-	      DEFINE_STRING(BGl_string1555z00zzeffect_effectz00,
-		BgL_bgl_string1555za700za7za7e1578za7, "side-effect?", 12);
-	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1551z00zzeffect_effectz00,
-		BgL_bgl_za762sideza7d2effect1579z00,
+		DEFINE_STRING(BGl_string1372z00zzeffect_effectz00,
+		BgL_bgl_string1372za700za7za7e1401za7, "side-effect?1223", 16);
+	      DEFINE_STRING(BGl_string1373z00zzeffect_effectz00,
+		BgL_bgl_string1373za700za7za7e1402za7, "No method for this object", 25);
+	      DEFINE_STRING(BGl_string1375z00zzeffect_effectz00,
+		BgL_bgl_string1375za700za7za7e1403za7, "side-effect?", 12);
+	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1371z00zzeffect_effectz00,
+		BgL_bgl_za762sideza7d2effect1404z00,
 		BGl_z62sidezd2effectzf31223z43zzeffect_effectz00, 0L, BUNSPEC, 1);
-	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1554z00zzeffect_effectz00,
-		BgL_bgl_za762sideza7d2effect1580z00,
+	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1374z00zzeffect_effectz00,
+		BgL_bgl_za762sideza7d2effect1405z00,
 		BGl_z62sidezd2effectzf3zd2node1226z91zzeffect_effectz00, 0L, BUNSPEC, 1);
-	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1556z00zzeffect_effectz00,
-		BgL_bgl_za762sideza7d2effect1581z00,
+	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1376z00zzeffect_effectz00,
+		BgL_bgl_za762sideza7d2effect1406z00,
 		BGl_z62sidezd2effectzf3zd2patch1228z91zzeffect_effectz00, 0L, BUNSPEC, 1);
-	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1557z00zzeffect_effectz00,
-		BgL_bgl_za762sideza7d2effect1582z00,
+	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1377z00zzeffect_effectz00,
+		BgL_bgl_za762sideza7d2effect1407z00,
 		BGl_z62sidezd2effectzf3zd2var1230z91zzeffect_effectz00, 0L, BUNSPEC, 1);
-	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1558z00zzeffect_effectz00,
-		BgL_bgl_za762sideza7d2effect1583z00,
+	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1378z00zzeffect_effectz00,
+		BgL_bgl_za762sideza7d2effect1408z00,
 		BGl_z62sidezd2effectzf3zd2nodezf2ef1232z63zzeffect_effectz00, 0L, BUNSPEC,
 		1);
-	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1559z00zzeffect_effectz00,
-		BgL_bgl_za762sideza7d2effect1584z00,
+	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1379z00zzeffect_effectz00,
+		BgL_bgl_za762sideza7d2effect1409z00,
 		BGl_z62sidezd2effectzf3zd2app1234z91zzeffect_effectz00, 0L, BUNSPEC, 1);
-	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1560z00zzeffect_effectz00,
-		BgL_bgl_za762sideza7d2effect1585z00,
+	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1380z00zzeffect_effectz00,
+		BgL_bgl_za762sideza7d2effect1410z00,
 		BGl_z62sidezd2effectzf3zd2setq1236z91zzeffect_effectz00, 0L, BUNSPEC, 1);
-	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1561z00zzeffect_effectz00,
-		BgL_bgl_za762sideza7d2effect1586z00,
+	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1381z00zzeffect_effectz00,
+		BgL_bgl_za762sideza7d2effect1411z00,
 		BGl_z62sidezd2effectzf3zd2fail1238z91zzeffect_effectz00, 0L, BUNSPEC, 1);
-	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1562z00zzeffect_effectz00,
-		BgL_bgl_za762sideza7d2effect1587z00,
+	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1382z00zzeffect_effectz00,
+		BgL_bgl_za762sideza7d2effect1412z00,
 		BGl_z62sidezd2effectzf3zd2setzd2exzd21240z91zzeffect_effectz00, 0L, BUNSPEC,
 		1);
-	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1563z00zzeffect_effectz00,
-		BgL_bgl_za762sideza7d2effect1588z00,
+	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1383z00zzeffect_effectz00,
+		BgL_bgl_za762sideza7d2effect1413z00,
 		BGl_z62sidezd2effectzf3zd2jumpzd2ex1242z43zzeffect_effectz00, 0L, BUNSPEC,
 		1);
-	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1564z00zzeffect_effectz00,
-		BgL_bgl_za762sideza7d2effect1589z00,
+	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1384z00zzeffect_effectz00,
+		BgL_bgl_za762sideza7d2effect1414z00,
 		BGl_z62sidezd2effectzf3zd2boxzd2set1244z43zzeffect_effectz00, 0L, BUNSPEC,
 		1);
-	      DEFINE_STRING(BGl_string1571z00zzeffect_effectz00,
-		BgL_bgl_string1571za700za7za7e1590za7, "effect_effect", 13);
-	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1565z00zzeffect_effectz00,
-		BgL_bgl_za762sideza7d2effect1591z00,
+	      DEFINE_STRING(BGl_string1391z00zzeffect_effectz00,
+		BgL_bgl_string1391za700za7za7e1415za7, "effect_effect", 13);
+	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1385z00zzeffect_effectz00,
+		BgL_bgl_za762sideza7d2effect1416z00,
 		BGl_z62sidezd2effectzf3zd2appzd2ly1246z43zzeffect_effectz00, 0L, BUNSPEC,
 		1);
-	      DEFINE_STRING(BGl_string1572z00zzeffect_effectz00,
-		BgL_bgl_string1572za700za7za7e1592za7, "read side-effect?1223 ", 22);
-	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1566z00zzeffect_effectz00,
-		BgL_bgl_za762sideza7d2effect1593z00,
+	      DEFINE_STRING(BGl_string1392z00zzeffect_effectz00,
+		BgL_bgl_string1392za700za7za7e1417za7, "read side-effect?1223 ", 22);
+	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1386z00zzeffect_effectz00,
+		BgL_bgl_za762sideza7d2effect1418z00,
 		BGl_z62sidezd2effectzf3zd2funcall1248z91zzeffect_effectz00, 0L, BUNSPEC, 1);
-	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1567z00zzeffect_effectz00,
-		BgL_bgl_za762sideza7d2effect1594z00,
+	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1387z00zzeffect_effectz00,
+		BgL_bgl_za762sideza7d2effect1419z00,
 		BGl_z62sidezd2effectzf3zd2cast1250z91zzeffect_effectz00, 0L, BUNSPEC, 1);
-	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1568z00zzeffect_effectz00,
-		BgL_bgl_za762sideza7d2effect1595z00,
+	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1388z00zzeffect_effectz00,
+		BgL_bgl_za762sideza7d2effect1420z00,
 		BGl_z62sidezd2effectzf3zd2sync1252z91zzeffect_effectz00, 0L, BUNSPEC, 1);
-	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1569z00zzeffect_effectz00,
-		BgL_bgl_za762sideza7d2effect1596z00,
+	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1389z00zzeffect_effectz00,
+		BgL_bgl_za762sideza7d2effect1421z00,
 		BGl_z62sidezd2effectzf3zd2retbloc1254z91zzeffect_effectz00, 0L, BUNSPEC, 1);
-	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1570z00zzeffect_effectz00,
-		BgL_bgl_za762sideza7d2effect1597z00,
+	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1390z00zzeffect_effectz00,
+		BgL_bgl_za762sideza7d2effect1422z00,
 		BGl_z62sidezd2effectzf3zd2return1256z91zzeffect_effectz00, 0L, BUNSPEC, 1);
 	     
 		DEFINE_EXPORT_BGL_GENERIC(BGl_sidezd2effectzf3zd2envzf3zzeffect_effectz00,
-		BgL_bgl_za762sideza7d2effect1598z00,
+		BgL_bgl_za762sideza7d2effect1423z00,
 		BGl_z62sidezd2effectzf3z43zzeffect_effectz00, 0L, BUNSPEC, 1);
 
 /* GC roots registration */
@@ -335,7 +336,7 @@ extern "C"
 
 /* module-initialization */
 	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zzeffect_effectz00(long
-		BgL_checksumz00_1740, char *BgL_fromz00_1741)
+		BgL_checksumz00_1745, char *BgL_fromz00_1746)
 	{
 		{
 			if (CBOOL(BGl_requirezd2initializa7ationz75zzeffect_effectz00))
@@ -390,71 +391,71 @@ extern "C"
 	{
 		{	/* Effect/effect.scm 19 */
 			{	/* Effect/effect.scm 19 */
-				obj_t BgL_cportz00_1708;
+				obj_t BgL_cportz00_1713;
 
 				{	/* Effect/effect.scm 19 */
-					obj_t BgL_stringz00_1715;
+					obj_t BgL_stringz00_1720;
 
-					BgL_stringz00_1715 = BGl_string1572z00zzeffect_effectz00;
+					BgL_stringz00_1720 = BGl_string1392z00zzeffect_effectz00;
 					{	/* Effect/effect.scm 19 */
-						obj_t BgL_startz00_1716;
+						obj_t BgL_startz00_1721;
 
-						BgL_startz00_1716 = BINT(0L);
+						BgL_startz00_1721 = BINT(0L);
 						{	/* Effect/effect.scm 19 */
-							obj_t BgL_endz00_1717;
+							obj_t BgL_endz00_1722;
 
-							BgL_endz00_1717 =
-								BINT(STRING_LENGTH(((obj_t) BgL_stringz00_1715)));
+							BgL_endz00_1722 =
+								BINT(STRING_LENGTH(((obj_t) BgL_stringz00_1720)));
 							{	/* Effect/effect.scm 19 */
 
-								BgL_cportz00_1708 =
+								BgL_cportz00_1713 =
 									BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00
-									(BgL_stringz00_1715, BgL_startz00_1716, BgL_endz00_1717);
+									(BgL_stringz00_1720, BgL_startz00_1721, BgL_endz00_1722);
 				}}}}
 				{
-					long BgL_iz00_1709;
+					long BgL_iz00_1714;
 
-					BgL_iz00_1709 = 1L;
-				BgL_loopz00_1710:
-					if ((BgL_iz00_1709 == -1L))
+					BgL_iz00_1714 = 1L;
+				BgL_loopz00_1715:
+					if ((BgL_iz00_1714 == (-1L)))
 						{	/* Effect/effect.scm 19 */
 							return BUNSPEC;
 						}
 					else
 						{	/* Effect/effect.scm 19 */
 							{	/* Effect/effect.scm 19 */
-								obj_t BgL_arg1575z00_1711;
+								obj_t BgL_arg1400z00_1716;
 
 								{	/* Effect/effect.scm 19 */
 
 									{	/* Effect/effect.scm 19 */
-										obj_t BgL_locationz00_1713;
+										obj_t BgL_locationz00_1718;
 
-										BgL_locationz00_1713 = BBOOL(((bool_t) 0));
+										BgL_locationz00_1718 = BBOOL(((bool_t) 0));
 										{	/* Effect/effect.scm 19 */
 
-											BgL_arg1575z00_1711 =
-												BGl_readz00zz__readerz00(BgL_cportz00_1708,
-												BgL_locationz00_1713);
+											BgL_arg1400z00_1716 =
+												BGl_readz00zz__readerz00(BgL_cportz00_1713,
+												BgL_locationz00_1718);
 										}
 									}
 								}
 								{	/* Effect/effect.scm 19 */
-									int BgL_tmpz00_1770;
+									int BgL_tmpz00_1775;
 
-									BgL_tmpz00_1770 = (int) (BgL_iz00_1709);
-									CNST_TABLE_SET(BgL_tmpz00_1770, BgL_arg1575z00_1711);
+									BgL_tmpz00_1775 = (int) (BgL_iz00_1714);
+									CNST_TABLE_SET(BgL_tmpz00_1775, BgL_arg1400z00_1716);
 							}}
 							{	/* Effect/effect.scm 19 */
-								int BgL_auxz00_1714;
+								int BgL_auxz00_1719;
 
-								BgL_auxz00_1714 = (int) ((BgL_iz00_1709 - 1L));
+								BgL_auxz00_1719 = (int) ((BgL_iz00_1714 - 1L));
 								{
-									long BgL_iz00_1775;
+									long BgL_iz00_1780;
 
-									BgL_iz00_1775 = (long) (BgL_auxz00_1714);
-									BgL_iz00_1709 = BgL_iz00_1775;
-									goto BgL_loopz00_1710;
+									BgL_iz00_1780 = (long) (BgL_auxz00_1719);
+									BgL_iz00_1714 = BgL_iz00_1780;
+									goto BgL_loopz00_1715;
 								}
 							}
 						}
@@ -506,8 +507,8 @@ extern "C"
 			return
 				BGl_registerzd2genericz12zc0zz__objectz00
 				(BGl_sidezd2effectzf3zd2envzf3zzeffect_effectz00,
-				BGl_proc1551z00zzeffect_effectz00, BGl_nodez00zzast_nodez00,
-				BGl_string1552z00zzeffect_effectz00);
+				BGl_proc1371z00zzeffect_effectz00, BGl_nodez00zzast_nodez00,
+				BGl_string1372z00zzeffect_effectz00);
 		}
 
 	}
@@ -515,14 +516,15 @@ extern "C"
 
 
 /* &side-effect?1223 */
-	obj_t BGl_z62sidezd2effectzf31223z43zzeffect_effectz00(obj_t BgL_envz00_1656,
-		obj_t BgL_nodez00_1657)
+	obj_t BGl_z62sidezd2effectzf31223z43zzeffect_effectz00(obj_t BgL_envz00_1661,
+		obj_t BgL_nodez00_1662)
 	{
 		{	/* Effect/effect.scm 26 */
 			return
-				BGl_errorz00zz__errorz00(CNST_TABLE_REF(0L),
-				BGl_string1553z00zzeffect_effectz00,
-				((obj_t) ((BgL_nodez00_bglt) BgL_nodez00_1657)));
+				BGl_errorz00zz__errorz00(
+				((obj_t)
+					CNST_TABLE_REF(0)), BGl_string1373z00zzeffect_effectz00,
+				((obj_t) ((BgL_nodez00_bglt) BgL_nodez00_1662)));
 		}
 
 	}
@@ -535,41 +537,41 @@ extern "C"
 	{
 		{	/* Effect/effect.scm 26 */
 			{	/* Effect/effect.scm 26 */
-				obj_t BgL_method1224z00_1373;
+				obj_t BgL_method1224z00_1378;
 
 				{	/* Effect/effect.scm 26 */
-					obj_t BgL_res1550z00_1644;
+					obj_t BgL_res1370z00_1649;
 
 					{	/* Effect/effect.scm 26 */
-						long BgL_objzd2classzd2numz00_1615;
+						long BgL_objzd2classzd2numz00_1620;
 
-						BgL_objzd2classzd2numz00_1615 =
+						BgL_objzd2classzd2numz00_1620 =
 							BGL_OBJECT_CLASS_NUM(((BgL_objectz00_bglt) BgL_nodez00_3));
 						{	/* Effect/effect.scm 26 */
-							obj_t BgL_arg1805z00_1616;
+							obj_t BgL_arg1862z00_1621;
 
-							BgL_arg1805z00_1616 =
+							BgL_arg1862z00_1621 =
 								PROCEDURE_REF(BGl_sidezd2effectzf3zd2envzf3zzeffect_effectz00,
 								(int) (1L));
 							{	/* Effect/effect.scm 26 */
-								int BgL_offsetz00_1619;
+								int BgL_offsetz00_1624;
 
-								BgL_offsetz00_1619 = (int) (BgL_objzd2classzd2numz00_1615);
+								BgL_offsetz00_1624 = (int) (BgL_objzd2classzd2numz00_1620);
 								{	/* Effect/effect.scm 26 */
-									long BgL_offsetz00_1620;
+									long BgL_offsetz00_1625;
 
-									BgL_offsetz00_1620 =
-										((long) (BgL_offsetz00_1619) - OBJECT_TYPE);
+									BgL_offsetz00_1625 =
+										((long) (BgL_offsetz00_1624) - OBJECT_TYPE);
 									{	/* Effect/effect.scm 26 */
-										long BgL_modz00_1621;
+										long BgL_modz00_1626;
 
-										BgL_modz00_1621 =
-											(BgL_offsetz00_1620 >> (int) ((long) ((int) (4L))));
+										BgL_modz00_1626 =
+											(BgL_offsetz00_1625 >> (int) ((long) ((int) (4L))));
 										{	/* Effect/effect.scm 26 */
-											long BgL_restz00_1623;
+											long BgL_restz00_1628;
 
-											BgL_restz00_1623 =
-												(BgL_offsetz00_1620 &
+											BgL_restz00_1628 =
+												(BgL_offsetz00_1625 &
 												(long) (
 													(int) (
 														((long) (
@@ -579,26 +581,20 @@ extern "C"
 											{	/* Effect/effect.scm 26 */
 
 												{	/* Effect/effect.scm 26 */
-													obj_t BgL_bucketz00_1625;
+													obj_t BgL_bucketz00_1630;
 
-													BgL_bucketz00_1625 =
+													BgL_bucketz00_1630 =
 														VECTOR_REF(
-														((obj_t) BgL_arg1805z00_1616), BgL_modz00_1621);
-													BgL_res1550z00_1644 =
+														((obj_t) BgL_arg1862z00_1621), BgL_modz00_1626);
+													BgL_res1370z00_1649 =
 														VECTOR_REF(
-														((obj_t) BgL_bucketz00_1625), BgL_restz00_1623);
+														((obj_t) BgL_bucketz00_1630), BgL_restz00_1628);
 					}}}}}}}}
-					BgL_method1224z00_1373 = BgL_res1550z00_1644;
+					BgL_method1224z00_1378 = BgL_res1370z00_1649;
 				}
 				return
-					CBOOL(
-					(VA_PROCEDUREP(BgL_method1224z00_1373) ? ((obj_t(*)(obj_t,
-									...))
-							PROCEDURE_ENTRY(BgL_method1224z00_1373)) (BgL_method1224z00_1373,
-							((obj_t) BgL_nodez00_3), BEOA) : ((obj_t(*)(obj_t,
-									obj_t))
-							PROCEDURE_ENTRY(BgL_method1224z00_1373)) (BgL_method1224z00_1373,
-							((obj_t) BgL_nodez00_3))));
+					CBOOL(BGL_PROCEDURE_CALL1(BgL_method1224z00_1378,
+						((obj_t) BgL_nodez00_3)));
 			}
 		}
 
@@ -607,13 +603,13 @@ extern "C"
 
 
 /* &side-effect? */
-	obj_t BGl_z62sidezd2effectzf3z43zzeffect_effectz00(obj_t BgL_envz00_1658,
-		obj_t BgL_nodez00_1659)
+	obj_t BGl_z62sidezd2effectzf3z43zzeffect_effectz00(obj_t BgL_envz00_1663,
+		obj_t BgL_nodez00_1664)
 	{
 		{	/* Effect/effect.scm 26 */
 			return
 				BBOOL(BGl_sidezd2effectzf3z21zzeffect_effectz00(
-					((BgL_nodez00_bglt) BgL_nodez00_1659)));
+					((BgL_nodez00_bglt) BgL_nodez00_1664)));
 		}
 
 	}
@@ -626,69 +622,69 @@ extern "C"
 		{	/* Effect/effect.scm 19 */
 			BGl_genericzd2addzd2methodz12z12zz__objectz00
 				(BGl_sidezd2effectzf3zd2envzf3zzeffect_effectz00,
-				BGl_nodez00zzast_nodez00, BGl_proc1554z00zzeffect_effectz00,
-				BGl_string1555z00zzeffect_effectz00);
+				BGl_nodez00zzast_nodez00, BGl_proc1374z00zzeffect_effectz00,
+				BGl_string1375z00zzeffect_effectz00);
 			BGl_genericzd2addzd2methodz12z12zz__objectz00
 				(BGl_sidezd2effectzf3zd2envzf3zzeffect_effectz00,
-				BGl_patchz00zzast_nodez00, BGl_proc1556z00zzeffect_effectz00,
-				BGl_string1555z00zzeffect_effectz00);
+				BGl_patchz00zzast_nodez00, BGl_proc1376z00zzeffect_effectz00,
+				BGl_string1375z00zzeffect_effectz00);
 			BGl_genericzd2addzd2methodz12z12zz__objectz00
 				(BGl_sidezd2effectzf3zd2envzf3zzeffect_effectz00,
-				BGl_varz00zzast_nodez00, BGl_proc1557z00zzeffect_effectz00,
-				BGl_string1555z00zzeffect_effectz00);
+				BGl_varz00zzast_nodez00, BGl_proc1377z00zzeffect_effectz00,
+				BGl_string1375z00zzeffect_effectz00);
 			BGl_genericzd2addzd2methodz12z12zz__objectz00
 				(BGl_sidezd2effectzf3zd2envzf3zzeffect_effectz00,
-				BGl_nodezf2effectzf2zzast_nodez00, BGl_proc1558z00zzeffect_effectz00,
-				BGl_string1555z00zzeffect_effectz00);
+				BGl_nodezf2effectzf2zzast_nodez00, BGl_proc1378z00zzeffect_effectz00,
+				BGl_string1375z00zzeffect_effectz00);
 			BGl_genericzd2addzd2methodz12z12zz__objectz00
 				(BGl_sidezd2effectzf3zd2envzf3zzeffect_effectz00,
-				BGl_appz00zzast_nodez00, BGl_proc1559z00zzeffect_effectz00,
-				BGl_string1555z00zzeffect_effectz00);
+				BGl_appz00zzast_nodez00, BGl_proc1379z00zzeffect_effectz00,
+				BGl_string1375z00zzeffect_effectz00);
 			BGl_genericzd2addzd2methodz12z12zz__objectz00
 				(BGl_sidezd2effectzf3zd2envzf3zzeffect_effectz00,
-				BGl_setqz00zzast_nodez00, BGl_proc1560z00zzeffect_effectz00,
-				BGl_string1555z00zzeffect_effectz00);
+				BGl_setqz00zzast_nodez00, BGl_proc1380z00zzeffect_effectz00,
+				BGl_string1375z00zzeffect_effectz00);
 			BGl_genericzd2addzd2methodz12z12zz__objectz00
 				(BGl_sidezd2effectzf3zd2envzf3zzeffect_effectz00,
-				BGl_failz00zzast_nodez00, BGl_proc1561z00zzeffect_effectz00,
-				BGl_string1555z00zzeffect_effectz00);
+				BGl_failz00zzast_nodez00, BGl_proc1381z00zzeffect_effectz00,
+				BGl_string1375z00zzeffect_effectz00);
 			BGl_genericzd2addzd2methodz12z12zz__objectz00
 				(BGl_sidezd2effectzf3zd2envzf3zzeffect_effectz00,
-				BGl_setzd2exzd2itz00zzast_nodez00, BGl_proc1562z00zzeffect_effectz00,
-				BGl_string1555z00zzeffect_effectz00);
+				BGl_setzd2exzd2itz00zzast_nodez00, BGl_proc1382z00zzeffect_effectz00,
+				BGl_string1375z00zzeffect_effectz00);
 			BGl_genericzd2addzd2methodz12z12zz__objectz00
 				(BGl_sidezd2effectzf3zd2envzf3zzeffect_effectz00,
-				BGl_jumpzd2exzd2itz00zzast_nodez00, BGl_proc1563z00zzeffect_effectz00,
-				BGl_string1555z00zzeffect_effectz00);
+				BGl_jumpzd2exzd2itz00zzast_nodez00, BGl_proc1383z00zzeffect_effectz00,
+				BGl_string1375z00zzeffect_effectz00);
 			BGl_genericzd2addzd2methodz12z12zz__objectz00
 				(BGl_sidezd2effectzf3zd2envzf3zzeffect_effectz00,
-				BGl_boxzd2setz12zc0zzast_nodez00, BGl_proc1564z00zzeffect_effectz00,
-				BGl_string1555z00zzeffect_effectz00);
+				BGl_boxzd2setz12zc0zzast_nodez00, BGl_proc1384z00zzeffect_effectz00,
+				BGl_string1375z00zzeffect_effectz00);
 			BGl_genericzd2addzd2methodz12z12zz__objectz00
 				(BGl_sidezd2effectzf3zd2envzf3zzeffect_effectz00,
-				BGl_appzd2lyzd2zzast_nodez00, BGl_proc1565z00zzeffect_effectz00,
-				BGl_string1555z00zzeffect_effectz00);
+				BGl_appzd2lyzd2zzast_nodez00, BGl_proc1385z00zzeffect_effectz00,
+				BGl_string1375z00zzeffect_effectz00);
 			BGl_genericzd2addzd2methodz12z12zz__objectz00
 				(BGl_sidezd2effectzf3zd2envzf3zzeffect_effectz00,
-				BGl_funcallz00zzast_nodez00, BGl_proc1566z00zzeffect_effectz00,
-				BGl_string1555z00zzeffect_effectz00);
+				BGl_funcallz00zzast_nodez00, BGl_proc1386z00zzeffect_effectz00,
+				BGl_string1375z00zzeffect_effectz00);
 			BGl_genericzd2addzd2methodz12z12zz__objectz00
 				(BGl_sidezd2effectzf3zd2envzf3zzeffect_effectz00,
-				BGl_castz00zzast_nodez00, BGl_proc1567z00zzeffect_effectz00,
-				BGl_string1555z00zzeffect_effectz00);
+				BGl_castz00zzast_nodez00, BGl_proc1387z00zzeffect_effectz00,
+				BGl_string1375z00zzeffect_effectz00);
 			BGl_genericzd2addzd2methodz12z12zz__objectz00
 				(BGl_sidezd2effectzf3zd2envzf3zzeffect_effectz00,
-				BGl_syncz00zzast_nodez00, BGl_proc1568z00zzeffect_effectz00,
-				BGl_string1555z00zzeffect_effectz00);
+				BGl_syncz00zzast_nodez00, BGl_proc1388z00zzeffect_effectz00,
+				BGl_string1375z00zzeffect_effectz00);
 			BGl_genericzd2addzd2methodz12z12zz__objectz00
 				(BGl_sidezd2effectzf3zd2envzf3zzeffect_effectz00,
-				BGl_retblockz00zzast_nodez00, BGl_proc1569z00zzeffect_effectz00,
-				BGl_string1555z00zzeffect_effectz00);
+				BGl_retblockz00zzast_nodez00, BGl_proc1389z00zzeffect_effectz00,
+				BGl_string1375z00zzeffect_effectz00);
 			return
 				BGl_genericzd2addzd2methodz12z12zz__objectz00
 				(BGl_sidezd2effectzf3zd2envzf3zzeffect_effectz00,
-				BGl_returnz00zzast_nodez00, BGl_proc1570z00zzeffect_effectz00,
-				BGl_string1555z00zzeffect_effectz00);
+				BGl_returnz00zzast_nodez00, BGl_proc1390z00zzeffect_effectz00,
+				BGl_string1375z00zzeffect_effectz00);
 		}
 
 	}
@@ -697,7 +693,7 @@ extern "C"
 
 /* &side-effect?-return1256 */
 	obj_t BGl_z62sidezd2effectzf3zd2return1256z91zzeffect_effectz00(obj_t
-		BgL_envz00_1676, obj_t BgL_nodez00_1677)
+		BgL_envz00_1681, obj_t BgL_nodez00_1682)
 	{
 		{	/* Effect/effect.scm 129 */
 			return BBOOL(((bool_t) 1));
@@ -709,13 +705,13 @@ extern "C"
 
 /* &side-effect?-retbloc1254 */
 	obj_t BGl_z62sidezd2effectzf3zd2retbloc1254z91zzeffect_effectz00(obj_t
-		BgL_envz00_1678, obj_t BgL_nodez00_1679)
+		BgL_envz00_1683, obj_t BgL_nodez00_1684)
 	{
 		{	/* Effect/effect.scm 122 */
 			return
 				BBOOL(BGl_sidezd2effectzf3z21zzeffect_effectz00(
 					(((BgL_retblockz00_bglt) COBJECT(
-								((BgL_retblockz00_bglt) BgL_nodez00_1679)))->BgL_bodyz00)));
+								((BgL_retblockz00_bglt) BgL_nodez00_1684)))->BgL_bodyz00)));
 		}
 
 	}
@@ -724,7 +720,7 @@ extern "C"
 
 /* &side-effect?-sync1252 */
 	obj_t BGl_z62sidezd2effectzf3zd2sync1252z91zzeffect_effectz00(obj_t
-		BgL_envz00_1680, obj_t BgL_nodez00_1681)
+		BgL_envz00_1685, obj_t BgL_nodez00_1686)
 	{
 		{	/* Effect/effect.scm 116 */
 			return BBOOL(((bool_t) 1));
@@ -736,13 +732,13 @@ extern "C"
 
 /* &side-effect?-cast1250 */
 	obj_t BGl_z62sidezd2effectzf3zd2cast1250z91zzeffect_effectz00(obj_t
-		BgL_envz00_1682, obj_t BgL_nodez00_1683)
+		BgL_envz00_1687, obj_t BgL_nodez00_1688)
 	{
 		{	/* Effect/effect.scm 109 */
 			return
 				BBOOL(BGl_sidezd2effectzf3z21zzeffect_effectz00(
 					(((BgL_castz00_bglt) COBJECT(
-								((BgL_castz00_bglt) BgL_nodez00_1683)))->BgL_argz00)));
+								((BgL_castz00_bglt) BgL_nodez00_1688)))->BgL_argz00)));
 		}
 
 	}
@@ -751,7 +747,7 @@ extern "C"
 
 /* &side-effect?-funcall1248 */
 	obj_t BGl_z62sidezd2effectzf3zd2funcall1248z91zzeffect_effectz00(obj_t
-		BgL_envz00_1684, obj_t BgL_nodez00_1685)
+		BgL_envz00_1689, obj_t BgL_nodez00_1690)
 	{
 		{	/* Effect/effect.scm 103 */
 			return BBOOL(((bool_t) 1));
@@ -763,7 +759,7 @@ extern "C"
 
 /* &side-effect?-app-ly1246 */
 	obj_t BGl_z62sidezd2effectzf3zd2appzd2ly1246z43zzeffect_effectz00(obj_t
-		BgL_envz00_1686, obj_t BgL_nodez00_1687)
+		BgL_envz00_1691, obj_t BgL_nodez00_1692)
 	{
 		{	/* Effect/effect.scm 97 */
 			return BBOOL(((bool_t) 1));
@@ -775,7 +771,7 @@ extern "C"
 
 /* &side-effect?-box-set1244 */
 	obj_t BGl_z62sidezd2effectzf3zd2boxzd2set1244z43zzeffect_effectz00(obj_t
-		BgL_envz00_1688, obj_t BgL_nodez00_1689)
+		BgL_envz00_1693, obj_t BgL_nodez00_1694)
 	{
 		{	/* Effect/effect.scm 91 */
 			return BBOOL(((bool_t) 1));
@@ -787,7 +783,7 @@ extern "C"
 
 /* &side-effect?-jump-ex1242 */
 	obj_t BGl_z62sidezd2effectzf3zd2jumpzd2ex1242z43zzeffect_effectz00(obj_t
-		BgL_envz00_1690, obj_t BgL_nodez00_1691)
+		BgL_envz00_1695, obj_t BgL_nodez00_1696)
 	{
 		{	/* Effect/effect.scm 85 */
 			return BBOOL(((bool_t) 1));
@@ -799,7 +795,7 @@ extern "C"
 
 /* &side-effect?-set-ex-1240 */
 	obj_t BGl_z62sidezd2effectzf3zd2setzd2exzd21240z91zzeffect_effectz00(obj_t
-		BgL_envz00_1692, obj_t BgL_nodez00_1693)
+		BgL_envz00_1697, obj_t BgL_nodez00_1698)
 	{
 		{	/* Effect/effect.scm 79 */
 			return BBOOL(((bool_t) 1));
@@ -811,7 +807,7 @@ extern "C"
 
 /* &side-effect?-fail1238 */
 	obj_t BGl_z62sidezd2effectzf3zd2fail1238z91zzeffect_effectz00(obj_t
-		BgL_envz00_1694, obj_t BgL_nodez00_1695)
+		BgL_envz00_1699, obj_t BgL_nodez00_1700)
 	{
 		{	/* Effect/effect.scm 73 */
 			return BBOOL(((bool_t) 1));
@@ -823,7 +819,7 @@ extern "C"
 
 /* &side-effect?-setq1236 */
 	obj_t BGl_z62sidezd2effectzf3zd2setq1236z91zzeffect_effectz00(obj_t
-		BgL_envz00_1696, obj_t BgL_nodez00_1697)
+		BgL_envz00_1701, obj_t BgL_nodez00_1702)
 	{
 		{	/* Effect/effect.scm 67 */
 			return BBOOL(((bool_t) 1));
@@ -835,38 +831,30 @@ extern "C"
 
 /* &side-effect?-app1234 */
 	obj_t BGl_z62sidezd2effectzf3zd2app1234z91zzeffect_effectz00(obj_t
-		BgL_envz00_1698, obj_t BgL_nodez00_1699)
+		BgL_envz00_1703, obj_t BgL_nodez00_1704)
 	{
 		{	/* Effect/effect.scm 58 */
 			{
 
 				{	/* Effect/effect.scm 59 */
-					obj_t BgL__ortest_1102z00_1734;
+					obj_t BgL__ortest_1102z00_1739;
 
 					{	/* Effect/effect.scm 58 */
-						obj_t BgL_nextzd2method1233zd2_1733;
+						obj_t BgL_nextzd2method1233zd2_1738;
 
-						BgL_nextzd2method1233zd2_1733 =
+						BgL_nextzd2method1233zd2_1738 =
 							BGl_findzd2superzd2classzd2methodzd2zz__objectz00(
 							((BgL_objectz00_bglt)
-								((BgL_appz00_bglt) BgL_nodez00_1699)),
+								((BgL_appz00_bglt) BgL_nodez00_1704)),
 							BGl_sidezd2effectzf3zd2envzf3zzeffect_effectz00,
 							BGl_appz00zzast_nodez00);
-						BgL__ortest_1102z00_1734 =
-							(VA_PROCEDUREP(BgL_nextzd2method1233zd2_1733) ? ((obj_t(*)(obj_t,
-										...))
-								PROCEDURE_ENTRY(BgL_nextzd2method1233zd2_1733))
-							(BgL_nextzd2method1233zd2_1733,
-								((obj_t) ((BgL_appz00_bglt) BgL_nodez00_1699)),
-								BEOA) : ((obj_t(*)(obj_t,
-										obj_t))
-								PROCEDURE_ENTRY(BgL_nextzd2method1233zd2_1733))
-							(BgL_nextzd2method1233zd2_1733,
-								((obj_t) ((BgL_appz00_bglt) BgL_nodez00_1699))));
+						BgL__ortest_1102z00_1739 =
+							BGL_PROCEDURE_CALL1(BgL_nextzd2method1233zd2_1738,
+							((obj_t) ((BgL_appz00_bglt) BgL_nodez00_1704)));
 					}
-					if (CBOOL(BgL__ortest_1102z00_1734))
+					if (CBOOL(BgL__ortest_1102z00_1739))
 						{	/* Effect/effect.scm 59 */
-							return BgL__ortest_1102z00_1734;
+							return BgL__ortest_1102z00_1739;
 						}
 					else
 						{	/* Effect/effect.scm 59 */
@@ -878,7 +866,7 @@ extern "C"
 																(((BgL_varz00_bglt) COBJECT(
 																			(((BgL_appz00_bglt) COBJECT(
 																						((BgL_appz00_bglt)
-																							BgL_nodez00_1699)))->
+																							BgL_nodez00_1704)))->
 																				BgL_funz00)))->BgL_variablez00)))->
 														BgL_valuez00))))->BgL_sidezd2effectzd2) == BTRUE));
 						}
@@ -892,19 +880,19 @@ extern "C"
 
 /* &side-effect?-node/ef1232 */
 	obj_t BGl_z62sidezd2effectzf3zd2nodezf2ef1232z63zzeffect_effectz00(obj_t
-		BgL_envz00_1700, obj_t BgL_nodez00_1701)
+		BgL_envz00_1705, obj_t BgL_nodez00_1706)
 	{
 		{	/* Effect/effect.scm 49 */
 			{	/* Effect/effect.scm 50 */
-				obj_t BgL_effectz00_1736;
+				obj_t BgL_effectz00_1741;
 
-				BgL_effectz00_1736 =
+				BgL_effectz00_1741 =
 					(((BgL_nodezf2effectzf2_bglt) COBJECT(
-							((BgL_nodezf2effectzf2_bglt) BgL_nodez00_1701)))->
+							((BgL_nodezf2effectzf2_bglt) BgL_nodez00_1706)))->
 					BgL_sidezd2effectzd2);
-				if (BOOLEANP(BgL_effectz00_1736))
+				if (BOOLEANP(BgL_effectz00_1741))
 					{	/* Effect/effect.scm 51 */
-						return BgL_effectz00_1736;
+						return BgL_effectz00_1741;
 					}
 				else
 					{	/* Effect/effect.scm 51 */
@@ -919,25 +907,26 @@ extern "C"
 
 /* &side-effect?-var1230 */
 	obj_t BGl_z62sidezd2effectzf3zd2var1230z91zzeffect_effectz00(obj_t
-		BgL_envz00_1702, obj_t BgL_nodez00_1703)
+		BgL_envz00_1707, obj_t BgL_nodez00_1708)
 	{
 		{	/* Effect/effect.scm 43 */
 			{	/* Effect/effect.scm 44 */
-				bool_t BgL_tmpz00_1873;
+				bool_t BgL_tmpz00_1879;
 
 				if (
 					((((BgL_variablez00_bglt) COBJECT(
 									(((BgL_varz00_bglt) COBJECT(
-												((BgL_varz00_bglt) BgL_nodez00_1703)))->
-										BgL_variablez00)))->BgL_accessz00) == CNST_TABLE_REF(1L)))
+												((BgL_varz00_bglt) BgL_nodez00_1708)))->
+										BgL_variablez00)))->BgL_accessz00) ==
+						((obj_t) CNST_TABLE_REF(1))))
 					{	/* Effect/effect.scm 44 */
-						BgL_tmpz00_1873 = ((bool_t) 0);
+						BgL_tmpz00_1879 = ((bool_t) 0);
 					}
 				else
 					{	/* Effect/effect.scm 44 */
-						BgL_tmpz00_1873 = ((bool_t) 1);
+						BgL_tmpz00_1879 = ((bool_t) 1);
 					}
-				return BBOOL(BgL_tmpz00_1873);
+				return BBOOL(BgL_tmpz00_1879);
 			}
 		}
 
@@ -947,7 +936,7 @@ extern "C"
 
 /* &side-effect?-patch1228 */
 	obj_t BGl_z62sidezd2effectzf3zd2patch1228z91zzeffect_effectz00(obj_t
-		BgL_envz00_1704, obj_t BgL_nodez00_1705)
+		BgL_envz00_1709, obj_t BgL_nodez00_1710)
 	{
 		{	/* Effect/effect.scm 37 */
 			return BBOOL(((bool_t) 1));
@@ -959,7 +948,7 @@ extern "C"
 
 /* &side-effect?-node1226 */
 	obj_t BGl_z62sidezd2effectzf3zd2node1226z91zzeffect_effectz00(obj_t
-		BgL_envz00_1706, obj_t BgL_nodez00_1707)
+		BgL_envz00_1711, obj_t BgL_nodez00_1712)
 	{
 		{	/* Effect/effect.scm 31 */
 			return BBOOL(((bool_t) 0));
@@ -974,12 +963,12 @@ extern "C"
 	{
 		{	/* Effect/effect.scm 19 */
 			BGl_modulezd2initializa7ationz75zztype_typez00(515343395L,
-				BSTRING_TO_STRING(BGl_string1571z00zzeffect_effectz00));
+				BSTRING_TO_STRING(BGl_string1391z00zzeffect_effectz00));
 			BGl_modulezd2initializa7ationz75zzast_varz00(90839984L,
-				BSTRING_TO_STRING(BGl_string1571z00zzeffect_effectz00));
+				BSTRING_TO_STRING(BGl_string1391z00zzeffect_effectz00));
 			return
 				BGl_modulezd2initializa7ationz75zzast_nodez00(469732712L,
-				BSTRING_TO_STRING(BGl_string1571z00zzeffect_effectz00));
+				BSTRING_TO_STRING(BGl_string1391z00zzeffect_effectz00));
 		}
 
 	}
