@@ -1,9 +1,9 @@
 /*===========================================================================*/
 /*   (Engine/interp.scm)                                                     */
-/*   Bigloo (4.5b)                                                           */
-/*   Inria -- Sophia Antipolis (c)       Fri Dec 22 05:17:06 PM CET 2023     */
+/*   Bigloo (4.6a)                                                           */
+/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
 /*===========================================================================*/
-/* COMPILATION: (/home/serrano/prgm/project/bigloo/bigloo/bin/bigloo -ldopt -L/home/serrano/prgm/project/bigloo/bigloo/libbacktrace/home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b  -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Engine/interp.scm) */
+/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Engine/interp.scm) */
 /* GC selection */
 #define THE_GC BOEHM_GC
 
@@ -85,28 +85,28 @@ extern "C"
 
 	   
 		 
-		DEFINE_STRING(BGl_string1072z00zzengine_interpz00,
-		BgL_bgl_string1072za700za7za7e1082za7, "Welcome to the interpreter", 26);
-	      DEFINE_STRING(BGl_string1073z00zzengine_interpz00,
-		BgL_bgl_string1073za700za7za7e1083za7, "Interpreting files: ", 20);
-	      DEFINE_STRING(BGl_string1074z00zzengine_interpz00,
-		BgL_bgl_string1074za700za7za7e1084za7, "HOME", 4);
-	      DEFINE_STRING(BGl_string1075z00zzengine_interpz00,
-		BgL_bgl_string1075za700za7za7e1085za7, "Can't file startup file -- ", 27);
-	      DEFINE_STRING(BGl_string1076z00zzengine_interpz00,
-		BgL_bgl_string1076za700za7za7e1086za7, "interp", 6);
-	      DEFINE_STRING(BGl_string1077z00zzengine_interpz00,
-		BgL_bgl_string1077za700za7za7e1087za7, "]", 1);
-	      DEFINE_STRING(BGl_string1078z00zzengine_interpz00,
-		BgL_bgl_string1078za700za7za7e1088za7, "      [reading afile ", 21);
-	      DEFINE_STRING(BGl_string1079z00zzengine_interpz00,
-		BgL_bgl_string1079za700za7za7e1089za7, "-i", 2);
-	      DEFINE_STRING(BGl_string1080z00zzengine_interpz00,
-		BgL_bgl_string1080za700za7za7e1090za7, "--", 2);
-	      DEFINE_STRING(BGl_string1081z00zzengine_interpz00,
-		BgL_bgl_string1081za700za7za7e1091za7, "engine_interp", 13);
+		DEFINE_STRING(BGl_string1098z00zzengine_interpz00,
+		BgL_bgl_string1098za700za7za7e1108za7, "Welcome to the interpreter", 26);
+	      DEFINE_STRING(BGl_string1099z00zzengine_interpz00,
+		BgL_bgl_string1099za700za7za7e1109za7, "Interpreting files: ", 20);
+	      DEFINE_STRING(BGl_string1100z00zzengine_interpz00,
+		BgL_bgl_string1100za700za7za7e1110za7, "HOME", 4);
+	      DEFINE_STRING(BGl_string1101z00zzengine_interpz00,
+		BgL_bgl_string1101za700za7za7e1111za7, "Can't file startup file -- ", 27);
+	      DEFINE_STRING(BGl_string1102z00zzengine_interpz00,
+		BgL_bgl_string1102za700za7za7e1112za7, "interp", 6);
+	      DEFINE_STRING(BGl_string1103z00zzengine_interpz00,
+		BgL_bgl_string1103za700za7za7e1113za7, "]", 1);
+	      DEFINE_STRING(BGl_string1104z00zzengine_interpz00,
+		BgL_bgl_string1104za700za7za7e1114za7, "      [reading afile ", 21);
+	      DEFINE_STRING(BGl_string1105z00zzengine_interpz00,
+		BgL_bgl_string1105za700za7za7e1115za7, "-i", 2);
+	      DEFINE_STRING(BGl_string1106z00zzengine_interpz00,
+		BgL_bgl_string1106za700za7za7e1116za7, "--", 2);
+	      DEFINE_STRING(BGl_string1107z00zzengine_interpz00,
+		BgL_bgl_string1107za700za7za7e1117za7, "engine_interp", 13);
 	      DEFINE_EXPORT_BGL_PROCEDURE(BGl_interpzd2envzd2zzengine_interpz00,
-		BgL_bgl_za762interpza762za7za7en1092z00, BGl_z62interpz62zzengine_interpz00,
+		BgL_bgl_za762interpza762za7za7en1118z00, BGl_z62interpz62zzengine_interpz00,
 		0L, BUNSPEC, 6);
 
 /* GC roots registration */
@@ -129,7 +129,7 @@ extern "C"
 
 /* module-initialization */
 	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zzengine_interpz00(long
-		BgL_checksumz00_144, char *BgL_fromz00_145)
+		BgL_checksumz00_145, char *BgL_fromz00_146)
 	{
 		{
 			if (CBOOL(BGl_requirezd2initializa7ationz75zzengine_interpz00))
@@ -193,42 +193,47 @@ extern "C"
 		obj_t BgL_l2z00_2)
 	{
 		{
-			{
-				obj_t BgL_headz00_11;
-
-				BgL_headz00_11 = MAKE_YOUNG_PAIR(BNIL, BgL_l2z00_2);
+			if (NULLP(BgL_l1z00_1))
 				{
-					obj_t BgL_prevz00_12;
-					obj_t BgL_tailz00_13;
+					return BgL_l2z00_2;
+				}
+			else
+				{
+					obj_t BgL_headz00_12;
 
-					BgL_prevz00_12 = BgL_headz00_11;
-					BgL_tailz00_13 = BgL_l1z00_1;
-				BgL_loopz00_14:
-					if (PAIRP(BgL_tailz00_13))
-						{
-							obj_t BgL_newzd2prevzd2_16;
+					BgL_headz00_12 = MAKE_YOUNG_PAIR(BNIL, BgL_l2z00_2);
+					{
+						obj_t BgL_prevz00_13;
+						obj_t BgL_tailz00_14;
 
-							BgL_newzd2prevzd2_16 =
-								MAKE_YOUNG_PAIR(CAR(BgL_tailz00_13), BgL_l2z00_2);
-							SET_CDR(BgL_prevz00_12, BgL_newzd2prevzd2_16);
+						BgL_prevz00_13 = BgL_headz00_12;
+						BgL_tailz00_14 = BgL_l1z00_1;
+					BgL_loopz00_15:
+						if (PAIRP(BgL_tailz00_14))
 							{
-								obj_t BgL_tailz00_171;
-								obj_t BgL_prevz00_170;
+								obj_t BgL_newzd2prevzd2_17;
 
-								BgL_prevz00_170 = BgL_newzd2prevzd2_16;
-								BgL_tailz00_171 = CDR(BgL_tailz00_13);
-								BgL_tailz00_13 = BgL_tailz00_171;
-								BgL_prevz00_12 = BgL_prevz00_170;
-								goto BgL_loopz00_14;
+								BgL_newzd2prevzd2_17 =
+									MAKE_YOUNG_PAIR(CAR(BgL_tailz00_14), BgL_l2z00_2);
+								SET_CDR(BgL_prevz00_13, BgL_newzd2prevzd2_17);
+								{
+									obj_t BgL_tailz00_174;
+									obj_t BgL_prevz00_173;
+
+									BgL_prevz00_173 = BgL_newzd2prevzd2_17;
+									BgL_tailz00_174 = CDR(BgL_tailz00_14);
+									BgL_tailz00_14 = BgL_tailz00_174;
+									BgL_prevz00_13 = BgL_prevz00_173;
+									goto BgL_loopz00_15;
+								}
+							}
+						else
+							{
+								BNIL;
 							}
-						}
-					else
-						{
-							BNIL;
-						}
-					return CDR(BgL_headz00_11);
+						return CDR(BgL_headz00_12);
+					}
 				}
-			}
 		}
 
 	}
@@ -243,122 +248,119 @@ extern "C"
 		{	/* Engine/interp.scm 23 */
 			BGl_za2bigloozd2interpreterza2zd2zz__readerz00 = BTRUE;
 			{	/* Engine/interp.scm 25 */
-				bool_t BgL_test1095z00_174;
+				bool_t BgL_test1122z00_177;
 
 				if (((long) CINT(BgL_verbz00_4) >= 0L))
 					{	/* Engine/interp.scm 25 */
 						if (PAIRP(BgL_filesz00_5))
 							{	/* Engine/interp.scm 25 */
-								BgL_test1095z00_174 = ((bool_t) 0);
+								BgL_test1122z00_177 = ((bool_t) 0);
 							}
 						else
 							{	/* Engine/interp.scm 25 */
-								BgL_test1095z00_174 = ((bool_t) 1);
+								BgL_test1122z00_177 = ((bool_t) 1);
 							}
 					}
 				else
 					{	/* Engine/interp.scm 25 */
-						BgL_test1095z00_174 = ((bool_t) 0);
+						BgL_test1122z00_177 = ((bool_t) 0);
 					}
-				if (BgL_test1095z00_174)
+				if (BgL_test1122z00_177)
 					{	/* Engine/interp.scm 25 */
-						(VA_PROCEDUREP(BgL_versionz00_3) ? ((obj_t(*)(obj_t,
-										...)) PROCEDURE_ENTRY(BgL_versionz00_3)) (BgL_versionz00_3,
-								BEOA) : ((obj_t(*)(obj_t))
-								PROCEDURE_ENTRY(BgL_versionz00_3)) (BgL_versionz00_3));
+						BGL_PROCEDURE_CALL0(BgL_versionz00_3);
 						{	/* Engine/interp.scm 28 */
-							obj_t BgL_list1023z00_22;
+							obj_t BgL_list1024z00_23;
 
-							BgL_list1023z00_22 =
-								MAKE_YOUNG_PAIR(BGl_string1072z00zzengine_interpz00, BNIL);
-							BGl_verbosez00zztools_speekz00(BINT(1L), BgL_list1023z00_22);
+							BgL_list1024z00_23 =
+								MAKE_YOUNG_PAIR(BGl_string1098z00zzengine_interpz00, BNIL);
+							BGl_verbosez00zztools_speekz00(BINT(1L), BgL_list1024z00_23);
 						}
 					}
 				else
 					{	/* Engine/interp.scm 29 */
-						obj_t BgL_list1024z00_23;
+						obj_t BgL_list1025z00_24;
 
 						{	/* Engine/interp.scm 29 */
-							obj_t BgL_arg1025z00_24;
+							obj_t BgL_arg1026z00_25;
 
 							{	/* Engine/interp.scm 29 */
-								obj_t BgL_arg1026z00_25;
+								obj_t BgL_arg1027z00_26;
 
-								BgL_arg1026z00_25 =
+								BgL_arg1027z00_26 =
 									MAKE_YOUNG_PAIR(BCHAR(((unsigned char) 10)), BNIL);
-								BgL_arg1025z00_24 =
-									MAKE_YOUNG_PAIR(BgL_filesz00_5, BgL_arg1026z00_25);
+								BgL_arg1026z00_25 =
+									MAKE_YOUNG_PAIR(BgL_filesz00_5, BgL_arg1027z00_26);
 							}
-							BgL_list1024z00_23 =
-								MAKE_YOUNG_PAIR(BGl_string1073z00zzengine_interpz00,
-								BgL_arg1025z00_24);
+							BgL_list1025z00_24 =
+								MAKE_YOUNG_PAIR(BGl_string1099z00zzengine_interpz00,
+								BgL_arg1026z00_25);
 						}
-						BGl_verbosez00zztools_speekz00(BINT(2L), BgL_list1024z00_23);
+						BGl_verbosez00zztools_speekz00(BINT(2L), BgL_list1025z00_24);
 			}}
 			command_line =
 				BGl_interpzd2parsezd2argsz00zzengine_interpz00(BgL_argsz00_8);
 			if (STRINGP(BgL_startupz00_6))
 				{	/* Engine/interp.scm 34 */
-					obj_t BgL_pathz00_29;
+					obj_t BgL_pathz00_30;
 
 					{	/* Engine/interp.scm 34 */
-						obj_t BgL_homez00_37;
+						obj_t BgL_homez00_38;
 
-						BgL_homez00_37 =
-							BGl_getenvz00zz__osz00(BGl_string1074z00zzengine_interpz00);
-						if (STRINGP(BgL_homez00_37))
+						BgL_homez00_38 =
+							BGl_getenvz00zz__osz00(BGl_string1100z00zzengine_interpz00);
+						if (STRINGP(BgL_homez00_38))
 							{	/* Engine/interp.scm 35 */
-								BgL_pathz00_29 = MAKE_YOUNG_PAIR(BgL_homez00_37, BgL_pathz00_7);
+								BgL_pathz00_30 = MAKE_YOUNG_PAIR(BgL_homez00_38, BgL_pathz00_7);
 							}
 						else
 							{	/* Engine/interp.scm 35 */
-								BgL_pathz00_29 = BgL_pathz00_7;
+								BgL_pathz00_30 = BgL_pathz00_7;
 							}
 					}
 					{	/* Engine/interp.scm 38 */
-						obj_t BgL_fstartupz00_30;
+						obj_t BgL_fstartupz00_31;
 
-						BgL_fstartupz00_30 =
+						BgL_fstartupz00_31 =
 							BGl_findzd2filezf2pathz20zz__osz00(BgL_startupz00_6,
-							BgL_pathz00_29);
-						if (CBOOL(BgL_fstartupz00_30))
+							BgL_pathz00_30);
+						if (CBOOL(BgL_fstartupz00_31))
 							{	/* Engine/interp.scm 40 */
-								obj_t BgL_envz00_32;
+								obj_t BgL_envz00_33;
 
-								BgL_envz00_32 = BGl_defaultzd2environmentzd2zz__evalz00();
+								BgL_envz00_33 = BGl_defaultzd2environmentzd2zz__evalz00();
 								{	/* Engine/interp.scm 40 */
 
-									BGl_loadqz00zz__evalz00(BgL_startupz00_6, BgL_envz00_32);
+									BGl_loadqz00zz__evalz00(BgL_startupz00_6, BgL_envz00_33);
 								}
 							}
 						else
 							{	/* Engine/interp.scm 41 */
-								obj_t BgL_list1028z00_33;
+								obj_t BgL_list1029z00_34;
 
 								{	/* Engine/interp.scm 41 */
-									obj_t BgL_arg1029z00_34;
+									obj_t BgL_arg1031z00_35;
 
 									{	/* Engine/interp.scm 41 */
-										obj_t BgL_arg1030z00_35;
+										obj_t BgL_arg1032z00_36;
 
 										{	/* Engine/interp.scm 41 */
-											obj_t BgL_arg1033z00_36;
+											obj_t BgL_arg1034z00_37;
 
-											BgL_arg1033z00_36 =
+											BgL_arg1034z00_37 =
 												MAKE_YOUNG_PAIR(BgL_startupz00_6, BNIL);
-											BgL_arg1030z00_35 =
-												MAKE_YOUNG_PAIR(BGl_string1075z00zzengine_interpz00,
-												BgL_arg1033z00_36);
+											BgL_arg1032z00_36 =
+												MAKE_YOUNG_PAIR(BGl_string1101z00zzengine_interpz00,
+												BgL_arg1034z00_37);
 										}
-										BgL_arg1029z00_34 =
+										BgL_arg1031z00_35 =
 											MAKE_YOUNG_PAIR(BCHAR(((unsigned char) 10)),
-											BgL_arg1030z00_35);
+											BgL_arg1032z00_36);
 									}
-									BgL_list1028z00_33 =
-										MAKE_YOUNG_PAIR(BGl_string1076z00zzengine_interpz00,
-										BgL_arg1029z00_34);
+									BgL_list1029z00_34 =
+										MAKE_YOUNG_PAIR(BGl_string1102z00zzengine_interpz00,
+										BgL_arg1031z00_35);
 								}
-								BGl_warningz00zz__errorz00(BgL_list1028z00_33);
+								BGl_warningz00zz__errorz00(BgL_list1029z00_34);
 				}}}
 			else
 				{	/* Engine/interp.scm 33 */
@@ -366,22 +368,22 @@ extern "C"
 				}
 			if (PAIRP(BgL_filesz00_5))
 				{
-					obj_t BgL_l1015z00_41;
+					obj_t BgL_l1015z00_42;
 
 					{	/* Engine/interp.scm 46 */
-						bool_t BgL_tmpz00_212;
+						bool_t BgL_tmpz00_215;
 
-						BgL_l1015z00_41 = BgL_filesz00_5;
-					BgL_zc3z04anonymousza31036ze3z87_42:
-						if (PAIRP(BgL_l1015z00_41))
+						BgL_l1015z00_42 = BgL_filesz00_5;
+					BgL_zc3z04anonymousza31037ze3z87_43:
+						if (PAIRP(BgL_l1015z00_42))
 							{	/* Engine/interp.scm 46 */
 								{	/* Engine/interp.scm 46 */
-									obj_t BgL_fz00_44;
+									obj_t BgL_fz00_45;
 
-									BgL_fz00_44 = CAR(BgL_l1015z00_41);
-									if (STRINGP(BgL_fz00_44))
+									BgL_fz00_45 = CAR(BgL_l1015z00_42);
+									if (STRINGP(BgL_fz00_45))
 										{	/* Engine/interp.scm 46 */
-											BGl_loadiz00zzengine_interpz00(BgL_fz00_44);
+											BGl_loadiz00zzengine_interpz00(BgL_fz00_45);
 										}
 									else
 										{	/* Engine/interp.scm 46 */
@@ -389,18 +391,18 @@ extern "C"
 										}
 								}
 								{
-									obj_t BgL_l1015z00_221;
+									obj_t BgL_l1015z00_224;
 
-									BgL_l1015z00_221 = CDR(BgL_l1015z00_41);
-									BgL_l1015z00_41 = BgL_l1015z00_221;
-									goto BgL_zc3z04anonymousza31036ze3z87_42;
+									BgL_l1015z00_224 = CDR(BgL_l1015z00_42);
+									BgL_l1015z00_42 = BgL_l1015z00_224;
+									goto BgL_zc3z04anonymousza31037ze3z87_43;
 								}
 							}
 						else
 							{	/* Engine/interp.scm 46 */
-								BgL_tmpz00_212 = ((bool_t) 1);
+								BgL_tmpz00_215 = ((bool_t) 1);
 							}
-						BBOOL(BgL_tmpz00_212);
+						BBOOL(BgL_tmpz00_215);
 					}
 				}
 			else
@@ -415,14 +417,14 @@ extern "C"
 
 
 /* &interp */
-	obj_t BGl_z62interpz62zzengine_interpz00(obj_t BgL_envz00_137,
-		obj_t BgL_versionz00_138, obj_t BgL_verbz00_139, obj_t BgL_filesz00_140,
-		obj_t BgL_startupz00_141, obj_t BgL_pathz00_142, obj_t BgL_argsz00_143)
+	obj_t BGl_z62interpz62zzengine_interpz00(obj_t BgL_envz00_138,
+		obj_t BgL_versionz00_139, obj_t BgL_verbz00_140, obj_t BgL_filesz00_141,
+		obj_t BgL_startupz00_142, obj_t BgL_pathz00_143, obj_t BgL_argsz00_144)
 	{
 		{	/* Engine/interp.scm 23 */
 			return
-				BGl_interpz00zzengine_interpz00(BgL_versionz00_138, BgL_verbz00_139,
-				BgL_filesz00_140, BgL_startupz00_141, BgL_pathz00_142, BgL_argsz00_143);
+				BGl_interpz00zzengine_interpz00(BgL_versionz00_139, BgL_verbz00_140,
+				BgL_filesz00_141, BgL_startupz00_142, BgL_pathz00_143, BgL_argsz00_144);
 		}
 
 	}
@@ -434,58 +436,58 @@ extern "C"
 	{
 		{	/* Engine/interp.scm 53 */
 			{	/* Engine/interp.scm 54 */
-				obj_t BgL_afilez00_48;
+				obj_t BgL_afilez00_49;
 
 				{	/* Engine/interp.scm 54 */
-					obj_t BgL_arg1046z00_56;
+					obj_t BgL_arg1047z00_57;
 
-					BgL_arg1046z00_56 = BGl_dirnamez00zz__osz00(BgL_fz00_9);
-					BgL_afilez00_48 =
-						BGl_makezd2filezd2namez00zz__osz00(BgL_arg1046z00_56,
+					BgL_arg1047z00_57 = BGl_dirnamez00zz__osz00(BgL_fz00_9);
+					BgL_afilez00_49 =
+						BGl_makezd2filezd2namez00zz__osz00(BgL_arg1047z00_57,
 						BGl_za2accesszd2filezd2defaultza2z00zzengine_paramz00);
 				}
-				if (fexists(BSTRING_TO_STRING(BgL_afilez00_48)))
+				if (fexists(BSTRING_TO_STRING(BgL_afilez00_49)))
 					{	/* Engine/interp.scm 55 */
 						{	/* Engine/interp.scm 56 */
-							obj_t BgL_list1041z00_50;
+							obj_t BgL_list1042z00_51;
 
 							{	/* Engine/interp.scm 56 */
-								obj_t BgL_arg1042z00_51;
+								obj_t BgL_arg1043z00_52;
 
 								{	/* Engine/interp.scm 56 */
-									obj_t BgL_arg1043z00_52;
+									obj_t BgL_arg1044z00_53;
 
 									{	/* Engine/interp.scm 56 */
-										obj_t BgL_arg1045z00_53;
+										obj_t BgL_arg1046z00_54;
 
-										BgL_arg1045z00_53 =
+										BgL_arg1046z00_54 =
 											MAKE_YOUNG_PAIR(BCHAR(((unsigned char) 10)), BNIL);
-										BgL_arg1043z00_52 =
-											MAKE_YOUNG_PAIR(BGl_string1077z00zzengine_interpz00,
-											BgL_arg1045z00_53);
+										BgL_arg1044z00_53 =
+											MAKE_YOUNG_PAIR(BGl_string1103z00zzengine_interpz00,
+											BgL_arg1046z00_54);
 									}
-									BgL_arg1042z00_51 =
-										MAKE_YOUNG_PAIR(BgL_afilez00_48, BgL_arg1043z00_52);
+									BgL_arg1043z00_52 =
+										MAKE_YOUNG_PAIR(BgL_afilez00_49, BgL_arg1044z00_53);
 								}
-								BgL_list1041z00_50 =
-									MAKE_YOUNG_PAIR(BGl_string1078z00zzengine_interpz00,
-									BgL_arg1042z00_51);
+								BgL_list1042z00_51 =
+									MAKE_YOUNG_PAIR(BGl_string1104z00zzengine_interpz00,
+									BgL_arg1043z00_52);
 							}
-							BGl_verbosez00zztools_speekz00(BINT(2L), BgL_list1041z00_50);
+							BGl_verbosez00zztools_speekz00(BINT(2L), BgL_list1042z00_51);
 						}
-						BGl_modulezd2loadzd2accesszd2filezd2zz__modulez00(BgL_afilez00_48);
+						BGl_modulezd2loadzd2accesszd2filezd2zz__modulez00(BgL_afilez00_49);
 					}
 				else
 					{	/* Engine/interp.scm 55 */
 						BFALSE;
 					}
 				{	/* Engine/interp.scm 58 */
-					obj_t BgL_envz00_55;
+					obj_t BgL_envz00_56;
 
-					BgL_envz00_55 = BGl_defaultzd2environmentzd2zz__evalz00();
+					BgL_envz00_56 = BGl_defaultzd2environmentzd2zz__evalz00();
 					{	/* Engine/interp.scm 58 */
 
-						return BGl_loadqz00zz__evalz00(BgL_fz00_9, BgL_envz00_55);
+						return BGl_loadqz00zz__evalz00(BgL_fz00_9, BgL_envz00_56);
 					}
 				}
 			}
@@ -500,72 +502,72 @@ extern "C"
 	{
 		{	/* Engine/interp.scm 63 */
 			{	/* Engine/interp.scm 64 */
-				obj_t BgL_g1012z00_57;
+				obj_t BgL_g1012z00_58;
 
 				{	/* Engine/interp.scm 64 */
-					obj_t BgL_arg1051z00_69;
+					obj_t BgL_arg1052z00_70;
 
 					{	/* Engine/interp.scm 64 */
-						obj_t BgL_tmpz00_242;
+						obj_t BgL_tmpz00_245;
 
-						BgL_tmpz00_242 = BGL_CURRENT_DYNAMIC_ENV();
-						BgL_arg1051z00_69 = BGL_ENV_CURRENT_INPUT_PORT(BgL_tmpz00_242);
+						BgL_tmpz00_245 = BGL_CURRENT_DYNAMIC_ENV();
+						BgL_arg1052z00_70 = BGL_ENV_CURRENT_INPUT_PORT(BgL_tmpz00_245);
 					}
 					{	/* Engine/interp.scm 64 */
 
 						{	/* Engine/interp.scm 64 */
 
-							BgL_g1012z00_57 =
-								BGl_readz00zz__readerz00(BgL_arg1051z00_69, BFALSE);
+							BgL_g1012z00_58 =
+								BGl_readz00zz__readerz00(BgL_arg1052z00_70, BFALSE);
 				}}}
 				{
-					obj_t BgL_ez00_59;
+					obj_t BgL_ez00_60;
 
-					BgL_ez00_59 = BgL_g1012z00_57;
-				BgL_zc3z04anonymousza31047ze3z87_60:
-					if (EOF_OBJECTP(BgL_ez00_59))
+					BgL_ez00_60 = BgL_g1012z00_58;
+				BgL_zc3z04anonymousza31048ze3z87_61:
+					if (EOF_OBJECTP(BgL_ez00_60))
 						{	/* Engine/interp.scm 65 */
 							return ((bool_t) 0);
 						}
 					else
 						{	/* Engine/interp.scm 65 */
 							{	/* Engine/interp.scm 67 */
-								obj_t BgL_envz00_63;
+								obj_t BgL_envz00_64;
 
-								BgL_envz00_63 = BGl_defaultzd2environmentzd2zz__evalz00();
+								BgL_envz00_64 = BGl_defaultzd2environmentzd2zz__evalz00();
 								{	/* Engine/interp.scm 67 */
 
-									BGl_evalz00zz__evalz00(BgL_ez00_59, BgL_envz00_63);
+									BGl_evalz00zz__evalz00(BgL_ez00_60, BgL_envz00_64);
 								}
 							}
 							{	/* Engine/interp.scm 68 */
-								obj_t BgL_arg1049z00_64;
+								obj_t BgL_arg1050z00_65;
 
 								{	/* Engine/interp.scm 68 */
-									obj_t BgL_arg1050z00_65;
+									obj_t BgL_arg1051z00_66;
 
 									{	/* Engine/interp.scm 68 */
-										obj_t BgL_tmpz00_250;
+										obj_t BgL_tmpz00_253;
 
-										BgL_tmpz00_250 = BGL_CURRENT_DYNAMIC_ENV();
-										BgL_arg1050z00_65 =
-											BGL_ENV_CURRENT_INPUT_PORT(BgL_tmpz00_250);
+										BgL_tmpz00_253 = BGL_CURRENT_DYNAMIC_ENV();
+										BgL_arg1051z00_66 =
+											BGL_ENV_CURRENT_INPUT_PORT(BgL_tmpz00_253);
 									}
 									{	/* Engine/interp.scm 68 */
 
 										{	/* Engine/interp.scm 68 */
 
-											BgL_arg1049z00_64 =
-												BGl_readz00zz__readerz00(BgL_arg1050z00_65, BFALSE);
+											BgL_arg1050z00_65 =
+												BGl_readz00zz__readerz00(BgL_arg1051z00_66, BFALSE);
 										}
 									}
 								}
 								{
-									obj_t BgL_ez00_254;
+									obj_t BgL_ez00_257;
 
-									BgL_ez00_254 = BgL_arg1049z00_64;
-									BgL_ez00_59 = BgL_ez00_254;
-									goto BgL_zc3z04anonymousza31047ze3z87_60;
+									BgL_ez00_257 = BgL_arg1050z00_65;
+									BgL_ez00_60 = BgL_ez00_257;
+									goto BgL_zc3z04anonymousza31048ze3z87_61;
 								}
 							}
 						}
@@ -582,175 +584,175 @@ extern "C"
 	{
 		{	/* Engine/interp.scm 73 */
 			{	/* Engine/interp.scm 74 */
-				obj_t BgL_g1013z00_72;
+				obj_t BgL_g1013z00_73;
 
-				BgL_g1013z00_72 = CDR(((obj_t) BgL_argsz00_10));
+				BgL_g1013z00_73 = CDR(((obj_t) BgL_argsz00_10));
 				{
-					obj_t BgL_argsz00_75;
-					obj_t BgL_resz00_76;
+					obj_t BgL_argsz00_76;
+					obj_t BgL_resz00_77;
 
-					BgL_argsz00_75 = BgL_g1013z00_72;
-					BgL_resz00_76 = BNIL;
-				BgL_zc3z04anonymousza31052ze3z87_77:
-					if (NULLP(BgL_argsz00_75))
+					BgL_argsz00_76 = BgL_g1013z00_73;
+					BgL_resz00_77 = BNIL;
+				BgL_zc3z04anonymousza31053ze3z87_78:
+					if (NULLP(BgL_argsz00_76))
 						{	/* Engine/interp.scm 78 */
-							obj_t BgL_arg1054z00_79;
+							obj_t BgL_arg1055z00_80;
 
-							BgL_arg1054z00_79 = bgl_reverse(BgL_resz00_76);
+							BgL_arg1055z00_80 = bgl_reverse(BgL_resz00_77);
 							return
 								BGl_appendzd221011zd2zzengine_interpz00
-								(BGl_za2srczd2filesza2zd2zzengine_paramz00, BgL_arg1054z00_79);
+								(BGl_za2srczd2filesza2zd2zzengine_paramz00, BgL_arg1055z00_80);
 						}
 					else
 						{	/* Engine/interp.scm 79 */
-							bool_t BgL_test1107z00_261;
+							bool_t BgL_test1134z00_264;
 
 							{	/* Engine/interp.scm 79 */
-								obj_t BgL_arg1071z00_94;
+								obj_t BgL_arg1097z00_95;
 
-								BgL_arg1071z00_94 = CAR(((obj_t) BgL_argsz00_75));
+								BgL_arg1097z00_95 = CAR(((obj_t) BgL_argsz00_76));
 								{	/* Engine/interp.scm 79 */
-									long BgL_l1z00_110;
+									long BgL_l1z00_111;
 
-									BgL_l1z00_110 = STRING_LENGTH(((obj_t) BgL_arg1071z00_94));
-									if ((BgL_l1z00_110 == 2L))
+									BgL_l1z00_111 = STRING_LENGTH(((obj_t) BgL_arg1097z00_95));
+									if ((BgL_l1z00_111 == 2L))
 										{	/* Engine/interp.scm 79 */
-											int BgL_arg1303z00_113;
+											int BgL_arg1343z00_114;
 
 											{	/* Engine/interp.scm 79 */
-												char *BgL_auxz00_271;
-												char *BgL_tmpz00_268;
+												char *BgL_auxz00_274;
+												char *BgL_tmpz00_271;
 
-												BgL_auxz00_271 =
+												BgL_auxz00_274 =
 													BSTRING_TO_STRING
-													(BGl_string1079z00zzengine_interpz00);
-												BgL_tmpz00_268 =
-													BSTRING_TO_STRING(((obj_t) BgL_arg1071z00_94));
-												BgL_arg1303z00_113 =
-													memcmp(BgL_tmpz00_268, BgL_auxz00_271, BgL_l1z00_110);
+													(BGl_string1105z00zzengine_interpz00);
+												BgL_tmpz00_271 =
+													BSTRING_TO_STRING(((obj_t) BgL_arg1097z00_95));
+												BgL_arg1343z00_114 =
+													memcmp(BgL_tmpz00_271, BgL_auxz00_274, BgL_l1z00_111);
 											}
-											BgL_test1107z00_261 = ((long) (BgL_arg1303z00_113) == 0L);
+											BgL_test1134z00_264 = ((long) (BgL_arg1343z00_114) == 0L);
 										}
 									else
 										{	/* Engine/interp.scm 79 */
-											BgL_test1107z00_261 = ((bool_t) 0);
+											BgL_test1134z00_264 = ((bool_t) 0);
 										}
 								}
 							}
-							if (BgL_test1107z00_261)
+							if (BgL_test1134z00_264)
 								{	/* Engine/interp.scm 80 */
-									obj_t BgL_arg1057z00_82;
+									obj_t BgL_arg1058z00_83;
 
-									BgL_arg1057z00_82 = CDR(((obj_t) BgL_argsz00_75));
+									BgL_arg1058z00_83 = CDR(((obj_t) BgL_argsz00_76));
 									{
-										obj_t BgL_argsz00_278;
+										obj_t BgL_argsz00_281;
 
-										BgL_argsz00_278 = BgL_arg1057z00_82;
-										BgL_argsz00_75 = BgL_argsz00_278;
-										goto BgL_zc3z04anonymousza31052ze3z87_77;
+										BgL_argsz00_281 = BgL_arg1058z00_83;
+										BgL_argsz00_76 = BgL_argsz00_281;
+										goto BgL_zc3z04anonymousza31053ze3z87_78;
 									}
 								}
 							else
 								{	/* Engine/interp.scm 81 */
-									bool_t BgL_test1109z00_279;
+									bool_t BgL_test1136z00_282;
 
 									{	/* Engine/interp.scm 81 */
-										obj_t BgL_arg1070z00_93;
+										obj_t BgL_arg1095z00_94;
 
-										BgL_arg1070z00_93 = CAR(((obj_t) BgL_argsz00_75));
-										BgL_test1109z00_279 =
+										BgL_arg1095z00_94 = CAR(((obj_t) BgL_argsz00_76));
+										BgL_test1136z00_282 =
 											CBOOL(BGl_memberz00zz__r4_pairs_and_lists_6_3z00
-											(BgL_arg1070z00_93,
+											(BgL_arg1095z00_94,
 												BGl_za2srczd2filesza2zd2zzengine_paramz00));
 									}
-									if (BgL_test1109z00_279)
+									if (BgL_test1136z00_282)
 										{	/* Engine/interp.scm 82 */
-											obj_t BgL_arg1060z00_85;
+											obj_t BgL_arg1063z00_86;
 
-											BgL_arg1060z00_85 = CDR(((obj_t) BgL_argsz00_75));
+											BgL_arg1063z00_86 = CDR(((obj_t) BgL_argsz00_76));
 											{
-												obj_t BgL_argsz00_286;
+												obj_t BgL_argsz00_289;
 
-												BgL_argsz00_286 = BgL_arg1060z00_85;
-												BgL_argsz00_75 = BgL_argsz00_286;
-												goto BgL_zc3z04anonymousza31052ze3z87_77;
+												BgL_argsz00_289 = BgL_arg1063z00_86;
+												BgL_argsz00_76 = BgL_argsz00_289;
+												goto BgL_zc3z04anonymousza31053ze3z87_78;
 											}
 										}
 									else
 										{	/* Engine/interp.scm 84 */
-											bool_t BgL_test1110z00_287;
+											bool_t BgL_test1137z00_290;
 
 											{	/* Engine/interp.scm 84 */
-												obj_t BgL_arg1068z00_92;
+												obj_t BgL_arg1083z00_93;
 
-												BgL_arg1068z00_92 = CAR(((obj_t) BgL_argsz00_75));
+												BgL_arg1083z00_93 = CAR(((obj_t) BgL_argsz00_76));
 												{	/* Engine/interp.scm 84 */
-													long BgL_l1z00_125;
+													long BgL_l1z00_126;
 
-													BgL_l1z00_125 =
-														STRING_LENGTH(((obj_t) BgL_arg1068z00_92));
-													if ((BgL_l1z00_125 == 2L))
+													BgL_l1z00_126 =
+														STRING_LENGTH(((obj_t) BgL_arg1083z00_93));
+													if ((BgL_l1z00_126 == 2L))
 														{	/* Engine/interp.scm 84 */
-															int BgL_arg1303z00_128;
+															int BgL_arg1343z00_129;
 
 															{	/* Engine/interp.scm 84 */
-																char *BgL_auxz00_297;
-																char *BgL_tmpz00_294;
+																char *BgL_auxz00_300;
+																char *BgL_tmpz00_297;
 
-																BgL_auxz00_297 =
+																BgL_auxz00_300 =
 																	BSTRING_TO_STRING
-																	(BGl_string1080z00zzengine_interpz00);
-																BgL_tmpz00_294 =
+																	(BGl_string1106z00zzengine_interpz00);
+																BgL_tmpz00_297 =
 																	BSTRING_TO_STRING(((obj_t)
-																		BgL_arg1068z00_92));
-																BgL_arg1303z00_128 =
-																	memcmp(BgL_tmpz00_294, BgL_auxz00_297,
-																	BgL_l1z00_125);
+																		BgL_arg1083z00_93));
+																BgL_arg1343z00_129 =
+																	memcmp(BgL_tmpz00_297, BgL_auxz00_300,
+																	BgL_l1z00_126);
 															}
-															BgL_test1110z00_287 =
-																((long) (BgL_arg1303z00_128) == 0L);
+															BgL_test1137z00_290 =
+																((long) (BgL_arg1343z00_129) == 0L);
 														}
 													else
 														{	/* Engine/interp.scm 84 */
-															BgL_test1110z00_287 = ((bool_t) 0);
+															BgL_test1137z00_290 = ((bool_t) 0);
 														}
 												}
 											}
-											if (BgL_test1110z00_287)
+											if (BgL_test1137z00_290)
 												{	/* Engine/interp.scm 85 */
-													obj_t BgL_arg1063z00_88;
+													obj_t BgL_arg1067z00_89;
 
-													BgL_arg1063z00_88 = CDR(((obj_t) BgL_argsz00_75));
+													BgL_arg1067z00_89 = CDR(((obj_t) BgL_argsz00_76));
 													{
-														obj_t BgL_argsz00_304;
+														obj_t BgL_argsz00_307;
 
-														BgL_argsz00_304 = BgL_arg1063z00_88;
-														BgL_argsz00_75 = BgL_argsz00_304;
-														goto BgL_zc3z04anonymousza31052ze3z87_77;
+														BgL_argsz00_307 = BgL_arg1067z00_89;
+														BgL_argsz00_76 = BgL_argsz00_307;
+														goto BgL_zc3z04anonymousza31053ze3z87_78;
 													}
 												}
 											else
 												{	/* Engine/interp.scm 87 */
-													obj_t BgL_arg1064z00_89;
-													obj_t BgL_arg1066z00_90;
+													obj_t BgL_arg1068z00_90;
+													obj_t BgL_arg1072z00_91;
 
-													BgL_arg1064z00_89 = CDR(((obj_t) BgL_argsz00_75));
+													BgL_arg1068z00_90 = CDR(((obj_t) BgL_argsz00_76));
 													{	/* Engine/interp.scm 87 */
-														obj_t BgL_arg1067z00_91;
+														obj_t BgL_arg1074z00_92;
 
-														BgL_arg1067z00_91 = CAR(((obj_t) BgL_argsz00_75));
-														BgL_arg1066z00_90 =
-															MAKE_YOUNG_PAIR(BgL_arg1067z00_91, BgL_resz00_76);
+														BgL_arg1074z00_92 = CAR(((obj_t) BgL_argsz00_76));
+														BgL_arg1072z00_91 =
+															MAKE_YOUNG_PAIR(BgL_arg1074z00_92, BgL_resz00_77);
 													}
 													{
-														obj_t BgL_resz00_311;
-														obj_t BgL_argsz00_310;
+														obj_t BgL_resz00_314;
+														obj_t BgL_argsz00_313;
 
-														BgL_argsz00_310 = BgL_arg1064z00_89;
-														BgL_resz00_311 = BgL_arg1066z00_90;
-														BgL_resz00_76 = BgL_resz00_311;
-														BgL_argsz00_75 = BgL_argsz00_310;
-														goto BgL_zc3z04anonymousza31052ze3z87_77;
+														BgL_argsz00_313 = BgL_arg1068z00_90;
+														BgL_resz00_314 = BgL_arg1072z00_91;
+														BgL_resz00_77 = BgL_resz00_314;
+														BgL_argsz00_76 = BgL_argsz00_313;
+														goto BgL_zc3z04anonymousza31053ze3z87_78;
 													}
 												}
 										}
@@ -801,11 +803,11 @@ extern "C"
 	obj_t BGl_importedzd2moduleszd2initz00zzengine_interpz00(void)
 	{
 		{	/* Engine/interp.scm 15 */
-			BGl_modulezd2initializa7ationz75zzengine_paramz00(517137079L,
-				BSTRING_TO_STRING(BGl_string1081z00zzengine_interpz00));
+			BGl_modulezd2initializa7ationz75zzengine_paramz00(161876678L,
+				BSTRING_TO_STRING(BGl_string1107z00zzengine_interpz00));
 			return
 				BGl_modulezd2initializa7ationz75zztools_speekz00(61247943L,
-				BSTRING_TO_STRING(BGl_string1081z00zzengine_interpz00));
+				BSTRING_TO_STRING(BGl_string1107z00zzengine_interpz00));
 		}
 
 	}
