@@ -1,9 +1,9 @@
 /*===========================================================================*/
 /*   (Expand/expander.scm)                                                   */
-/*   Bigloo (4.5b)                                                           */
-/*   Inria -- Sophia Antipolis (c)       Fri Dec 22 05:17:06 PM CET 2023     */
+/*   Bigloo (4.6a)                                                           */
+/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
 /*===========================================================================*/
-/* COMPILATION: (/home/serrano/prgm/project/bigloo/bigloo/bin/bigloo -ldopt -L/home/serrano/prgm/project/bigloo/bigloo/libbacktrace/home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b  -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Expand/expander.scm) */
+/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Expand/expander.scm) */
 /* GC selection */
 #define THE_GC BOEHM_GC
 
@@ -128,88 +128,87 @@ extern "C"
 
 	   
 		 
-		DEFINE_STRING(BGl_string1083z00zzexpand_expanderz00,
-		BgL_bgl_string1083za700za7za7e1093za7, "install-O-comptime-expander", 27);
-	      DEFINE_STRING(BGl_string1084z00zzexpand_expanderz00,
-		BgL_bgl_string1084za700za7za7e1094za7,
-		"Illegal re-installation of O-expander", 37);
-	      DEFINE_STRING(BGl_string1085z00zzexpand_expanderz00,
-		BgL_bgl_string1085za700za7za7e1095za7, "install-G-comptime-expander", 27);
-	      DEFINE_STRING(BGl_string1086z00zzexpand_expanderz00,
-		BgL_bgl_string1086za700za7za7e1096za7,
-		"Illegal re-installation of G-expander", 37);
-	      DEFINE_STRING(BGl_string1087z00zzexpand_expanderz00,
-		BgL_bgl_string1087za700za7za7e1097za7, "expand", 6);
-	      DEFINE_STRING(BGl_string1088z00zzexpand_expanderz00,
-		BgL_bgl_string1088za700za7za7e1098za7, "Can't find syntax definition", 28);
-	      DEFINE_STRING(BGl_string1089z00zzexpand_expanderz00,
-		BgL_bgl_string1089za700za7za7e1099za7, "Can't find macro definition", 27);
-	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_addzd2Ozd2macrozd2toplevelz12zd2envz12zzexpand_expanderz00,
-		BgL_bgl_za762addza7d2oza7d2mac1100za7,
+		BgL_bgl_za762addza7d2oza7d2mac1111za7,
 		BGl_z62addzd2Ozd2macrozd2toplevelz12za2zzexpand_expanderz00, 0L, BUNSPEC,
 		1);
-	      DEFINE_STRING(BGl_string1090z00zzexpand_expanderz00,
-		BgL_bgl_string1090za700za7za7e1101za7, "expand_expander", 15);
-	      DEFINE_STRING(BGl_string1091z00zzexpand_expanderz00,
-		BgL_bgl_string1091za700za7za7e1102za7, "syntax expander ", 16);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_checkzd2tozd2bezd2macroszd2envz00zzexpand_expanderz00,
-		BgL_bgl_za762checkza7d2toza7d21103za7,
+		BgL_bgl_za762checkza7d2toza7d21112za7,
 		BGl_z62checkzd2tozd2bezd2macroszb0zzexpand_expanderz00, 0L, BUNSPEC, 0);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_findzd2Gzd2expanderzd2envzd2zzexpand_expanderz00,
-		BgL_bgl_za762findza7d2gza7d2ex1104za7,
+		BgL_bgl_za762findza7d2gza7d2ex1113za7,
 		BGl_z62findzd2Gzd2expanderz62zzexpand_expanderz00, 0L, BUNSPEC, 1);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_installzd2Ozd2comptimezd2expanderzd2envz00zzexpand_expanderz00,
-		BgL_bgl_za762installza7d2oza7d1105za7,
+		BgL_bgl_za762installza7d2oza7d1114za7,
 		BGl_z62installzd2Ozd2comptimezd2expanderzb0zzexpand_expanderz00, 0L,
 		BUNSPEC, 2);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_tozd2bezd2macroz12zd2envzc0zzexpand_expanderz00,
-		BgL_bgl_za762toza7d2beza7d2mac1106za7,
+		BgL_bgl_za762toza7d2beza7d2mac1115za7,
 		BGl_z62tozd2bezd2macroz12z70zzexpand_expanderz00, 0L, BUNSPEC, 2);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_initializa7ezd2Genvz12zd2envzb5zzexpand_expanderz00,
-		BgL_bgl_za762initializa7a7eza71107za7,
+		BgL_bgl_za762initializa7a7eza71116za7,
 		BGl_z62initializa7ezd2Genvz12z05zzexpand_expanderz00, 0L, BUNSPEC, 0);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_initializa7ezd2Oenvz12zd2envzb5zzexpand_expanderz00,
-		BgL_bgl_za762initializa7a7eza71108za7,
+		BgL_bgl_za762initializa7a7eza71117za7,
 		BGl_z62initializa7ezd2Oenvz12z05zzexpand_expanderz00, 0L, BUNSPEC, 0);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_getzd2Ozd2macrozd2toplevelzd2envz00zzexpand_expanderz00,
-		BgL_bgl_za762getza7d2oza7d2mac1109za7,
+		BgL_bgl_za762getza7d2oza7d2mac1118za7,
 		BGl_z62getzd2Ozd2macrozd2toplevelzb0zzexpand_expanderz00, 0L, BUNSPEC, 0);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_findzd2Ozd2expanderzd2envzd2zzexpand_expanderz00,
-		BgL_bgl_za762findza7d2oza7d2ex1110za7,
+		BgL_bgl_za762findza7d2oza7d2ex1119za7,
 		BGl_z62findzd2Ozd2expanderz62zzexpand_expanderz00, 0L, BUNSPEC, 1);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_unbindzd2Ozd2expanderz12zd2envzc0zzexpand_expanderz00,
-		BgL_bgl_za762unbindza7d2oza7d21111za7,
+		BgL_bgl_za762unbindza7d2oza7d21120za7,
 		BGl_z62unbindzd2Ozd2expanderz12z70zzexpand_expanderz00, 0L, BUNSPEC, 1);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_installzd2Gzd2comptimezd2expanderzd2envz00zzexpand_expanderz00,
-		BgL_bgl_za762installza7d2gza7d1112za7,
+		BgL_bgl_za762installza7d2gza7d1121za7,
 		BGl_z62installzd2Gzd2comptimezd2expanderzb0zzexpand_expanderz00, 0L,
 		BUNSPEC, 2);
+	      DEFINE_STRING(BGl_string1100z00zzexpand_expanderz00,
+		BgL_bgl_string1100za700za7za7e1122za7, "install-O-comptime-expander", 27);
+	      DEFINE_STRING(BGl_string1101z00zzexpand_expanderz00,
+		BgL_bgl_string1101za700za7za7e1123za7,
+		"Illegal re-installation of O-expander", 37);
+	      DEFINE_STRING(BGl_string1102z00zzexpand_expanderz00,
+		BgL_bgl_string1102za700za7za7e1124za7, "install-G-comptime-expander", 27);
+	      DEFINE_STRING(BGl_string1103z00zzexpand_expanderz00,
+		BgL_bgl_string1103za700za7za7e1125za7,
+		"Illegal re-installation of G-expander", 37);
+	      DEFINE_STRING(BGl_string1104z00zzexpand_expanderz00,
+		BgL_bgl_string1104za700za7za7e1126za7, "expand", 6);
+	      DEFINE_STRING(BGl_string1105z00zzexpand_expanderz00,
+		BgL_bgl_string1105za700za7za7e1127za7, "Can't find syntax definition", 28);
+	      DEFINE_STRING(BGl_string1106z00zzexpand_expanderz00,
+		BgL_bgl_string1106za700za7za7e1128za7, "Can't find macro definition", 27);
+	      DEFINE_STRING(BGl_string1107z00zzexpand_expanderz00,
+		BgL_bgl_string1107za700za7za7e1129za7, "expand_expander", 15);
+	      DEFINE_STRING(BGl_string1108z00zzexpand_expanderz00,
+		BgL_bgl_string1108za700za7za7e1130za7, "syntax expander ", 16);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_unbindzd2Gzd2expanderz12zd2envzc0zzexpand_expanderz00,
-		BgL_bgl_za762unbindza7d2gza7d21113za7,
+		BgL_bgl_za762unbindza7d2gza7d21131za7,
 		BGl_z62unbindzd2Gzd2expanderz12z70zzexpand_expanderz00, 0L, BUNSPEC, 1);
 
 /* GC roots registration */
@@ -240,7 +239,7 @@ extern "C"
 /* module-initialization */
 	BGL_EXPORTED_DEF obj_t
 		BGl_modulezd2initializa7ationz75zzexpand_expanderz00(long
-		BgL_checksumz00_186, char *BgL_fromz00_187)
+		BgL_checksumz00_187, char *BgL_fromz00_188)
 	{
 		{
 			if (CBOOL(BGl_requirezd2initializa7ationz75zzexpand_expanderz00))
@@ -295,70 +294,70 @@ extern "C"
 	{
 		{	/* Expand/expander.scm 15 */
 			{	/* Expand/expander.scm 15 */
-				obj_t BgL_cportz00_174;
+				obj_t BgL_cportz00_175;
 
 				{	/* Expand/expander.scm 15 */
-					obj_t BgL_stringz00_181;
+					obj_t BgL_stringz00_182;
 
-					BgL_stringz00_181 = BGl_string1091z00zzexpand_expanderz00;
+					BgL_stringz00_182 = BGl_string1108z00zzexpand_expanderz00;
 					{	/* Expand/expander.scm 15 */
-						obj_t BgL_startz00_182;
+						obj_t BgL_startz00_183;
 
-						BgL_startz00_182 = BINT(0L);
+						BgL_startz00_183 = BINT(0L);
 						{	/* Expand/expander.scm 15 */
-							obj_t BgL_endz00_183;
+							obj_t BgL_endz00_184;
 
-							BgL_endz00_183 = BINT(STRING_LENGTH(((obj_t) BgL_stringz00_181)));
+							BgL_endz00_184 = BINT(STRING_LENGTH(((obj_t) BgL_stringz00_182)));
 							{	/* Expand/expander.scm 15 */
 
-								BgL_cportz00_174 =
+								BgL_cportz00_175 =
 									BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00
-									(BgL_stringz00_181, BgL_startz00_182, BgL_endz00_183);
+									(BgL_stringz00_182, BgL_startz00_183, BgL_endz00_184);
 				}}}}
 				{
-					long BgL_iz00_175;
+					long BgL_iz00_176;
 
-					BgL_iz00_175 = 1L;
-				BgL_loopz00_176:
-					if ((BgL_iz00_175 == -1L))
+					BgL_iz00_176 = 1L;
+				BgL_loopz00_177:
+					if ((BgL_iz00_176 == (-1L)))
 						{	/* Expand/expander.scm 15 */
 							return BUNSPEC;
 						}
 					else
 						{	/* Expand/expander.scm 15 */
 							{	/* Expand/expander.scm 15 */
-								obj_t BgL_arg1092z00_177;
+								obj_t BgL_arg1110z00_178;
 
 								{	/* Expand/expander.scm 15 */
 
 									{	/* Expand/expander.scm 15 */
-										obj_t BgL_locationz00_179;
+										obj_t BgL_locationz00_180;
 
-										BgL_locationz00_179 = BBOOL(((bool_t) 0));
+										BgL_locationz00_180 = BBOOL(((bool_t) 0));
 										{	/* Expand/expander.scm 15 */
 
-											BgL_arg1092z00_177 =
-												BGl_readz00zz__readerz00(BgL_cportz00_174,
-												BgL_locationz00_179);
+											BgL_arg1110z00_178 =
+												BGl_readz00zz__readerz00(BgL_cportz00_175,
+												BgL_locationz00_180);
 										}
 									}
 								}
 								{	/* Expand/expander.scm 15 */
-									int BgL_tmpz00_216;
+									int BgL_tmpz00_217;
 
-									BgL_tmpz00_216 = (int) (BgL_iz00_175);
-									CNST_TABLE_SET(BgL_tmpz00_216, BgL_arg1092z00_177);
+									BgL_tmpz00_217 = (int) (BgL_iz00_176);
+									CNST_TABLE_SET(BgL_tmpz00_217, BgL_arg1110z00_178);
 							}}
 							{	/* Expand/expander.scm 15 */
-								int BgL_auxz00_180;
+								int BgL_auxz00_181;
 
-								BgL_auxz00_180 = (int) ((BgL_iz00_175 - 1L));
+								BgL_auxz00_181 = (int) ((BgL_iz00_176 - 1L));
 								{
-									long BgL_iz00_221;
+									long BgL_iz00_222;
 
-									BgL_iz00_221 = (long) (BgL_auxz00_180);
-									BgL_iz00_175 = BgL_iz00_221;
-									goto BgL_loopz00_176;
+									BgL_iz00_222 = (long) (BgL_auxz00_181);
+									BgL_iz00_176 = BgL_iz00_222;
+									goto BgL_loopz00_177;
 								}
 							}
 						}
@@ -410,7 +409,7 @@ extern "C"
 
 /* &initialize-Oenv! */
 	obj_t BGl_z62initializa7ezd2Oenvz12z05zzexpand_expanderz00(obj_t
-		BgL_envz00_145)
+		BgL_envz00_146)
 	{
 		{	/* Expand/expander.scm 41 */
 			return BGl_initializa7ezd2Oenvz12z67zzexpand_expanderz00();
@@ -437,12 +436,12 @@ extern "C"
 
 /* &add-O-macro-toplevel! */
 	obj_t BGl_z62addzd2Ozd2macrozd2toplevelz12za2zzexpand_expanderz00(obj_t
-		BgL_envz00_146, obj_t BgL_expz00_147)
+		BgL_envz00_147, obj_t BgL_expz00_148)
 	{
 		{	/* Expand/expander.scm 52 */
 			return
 				BGl_addzd2Ozd2macrozd2toplevelz12zc0zzexpand_expanderz00
-				(BgL_expz00_147);
+				(BgL_expz00_148);
 		}
 
 	}
@@ -455,11 +454,11 @@ extern "C"
 	{
 		{	/* Expand/expander.scm 58 */
 			{	/* Expand/expander.scm 59 */
-				obj_t BgL_vz00_44;
+				obj_t BgL_vz00_45;
 
-				BgL_vz00_44 = BGl_za2Ozd2macrozd2toplevelza2z00zzexpand_expanderz00;
+				BgL_vz00_45 = BGl_za2Ozd2macrozd2toplevelza2z00zzexpand_expanderz00;
 				BGl_za2Ozd2macrozd2toplevelza2z00zzexpand_expanderz00 = BNIL;
-				return BgL_vz00_44;
+				return BgL_vz00_45;
 			}
 		}
 
@@ -469,7 +468,7 @@ extern "C"
 
 /* &get-O-macro-toplevel */
 	obj_t BGl_z62getzd2Ozd2macrozd2toplevelzb0zzexpand_expanderz00(obj_t
-		BgL_envz00_148)
+		BgL_envz00_149)
 	{
 		{	/* Expand/expander.scm 58 */
 			return BGl_getzd2Ozd2macrozd2toplevelzd2zzexpand_expanderz00();
@@ -486,80 +485,81 @@ extern "C"
 	{
 		{	/* Expand/expander.scm 70 */
 			{	/* Expand/expander.scm 71 */
-				bool_t BgL_test1116z00_229;
+				bool_t BgL_test1134z00_230;
 
 				{	/* Expand/expander.scm 71 */
-					obj_t BgL_arg1039z00_55;
+					obj_t BgL_arg1039z00_56;
 
 					{	/* Expand/expander.scm 90 */
-						obj_t BgL__andtest_1012z00_115;
+						obj_t BgL__andtest_1012z00_116;
 
-						BgL__andtest_1012z00_115 =
+						BgL__andtest_1012z00_116 =
 							BGl_za2optimzd2Ozd2macrozf3za2zf3zzengine_paramz00;
-						if (CBOOL(BgL__andtest_1012z00_115))
+						if (CBOOL(BgL__andtest_1012z00_116))
 							{	/* Expand/expander.scm 90 */
-								BgL_arg1039z00_55 =
+								BgL_arg1039z00_56 =
 									BGl_hashtablezd2getzd2zz__hashz00
 									(BGl_za2Oenvza2z00zzexpand_expanderz00, BgL_keywordz00_14);
 							}
 						else
 							{	/* Expand/expander.scm 90 */
-								BgL_arg1039z00_55 = BFALSE;
+								BgL_arg1039z00_56 = BFALSE;
 							}
 					}
-					if (STRUCTP(BgL_arg1039z00_55))
+					if (STRUCTP(BgL_arg1039z00_56))
 						{	/* Expand/expander.scm 71 */
-							BgL_test1116z00_229 =
-								(STRUCT_KEY(BgL_arg1039z00_55) == CNST_TABLE_REF(0L));
+							BgL_test1134z00_230 =
+								(STRUCT_KEY(BgL_arg1039z00_56) == ((obj_t) CNST_TABLE_REF(0)));
 						}
 					else
 						{	/* Expand/expander.scm 71 */
-							BgL_test1116z00_229 = ((bool_t) 0);
+							BgL_test1134z00_230 = ((bool_t) 0);
 						}
 				}
-				if (BgL_test1116z00_229)
+				if (BgL_test1134z00_230)
 					{	/* Expand/expander.scm 71 */
 						return
 							BGl_internalzd2errorzd2zztools_errorz00
-							(BGl_string1083z00zzexpand_expanderz00,
-							BGl_string1084z00zzexpand_expanderz00, BgL_keywordz00_14);
+							(BGl_string1100z00zzexpand_expanderz00,
+							BGl_string1101z00zzexpand_expanderz00, BgL_keywordz00_14);
 					}
 				else
 					{	/* Expand/expander.scm 75 */
-						obj_t BgL_newz00_47;
+						obj_t BgL_newz00_48;
 
 						{	/* Expand/expander.scm 76 */
-							obj_t BgL_zc3z04anonymousza31037ze3z87_149;
+							obj_t BgL_zc3z04anonymousza31037ze3z87_150;
 
-							BgL_zc3z04anonymousza31037ze3z87_149 =
+							BgL_zc3z04anonymousza31037ze3z87_150 =
 								MAKE_FX_PROCEDURE
 								(BGl_z62zc3z04anonymousza31037ze3ze5zzexpand_expanderz00,
 								(int) (2L), (int) (1L));
-							PROCEDURE_SET(BgL_zc3z04anonymousza31037ze3z87_149, (int) (0L),
+							PROCEDURE_SET(BgL_zc3z04anonymousza31037ze3z87_150, (int) (0L),
 								BgL_functionz00_15);
 							{	/* Expand/expander.scm 75 */
-								obj_t BgL_newz00_120;
+								obj_t BgL_newz00_121;
 
-								BgL_newz00_120 = create_struct(CNST_TABLE_REF(0L), (int) (2L));
-								{	/* Expand/expander.scm 75 */
-									int BgL_tmpz00_247;
-
-									BgL_tmpz00_247 = (int) (1L);
-									STRUCT_SET(BgL_newz00_120, BgL_tmpz00_247,
-										BgL_zc3z04anonymousza31037ze3z87_149);
-								}
+								BgL_newz00_121 =
+									create_struct(((obj_t) CNST_TABLE_REF(0)), (int) (2L));
 								{	/* Expand/expander.scm 75 */
 									int BgL_tmpz00_250;
 
-									BgL_tmpz00_250 = (int) (0L);
-									STRUCT_SET(BgL_newz00_120, BgL_tmpz00_250, BgL_keywordz00_14);
+									BgL_tmpz00_250 = (int) (1L);
+									STRUCT_SET(BgL_newz00_121, BgL_tmpz00_250,
+										BgL_zc3z04anonymousza31037ze3z87_150);
 								}
-								BgL_newz00_47 = BgL_newz00_120;
+								{	/* Expand/expander.scm 75 */
+									int BgL_tmpz00_253;
+
+									BgL_tmpz00_253 = (int) (0L);
+									STRUCT_SET(BgL_newz00_121, BgL_tmpz00_253, BgL_keywordz00_14);
+								}
+								BgL_newz00_48 = BgL_newz00_121;
 						}}
 						BGl_hashtablezd2putz12zc0zz__hashz00
 							(BGl_za2Oenvza2z00zzexpand_expanderz00, BgL_keywordz00_14,
-							BgL_newz00_47);
-						return BgL_newz00_47;
+							BgL_newz00_48);
+						return BgL_newz00_48;
 					}
 			}
 		}
@@ -570,12 +570,12 @@ extern "C"
 
 /* &install-O-comptime-expander */
 	obj_t BGl_z62installzd2Ozd2comptimezd2expanderzb0zzexpand_expanderz00(obj_t
-		BgL_envz00_150, obj_t BgL_keywordz00_151, obj_t BgL_functionz00_152)
+		BgL_envz00_151, obj_t BgL_keywordz00_152, obj_t BgL_functionz00_153)
 	{
 		{	/* Expand/expander.scm 70 */
 			return
 				BGl_installzd2Ozd2comptimezd2expanderzd2zzexpand_expanderz00
-				(BgL_keywordz00_151, BgL_functionz00_152);
+				(BgL_keywordz00_152, BgL_functionz00_153);
 		}
 
 	}
@@ -584,33 +584,28 @@ extern "C"
 
 /* &<@anonymous:1037> */
 	obj_t BGl_z62zc3z04anonymousza31037ze3ze5zzexpand_expanderz00(obj_t
-		BgL_envz00_153, obj_t BgL_xz00_155, obj_t BgL_ez00_156)
+		BgL_envz00_154, obj_t BgL_xz00_156, obj_t BgL_ez00_157)
 	{
 		{	/* Expand/expander.scm 75 */
 			{	/* Expand/expander.scm 76 */
-				obj_t BgL_functionz00_154;
+				obj_t BgL_functionz00_155;
 
-				BgL_functionz00_154 =
-					((obj_t) PROCEDURE_REF(BgL_envz00_153, (int) (0L)));
+				BgL_functionz00_155 =
+					((obj_t) PROCEDURE_REF(BgL_envz00_154, (int) (0L)));
 				{	/* Expand/expander.scm 76 */
-					obj_t BgL_newxz00_185;
+					obj_t BgL_newxz00_186;
 
-					BgL_newxz00_185 =
-						(VA_PROCEDUREP(BgL_functionz00_154) ? ((obj_t(*)(obj_t,
-									...))
-							PROCEDURE_ENTRY(BgL_functionz00_154)) (BgL_functionz00_154,
-							BgL_xz00_155, BgL_ez00_156, BEOA) : ((obj_t(*)(obj_t, obj_t,
-									obj_t))
-							PROCEDURE_ENTRY(BgL_functionz00_154)) (BgL_functionz00_154,
-							BgL_xz00_155, BgL_ez00_156));
-					if (PAIRP(BgL_newxz00_185))
+					BgL_newxz00_186 =
+						BGL_PROCEDURE_CALL2(BgL_functionz00_155, BgL_xz00_156,
+						BgL_ez00_157);
+					if (PAIRP(BgL_newxz00_186))
 						{	/* Expand/expander.scm 77 */
 							return
-								BGl_epairifyz00zztools_miscz00(BgL_newxz00_185, BgL_xz00_155);
+								BGl_epairifyz00zztools_miscz00(BgL_newxz00_186, BgL_xz00_156);
 						}
 					else
 						{	/* Expand/expander.scm 77 */
-							return BgL_newxz00_185;
+							return BgL_newxz00_186;
 						}
 				}
 			}
@@ -626,11 +621,11 @@ extern "C"
 	{
 		{	/* Expand/expander.scm 89 */
 			{	/* Expand/expander.scm 90 */
-				obj_t BgL__andtest_1012z00_123;
+				obj_t BgL__andtest_1012z00_124;
 
-				BgL__andtest_1012z00_123 =
+				BgL__andtest_1012z00_124 =
 					BGl_za2optimzd2Ozd2macrozf3za2zf3zzengine_paramz00;
-				if (CBOOL(BgL__andtest_1012z00_123))
+				if (CBOOL(BgL__andtest_1012z00_124))
 					{	/* Expand/expander.scm 90 */
 						return
 							BGl_hashtablezd2getzd2zz__hashz00
@@ -648,11 +643,11 @@ extern "C"
 
 
 /* &find-O-expander */
-	obj_t BGl_z62findzd2Ozd2expanderz62zzexpand_expanderz00(obj_t BgL_envz00_157,
-		obj_t BgL_symbolz00_158)
+	obj_t BGl_z62findzd2Ozd2expanderz62zzexpand_expanderz00(obj_t BgL_envz00_158,
+		obj_t BgL_symbolz00_159)
 	{
 		{	/* Expand/expander.scm 89 */
-			return BGl_findzd2Ozd2expanderz00zzexpand_expanderz00(BgL_symbolz00_158);
+			return BGl_findzd2Ozd2expanderz00zzexpand_expanderz00(BgL_symbolz00_159);
 		}
 
 	}
@@ -675,11 +670,11 @@ extern "C"
 
 /* &unbind-O-expander! */
 	obj_t BGl_z62unbindzd2Ozd2expanderz12z70zzexpand_expanderz00(obj_t
-		BgL_envz00_159, obj_t BgL_symbolz00_160)
+		BgL_envz00_160, obj_t BgL_symbolz00_161)
 	{
 		{	/* Expand/expander.scm 95 */
 			return
-				BGl_unbindzd2Ozd2expanderz12z12zzexpand_expanderz00(BgL_symbolz00_160);
+				BGl_unbindzd2Ozd2expanderz12z12zzexpand_expanderz00(BgL_symbolz00_161);
 		}
 
 	}
@@ -700,7 +695,7 @@ extern "C"
 
 /* &initialize-Genv! */
 	obj_t BGl_z62initializa7ezd2Genvz12z05zzexpand_expanderz00(obj_t
-		BgL_envz00_161)
+		BgL_envz00_162)
 	{
 		{	/* Expand/expander.scm 106 */
 			return BGl_initializa7ezd2Genvz12z67zzexpand_expanderz00();
@@ -717,56 +712,57 @@ extern "C"
 	{
 		{	/* Expand/expander.scm 116 */
 			{	/* Expand/expander.scm 117 */
-				bool_t BgL_test1121z00_275;
+				bool_t BgL_test1139z00_278;
 
 				{	/* Expand/expander.scm 117 */
-					obj_t BgL_arg1043z00_61;
+					obj_t BgL_arg1043z00_62;
 
-					BgL_arg1043z00_61 =
+					BgL_arg1043z00_62 =
 						BGl_findzd2Gzd2expanderz00zzexpand_expanderz00(BgL_keywordz00_18);
-					if (STRUCTP(BgL_arg1043z00_61))
+					if (STRUCTP(BgL_arg1043z00_62))
 						{	/* Expand/expander.scm 117 */
-							BgL_test1121z00_275 =
-								(STRUCT_KEY(BgL_arg1043z00_61) == CNST_TABLE_REF(0L));
+							BgL_test1139z00_278 =
+								(STRUCT_KEY(BgL_arg1043z00_62) == ((obj_t) CNST_TABLE_REF(0)));
 						}
 					else
 						{	/* Expand/expander.scm 117 */
-							BgL_test1121z00_275 = ((bool_t) 0);
+							BgL_test1139z00_278 = ((bool_t) 0);
 						}
 				}
-				if (BgL_test1121z00_275)
+				if (BgL_test1139z00_278)
 					{	/* Expand/expander.scm 117 */
 						return
 							BGl_internalzd2errorzd2zztools_errorz00
-							(BGl_string1085z00zzexpand_expanderz00,
-							BGl_string1086z00zzexpand_expanderz00, BgL_keywordz00_18);
+							(BGl_string1102z00zzexpand_expanderz00,
+							BGl_string1103z00zzexpand_expanderz00, BgL_keywordz00_18);
 					}
 				else
 					{	/* Expand/expander.scm 121 */
-						obj_t BgL_newz00_60;
+						obj_t BgL_newz00_61;
 
 						{	/* Expand/expander.scm 121 */
-							obj_t BgL_newz00_128;
+							obj_t BgL_newz00_129;
 
-							BgL_newz00_128 = create_struct(CNST_TABLE_REF(0L), (int) (2L));
+							BgL_newz00_129 =
+								create_struct(((obj_t) CNST_TABLE_REF(0)), (int) (2L));
 							{	/* Expand/expander.scm 121 */
-								int BgL_tmpz00_286;
+								int BgL_tmpz00_291;
 
-								BgL_tmpz00_286 = (int) (1L);
-								STRUCT_SET(BgL_newz00_128, BgL_tmpz00_286, BgL_functionz00_19);
+								BgL_tmpz00_291 = (int) (1L);
+								STRUCT_SET(BgL_newz00_129, BgL_tmpz00_291, BgL_functionz00_19);
 							}
 							{	/* Expand/expander.scm 121 */
-								int BgL_tmpz00_289;
+								int BgL_tmpz00_294;
 
-								BgL_tmpz00_289 = (int) (0L);
-								STRUCT_SET(BgL_newz00_128, BgL_tmpz00_289, BgL_keywordz00_18);
+								BgL_tmpz00_294 = (int) (0L);
+								STRUCT_SET(BgL_newz00_129, BgL_tmpz00_294, BgL_keywordz00_18);
 							}
-							BgL_newz00_60 = BgL_newz00_128;
+							BgL_newz00_61 = BgL_newz00_129;
 						}
 						BGl_hashtablezd2putz12zc0zz__hashz00
 							(BGl_za2Genvza2z00zzexpand_expanderz00, BgL_keywordz00_18,
-							BgL_newz00_60);
-						return BgL_newz00_60;
+							BgL_newz00_61);
+						return BgL_newz00_61;
 					}
 			}
 		}
@@ -777,12 +773,12 @@ extern "C"
 
 /* &install-G-comptime-expander */
 	obj_t BGl_z62installzd2Gzd2comptimezd2expanderzb0zzexpand_expanderz00(obj_t
-		BgL_envz00_162, obj_t BgL_keywordz00_163, obj_t BgL_functionz00_164)
+		BgL_envz00_163, obj_t BgL_keywordz00_164, obj_t BgL_functionz00_165)
 	{
 		{	/* Expand/expander.scm 116 */
 			return
 				BGl_installzd2Gzd2comptimezd2expanderzd2zzexpand_expanderz00
-				(BgL_keywordz00_163, BgL_functionz00_164);
+				(BgL_keywordz00_164, BgL_functionz00_165);
 		}
 
 	}
@@ -797,22 +793,22 @@ extern "C"
 			if (BGl_numberzf3zf3zz__r4_numbers_6_5z00
 				(BGl_za2compilerzd2debugza2zd2zzengine_paramz00))
 				{	/* Expand/expander.scm 132 */
-					bool_t BgL_test1124z00_296;
+					bool_t BgL_test1142z00_301;
 
 					if (INTEGERP(BGl_za2compilerzd2debugza2zd2zzengine_paramz00))
 						{	/* Expand/expander.scm 132 */
-							BgL_test1124z00_296 =
+							BgL_test1142z00_301 =
 								(
 								(long) CINT(BGl_za2compilerzd2debugza2zd2zzengine_paramz00) >=
 								1L);
 						}
 					else
 						{	/* Expand/expander.scm 132 */
-							BgL_test1124z00_296 =
+							BgL_test1142z00_301 =
 								BGl_2ze3zd3z30zz__r4_numbers_6_5z00
 								(BGl_za2compilerzd2debugza2zd2zzengine_paramz00, BINT(1L));
 						}
-					if (BgL_test1124z00_296)
+					if (BgL_test1142z00_301)
 						{	/* Expand/expander.scm 132 */
 							return
 								BGl_hashtablezd2getzd2zz__hashz00
@@ -834,11 +830,11 @@ extern "C"
 
 
 /* &find-G-expander */
-	obj_t BGl_z62findzd2Gzd2expanderz62zzexpand_expanderz00(obj_t BgL_envz00_165,
-		obj_t BgL_symbolz00_166)
+	obj_t BGl_z62findzd2Gzd2expanderz62zzexpand_expanderz00(obj_t BgL_envz00_166,
+		obj_t BgL_symbolz00_167)
 	{
 		{	/* Expand/expander.scm 131 */
-			return BGl_findzd2Gzd2expanderz00zzexpand_expanderz00(BgL_symbolz00_166);
+			return BGl_findzd2Gzd2expanderz00zzexpand_expanderz00(BgL_symbolz00_167);
 		}
 
 	}
@@ -861,11 +857,11 @@ extern "C"
 
 /* &unbind-G-expander! */
 	obj_t BGl_z62unbindzd2Gzd2expanderz12z70zzexpand_expanderz00(obj_t
-		BgL_envz00_167, obj_t BgL_symbolz00_168)
+		BgL_envz00_168, obj_t BgL_symbolz00_169)
 	{
 		{	/* Expand/expander.scm 138 */
 			return
-				BGl_unbindzd2Gzd2expanderz12z12zzexpand_expanderz00(BgL_symbolz00_168);
+				BGl_unbindzd2Gzd2expanderz12z12zzexpand_expanderz00(BgL_symbolz00_169);
 		}
 
 	}
@@ -884,11 +880,11 @@ extern "C"
 				}
 			else
 				{	/* Expand/expander.scm 151 */
-					obj_t BgL_arg1045z00_65;
+					obj_t BgL_arg1046z00_66;
 
-					BgL_arg1045z00_65 = MAKE_YOUNG_PAIR(BgL_idz00_22, BgL_srcz00_23);
+					BgL_arg1046z00_66 = MAKE_YOUNG_PAIR(BgL_idz00_22, BgL_srcz00_23);
 					return (BGl_za2tozd2bezd2macrosza2z00zzexpand_expanderz00 =
-						MAKE_YOUNG_PAIR(BgL_arg1045z00_65,
+						MAKE_YOUNG_PAIR(BgL_arg1046z00_66,
 							BGl_za2tozd2bezd2macrosza2z00zzexpand_expanderz00), BUNSPEC);
 				}
 		}
@@ -898,13 +894,13 @@ extern "C"
 
 
 /* &to-be-macro! */
-	obj_t BGl_z62tozd2bezd2macroz12z70zzexpand_expanderz00(obj_t BgL_envz00_169,
-		obj_t BgL_idz00_170, obj_t BgL_srcz00_171)
+	obj_t BGl_z62tozd2bezd2macroz12z70zzexpand_expanderz00(obj_t BgL_envz00_170,
+		obj_t BgL_idz00_171, obj_t BgL_srcz00_172)
 	{
 		{	/* Expand/expander.scm 149 */
 			return
-				BGl_tozd2bezd2macroz12z12zzexpand_expanderz00(BgL_idz00_170,
-				BgL_srcz00_171);
+				BGl_tozd2bezd2macroz12z12zzexpand_expanderz00(BgL_idz00_171,
+				BgL_srcz00_172);
 		}
 
 	}
@@ -917,151 +913,155 @@ extern "C"
 	{
 		{	/* Expand/expander.scm 156 */
 			{
-				obj_t BgL_l1015z00_67;
+				obj_t BgL_l1015z00_68;
 
 				{	/* Expand/expander.scm 157 */
-					bool_t BgL_tmpz00_314;
+					bool_t BgL_tmpz00_319;
 
-					BgL_l1015z00_67 = BGl_za2tozd2bezd2macrosza2z00zzexpand_expanderz00;
-				BgL_zc3z04anonymousza31046ze3z87_68:
-					if (PAIRP(BgL_l1015z00_67))
+					BgL_l1015z00_68 = BGl_za2tozd2bezd2macrosza2z00zzexpand_expanderz00;
+				BgL_zc3z04anonymousza31047ze3z87_69:
+					if (PAIRP(BgL_l1015z00_68))
 						{	/* Expand/expander.scm 157 */
 							{	/* Expand/expander.scm 158 */
-								obj_t BgL_mz00_70;
+								obj_t BgL_mz00_71;
 
-								BgL_mz00_70 = CAR(BgL_l1015z00_67);
+								BgL_mz00_71 = CAR(BgL_l1015z00_68);
 								{
-									obj_t BgL_idz00_73;
-									obj_t BgL_idz00_71;
+									obj_t BgL_idz00_74;
+									obj_t BgL_idz00_72;
 
 									{	/* Expand/expander.scm 158 */
-										obj_t BgL_ezd2104zd2_76;
+										obj_t BgL_ezd2104zd2_77;
 
-										BgL_ezd2104zd2_76 = CDR(((obj_t) BgL_mz00_70));
-										if (PAIRP(BgL_ezd2104zd2_76))
+										BgL_ezd2104zd2_77 = CDR(((obj_t) BgL_mz00_71));
+										if (PAIRP(BgL_ezd2104zd2_77))
 											{	/* Expand/expander.scm 158 */
-												obj_t BgL_cdrzd2108zd2_78;
+												obj_t BgL_cdrzd2108zd2_79;
 
-												BgL_cdrzd2108zd2_78 = CDR(BgL_ezd2104zd2_76);
-												if ((CAR(BgL_ezd2104zd2_76) == CNST_TABLE_REF(1L)))
+												BgL_cdrzd2108zd2_79 = CDR(BgL_ezd2104zd2_77);
+												if (
+													(CAR(BgL_ezd2104zd2_77) ==
+														((obj_t) CNST_TABLE_REF(1))))
 													{	/* Expand/expander.scm 158 */
-														if (PAIRP(BgL_cdrzd2108zd2_78))
+														if (PAIRP(BgL_cdrzd2108zd2_79))
 															{	/* Expand/expander.scm 158 */
-																if (NULLP(CDR(BgL_cdrzd2108zd2_78)))
+																if (NULLP(CDR(BgL_cdrzd2108zd2_79)))
 																	{	/* Expand/expander.scm 158 */
-																		BgL_idz00_71 = CAR(BgL_cdrzd2108zd2_78);
+																		BgL_idz00_72 = CAR(BgL_cdrzd2108zd2_79);
 																		if (CBOOL
 																			(BGl_getzd2compilerzd2expanderz00zz__macroz00
-																				(BgL_idz00_71)))
+																				(BgL_idz00_72)))
 																			{	/* Expand/expander.scm 160 */
 																				BFALSE;
 																			}
 																		else
 																			{	/* Expand/expander.scm 160 */
 																				BGl_errorz00zz__errorz00
-																					(BGl_string1087z00zzexpand_expanderz00,
-																					BGl_string1088z00zzexpand_expanderz00,
-																					BgL_idz00_71);
+																					(BGl_string1104z00zzexpand_expanderz00,
+																					BGl_string1105z00zzexpand_expanderz00,
+																					BgL_idz00_72);
 																			}
 																	}
 																else
 																	{	/* Expand/expander.scm 158 */
-																	BgL_tagzd2103zd2_75:
+																	BgL_tagzd2103zd2_76:
 																		{	/* Expand/expander.scm 170 */
-																			bool_t BgL_test1133z00_337;
+																			bool_t BgL_test1151z00_343;
 
 																			{	/* Expand/expander.scm 170 */
-																				obj_t BgL_arg1073z00_101;
+																				obj_t BgL_arg1083z00_102;
 
-																				BgL_arg1073z00_101 =
-																					CAR(((obj_t) BgL_mz00_70));
-																				BgL_test1133z00_337 =
+																				BgL_arg1083z00_102 =
+																					CAR(((obj_t) BgL_mz00_71));
+																				BgL_test1151z00_343 =
 																					CBOOL
 																					(BGl_getzd2compilerzd2expanderz00zz__macroz00
-																					(BgL_arg1073z00_101));
+																					(BgL_arg1083z00_102));
 																			}
-																			if (BgL_test1133z00_337)
+																			if (BgL_test1151z00_343)
 																				{	/* Expand/expander.scm 170 */
 																					BFALSE;
 																				}
 																			else
 																				{	/* Expand/expander.scm 173 */
-																					obj_t BgL_arg1072z00_100;
+																					obj_t BgL_arg1074z00_101;
 
-																					BgL_arg1072z00_100 =
-																						CDR(((obj_t) BgL_mz00_70));
+																					BgL_arg1074z00_101 =
+																						CDR(((obj_t) BgL_mz00_71));
 																					BGl_errorz00zz__errorz00
-																						(BGl_string1087z00zzexpand_expanderz00,
-																						BGl_string1089z00zzexpand_expanderz00,
-																						BgL_arg1072z00_100);
+																						(BGl_string1104z00zzexpand_expanderz00,
+																						BGl_string1106z00zzexpand_expanderz00,
+																						BgL_arg1074z00_101);
 																				}
 																		}
 																	}
 															}
 														else
 															{	/* Expand/expander.scm 158 */
-																goto BgL_tagzd2103zd2_75;
+																goto BgL_tagzd2103zd2_76;
 															}
 													}
 												else
 													{	/* Expand/expander.scm 158 */
-														if ((CAR(BgL_ezd2104zd2_76) == CNST_TABLE_REF(0L)))
+														if (
+															(CAR(BgL_ezd2104zd2_77) ==
+																((obj_t) CNST_TABLE_REF(0))))
 															{	/* Expand/expander.scm 158 */
-																if (PAIRP(BgL_cdrzd2108zd2_78))
+																if (PAIRP(BgL_cdrzd2108zd2_79))
 																	{	/* Expand/expander.scm 158 */
-																		if (NULLP(CDR(BgL_cdrzd2108zd2_78)))
+																		if (NULLP(CDR(BgL_cdrzd2108zd2_79)))
 																			{	/* Expand/expander.scm 158 */
-																				BgL_idz00_73 = CAR(BgL_cdrzd2108zd2_78);
+																				BgL_idz00_74 = CAR(BgL_cdrzd2108zd2_79);
 																				if (CBOOL
 																					(BGl_getzd2compilerzd2expanderz00zz__macroz00
-																						(BgL_idz00_73)))
+																						(BgL_idz00_74)))
 																					{	/* Expand/expander.scm 165 */
 																						BFALSE;
 																					}
 																				else
 																					{	/* Expand/expander.scm 165 */
 																						BGl_errorz00zz__errorz00
-																							(BGl_string1087z00zzexpand_expanderz00,
-																							BGl_string1088z00zzexpand_expanderz00,
-																							BgL_idz00_73);
+																							(BGl_string1104z00zzexpand_expanderz00,
+																							BGl_string1105z00zzexpand_expanderz00,
+																							BgL_idz00_74);
 																					}
 																			}
 																		else
 																			{	/* Expand/expander.scm 158 */
-																				goto BgL_tagzd2103zd2_75;
+																				goto BgL_tagzd2103zd2_76;
 																			}
 																	}
 																else
 																	{	/* Expand/expander.scm 158 */
-																		goto BgL_tagzd2103zd2_75;
+																		goto BgL_tagzd2103zd2_76;
 																	}
 															}
 														else
 															{	/* Expand/expander.scm 158 */
-																goto BgL_tagzd2103zd2_75;
+																goto BgL_tagzd2103zd2_76;
 															}
 													}
 											}
 										else
 											{	/* Expand/expander.scm 158 */
-												goto BgL_tagzd2103zd2_75;
+												goto BgL_tagzd2103zd2_76;
 											}
 									}
 								}
 							}
 							{
-								obj_t BgL_l1015z00_359;
+								obj_t BgL_l1015z00_366;
 
-								BgL_l1015z00_359 = CDR(BgL_l1015z00_67);
-								BgL_l1015z00_67 = BgL_l1015z00_359;
-								goto BgL_zc3z04anonymousza31046ze3z87_68;
+								BgL_l1015z00_366 = CDR(BgL_l1015z00_68);
+								BgL_l1015z00_68 = BgL_l1015z00_366;
+								goto BgL_zc3z04anonymousza31047ze3z87_69;
 							}
 						}
 					else
 						{	/* Expand/expander.scm 157 */
-							BgL_tmpz00_314 = ((bool_t) 1);
+							BgL_tmpz00_319 = ((bool_t) 1);
 						}
-					return BBOOL(BgL_tmpz00_314);
+					return BBOOL(BgL_tmpz00_319);
 				}
 			}
 		}
@@ -1072,7 +1072,7 @@ extern "C"
 
 /* &check-to-be-macros */
 	obj_t BGl_z62checkzd2tozd2bezd2macroszb0zzexpand_expanderz00(obj_t
-		BgL_envz00_172)
+		BgL_envz00_173)
 	{
 		{	/* Expand/expander.scm 156 */
 			return BGl_checkzd2tozd2bezd2macroszd2zzexpand_expanderz00();
@@ -1120,12 +1120,12 @@ extern "C"
 	{
 		{	/* Expand/expander.scm 15 */
 			BGl_modulezd2initializa7ationz75zztools_errorz00(300504031L,
-				BSTRING_TO_STRING(BGl_string1090z00zzexpand_expanderz00));
-			BGl_modulezd2initializa7ationz75zzengine_paramz00(517137079L,
-				BSTRING_TO_STRING(BGl_string1090z00zzexpand_expanderz00));
+				BSTRING_TO_STRING(BGl_string1107z00zzexpand_expanderz00));
+			BGl_modulezd2initializa7ationz75zzengine_paramz00(161876678L,
+				BSTRING_TO_STRING(BGl_string1107z00zzexpand_expanderz00));
 			return
 				BGl_modulezd2initializa7ationz75zztools_miscz00(9470071L,
-				BSTRING_TO_STRING(BGl_string1090z00zzexpand_expanderz00));
+				BSTRING_TO_STRING(BGl_string1107z00zzexpand_expanderz00));
 		}
 
 	}
