@@ -1,9 +1,9 @@
 /*===========================================================================*/
 /*   (Foreign/access.scm)                                                    */
-/*   Bigloo (4.5b)                                                           */
-/*   Inria -- Sophia Antipolis (c)       Fri Dec 22 05:17:06 PM CET 2023     */
+/*   Bigloo (4.6a)                                                           */
+/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
 /*===========================================================================*/
-/* COMPILATION: (/home/serrano/prgm/project/bigloo/bigloo/bin/bigloo -ldopt -L/home/serrano/prgm/project/bigloo/bigloo/libbacktrace/home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b  -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Foreign/access.scm) */
+/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Foreign/access.scm) */
 /* GC selection */
 #define THE_GC BOEHM_GC
 
@@ -38,6 +38,7 @@ extern "C"
 		obj_t BgL_parentsz00;
 		bool_t BgL_initzf3zf3;
 		bool_t BgL_magiczf3zf3;
+		obj_t BgL_nullz00;
 		obj_t BgL_z42z42;
 		obj_t BgL_aliasz00;
 		obj_t BgL_pointedzd2tozd2byz00;
@@ -96,19 +97,19 @@ extern "C"
 
 	   
 		 
-		DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1062z00zzforeign_accessz00,
-		BgL_bgl_za762makeza7d2ctypeza71065za7,
+		DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1063z00zzforeign_accessz00,
+		BgL_bgl_za762makeza7d2ctypeza71066za7,
 		BGl_z62makezd2ctypezd2accessesz121050z70zzforeign_accessz00, 0L, BUNSPEC,
 		3);
 	     
 		DEFINE_EXPORT_BGL_GENERIC
 		(BGl_makezd2ctypezd2accessesz12zd2envzc0zzforeign_accessz00,
-		BgL_bgl_za762makeza7d2ctypeza71066za7,
+		BgL_bgl_za762makeza7d2ctypeza71067za7,
 		BGl_z62makezd2ctypezd2accessesz12z70zzforeign_accessz00, 0L, BUNSPEC, 3);
-	      DEFINE_STRING(BGl_string1063z00zzforeign_accessz00,
-		BgL_bgl_string1063za700za7za7f1067za7, "make-ctype-accesses!1050", 24);
 	      DEFINE_STRING(BGl_string1064z00zzforeign_accessz00,
-		BgL_bgl_string1064za700za7za7f1068za7, "foreign_access", 14);
+		BgL_bgl_string1064za700za7za7f1068za7, "make-ctype-accesses!1050", 24);
+	      DEFINE_STRING(BGl_string1065z00zzforeign_accessz00,
+		BgL_bgl_string1065za700za7za7f1069za7, "foreign_access", 14);
 
 /* GC roots registration */
 	static obj_t bgl_gc_roots_register()
@@ -131,7 +132,7 @@ extern "C"
 /* module-initialization */
 	BGL_EXPORTED_DEF obj_t
 		BGl_modulezd2initializa7ationz75zzforeign_accessz00(long
-		BgL_checksumz00_125, char *BgL_fromz00_126)
+		BgL_checksumz00_126, char *BgL_fromz00_127)
 	{
 		{
 			if (CBOOL(BGl_requirezd2initializa7ationz75zzforeign_accessz00))
@@ -212,8 +213,8 @@ extern "C"
 			return
 				BGl_registerzd2genericz12zc0zz__objectz00
 				(BGl_makezd2ctypezd2accessesz12zd2envzc0zzforeign_accessz00,
-				BGl_proc1062z00zzforeign_accessz00, BGl_typez00zztype_typez00,
-				BGl_string1063z00zzforeign_accessz00);
+				BGl_proc1063z00zzforeign_accessz00, BGl_typez00zztype_typez00,
+				BGl_string1064z00zzforeign_accessz00);
 		}
 
 	}
@@ -222,8 +223,8 @@ extern "C"
 
 /* &make-ctype-accesses!1050 */
 	obj_t BGl_z62makezd2ctypezd2accessesz121050z70zzforeign_accessz00(obj_t
-		BgL_envz00_115, obj_t BgL_whatz00_116, obj_t BgL_whoz00_117,
-		obj_t BgL_locz00_118)
+		BgL_envz00_116, obj_t BgL_whatz00_117, obj_t BgL_whoz00_118,
+		obj_t BgL_locz00_119)
 	{
 		{	/* Foreign/access.scm 34 */
 			return BNIL;
@@ -240,41 +241,41 @@ extern "C"
 	{
 		{	/* Foreign/access.scm 34 */
 			{	/* Foreign/access.scm 34 */
-				obj_t BgL_method1051z00_79;
+				obj_t BgL_method1051z00_80;
 
 				{	/* Foreign/access.scm 34 */
-					obj_t BgL_res1061z00_113;
+					obj_t BgL_res1062z00_114;
 
 					{	/* Foreign/access.scm 34 */
-						long BgL_objzd2classzd2numz00_84;
+						long BgL_objzd2classzd2numz00_85;
 
-						BgL_objzd2classzd2numz00_84 =
+						BgL_objzd2classzd2numz00_85 =
 							BGL_OBJECT_CLASS_NUM(((BgL_objectz00_bglt) BgL_whatz00_3));
 						{	/* Foreign/access.scm 34 */
-							obj_t BgL_arg1805z00_85;
+							obj_t BgL_arg1862z00_86;
 
-							BgL_arg1805z00_85 =
+							BgL_arg1862z00_86 =
 								PROCEDURE_REF
 								(BGl_makezd2ctypezd2accessesz12zd2envzc0zzforeign_accessz00,
 								(int) (1L));
 							{	/* Foreign/access.scm 34 */
-								int BgL_offsetz00_88;
+								int BgL_offsetz00_89;
 
-								BgL_offsetz00_88 = (int) (BgL_objzd2classzd2numz00_84);
+								BgL_offsetz00_89 = (int) (BgL_objzd2classzd2numz00_85);
 								{	/* Foreign/access.scm 34 */
-									long BgL_offsetz00_89;
+									long BgL_offsetz00_90;
 
-									BgL_offsetz00_89 = ((long) (BgL_offsetz00_88) - OBJECT_TYPE);
+									BgL_offsetz00_90 = ((long) (BgL_offsetz00_89) - OBJECT_TYPE);
 									{	/* Foreign/access.scm 34 */
-										long BgL_modz00_90;
+										long BgL_modz00_91;
 
-										BgL_modz00_90 =
-											(BgL_offsetz00_89 >> (int) ((long) ((int) (4L))));
+										BgL_modz00_91 =
+											(BgL_offsetz00_90 >> (int) ((long) ((int) (4L))));
 										{	/* Foreign/access.scm 34 */
-											long BgL_restz00_92;
+											long BgL_restz00_93;
 
-											BgL_restz00_92 =
-												(BgL_offsetz00_89 &
+											BgL_restz00_93 =
+												(BgL_offsetz00_90 &
 												(long) (
 													(int) (
 														((long) (
@@ -284,26 +285,20 @@ extern "C"
 											{	/* Foreign/access.scm 34 */
 
 												{	/* Foreign/access.scm 34 */
-													obj_t BgL_bucketz00_94;
+													obj_t BgL_bucketz00_95;
 
-													BgL_bucketz00_94 =
+													BgL_bucketz00_95 =
 														VECTOR_REF(
-														((obj_t) BgL_arg1805z00_85), BgL_modz00_90);
-													BgL_res1061z00_113 =
+														((obj_t) BgL_arg1862z00_86), BgL_modz00_91);
+													BgL_res1062z00_114 =
 														VECTOR_REF(
-														((obj_t) BgL_bucketz00_94), BgL_restz00_92);
+														((obj_t) BgL_bucketz00_95), BgL_restz00_93);
 					}}}}}}}}
-					BgL_method1051z00_79 = BgL_res1061z00_113;
+					BgL_method1051z00_80 = BgL_res1062z00_114;
 				}
 				return
-					(VA_PROCEDUREP(BgL_method1051z00_79) ? ((obj_t(*)(obj_t,
-								...))
-						PROCEDURE_ENTRY(BgL_method1051z00_79)) (BgL_method1051z00_79,
-						((obj_t) BgL_whatz00_3), ((obj_t) BgL_whoz00_4), BgL_locz00_5,
-						BEOA) : ((obj_t(*)(obj_t, obj_t, obj_t,
-								obj_t))
-						PROCEDURE_ENTRY(BgL_method1051z00_79)) (BgL_method1051z00_79,
-						((obj_t) BgL_whatz00_3), ((obj_t) BgL_whoz00_4), BgL_locz00_5));
+					BGL_PROCEDURE_CALL3(BgL_method1051z00_80,
+					((obj_t) BgL_whatz00_3), ((obj_t) BgL_whoz00_4), BgL_locz00_5);
 			}
 		}
 
@@ -313,14 +308,14 @@ extern "C"
 
 /* &make-ctype-accesses! */
 	obj_t BGl_z62makezd2ctypezd2accessesz12z70zzforeign_accessz00(obj_t
-		BgL_envz00_119, obj_t BgL_whatz00_120, obj_t BgL_whoz00_121,
-		obj_t BgL_locz00_122)
+		BgL_envz00_120, obj_t BgL_whatz00_121, obj_t BgL_whoz00_122,
+		obj_t BgL_locz00_123)
 	{
 		{	/* Foreign/access.scm 34 */
 			return
 				BGl_makezd2ctypezd2accessesz12z12zzforeign_accessz00(
-				((BgL_typez00_bglt) BgL_whatz00_120),
-				((BgL_typez00_bglt) BgL_whoz00_121), BgL_locz00_122);
+				((BgL_typez00_bglt) BgL_whatz00_121),
+				((BgL_typez00_bglt) BgL_whoz00_122), BgL_locz00_123);
 		}
 
 	}
@@ -343,20 +338,20 @@ extern "C"
 	{
 		{	/* Foreign/access.scm 19 */
 			BGl_modulezd2initializa7ationz75zztype_typez00(515343395L,
-				BSTRING_TO_STRING(BGl_string1064z00zzforeign_accessz00));
+				BSTRING_TO_STRING(BGl_string1065z00zzforeign_accessz00));
 			BGl_modulezd2initializa7ationz75zzforeign_caliasz00(237925119L,
-				BSTRING_TO_STRING(BGl_string1064z00zzforeign_accessz00));
+				BSTRING_TO_STRING(BGl_string1065z00zzforeign_accessz00));
 			BGl_modulezd2initializa7ationz75zzforeign_cenumz00(263357126L,
-				BSTRING_TO_STRING(BGl_string1064z00zzforeign_accessz00));
+				BSTRING_TO_STRING(BGl_string1065z00zzforeign_accessz00));
 			BGl_modulezd2initializa7ationz75zzforeign_copaquez00(499858556L,
-				BSTRING_TO_STRING(BGl_string1064z00zzforeign_accessz00));
+				BSTRING_TO_STRING(BGl_string1065z00zzforeign_accessz00));
 			BGl_modulezd2initializa7ationz75zzforeign_cfunctionz00(225725399L,
-				BSTRING_TO_STRING(BGl_string1064z00zzforeign_accessz00));
+				BSTRING_TO_STRING(BGl_string1065z00zzforeign_accessz00));
 			BGl_modulezd2initializa7ationz75zzforeign_cpointerz00(166831446L,
-				BSTRING_TO_STRING(BGl_string1064z00zzforeign_accessz00));
+				BSTRING_TO_STRING(BGl_string1065z00zzforeign_accessz00));
 			return
 				BGl_modulezd2initializa7ationz75zzforeign_cstructz00(216464466L,
-				BSTRING_TO_STRING(BGl_string1064z00zzforeign_accessz00));
+				BSTRING_TO_STRING(BGl_string1065z00zzforeign_accessz00));
 		}
 
 	}
