@@ -1,9 +1,9 @@
 /*===========================================================================*/
 /*   (Foreign/calias.scm)                                                    */
-/*   Bigloo (4.5b)                                                           */
-/*   Inria -- Sophia Antipolis (c)       Fri Dec 22 05:17:06 PM CET 2023     */
+/*   Bigloo (4.6a)                                                           */
+/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
 /*===========================================================================*/
-/* COMPILATION: (/home/serrano/prgm/project/bigloo/bigloo/bin/bigloo -ldopt -L/home/serrano/prgm/project/bigloo/bigloo/libbacktrace/home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b  -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Foreign/calias.scm) */
+/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Foreign/calias.scm) */
 /* GC selection */
 #define THE_GC BOEHM_GC
 
@@ -38,6 +38,7 @@ extern "C"
 		obj_t BgL_parentsz00;
 		bool_t BgL_initzf3zf3;
 		bool_t BgL_magiczf3zf3;
+		obj_t BgL_nullz00;
 		obj_t BgL_z42z42;
 		obj_t BgL_aliasz00;
 		obj_t BgL_pointedzd2tozd2byz00;
@@ -89,17 +90,17 @@ extern "C"
 
 	   
 		 
-		DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1144z00zzforeign_caliasz00,
-		BgL_bgl_za762makeza7d2ctypeza71147za7,
+		DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1143z00zzforeign_caliasz00,
+		BgL_bgl_za762makeza7d2ctypeza71146za7,
 		BGl_z62makezd2ctypezd2accessesz121090z70zzforeign_caliasz00, 0L, BUNSPEC,
 		3);
 	extern obj_t BGl_makezd2ctypezd2accessesz12zd2envzc0zzforeign_accessz00;
 	   
 		 
-		DEFINE_STRING(BGl_string1145z00zzforeign_caliasz00,
-		BgL_bgl_string1145za700za7za7f1148za7, "make-ctype-accesses!", 20);
-	      DEFINE_STRING(BGl_string1146z00zzforeign_caliasz00,
-		BgL_bgl_string1146za700za7za7f1149za7, "foreign_calias", 14);
+		DEFINE_STRING(BGl_string1144z00zzforeign_caliasz00,
+		BgL_bgl_string1144za700za7za7f1147za7, "make-ctype-accesses!", 20);
+	      DEFINE_STRING(BGl_string1145z00zzforeign_caliasz00,
+		BgL_bgl_string1145za700za7za7f1148za7, "foreign_calias", 14);
 
 /* GC roots registration */
 	static obj_t bgl_gc_roots_register()
@@ -122,7 +123,7 @@ extern "C"
 /* module-initialization */
 	BGL_EXPORTED_DEF obj_t
 		BGl_modulezd2initializa7ationz75zzforeign_caliasz00(long
-		BgL_checksumz00_588, char *BgL_fromz00_589)
+		BgL_checksumz00_589, char *BgL_fromz00_590)
 	{
 		{
 			if (CBOOL(BGl_requirezd2initializa7ationz75zzforeign_caliasz00))
@@ -209,8 +210,8 @@ extern "C"
 			return
 				BGl_genericzd2addzd2methodz12z12zz__objectz00
 				(BGl_makezd2ctypezd2accessesz12zd2envzc0zzforeign_accessz00,
-				BGl_caliasz00zzforeign_ctypez00, BGl_proc1144z00zzforeign_caliasz00,
-				BGl_string1145z00zzforeign_caliasz00);
+				BGl_caliasz00zzforeign_ctypez00, BGl_proc1143z00zzforeign_caliasz00,
+				BGl_string1144z00zzforeign_caliasz00);
 		}
 
 	}
@@ -219,21 +220,21 @@ extern "C"
 
 /* &make-ctype-accesses!1090 */
 	obj_t BGl_z62makezd2ctypezd2accessesz121090z70zzforeign_caliasz00(obj_t
-		BgL_envz00_577, obj_t BgL_whatz00_578, obj_t BgL_whoz00_579,
-		obj_t BgL_locz00_580)
+		BgL_envz00_578, obj_t BgL_whatz00_579, obj_t BgL_whoz00_580,
+		obj_t BgL_locz00_581)
 	{
 		{	/* Foreign/calias.scm 26 */
 			{	/* Tools/trace.sch 53 */
-				obj_t BgL_arg1095z00_587;
+				obj_t BgL_arg1098z00_588;
 
-				BgL_arg1095z00_587 =
+				BgL_arg1098z00_588 =
 					(((BgL_typez00_bglt) COBJECT(
 							((BgL_typez00_bglt)
-								((BgL_typez00_bglt) BgL_whatz00_578))))->BgL_aliasz00);
+								((BgL_typez00_bglt) BgL_whatz00_579))))->BgL_aliasz00);
 				return
 					BGl_makezd2ctypezd2accessesz12z12zzforeign_accessz00(
-					((BgL_typez00_bglt) BgL_arg1095z00_587),
-					((BgL_typez00_bglt) BgL_whoz00_579), BgL_locz00_580);
+					((BgL_typez00_bglt) BgL_arg1098z00_588),
+					((BgL_typez00_bglt) BgL_whoz00_580), BgL_locz00_581);
 			}
 		}
 
@@ -246,18 +247,18 @@ extern "C"
 	{
 		{	/* Foreign/calias.scm 15 */
 			BGl_modulezd2initializa7ationz75zztools_tracez00(54713316L,
-				BSTRING_TO_STRING(BGl_string1146z00zzforeign_caliasz00));
+				BSTRING_TO_STRING(BGl_string1145z00zzforeign_caliasz00));
 			BGl_modulezd2initializa7ationz75zztype_toolsz00(453414928L,
-				BSTRING_TO_STRING(BGl_string1146z00zzforeign_caliasz00));
+				BSTRING_TO_STRING(BGl_string1145z00zzforeign_caliasz00));
 			BGl_modulezd2initializa7ationz75zztype_typez00(515343395L,
-				BSTRING_TO_STRING(BGl_string1146z00zzforeign_caliasz00));
+				BSTRING_TO_STRING(BGl_string1145z00zzforeign_caliasz00));
 			BGl_modulezd2initializa7ationz75zztools_shapez00(365925558L,
-				BSTRING_TO_STRING(BGl_string1146z00zzforeign_caliasz00));
+				BSTRING_TO_STRING(BGl_string1145z00zzforeign_caliasz00));
 			BGl_modulezd2initializa7ationz75zzforeign_ctypez00(396356879L,
-				BSTRING_TO_STRING(BGl_string1146z00zzforeign_caliasz00));
+				BSTRING_TO_STRING(BGl_string1145z00zzforeign_caliasz00));
 			return
 				BGl_modulezd2initializa7ationz75zzforeign_accessz00(471073666L,
-				BSTRING_TO_STRING(BGl_string1146z00zzforeign_caliasz00));
+				BSTRING_TO_STRING(BGl_string1145z00zzforeign_caliasz00));
 		}
 
 	}
