@@ -1,10 +1,10 @@
 ;*=====================================================================*/
-;*    serrano/prgm/project/bigloo/comptime/Globalize/globalize.scm     */
+;*    .../project/bigloo/bigloo/comptime/Globalize/globalize.scm       */
 ;*    -------------------------------------------------------------    */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Thu Jan 26 14:45:58 1995                          */
-;*    Last change :  Mon May 15 07:50:36 2000 (serrano)                */
-;*    Copyright   :  1995-2000 Manuel Serrano, see LICENSE file        */
+;*    Last change :  Tue Jun 25 14:50:32 2024 (serrano)                */
+;*    Copyright   :  1995-2024 Manuel Serrano, see LICENSE file        */
 ;*    -------------------------------------------------------------    */
 ;*    The `globalization' process                                      */
 ;*=====================================================================*/
@@ -17,9 +17,11 @@
 	    "Tools/verbose.sch")
    (import  tools_shape
 	    tools_speek
+	    engine_param
 	    type_type
 	    ast_var
 	    ast_node
+	    ast_dump
 	    globalize_ginfo
 	    globalize_node
 	    globalize_free
@@ -28,7 +30,8 @@
 	    globalize_integration
 	    globalize_new-body
 	    globalize_local->global
-	    globalize_global-closure)
+	    globalize_global-closure
+	    ast_check-sharing)
    (export  (globalize! global::global)
 	    *E*
 	    *G0*
@@ -46,51 +49,57 @@
 ;*---------------------------------------------------------------------*/
 (define (globalize! global)
    (trace globalize
-	  "========================================" #\newline
-	  (shape global) " "
-	  (if (global/Ginfo-escape? global) "[escaping]" "[non escaping]")
-	  #\Newline
-	  "----------------------------------------" #\newline)
-   (verbose 3 "        " (shape global) " : " #\Newline)
+      "========================================" #\newline
+      (shape global) " "
+      (if (global/Ginfo-escape? global) "[escaping]" "[non escaping]")
+      #\Newline
+      "----------------------------------------" #\newline)
+   (verbose 3 "        " (shape global) ": " #\Newline)
    (let ((fun (global-value global)))
       (set! *E*  '())
       (set! *G0* '())
       (set! *G1* '())
       (Gn! (sfun-args fun) (sfun-body fun) global '())
       (trace globalize
-	     "   E  : " (shape *E*)
-	     #\Newline
-	     "   G0 : " (shape *G0*)
-	     #\Newline
-	     "   G1 : " (shape *G1*)
-	     #\Newline)
+	 "   E  : " (shape *E*)
+	 #\Newline
+	 "   G0 : " (shape *G0*)
+	 #\Newline
+	 "   G1 : " (shape *G1*)
+	 #\Newline)
       ;; we compute the integration property
-      (set-integration!)
+      (set-integration! global *E* *G0* *G1*)
       ;; we computed the really globalised functions.
       (let ((G (let loop ((G1 *G1*)
 			  (G  *E*))
 		  (cond
 		     ((null? G1)
-		      (trace globalize "   G  : " (shape G) #\Newline)
 		      G)
-		     ((local? (sfun/Ginfo-integrator (local-value (car G1))))
+		     ((variable? (sfun/Ginfo-integrator (local-value (car G1))))
 		      (loop (cdr G1) G))
 		     (else
 		      (loop (cdr G1) (cons (car G1) G)))))))
+	 (trace globalize "   G  : " (shape G) #\Newline)
 	 ;; we print the globalization result
 	 (verb-globalization)
-	 ;; for each globalized function, we computed its new body
+	 ;; for each globalized function, compute its new body
 	 (set-globalized-new-bodies! global G)
-	 ;; for each globalized function, we computes its set of
+	 ;; for each globalized function, compute its set of
 	 ;; kaptured variables.
 	 (set-kaptured! G)
 	 ;; then, we compute new global definitions
-	 (let loop ((G     G)
+	 (let loop ((G G)
 		    (new-G (if (global/Ginfo-escape? global)
-			       (list (global-closure global
-						     (node-loc
-						      (sfun-body fun)))
-				     global)
+			       (let ((clo (global-closure global
+					     (node-loc (sfun-body fun)))))
+				  (if (and (or (global-optional? global)
+					       (global-key? global)))
+				      ;; optional global functions have
+				      ;; a pre-defined closure (which is
+				      ;; returned by global-closure but that
+				      ;; already exists in the tred). 
+				      (list global)
+				      (list clo global)))
 			       (list global))))
 	    (if (null? G)
 		;; we still have, to globalize the global function
@@ -98,8 +107,7 @@
 		   (sfun-body-set! fun body)
 		   (trace globalize #a012 #\Newline)
 		   new-G)
-		(loop (cdr G)
-		      (cons (local->global (car G)) new-G)))))))
+		(loop (cdr G) (cons (local->global (car G)) new-G)))))))
 
 ;*---------------------------------------------------------------------*/
 ;*    verb-globalization ...                                           */
