@@ -3,8 +3,8 @@
 ;*    -------------------------------------------------------------    */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Mon Jan 30 07:30:09 1995                          */
-;*    Last change :  Mon May 15 07:51:08 2000 (serrano)                */
-;*    Copyright   :  1995-2000 Manuel Serrano, see LICENSE file        */
+;*    Last change :  Wed Jan 22 08:36:10 2014 (serrano)                */
+;*    Copyright   :  1995-2020 Manuel Serrano, see LICENSE file        */
 ;*    -------------------------------------------------------------    */
 ;*    The `kaptured' computation                                       */
 ;*=====================================================================*/
@@ -33,16 +33,14 @@
 ;*---------------------------------------------------------------------*/
 ;*    set-kaptured! ...                                                */
 ;*---------------------------------------------------------------------*/
-(define (set-kaptured! local*)
+(define (set-kaptured! localfun*)
    ;; first we compute the transitive closure of the `cto' property
    ;; (i.e. we add to local the cto fields of its including local functions).
-   (for-each (lambda (local)
-		(cto-transitive-closure! local))
-	     local*)
+   (for-each (lambda (localfun)
+		(cto-transitive-closure! localfun))
+	     localfun*)
    ;; then we compute the kaptured property.
-   (for-each (lambda (local)
-		(set-one-kaptured! local local))
-	     local*))
+   (for-each set-one-kaptured! localfun*))
 
 ;*---------------------------------------------------------------------*/
 ;*    set-one-kaptured! ...                                            */
@@ -50,85 +48,74 @@
 ;*    This function computes the set of kaptured variables and         */
 ;*    the future globalized body.                                      */
 ;*---------------------------------------------------------------------*/
-(define (set-one-kaptured! local::local locking)
-   (trace (globalize 2) "set-one-kaptured: " (shape local) " [locking:"
-	  (shape locking) #\]
-	  #\Newline)
-   (let* ((info     (local-value local))
+(define (set-one-kaptured! localfun::local)
+   (trace globalize "set-one-kaptured: " (shape localfun)
+      " [cto=" (shape (sfun/Ginfo-cto* (local-value localfun))) "]"
+      #\Newline)
+   (let ((kaptured (get-one-kaptured localfun '()))
+	 (info (local-value localfun))
+	 (stackable (eq? (sfun-stackable (local-value localfun)) #t)))
+      (sfun/Ginfo-kaptured-set! info kaptured)
+      (for-each (lambda (local)
+		   (let ((lv (local-value local)))
+		      ;; a box can be stack allocated if it is only refeenced
+		      ;; by _one_ stackable closure
+		      (svar/Ginfo-stackable-set! lv
+			 (and stackable (not (svar/Ginfo-kaptured? lv))))
+		      (svar/Ginfo-kaptured?-set! lv #t)))
+	 kaptured)
+      kaptured))
+
+;*---------------------------------------------------------------------*/
+;*    get-one-kaptured ...                                             */
+;*---------------------------------------------------------------------*/
+(define (get-one-kaptured local stack)
+   (trace (globalize 1)
+      (trace-tab (length stack))
+      ">>> get-one-kaptured: " (shape local)
+      " [stack=" (length stack) "]"
+      #\Newline)
+   (let* ((info (local-value local))
 	  (kaptured (sfun/Ginfo-kaptured info)))
       (cond
 	 ((or (pair? kaptured) (null? kaptured))
-	  (trace (globalize 2) "--> (or pair? null?) [" (shape local)
-		 "] " (shape kaptured) #\Newline)
-	  (vector #t locking kaptured))
-	 ((local? kaptured)
-	  (trace (globalize 2) "--> local? [" (shape local)
-		 "] " (shape kaptured) #\Newline)
-	  (vector #f locking '()))
+	  (trace (globalize 1)
+	     (trace-tab (length stack))
+	     "<<< get-one-kaptured: " (shape local)
+	     " already known: " (map shape kaptured) "\n")
+	  kaptured)
+	 ((memq local stack)
+	  (trace (globalize 1)
+	     (trace-tab (length stack))
+	     "<<< get-one-kaptured: " (shape local)
+	     " in stack\n")
+	  '())
 	 (else
-	  (trace (globalize 2) "--> cto* [" (shape local) "] "
-		 (shape (sfun/Ginfo-cto* info)) #\Newline)
-	  (let ((new-body (sfun/Ginfo-new-body info)))
-	     ;; before entering the recursion we mark this function
-	     (sfun/Ginfo-kaptured-set! info local)
-	     ;; we walk across the call-graph
-	     (let loop ((kaptured '())
-			(cto      (append (sfun/Ginfo-cto* info)
-					  (sfun/Ginfo-cfunction info)))
-			(setter?  #t))
-		(trace (globalize 2)
-		       "loop( " (shape local) " ) : " #\Newline
-		       "      "  (shape kaptured) #\Newline
-		       "      "  (shape cto) #\Newline
-		       "      "  setter? #\Newline)
-		(cond
-		   ((null? cto)
-		    (let* ((free      (get-free-vars new-body local))
-			   (fkaptured (free-from kaptured local))
-			   (kaptured  (union (cons free fkaptured))))
-		       (trace globalize
-			      "   kaptured(" (shape local) ") : "
-			      (shape kaptured) #\Newline)
-		       (trace (globalize 2)
-			      "       free(" (shape local) ") : "
-			      (shape free) #\Newline)
-		       (if setter?
-			   (begin
-			      ;; we store kaptured variables
-			      (sfun/Ginfo-kaptured-set! info kaptured)
-			      ;; we mark that kaptured variable are
-			      (for-each (lambda (local)
-					   (svar/Ginfo-kaptured?-set!
-					    (local-value local) #t))
-					kaptured))
-			   (sfun/Ginfo-kaptured-set! info #f))
-		       (vector setter? locking kaptured)))
-		   ((eq? (car cto) local)
-		    (trace (globalize 2) "  (eq? (car cto) local)"
-			   #\Newline)
-		    (loop kaptured
-			  (cdr cto)
-			  setter?))
-		   ((sfun/Ginfo-G? (local-value (car cto)))
-		    (trace (globalize 2) "  (sfun/Ginfo-G? (car cto))"
-			   #\Newline)
-		    (let ((other-kaptured (set-one-kaptured! (car cto)
-							     locking)))
-		       (if (not (vector-ref other-kaptured 0))
-			   (loop (cons (vector-ref other-kaptured 2) kaptured)
-				 (cdr cto)
-				 (and setter?
-				      (eq? (vector-ref other-kaptured 1)
-					   local)))
-			   (loop (cons (vector-ref other-kaptured 2) kaptured)
-				 (cdr cto)
-				 setter?))))
-		   (else
-		    (trace (globalize 2) "  not globalized (car cto)"
-			   #\Newline)
-		    (loop kaptured
-			  (cdr cto)
-			  setter?)))))))))
+	  (let loop ((kaptured '())
+		     (cto (append (sfun/Ginfo-cto* info)
+			     (sfun/Ginfo-efunctions info)))
+		     (nstack (cons local stack)))
+	     (cond
+		((null? cto)
+		 (let* ((new-body (sfun/Ginfo-new-body info))
+			(free (get-free-vars new-body local))
+			(fkaptured (free-from kaptured local)))
+		    (trace (globalize 1)
+		       (trace-tab (length stack))
+		       "<<< get-one-kaptured: " (shape local)
+		       " efunctions=" (map shape (sfun/Ginfo-efunctions info))
+		       " cto*=" (map shape (sfun/Ginfo-cto* info))
+		       " free-vars=" (map shape free)
+		       " fkaptured=" (map shape fkaptured)
+		       "\n")
+		    (union (cons free fkaptured))))
+		((sfun/Ginfo-G? (local-value (car cto)))
+		 (let ((other-kaptured (get-one-kaptured (car cto) nstack)))
+		    (loop (cons other-kaptured kaptured)
+		       (cdr cto)
+		       (cons (car cto) nstack))))
+		(else
+		 (loop kaptured (cdr cto) nstack))))))))
 
 ;*---------------------------------------------------------------------*/
 ;*    *union-round* ...                                                */
