@@ -1,9 +1,9 @@
 /*===========================================================================*/
 /*   (Hgen/walk.scm)                                                         */
-/*   Bigloo (4.5b)                                                           */
-/*   Inria -- Sophia Antipolis (c)       Fri Dec 22 05:17:06 PM CET 2023     */
+/*   Bigloo (4.6a)                                                           */
+/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
 /*===========================================================================*/
-/* COMPILATION: (/home/serrano/prgm/project/bigloo/bigloo/bin/bigloo -ldopt -L/home/serrano/prgm/project/bigloo/bigloo/libbacktrace/home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b  -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Hgen/walk.scm) */
+/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Hgen/walk.scm) */
 /* GC selection */
 #define THE_GC BOEHM_GC
 
@@ -38,6 +38,7 @@ extern "C"
 		obj_t BgL_parentsz00;
 		bool_t BgL_initzf3zf3;
 		bool_t BgL_magiczf3zf3;
+		obj_t BgL_nullz00;
 		obj_t BgL_z42z42;
 		obj_t BgL_aliasz00;
 		obj_t BgL_pointedzd2tozd2byz00;
@@ -89,7 +90,7 @@ extern "C"
 		obj_t BgL_libraryz00;
 		obj_t BgL_pragmaz00;
 		obj_t BgL_srcz00;
-		obj_t BgL_jvmzd2typezd2namez00;
+		obj_t BgL_qualifiedzd2typezd2namez00;
 		obj_t BgL_initz00;
 		obj_t BgL_aliasz00;
 	}                *BgL_globalz00_bglt;
@@ -120,7 +121,7 @@ extern "C"
 	BGL_EXPORTED_DECL obj_t BGl_hgenzd2walkzd2zzhgen_walkz00(void);
 	BGL_IMPORT obj_t BGl_stringzd2upcasezd2zz__r4_strings_6_7z00(obj_t);
 	BGL_IMPORT bool_t BGl_bigloozd2needzd2manglingzf3zf3zz__biglooz00(obj_t);
-	static obj_t BGl_z62zc3z04anonymousza31281ze3ze5zzhgen_walkz00(obj_t);
+	static obj_t BGl_z62zc3z04anonymousza31273ze3ze5zzhgen_walkz00(obj_t);
 	extern obj_t BGl_za2moduleza2z00zzmodule_modulez00;
 	BGL_EXPORTED_DECL obj_t BGl_modulezd2initializa7ationz75zzhgen_walkz00(long,
 		char *);
@@ -170,31 +171,31 @@ extern "C"
 
 	   
 		 
-		DEFINE_EXPORT_BGL_PROCEDURE(BGl_hgenzd2walkzd2envz00zzhgen_walkz00,
-		BgL_bgl_za762hgenza7d2walkza7b1596za7, BGl_z62hgenzd2walkzb0zzhgen_walkz00,
-		0L, BUNSPEC, 0);
-	      DEFINE_STRING(BGl_string1585z00zzhgen_walkz00,
-		BgL_bgl_string1585za700za7za7h1597za7, "C headers generation", 20);
-	      DEFINE_STRING(BGl_string1586z00zzhgen_walkz00,
-		BgL_bgl_string1586za700za7za7h1598za7, "   . ", 5);
-	      DEFINE_STRING(BGl_string1588z00zzhgen_walkz00,
-		BgL_bgl_string1588za700za7za7h1599za7, "failure during prelude hook", 27);
-	      DEFINE_STRING(BGl_string1589z00zzhgen_walkz00,
-		BgL_bgl_string1589za700za7za7h1600za7, "#ifndef __BGL_~a_H\n", 19);
-	      DEFINE_STRING(BGl_string1590z00zzhgen_walkz00,
-		BgL_bgl_string1590za700za7za7h1601za7, "#define __BGL_~a_H\n", 19);
-	      DEFINE_STRING(BGl_string1591z00zzhgen_walkz00,
-		BgL_bgl_string1591za700za7za7h1602za7, "#endif // __BGL_~a_H\n", 21);
-	      DEFINE_STRING(BGl_string1592z00zzhgen_walkz00,
-		BgL_bgl_string1592za700za7za7h1603za7, ".h", 2);
-	      DEFINE_STRING(BGl_string1593z00zzhgen_walkz00,
-		BgL_bgl_string1593za700za7za7h1604za7, "hgen_walk", 9);
-	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1587z00zzhgen_walkz00,
-		BgL_bgl_za762za7c3za704anonymo1605za7,
-		BGl_z62zc3z04anonymousza31281ze3ze5zzhgen_walkz00, 0L, BUNSPEC, 0);
-	      DEFINE_STRING(BGl_string1594z00zzhgen_walkz00,
-		BgL_bgl_string1594za700za7za7h1606za7,
+		DEFINE_STRING(BGl_string1406z00zzhgen_walkz00,
+		BgL_bgl_string1406za700za7za7h1417za7, "C headers generation", 20);
+	      DEFINE_STRING(BGl_string1407z00zzhgen_walkz00,
+		BgL_bgl_string1407za700za7za7h1418za7, "   . ", 5);
+	      DEFINE_STRING(BGl_string1409z00zzhgen_walkz00,
+		BgL_bgl_string1409za700za7za7h1419za7, "failure during prelude hook", 27);
+	      DEFINE_STRING(BGl_string1410z00zzhgen_walkz00,
+		BgL_bgl_string1410za700za7za7h1420za7, "#ifndef __BGL_~a_H\n", 19);
+	      DEFINE_STRING(BGl_string1411z00zzhgen_walkz00,
+		BgL_bgl_string1411za700za7za7h1421za7, "#define __BGL_~a_H\n", 19);
+	      DEFINE_STRING(BGl_string1412z00zzhgen_walkz00,
+		BgL_bgl_string1412za700za7za7h1422za7, "#endif // __BGL_~a_H\n", 21);
+	      DEFINE_STRING(BGl_string1413z00zzhgen_walkz00,
+		BgL_bgl_string1413za700za7za7h1423za7, ".h", 2);
+	      DEFINE_STRING(BGl_string1414z00zzhgen_walkz00,
+		BgL_bgl_string1414za700za7za7h1424za7, "hgen_walk", 9);
+	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1408z00zzhgen_walkz00,
+		BgL_bgl_za762za7c3za704anonymo1425za7,
+		BGl_z62zc3z04anonymousza31273ze3ze5zzhgen_walkz00, 0L, BUNSPEC, 0);
+	      DEFINE_STRING(BGl_string1415z00zzhgen_walkz00,
+		BgL_bgl_string1415za700za7za7h1426za7,
 		"pass-started ((lambda () (start-emission! \".h\"))) ", 50);
+	      DEFINE_EXPORT_BGL_PROCEDURE(BGl_hgenzd2walkzd2envz00zzhgen_walkz00,
+		BgL_bgl_za762hgenza7d2walkza7b1427za7, BGl_z62hgenzd2walkzb0zzhgen_walkz00,
+		0L, BUNSPEC, 0);
 
 /* GC roots registration */
 	static obj_t bgl_gc_roots_register()
@@ -214,7 +215,7 @@ extern "C"
 
 /* module-initialization */
 	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zzhgen_walkz00(long
-		BgL_checksumz00_1911, char *BgL_fromz00_1912)
+		BgL_checksumz00_1922, char *BgL_fromz00_1923)
 	{
 		{
 			if (CBOOL(BGl_requirezd2initializa7ationz75zzhgen_walkz00))
@@ -266,71 +267,71 @@ extern "C"
 	{
 		{	/* Hgen/walk.scm 15 */
 			{	/* Hgen/walk.scm 15 */
-				obj_t BgL_cportz00_1900;
+				obj_t BgL_cportz00_1911;
 
 				{	/* Hgen/walk.scm 15 */
-					obj_t BgL_stringz00_1907;
+					obj_t BgL_stringz00_1918;
 
-					BgL_stringz00_1907 = BGl_string1594z00zzhgen_walkz00;
+					BgL_stringz00_1918 = BGl_string1415z00zzhgen_walkz00;
 					{	/* Hgen/walk.scm 15 */
-						obj_t BgL_startz00_1908;
+						obj_t BgL_startz00_1919;
 
-						BgL_startz00_1908 = BINT(0L);
+						BgL_startz00_1919 = BINT(0L);
 						{	/* Hgen/walk.scm 15 */
-							obj_t BgL_endz00_1909;
+							obj_t BgL_endz00_1920;
 
-							BgL_endz00_1909 =
-								BINT(STRING_LENGTH(((obj_t) BgL_stringz00_1907)));
+							BgL_endz00_1920 =
+								BINT(STRING_LENGTH(((obj_t) BgL_stringz00_1918)));
 							{	/* Hgen/walk.scm 15 */
 
-								BgL_cportz00_1900 =
+								BgL_cportz00_1911 =
 									BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00
-									(BgL_stringz00_1907, BgL_startz00_1908, BgL_endz00_1909);
+									(BgL_stringz00_1918, BgL_startz00_1919, BgL_endz00_1920);
 				}}}}
 				{
-					long BgL_iz00_1901;
+					long BgL_iz00_1912;
 
-					BgL_iz00_1901 = 1L;
-				BgL_loopz00_1902:
-					if ((BgL_iz00_1901 == -1L))
+					BgL_iz00_1912 = 1L;
+				BgL_loopz00_1913:
+					if ((BgL_iz00_1912 == (-1L)))
 						{	/* Hgen/walk.scm 15 */
 							return BUNSPEC;
 						}
 					else
 						{	/* Hgen/walk.scm 15 */
 							{	/* Hgen/walk.scm 15 */
-								obj_t BgL_arg1595z00_1903;
+								obj_t BgL_arg1416z00_1914;
 
 								{	/* Hgen/walk.scm 15 */
 
 									{	/* Hgen/walk.scm 15 */
-										obj_t BgL_locationz00_1905;
+										obj_t BgL_locationz00_1916;
 
-										BgL_locationz00_1905 = BBOOL(((bool_t) 0));
+										BgL_locationz00_1916 = BBOOL(((bool_t) 0));
 										{	/* Hgen/walk.scm 15 */
 
-											BgL_arg1595z00_1903 =
-												BGl_readz00zz__readerz00(BgL_cportz00_1900,
-												BgL_locationz00_1905);
+											BgL_arg1416z00_1914 =
+												BGl_readz00zz__readerz00(BgL_cportz00_1911,
+												BgL_locationz00_1916);
 										}
 									}
 								}
 								{	/* Hgen/walk.scm 15 */
-									int BgL_tmpz00_1941;
+									int BgL_tmpz00_1952;
 
-									BgL_tmpz00_1941 = (int) (BgL_iz00_1901);
-									CNST_TABLE_SET(BgL_tmpz00_1941, BgL_arg1595z00_1903);
+									BgL_tmpz00_1952 = (int) (BgL_iz00_1912);
+									CNST_TABLE_SET(BgL_tmpz00_1952, BgL_arg1416z00_1914);
 							}}
 							{	/* Hgen/walk.scm 15 */
-								int BgL_auxz00_1906;
+								int BgL_auxz00_1917;
 
-								BgL_auxz00_1906 = (int) ((BgL_iz00_1901 - 1L));
+								BgL_auxz00_1917 = (int) ((BgL_iz00_1912 - 1L));
 								{
-									long BgL_iz00_1946;
+									long BgL_iz00_1957;
 
-									BgL_iz00_1946 = (long) (BgL_auxz00_1906);
-									BgL_iz00_1901 = BgL_iz00_1946;
-									goto BgL_loopz00_1902;
+									BgL_iz00_1957 = (long) (BgL_auxz00_1917);
+									BgL_iz00_1912 = BgL_iz00_1957;
+									goto BgL_loopz00_1913;
 								}
 							}
 						}
@@ -358,305 +359,313 @@ extern "C"
 	{
 		{	/* Hgen/walk.scm 30 */
 			{	/* Hgen/walk.scm 31 */
-				obj_t BgL_list1258z00_1587;
+				obj_t BgL_list1255z00_1592;
 
 				{	/* Hgen/walk.scm 31 */
-					obj_t BgL_arg1259z00_1588;
+					obj_t BgL_arg1256z00_1593;
 
 					{	/* Hgen/walk.scm 31 */
-						obj_t BgL_arg1260z00_1589;
+						obj_t BgL_arg1258z00_1594;
 
-						BgL_arg1260z00_1589 =
+						BgL_arg1258z00_1594 =
 							MAKE_YOUNG_PAIR(BCHAR(((unsigned char) 10)), BNIL);
-						BgL_arg1259z00_1588 =
-							MAKE_YOUNG_PAIR(BGl_string1585z00zzhgen_walkz00,
-							BgL_arg1260z00_1589);
+						BgL_arg1256z00_1593 =
+							MAKE_YOUNG_PAIR(BGl_string1406z00zzhgen_walkz00,
+							BgL_arg1258z00_1594);
 					}
-					BgL_list1258z00_1587 =
-						MAKE_YOUNG_PAIR(BGl_string1586z00zzhgen_walkz00,
-						BgL_arg1259z00_1588);
+					BgL_list1255z00_1592 =
+						MAKE_YOUNG_PAIR(BGl_string1407z00zzhgen_walkz00,
+						BgL_arg1256z00_1593);
 				}
-				BGl_verbosez00zztools_speekz00(BINT(1L), BgL_list1258z00_1587);
+				BGl_verbosez00zztools_speekz00(BINT(1L), BgL_list1255z00_1592);
 			}
 			BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00 = BINT(0L);
 			BGl_za2currentzd2passza2zd2zzengine_passz00 =
-				BGl_string1585z00zzhgen_walkz00;
+				BGl_string1406z00zzhgen_walkz00;
 			{	/* Hgen/walk.scm 31 */
-				obj_t BgL_g1110z00_1590;
-				obj_t BgL_g1111z00_1591;
+				obj_t BgL_g1110z00_1595;
+				obj_t BgL_g1111z00_1596;
 
 				{	/* Hgen/walk.scm 31 */
-					obj_t BgL_list1280z00_1605;
+					obj_t BgL_list1272z00_1610;
 
-					BgL_list1280z00_1605 =
-						MAKE_YOUNG_PAIR(BGl_proc1587z00zzhgen_walkz00, BNIL);
-					BgL_g1110z00_1590 = BgL_list1280z00_1605;
+					BgL_list1272z00_1610 =
+						MAKE_YOUNG_PAIR(BGl_proc1408z00zzhgen_walkz00, BNIL);
+					BgL_g1110z00_1595 = BgL_list1272z00_1610;
 				}
-				BgL_g1111z00_1591 = CNST_TABLE_REF(0L);
+				BgL_g1111z00_1596 = ((obj_t) CNST_TABLE_REF(0));
 				{
-					obj_t BgL_hooksz00_1593;
-					obj_t BgL_hnamesz00_1594;
+					obj_t BgL_hooksz00_1598;
+					obj_t BgL_hnamesz00_1599;
 
-					BgL_hooksz00_1593 = BgL_g1110z00_1590;
-					BgL_hnamesz00_1594 = BgL_g1111z00_1591;
-				BgL_zc3z04anonymousza31261ze3z87_1595:
-					if (NULLP(BgL_hooksz00_1593))
+					BgL_hooksz00_1598 = BgL_g1110z00_1595;
+					BgL_hnamesz00_1599 = BgL_g1111z00_1596;
+				BgL_zc3z04anonymousza31259ze3z87_1600:
+					if (NULLP(BgL_hooksz00_1598))
 						{	/* Hgen/walk.scm 31 */
-							CNST_TABLE_REF(1L);
+							((obj_t) CNST_TABLE_REF(1));
 						}
 					else
 						{	/* Hgen/walk.scm 31 */
-							bool_t BgL_test1610z00_1961;
+							bool_t BgL_test1431z00_1974;
 
 							{	/* Hgen/walk.scm 31 */
-								obj_t BgL_fun1278z00_1602;
+								obj_t BgL_fun1270z00_1607;
 
-								BgL_fun1278z00_1602 = CAR(((obj_t) BgL_hooksz00_1593));
-								BgL_test1610z00_1961 =
-									CBOOL(
-									(VA_PROCEDUREP(BgL_fun1278z00_1602) ? ((obj_t(*)(obj_t,
-													...))
-											PROCEDURE_ENTRY(BgL_fun1278z00_1602))
-										(BgL_fun1278z00_1602,
-											BEOA) : ((obj_t(*)(obj_t))
-											PROCEDURE_ENTRY(BgL_fun1278z00_1602))
-										(BgL_fun1278z00_1602)));
+								BgL_fun1270z00_1607 = CAR(((obj_t) BgL_hooksz00_1598));
+								BgL_test1431z00_1974 =
+									CBOOL(BGL_PROCEDURE_CALL0(BgL_fun1270z00_1607));
 							}
-							if (BgL_test1610z00_1961)
+							if (BgL_test1431z00_1974)
 								{	/* Hgen/walk.scm 31 */
-									obj_t BgL_arg1275z00_1599;
-									obj_t BgL_arg1276z00_1600;
+									obj_t BgL_arg1266z00_1604;
+									obj_t BgL_arg1267z00_1605;
 
-									BgL_arg1275z00_1599 = CDR(((obj_t) BgL_hooksz00_1593));
-									BgL_arg1276z00_1600 = CDR(((obj_t) BgL_hnamesz00_1594));
+									BgL_arg1266z00_1604 = CDR(((obj_t) BgL_hooksz00_1598));
+									BgL_arg1267z00_1605 = CDR(((obj_t) BgL_hnamesz00_1599));
 									{
-										obj_t BgL_hnamesz00_1973;
-										obj_t BgL_hooksz00_1972;
+										obj_t BgL_hnamesz00_1986;
+										obj_t BgL_hooksz00_1985;
 
-										BgL_hooksz00_1972 = BgL_arg1275z00_1599;
-										BgL_hnamesz00_1973 = BgL_arg1276z00_1600;
-										BgL_hnamesz00_1594 = BgL_hnamesz00_1973;
-										BgL_hooksz00_1593 = BgL_hooksz00_1972;
-										goto BgL_zc3z04anonymousza31261ze3z87_1595;
+										BgL_hooksz00_1985 = BgL_arg1266z00_1604;
+										BgL_hnamesz00_1986 = BgL_arg1267z00_1605;
+										BgL_hnamesz00_1599 = BgL_hnamesz00_1986;
+										BgL_hooksz00_1598 = BgL_hooksz00_1985;
+										goto BgL_zc3z04anonymousza31259ze3z87_1600;
 									}
 								}
 							else
 								{	/* Hgen/walk.scm 31 */
-									obj_t BgL_arg1277z00_1601;
+									obj_t BgL_arg1268z00_1606;
 
-									BgL_arg1277z00_1601 = CAR(((obj_t) BgL_hnamesz00_1594));
+									BgL_arg1268z00_1606 = CAR(((obj_t) BgL_hnamesz00_1599));
 									BGl_internalzd2errorzd2zztools_errorz00
-										(BGl_string1585z00zzhgen_walkz00,
-										BGl_string1588z00zzhgen_walkz00, BgL_arg1277z00_1601);
+										(BGl_string1406z00zzhgen_walkz00,
+										BGl_string1409z00zzhgen_walkz00, BgL_arg1268z00_1606);
 								}
 						}
 				}
 			}
 			BGl_emitzd2headerzd2zzbackend_c_emitz00();
 			{	/* Hgen/walk.scm 36 */
-				obj_t BgL_clistz00_1608;
+				obj_t BgL_clistz00_1613;
 
 				{	/* Hgen/walk.scm 36 */
-					obj_t BgL_hook1252z00_1613;
+					obj_t BgL_hook1249z00_1618;
 
-					BgL_hook1252z00_1613 = MAKE_YOUNG_PAIR(BFALSE, BNIL);
+					BgL_hook1249z00_1618 = MAKE_YOUNG_PAIR(BFALSE, BNIL);
 					{	/* Hgen/walk.scm 40 */
-						obj_t BgL_g1253z00_1614;
+						obj_t BgL_g1250z00_1619;
 
-						BgL_g1253z00_1614 = BGl_getzd2classzd2listz00zzobject_classz00();
+						BgL_g1250z00_1619 = BGl_getzd2classzd2listz00zzobject_classz00();
 						{
-							obj_t BgL_l1249z00_1616;
-							obj_t BgL_h1250z00_1617;
+							obj_t BgL_l1246z00_1621;
+							obj_t BgL_h1247z00_1622;
 
-							BgL_l1249z00_1616 = BgL_g1253z00_1614;
-							BgL_h1250z00_1617 = BgL_hook1252z00_1613;
-						BgL_zc3z04anonymousza31285ze3z87_1618:
-							if (NULLP(BgL_l1249z00_1616))
+							BgL_l1246z00_1621 = BgL_g1250z00_1619;
+							BgL_h1247z00_1622 = BgL_hook1249z00_1618;
+						BgL_zc3z04anonymousza31277ze3z87_1623:
+							if (NULLP(BgL_l1246z00_1621))
 								{	/* Hgen/walk.scm 40 */
-									BgL_clistz00_1608 = CDR(BgL_hook1252z00_1613);
+									BgL_clistz00_1613 = CDR(BgL_hook1249z00_1618);
 								}
 							else
 								{	/* Hgen/walk.scm 40 */
-									bool_t BgL_test1612z00_1983;
+									bool_t BgL_test1433z00_1996;
 
 									{	/* Hgen/walk.scm 37 */
-										obj_t BgL_cz00_1629;
+										obj_t BgL_cz00_1634;
 
-										BgL_cz00_1629 = CAR(((obj_t) BgL_l1249z00_1616));
+										BgL_cz00_1634 = CAR(((obj_t) BgL_l1246z00_1621));
 										{	/* Hgen/walk.scm 37 */
-											bool_t BgL_test1614z00_1986;
+											bool_t BgL_test1434z00_1999;
 
 											{	/* Hgen/walk.scm 37 */
-												obj_t BgL_classz00_1824;
+												obj_t BgL_classz00_1829;
 
-												BgL_classz00_1824 = BGl_tclassz00zzobject_classz00;
-												if (BGL_OBJECTP(BgL_cz00_1629))
+												BgL_classz00_1829 = BGl_tclassz00zzobject_classz00;
+												if (BGL_OBJECTP(BgL_cz00_1634))
 													{	/* Hgen/walk.scm 37 */
-														BgL_objectz00_bglt BgL_arg1801z00_1826;
+														BgL_objectz00_bglt BgL_arg1858z00_1831;
 
-														BgL_arg1801z00_1826 =
-															(BgL_objectz00_bglt) (BgL_cz00_1629);
+														BgL_arg1858z00_1831 =
+															(BgL_objectz00_bglt) (BgL_cz00_1634);
 														if (BGL_CONDEXPAND_ISA_ARCH64())
 															{	/* Hgen/walk.scm 37 */
-																long BgL_idxz00_1832;
+																long BgL_idxz00_1837;
 
-																BgL_idxz00_1832 =
+																BgL_idxz00_1837 =
 																	BGL_OBJECT_INHERITANCE_NUM
-																	(BgL_arg1801z00_1826);
-																BgL_test1614z00_1986 =
+																	(BgL_arg1858z00_1831);
+																BgL_test1434z00_1999 =
 																	(VECTOR_REF
 																	(BGl_za2inheritancesza2z00zz__objectz00,
-																		(BgL_idxz00_1832 + 2L)) ==
-																	BgL_classz00_1824);
+																		(BgL_idxz00_1837 + 2L)) ==
+																	BgL_classz00_1829);
 															}
 														else
 															{	/* Hgen/walk.scm 37 */
-																bool_t BgL_res1583z00_1854;
+																bool_t BgL_res1404z00_1862;
 
 																{	/* Hgen/walk.scm 37 */
-																	obj_t BgL_oclassz00_1840;
+																	obj_t BgL_oclassz00_1845;
 
 																	{	/* Hgen/walk.scm 37 */
-																		long BgL_arg1808z00_1846;
+																		obj_t BgL_arg1866z00_1853;
+																		long BgL_arg1867z00_1854;
 
+																		BgL_arg1866z00_1853 =
+																			(BGl_za2classesza2z00zz__objectz00);
 																		{	/* Hgen/walk.scm 37 */
-																			long BgL_arg1809z00_1847;
+																			long BgL_arg1869z00_1855;
 
-																			BgL_arg1809z00_1847 =
+																			BgL_arg1869z00_1855 =
 																				BGL_OBJECT_CLASS_NUM
-																				(BgL_arg1801z00_1826);
-																			BgL_arg1808z00_1846 =
-																				(BgL_arg1809z00_1847 - OBJECT_TYPE);
+																				(BgL_arg1858z00_1831);
+																			BgL_arg1867z00_1854 =
+																				(BgL_arg1869z00_1855 - OBJECT_TYPE);
 																		}
-																		BgL_oclassz00_1840 =
-																			VECTOR_REF
-																			(BGl_za2classesza2z00zz__objectz00,
-																			BgL_arg1808z00_1846);
+																		BgL_oclassz00_1845 =
+																			VECTOR_REF(BgL_arg1866z00_1853,
+																			BgL_arg1867z00_1854);
 																	}
 																	{	/* Hgen/walk.scm 37 */
-																		bool_t BgL__ortest_1115z00_1841;
+																		bool_t BgL__ortest_1115z00_1846;
 
-																		BgL__ortest_1115z00_1841 =
-																			(BgL_classz00_1824 == BgL_oclassz00_1840);
-																		if (BgL__ortest_1115z00_1841)
+																		BgL__ortest_1115z00_1846 =
+																			(BgL_classz00_1829 == BgL_oclassz00_1845);
+																		if (BgL__ortest_1115z00_1846)
 																			{	/* Hgen/walk.scm 37 */
-																				BgL_res1583z00_1854 =
-																					BgL__ortest_1115z00_1841;
+																				BgL_res1404z00_1862 =
+																					BgL__ortest_1115z00_1846;
 																			}
 																		else
 																			{	/* Hgen/walk.scm 37 */
-																				long BgL_odepthz00_1842;
+																				long BgL_odepthz00_1847;
 
-																				BgL_odepthz00_1842 =
-																					BGL_CLASS_DEPTH(BgL_oclassz00_1840);
-																				if ((2L < BgL_odepthz00_1842))
+																				{	/* Hgen/walk.scm 37 */
+																					obj_t BgL_arg1855z00_1848;
+
+																					BgL_arg1855z00_1848 =
+																						(BgL_oclassz00_1845);
+																					BgL_odepthz00_1847 =
+																						BGL_CLASS_DEPTH
+																						(BgL_arg1855z00_1848);
+																				}
+																				if ((2L < BgL_odepthz00_1847))
 																					{	/* Hgen/walk.scm 37 */
-																						obj_t BgL_arg1797z00_1844;
+																						obj_t BgL_arg1853z00_1850;
 
-																						BgL_arg1797z00_1844 =
-																							BGL_CLASS_ANCESTORS_REF
-																							(BgL_oclassz00_1840, 2L);
-																						BgL_res1583z00_1854 =
-																							(BgL_arg1797z00_1844 ==
-																							BgL_classz00_1824);
+																						{	/* Hgen/walk.scm 37 */
+																							obj_t BgL_arg1854z00_1851;
+
+																							BgL_arg1854z00_1851 =
+																								(BgL_oclassz00_1845);
+																							BgL_arg1853z00_1850 =
+																								BGL_CLASS_ANCESTORS_REF
+																								(BgL_arg1854z00_1851, 2L);
+																						}
+																						BgL_res1404z00_1862 =
+																							(BgL_arg1853z00_1850 ==
+																							BgL_classz00_1829);
 																					}
 																				else
 																					{	/* Hgen/walk.scm 37 */
-																						BgL_res1583z00_1854 = ((bool_t) 0);
+																						BgL_res1404z00_1862 = ((bool_t) 0);
 																					}
 																			}
 																	}
 																}
-																BgL_test1614z00_1986 = BgL_res1583z00_1854;
+																BgL_test1434z00_1999 = BgL_res1404z00_1862;
 															}
 													}
 												else
 													{	/* Hgen/walk.scm 37 */
-														BgL_test1614z00_1986 = ((bool_t) 0);
+														BgL_test1434z00_1999 = ((bool_t) 0);
 													}
 											}
-											if (BgL_test1614z00_1986)
+											if (BgL_test1434z00_1999)
 												{	/* Hgen/walk.scm 38 */
-													obj_t BgL_arg1322z00_1631;
+													obj_t BgL_arg1287z00_1636;
 
 													{	/* Hgen/walk.scm 38 */
-														BgL_globalz00_bglt BgL_arg1323z00_1632;
+														BgL_globalz00_bglt BgL_arg1288z00_1637;
 
 														{
-															BgL_tclassz00_bglt BgL_auxz00_2006;
+															BgL_tclassz00_bglt BgL_auxz00_2022;
 
 															{
-																obj_t BgL_auxz00_2007;
+																obj_t BgL_auxz00_2023;
 
 																{	/* Hgen/walk.scm 38 */
-																	BgL_objectz00_bglt BgL_tmpz00_2008;
+																	BgL_objectz00_bglt BgL_tmpz00_2024;
 
-																	BgL_tmpz00_2008 =
+																	BgL_tmpz00_2024 =
 																		((BgL_objectz00_bglt)
-																		((BgL_typez00_bglt) BgL_cz00_1629));
-																	BgL_auxz00_2007 =
-																		BGL_OBJECT_WIDENING(BgL_tmpz00_2008);
+																		((BgL_typez00_bglt) BgL_cz00_1634));
+																	BgL_auxz00_2023 =
+																		BGL_OBJECT_WIDENING(BgL_tmpz00_2024);
 																}
-																BgL_auxz00_2006 =
-																	((BgL_tclassz00_bglt) BgL_auxz00_2007);
+																BgL_auxz00_2022 =
+																	((BgL_tclassz00_bglt) BgL_auxz00_2023);
 															}
-															BgL_arg1323z00_1632 =
+															BgL_arg1288z00_1637 =
 																(((BgL_tclassz00_bglt)
-																	COBJECT(BgL_auxz00_2006))->BgL_holderz00);
+																	COBJECT(BgL_auxz00_2022))->BgL_holderz00);
 														}
-														BgL_arg1322z00_1631 =
+														BgL_arg1287z00_1636 =
 															(((BgL_globalz00_bglt)
-																COBJECT(BgL_arg1323z00_1632))->BgL_modulez00);
+																COBJECT(BgL_arg1288z00_1637))->BgL_modulez00);
 													}
-													BgL_test1612z00_1983 =
-														(BgL_arg1322z00_1631 ==
+													BgL_test1433z00_1996 =
+														(BgL_arg1287z00_1636 ==
 														BGl_za2moduleza2z00zzmodule_modulez00);
 												}
 											else
 												{	/* Hgen/walk.scm 37 */
-													BgL_test1612z00_1983 = ((bool_t) 0);
+													BgL_test1433z00_1996 = ((bool_t) 0);
 												}
 										}
 									}
-									if (BgL_test1612z00_1983)
+									if (BgL_test1433z00_1996)
 										{	/* Hgen/walk.scm 40 */
-											obj_t BgL_nh1251z00_1625;
+											obj_t BgL_nh1248z00_1630;
 
 											{	/* Hgen/walk.scm 40 */
-												obj_t BgL_arg1292z00_1627;
+												obj_t BgL_arg1284z00_1632;
 
-												BgL_arg1292z00_1627 = CAR(((obj_t) BgL_l1249z00_1616));
-												BgL_nh1251z00_1625 =
-													MAKE_YOUNG_PAIR(BgL_arg1292z00_1627, BNIL);
+												BgL_arg1284z00_1632 = CAR(((obj_t) BgL_l1246z00_1621));
+												BgL_nh1248z00_1630 =
+													MAKE_YOUNG_PAIR(BgL_arg1284z00_1632, BNIL);
 											}
-											SET_CDR(BgL_h1250z00_1617, BgL_nh1251z00_1625);
+											SET_CDR(BgL_h1247z00_1622, BgL_nh1248z00_1630);
 											{	/* Hgen/walk.scm 40 */
-												obj_t BgL_arg1291z00_1626;
+												obj_t BgL_arg1282z00_1631;
 
-												BgL_arg1291z00_1626 = CDR(((obj_t) BgL_l1249z00_1616));
+												BgL_arg1282z00_1631 = CDR(((obj_t) BgL_l1246z00_1621));
 												{
-													obj_t BgL_h1250z00_2023;
-													obj_t BgL_l1249z00_2022;
+													obj_t BgL_h1247z00_2039;
+													obj_t BgL_l1246z00_2038;
 
-													BgL_l1249z00_2022 = BgL_arg1291z00_1626;
-													BgL_h1250z00_2023 = BgL_nh1251z00_1625;
-													BgL_h1250z00_1617 = BgL_h1250z00_2023;
-													BgL_l1249z00_1616 = BgL_l1249z00_2022;
-													goto BgL_zc3z04anonymousza31285ze3z87_1618;
+													BgL_l1246z00_2038 = BgL_arg1282z00_1631;
+													BgL_h1247z00_2039 = BgL_nh1248z00_1630;
+													BgL_h1247z00_1622 = BgL_h1247z00_2039;
+													BgL_l1246z00_1621 = BgL_l1246z00_2038;
+													goto BgL_zc3z04anonymousza31277ze3z87_1623;
 												}
 											}
 										}
 									else
 										{	/* Hgen/walk.scm 40 */
-											obj_t BgL_arg1294z00_1628;
+											obj_t BgL_arg1285z00_1633;
 
-											BgL_arg1294z00_1628 = CDR(((obj_t) BgL_l1249z00_1616));
+											BgL_arg1285z00_1633 = CDR(((obj_t) BgL_l1246z00_1621));
 											{
-												obj_t BgL_l1249z00_2026;
+												obj_t BgL_l1246z00_2042;
 
-												BgL_l1249z00_2026 = BgL_arg1294z00_1628;
-												BgL_l1249z00_1616 = BgL_l1249z00_2026;
-												goto BgL_zc3z04anonymousza31285ze3z87_1618;
+												BgL_l1246z00_2042 = BgL_arg1285z00_1633;
+												BgL_l1246z00_1621 = BgL_l1246z00_2042;
+												goto BgL_zc3z04anonymousza31277ze3z87_1623;
 											}
 										}
 								}
@@ -664,40 +673,40 @@ extern "C"
 					}
 				}
 				{	/* Hgen/walk.scm 41 */
-					obj_t BgL_namez00_1609;
+					obj_t BgL_namez00_1614;
 
-					BgL_namez00_1609 =
+					BgL_namez00_1614 =
 						BGl_modulezd2ze3idz31zzhgen_walkz00
 						(BGl_za2moduleza2z00zzmodule_modulez00);
 					bgl_display_char(((unsigned char) 10),
 						BGl_za2czd2portza2zd2zzbackend_c_emitz00);
 					{	/* Hgen/walk.scm 43 */
-						obj_t BgL_list1282z00_1610;
+						obj_t BgL_list1274z00_1615;
 
-						BgL_list1282z00_1610 = MAKE_YOUNG_PAIR(BgL_namez00_1609, BNIL);
+						BgL_list1274z00_1615 = MAKE_YOUNG_PAIR(BgL_namez00_1614, BNIL);
 						BGl_fprintfz00zz__r4_output_6_10_3z00
 							(BGl_za2czd2portza2zd2zzbackend_c_emitz00,
-							BGl_string1589z00zzhgen_walkz00, BgL_list1282z00_1610);
+							BGl_string1410z00zzhgen_walkz00, BgL_list1274z00_1615);
 					}
 					{	/* Hgen/walk.scm 44 */
-						obj_t BgL_list1283z00_1611;
+						obj_t BgL_list1275z00_1616;
 
-						BgL_list1283z00_1611 = MAKE_YOUNG_PAIR(BgL_namez00_1609, BNIL);
+						BgL_list1275z00_1616 = MAKE_YOUNG_PAIR(BgL_namez00_1614, BNIL);
 						BGl_fprintfz00zz__r4_output_6_10_3z00
 							(BGl_za2czd2portza2zd2zzbackend_c_emitz00,
-							BGl_string1590z00zzhgen_walkz00, BgL_list1283z00_1611);
+							BGl_string1411z00zzhgen_walkz00, BgL_list1275z00_1616);
 					}
-					BGl_emitzd2classzd2typesz00zzbackend_c_prototypez00(BgL_clistz00_1608,
+					BGl_emitzd2classzd2typesz00zzbackend_c_prototypez00(BgL_clistz00_1613,
 						BGl_za2czd2portza2zd2zzbackend_c_emitz00);
 					bgl_display_char(((unsigned char) 10),
 						BGl_za2czd2portza2zd2zzbackend_c_emitz00);
 					{	/* Hgen/walk.scm 47 */
-						obj_t BgL_list1284z00_1612;
+						obj_t BgL_list1276z00_1617;
 
-						BgL_list1284z00_1612 = MAKE_YOUNG_PAIR(BgL_namez00_1609, BNIL);
+						BgL_list1276z00_1617 = MAKE_YOUNG_PAIR(BgL_namez00_1614, BNIL);
 						BGl_fprintfz00zz__r4_output_6_10_3z00
 							(BGl_za2czd2portza2zd2zzbackend_c_emitz00,
-							BGl_string1591z00zzhgen_walkz00, BgL_list1284z00_1612);
+							BGl_string1412z00zzhgen_walkz00, BgL_list1276z00_1617);
 			}}}
 			BGL_TAIL return BGl_stopzd2emissionz12zc0zzbackend_c_emitz00();
 		}
@@ -707,7 +716,7 @@ extern "C"
 
 
 /* &hgen-walk */
-	obj_t BGl_z62hgenzd2walkzb0zzhgen_walkz00(obj_t BgL_envz00_1898)
+	obj_t BGl_z62hgenzd2walkzb0zzhgen_walkz00(obj_t BgL_envz00_1909)
 	{
 		{	/* Hgen/walk.scm 30 */
 			return BGl_hgenzd2walkzd2zzhgen_walkz00();
@@ -717,13 +726,13 @@ extern "C"
 
 
 
-/* &<@anonymous:1281> */
-	obj_t BGl_z62zc3z04anonymousza31281ze3ze5zzhgen_walkz00(obj_t BgL_envz00_1899)
+/* &<@anonymous:1273> */
+	obj_t BGl_z62zc3z04anonymousza31273ze3ze5zzhgen_walkz00(obj_t BgL_envz00_1910)
 	{
 		{	/* Hgen/walk.scm 31 */
 			return
 				BGl_startzd2emissionz12zc0zzbackend_c_emitz00
-				(BGl_string1592z00zzhgen_walkz00);
+				(BGl_string1413z00zzhgen_walkz00);
 		}
 
 	}
@@ -735,22 +744,22 @@ extern "C"
 	{
 		{	/* Hgen/walk.scm 53 */
 			{	/* Hgen/walk.scm 54 */
-				obj_t BgL_namez00_1634;
+				obj_t BgL_namez00_1639;
 
 				{	/* Hgen/walk.scm 54 */
-					obj_t BgL_arg1330z00_1636;
+					obj_t BgL_arg1291z00_1641;
 
-					BgL_arg1330z00_1636 = SYMBOL_TO_STRING(((obj_t) BgL_modz00_3));
-					BgL_namez00_1634 =
-						BGl_stringzd2upcasezd2zz__r4_strings_6_7z00(BgL_arg1330z00_1636);
+					BgL_arg1291z00_1641 = SYMBOL_TO_STRING(((obj_t) BgL_modz00_3));
+					BgL_namez00_1639 =
+						BGl_stringzd2upcasezd2zz__r4_strings_6_7z00(BgL_arg1291z00_1641);
 				}
-				if (BGl_bigloozd2needzd2manglingzf3zf3zz__biglooz00(BgL_namez00_1634))
+				if (BGl_bigloozd2needzd2manglingzf3zf3zz__biglooz00(BgL_namez00_1639))
 					{	/* Hgen/walk.scm 55 */
-						return bigloo_mangle(BgL_namez00_1634);
+						return bigloo_mangle(BgL_namez00_1639);
 					}
 				else
 					{	/* Hgen/walk.scm 55 */
-						return BgL_namez00_1634;
+						return BgL_namez00_1639;
 					}
 			}
 		}
@@ -797,26 +806,26 @@ extern "C"
 	{
 		{	/* Hgen/walk.scm 15 */
 			BGl_modulezd2initializa7ationz75zztools_speekz00(61247943L,
-				BSTRING_TO_STRING(BGl_string1593z00zzhgen_walkz00));
+				BSTRING_TO_STRING(BGl_string1414z00zzhgen_walkz00));
 			BGl_modulezd2initializa7ationz75zztools_errorz00(300504031L,
-				BSTRING_TO_STRING(BGl_string1593z00zzhgen_walkz00));
+				BSTRING_TO_STRING(BGl_string1414z00zzhgen_walkz00));
 			BGl_modulezd2initializa7ationz75zzengine_passz00(373082237L,
-				BSTRING_TO_STRING(BGl_string1593z00zzhgen_walkz00));
+				BSTRING_TO_STRING(BGl_string1414z00zzhgen_walkz00));
 			BGl_modulezd2initializa7ationz75zztype_typez00(515343395L,
-				BSTRING_TO_STRING(BGl_string1593z00zzhgen_walkz00));
+				BSTRING_TO_STRING(BGl_string1414z00zzhgen_walkz00));
 			BGl_modulezd2initializa7ationz75zzobject_classz00(502007119L,
-				BSTRING_TO_STRING(BGl_string1593z00zzhgen_walkz00));
+				BSTRING_TO_STRING(BGl_string1414z00zzhgen_walkz00));
 			BGl_modulezd2initializa7ationz75zzast_varz00(90839984L,
-				BSTRING_TO_STRING(BGl_string1593z00zzhgen_walkz00));
+				BSTRING_TO_STRING(BGl_string1414z00zzhgen_walkz00));
 			BGl_modulezd2initializa7ationz75zzast_nodez00(469732712L,
-				BSTRING_TO_STRING(BGl_string1593z00zzhgen_walkz00));
+				BSTRING_TO_STRING(BGl_string1414z00zzhgen_walkz00));
 			BGl_modulezd2initializa7ationz75zzmodule_modulez00(158397907L,
-				BSTRING_TO_STRING(BGl_string1593z00zzhgen_walkz00));
-			BGl_modulezd2initializa7ationz75zzbackend_c_emitz00(14466025L,
-				BSTRING_TO_STRING(BGl_string1593z00zzhgen_walkz00));
+				BSTRING_TO_STRING(BGl_string1414z00zzhgen_walkz00));
+			BGl_modulezd2initializa7ationz75zzbackend_c_emitz00(474089076L,
+				BSTRING_TO_STRING(BGl_string1414z00zzhgen_walkz00));
 			return
 				BGl_modulezd2initializa7ationz75zzbackend_c_prototypez00(364917963L,
-				BSTRING_TO_STRING(BGl_string1593z00zzhgen_walkz00));
+				BSTRING_TO_STRING(BGl_string1414z00zzhgen_walkz00));
 		}
 
 	}
