@@ -1,9 +1,9 @@
 /*===========================================================================*/
 /*   (Init/extend.scm)                                                       */
-/*   Bigloo (4.5b)                                                           */
-/*   Inria -- Sophia Antipolis (c)       Fri Dec 22 05:17:06 PM CET 2023     */
+/*   Bigloo (4.6a)                                                           */
+/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
 /*===========================================================================*/
-/* COMPILATION: (/home/serrano/prgm/project/bigloo/bigloo/bin/bigloo -ldopt -L/home/serrano/prgm/project/bigloo/bigloo/libbacktrace/home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b  -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Init/extend.scm) */
+/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Init/extend.scm) */
 /* GC selection */
 #define THE_GC BOEHM_GC
 
@@ -75,22 +75,22 @@ extern "C"
 	   
 		 
 		DEFINE_EXPORT_BGL_PROCEDURE(BGl_loadzd2extendzd2envz00zzinit_extendz00,
-		BgL_bgl_za762loadza7d2extend1064z00,
+		BgL_bgl_za762loadza7d2extend1062z00,
 		BGl_z62loadzd2extendzb0zzinit_extendz00, 0L, BUNSPEC, 1);
+	      DEFINE_STRING(BGl_string1054z00zzinit_extendz00,
+		BgL_bgl_string1054za700za7za7i1063za7, "   . ", 5);
 	      DEFINE_STRING(BGl_string1055z00zzinit_extendz00,
-		BgL_bgl_string1055za700za7za7i1065za7, "   . ", 5);
+		BgL_bgl_string1055za700za7za7i1064za7, "failure during prelude hook", 27);
 	      DEFINE_STRING(BGl_string1056z00zzinit_extendz00,
-		BgL_bgl_string1056za700za7za7i1066za7, "failure during prelude hook", 27);
+		BgL_bgl_string1056za700za7za7i1065za7, ".init", 5);
 	      DEFINE_STRING(BGl_string1057z00zzinit_extendz00,
-		BgL_bgl_string1057za700za7za7i1067za7, ".init", 5);
+		BgL_bgl_string1057za700za7za7i1066za7, "parse-args", 10);
 	      DEFINE_STRING(BGl_string1058z00zzinit_extendz00,
-		BgL_bgl_string1058za700za7za7i1068za7, "parse-args", 10);
+		BgL_bgl_string1058za700za7za7i1067za7, "Can't find extend file", 22);
 	      DEFINE_STRING(BGl_string1059z00zzinit_extendz00,
-		BgL_bgl_string1059za700za7za7i1069za7, "Can't find extend file", 22);
+		BgL_bgl_string1059za700za7za7i1068za7, "init_extend", 11);
 	      DEFINE_STRING(BGl_string1060z00zzinit_extendz00,
-		BgL_bgl_string1060za700za7za7i1070za7, "init_extend", 11);
-	      DEFINE_STRING(BGl_string1061z00zzinit_extendz00,
-		BgL_bgl_string1061za700za7za7i1071za7, "pass-started ", 13);
+		BgL_bgl_string1060za700za7za7i1069za7, "pass-started ", 13);
 
 /* GC roots registration */
 	static obj_t bgl_gc_roots_register()
@@ -112,7 +112,7 @@ extern "C"
 
 /* module-initialization */
 	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zzinit_extendz00(long
-		BgL_checksumz00_79, char *BgL_fromz00_80)
+		BgL_checksumz00_80, char *BgL_fromz00_81)
 	{
 		{
 			if (CBOOL(BGl_requirezd2initializa7ationz75zzinit_extendz00))
@@ -159,70 +159,70 @@ extern "C"
 	{
 		{	/* Init/extend.scm 16 */
 			{	/* Init/extend.scm 16 */
-				obj_t BgL_cportz00_68;
+				obj_t BgL_cportz00_69;
 
 				{	/* Init/extend.scm 16 */
-					obj_t BgL_stringz00_75;
+					obj_t BgL_stringz00_76;
 
-					BgL_stringz00_75 = BGl_string1061z00zzinit_extendz00;
+					BgL_stringz00_76 = BGl_string1060z00zzinit_extendz00;
 					{	/* Init/extend.scm 16 */
-						obj_t BgL_startz00_76;
+						obj_t BgL_startz00_77;
 
-						BgL_startz00_76 = BINT(0L);
+						BgL_startz00_77 = BINT(0L);
 						{	/* Init/extend.scm 16 */
-							obj_t BgL_endz00_77;
+							obj_t BgL_endz00_78;
 
-							BgL_endz00_77 = BINT(STRING_LENGTH(((obj_t) BgL_stringz00_75)));
+							BgL_endz00_78 = BINT(STRING_LENGTH(((obj_t) BgL_stringz00_76)));
 							{	/* Init/extend.scm 16 */
 
-								BgL_cportz00_68 =
+								BgL_cportz00_69 =
 									BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00
-									(BgL_stringz00_75, BgL_startz00_76, BgL_endz00_77);
+									(BgL_stringz00_76, BgL_startz00_77, BgL_endz00_78);
 				}}}}
 				{
-					long BgL_iz00_69;
+					long BgL_iz00_70;
 
-					BgL_iz00_69 = 0L;
-				BgL_loopz00_70:
-					if ((BgL_iz00_69 == -1L))
+					BgL_iz00_70 = 0L;
+				BgL_loopz00_71:
+					if ((BgL_iz00_70 == (-1L)))
 						{	/* Init/extend.scm 16 */
 							return BUNSPEC;
 						}
 					else
 						{	/* Init/extend.scm 16 */
 							{	/* Init/extend.scm 16 */
-								obj_t BgL_arg1063z00_71;
+								obj_t BgL_arg1061z00_72;
 
 								{	/* Init/extend.scm 16 */
 
 									{	/* Init/extend.scm 16 */
-										obj_t BgL_locationz00_73;
+										obj_t BgL_locationz00_74;
 
-										BgL_locationz00_73 = BBOOL(((bool_t) 0));
+										BgL_locationz00_74 = BBOOL(((bool_t) 0));
 										{	/* Init/extend.scm 16 */
 
-											BgL_arg1063z00_71 =
-												BGl_readz00zz__readerz00(BgL_cportz00_68,
-												BgL_locationz00_73);
+											BgL_arg1061z00_72 =
+												BGl_readz00zz__readerz00(BgL_cportz00_69,
+												BgL_locationz00_74);
 										}
 									}
 								}
 								{	/* Init/extend.scm 16 */
-									int BgL_tmpz00_105;
+									int BgL_tmpz00_106;
 
-									BgL_tmpz00_105 = (int) (BgL_iz00_69);
-									CNST_TABLE_SET(BgL_tmpz00_105, BgL_arg1063z00_71);
+									BgL_tmpz00_106 = (int) (BgL_iz00_70);
+									CNST_TABLE_SET(BgL_tmpz00_106, BgL_arg1061z00_72);
 							}}
 							{	/* Init/extend.scm 16 */
-								int BgL_auxz00_74;
+								int BgL_auxz00_75;
 
-								BgL_auxz00_74 = (int) ((BgL_iz00_69 - 1L));
+								BgL_auxz00_75 = (int) ((BgL_iz00_70 - 1L));
 								{
-									long BgL_iz00_110;
+									long BgL_iz00_111;
 
-									BgL_iz00_110 = (long) (BgL_auxz00_74);
-									BgL_iz00_69 = BgL_iz00_110;
-									goto BgL_loopz00_70;
+									BgL_iz00_111 = (long) (BgL_auxz00_75);
+									BgL_iz00_70 = BgL_iz00_111;
+									goto BgL_loopz00_71;
 								}
 							}
 						}
@@ -273,230 +273,214 @@ extern "C"
 						MAKE_YOUNG_PAIR(BgL_extendzd2namezd2_3,
 						BGl_za2extendzd2tableza2zd2zzinit_extendz00);
 					{	/* Init/extend.scm 28 */
-						obj_t BgL_fnamez00_13;
+						obj_t BgL_fnamez00_14;
 
-						BgL_fnamez00_13 =
+						BgL_fnamez00_14 =
 							BGl_findzd2filezf2pathz20zz__osz00(BgL_extendzd2namezd2_3,
 							BGl_za2libzd2dirza2zd2zzengine_paramz00);
-						if (CBOOL(BgL_fnamez00_13))
+						if (CBOOL(BgL_fnamez00_14))
 							{	/* Init/extend.scm 29 */
 								{	/* Init/extend.scm 31 */
-									obj_t BgL_list1024z00_14;
+									obj_t BgL_list1025z00_15;
 
 									{	/* Init/extend.scm 31 */
-										obj_t BgL_arg1025z00_15;
+										obj_t BgL_arg1026z00_16;
 
 										{	/* Init/extend.scm 31 */
-											obj_t BgL_arg1026z00_16;
+											obj_t BgL_arg1027z00_17;
 
-											BgL_arg1026z00_16 =
+											BgL_arg1027z00_17 =
 												MAKE_YOUNG_PAIR(BCHAR(((unsigned char) 10)), BNIL);
-											BgL_arg1025z00_15 =
-												MAKE_YOUNG_PAIR(BgL_fnamez00_13, BgL_arg1026z00_16);
+											BgL_arg1026z00_16 =
+												MAKE_YOUNG_PAIR(BgL_fnamez00_14, BgL_arg1027z00_17);
 										}
-										BgL_list1024z00_14 =
-											MAKE_YOUNG_PAIR(BGl_string1055z00zzinit_extendz00,
-											BgL_arg1025z00_15);
+										BgL_list1025z00_15 =
+											MAKE_YOUNG_PAIR(BGl_string1054z00zzinit_extendz00,
+											BgL_arg1026z00_16);
 									}
-									BGl_verbosez00zztools_speekz00(BINT(1L), BgL_list1024z00_14);
+									BGl_verbosez00zztools_speekz00(BINT(1L), BgL_list1025z00_15);
 								}
 								BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00 = BINT(0L);
-								BGl_za2currentzd2passza2zd2zzengine_passz00 = BgL_fnamez00_13;
+								BGl_za2currentzd2passza2zd2zzengine_passz00 = BgL_fnamez00_14;
 								{	/* Init/extend.scm 31 */
-									obj_t BgL_g1016z00_17;
+									obj_t BgL_g1016z00_18;
 
-									BgL_g1016z00_17 = BNIL;
+									BgL_g1016z00_18 = BNIL;
 									{
-										obj_t BgL_hooksz00_20;
-										obj_t BgL_hnamesz00_21;
+										obj_t BgL_hooksz00_21;
+										obj_t BgL_hnamesz00_22;
 
-										BgL_hooksz00_20 = BgL_g1016z00_17;
-										BgL_hnamesz00_21 = BNIL;
-									BgL_zc3z04anonymousza31027ze3z87_22:
-										if (NULLP(BgL_hooksz00_20))
+										BgL_hooksz00_21 = BgL_g1016z00_18;
+										BgL_hnamesz00_22 = BNIL;
+									BgL_zc3z04anonymousza31028ze3z87_23:
+										if (NULLP(BgL_hooksz00_21))
 											{	/* Init/extend.scm 31 */
-												CNST_TABLE_REF(0L);
+												((obj_t) CNST_TABLE_REF(0));
 											}
 										else
 											{	/* Init/extend.scm 31 */
-												bool_t BgL_test1077z00_130;
+												bool_t BgL_test1075z00_132;
 
 												{	/* Init/extend.scm 31 */
-													obj_t BgL_fun1037z00_29;
+													obj_t BgL_fun1037z00_30;
 
-													BgL_fun1037z00_29 = CAR(((obj_t) BgL_hooksz00_20));
-													BgL_test1077z00_130 =
-														CBOOL(
-														(VA_PROCEDUREP(BgL_fun1037z00_29)
-															? ((obj_t(*)(obj_t,
-																		...))
-																PROCEDURE_ENTRY(BgL_fun1037z00_29))
-															(BgL_fun1037z00_29,
-																BEOA) : ((obj_t(*)(obj_t))
-																PROCEDURE_ENTRY(BgL_fun1037z00_29))
-															(BgL_fun1037z00_29)));
+													BgL_fun1037z00_30 = CAR(((obj_t) BgL_hooksz00_21));
+													BgL_test1075z00_132 =
+														CBOOL(BGL_PROCEDURE_CALL0(BgL_fun1037z00_30));
 												}
-												if (BgL_test1077z00_130)
+												if (BgL_test1075z00_132)
 													{	/* Init/extend.scm 31 */
-														obj_t BgL_arg1033z00_26;
 														obj_t BgL_arg1034z00_27;
+														obj_t BgL_arg1035z00_28;
 
-														BgL_arg1033z00_26 = CDR(((obj_t) BgL_hooksz00_20));
-														BgL_arg1034z00_27 = CDR(((obj_t) BgL_hnamesz00_21));
+														BgL_arg1034z00_27 = CDR(((obj_t) BgL_hooksz00_21));
+														BgL_arg1035z00_28 = CDR(((obj_t) BgL_hnamesz00_22));
 														{
-															obj_t BgL_hnamesz00_142;
-															obj_t BgL_hooksz00_141;
+															obj_t BgL_hnamesz00_144;
+															obj_t BgL_hooksz00_143;
 
-															BgL_hooksz00_141 = BgL_arg1033z00_26;
-															BgL_hnamesz00_142 = BgL_arg1034z00_27;
-															BgL_hnamesz00_21 = BgL_hnamesz00_142;
-															BgL_hooksz00_20 = BgL_hooksz00_141;
-															goto BgL_zc3z04anonymousza31027ze3z87_22;
+															BgL_hooksz00_143 = BgL_arg1034z00_27;
+															BgL_hnamesz00_144 = BgL_arg1035z00_28;
+															BgL_hnamesz00_22 = BgL_hnamesz00_144;
+															BgL_hooksz00_21 = BgL_hooksz00_143;
+															goto BgL_zc3z04anonymousza31028ze3z87_23;
 														}
 													}
 												else
 													{	/* Init/extend.scm 31 */
-														obj_t BgL_arg1036z00_28;
+														obj_t BgL_arg1036z00_29;
 
-														BgL_arg1036z00_28 = CAR(((obj_t) BgL_hnamesz00_21));
+														BgL_arg1036z00_29 = CAR(((obj_t) BgL_hnamesz00_22));
 														BGl_internalzd2errorzd2zztools_errorz00
-															(BgL_fnamez00_13,
-															BGl_string1056z00zzinit_extendz00,
-															BgL_arg1036z00_28);
+															(BgL_fnamez00_14,
+															BGl_string1055z00zzinit_extendz00,
+															BgL_arg1036z00_29);
 													}
 											}
 									}
 								}
 								{	/* Init/extend.scm 32 */
-									obj_t BgL_envz00_33;
+									obj_t BgL_envz00_34;
 
-									BgL_envz00_33 = BGl_defaultzd2environmentzd2zz__evalz00();
+									BgL_envz00_34 = BGl_defaultzd2environmentzd2zz__evalz00();
 									{	/* Init/extend.scm 32 */
 
 										return
-											BGl_loadqz00zz__evalz00(BgL_fnamez00_13, BgL_envz00_33);
+											BGl_loadqz00zz__evalz00(BgL_fnamez00_14, BgL_envz00_34);
 									}
 								}
 							}
 						else
 							{	/* Init/extend.scm 33 */
-								obj_t BgL_fnamez00_34;
+								obj_t BgL_fnamez00_35;
 
 								{	/* Init/extend.scm 33 */
-									obj_t BgL_arg1052z00_55;
+									obj_t BgL_arg1051z00_56;
 
-									BgL_arg1052z00_55 =
+									BgL_arg1051z00_56 =
 										string_append(BgL_extendzd2namezd2_3,
-										BGl_string1057z00zzinit_extendz00);
-									BgL_fnamez00_34 =
-										BGl_findzd2filezf2pathz20zz__osz00(BgL_arg1052z00_55,
+										BGl_string1056z00zzinit_extendz00);
+									BgL_fnamez00_35 =
+										BGl_findzd2filezf2pathz20zz__osz00(BgL_arg1051z00_56,
 										BGl_za2libzd2dirza2zd2zzengine_paramz00);
 								}
-								if (CBOOL(BgL_fnamez00_34))
+								if (CBOOL(BgL_fnamez00_35))
 									{	/* Init/extend.scm 35 */
 										{	/* Init/extend.scm 37 */
-											obj_t BgL_list1039z00_35;
+											obj_t BgL_list1039z00_36;
 
 											{	/* Init/extend.scm 37 */
-												obj_t BgL_arg1040z00_36;
+												obj_t BgL_arg1040z00_37;
 
 												{	/* Init/extend.scm 37 */
-													obj_t BgL_arg1041z00_37;
+													obj_t BgL_arg1041z00_38;
 
-													BgL_arg1041z00_37 =
+													BgL_arg1041z00_38 =
 														MAKE_YOUNG_PAIR(BCHAR(((unsigned char) 10)), BNIL);
-													BgL_arg1040z00_36 =
-														MAKE_YOUNG_PAIR(BgL_fnamez00_34, BgL_arg1041z00_37);
+													BgL_arg1040z00_37 =
+														MAKE_YOUNG_PAIR(BgL_fnamez00_35, BgL_arg1041z00_38);
 												}
-												BgL_list1039z00_35 =
-													MAKE_YOUNG_PAIR(BGl_string1055z00zzinit_extendz00,
-													BgL_arg1040z00_36);
+												BgL_list1039z00_36 =
+													MAKE_YOUNG_PAIR(BGl_string1054z00zzinit_extendz00,
+													BgL_arg1040z00_37);
 											}
 											BGl_verbosez00zztools_speekz00(BINT(1L),
-												BgL_list1039z00_35);
+												BgL_list1039z00_36);
 										}
 										BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00 =
 											BINT(0L);
 										BGl_za2currentzd2passza2zd2zzengine_passz00 =
-											BgL_fnamez00_34;
+											BgL_fnamez00_35;
 										{	/* Init/extend.scm 37 */
-											obj_t BgL_g1018z00_38;
+											obj_t BgL_g1018z00_39;
 
-											BgL_g1018z00_38 = BNIL;
+											BgL_g1018z00_39 = BNIL;
 											{
-												obj_t BgL_hooksz00_41;
-												obj_t BgL_hnamesz00_42;
+												obj_t BgL_hooksz00_42;
+												obj_t BgL_hnamesz00_43;
 
-												BgL_hooksz00_41 = BgL_g1018z00_38;
-												BgL_hnamesz00_42 = BNIL;
-											BgL_zc3z04anonymousza31042ze3z87_43:
-												if (NULLP(BgL_hooksz00_41))
+												BgL_hooksz00_42 = BgL_g1018z00_39;
+												BgL_hnamesz00_43 = BNIL;
+											BgL_zc3z04anonymousza31042ze3z87_44:
+												if (NULLP(BgL_hooksz00_42))
 													{	/* Init/extend.scm 37 */
-														CNST_TABLE_REF(0L);
+														((obj_t) CNST_TABLE_REF(0));
 													}
 												else
 													{	/* Init/extend.scm 37 */
-														bool_t BgL_test1080z00_162;
+														bool_t BgL_test1078z00_165;
 
 														{	/* Init/extend.scm 37 */
-															obj_t BgL_fun1050z00_50;
+															obj_t BgL_fun1049z00_51;
 
-															BgL_fun1050z00_50 =
-																CAR(((obj_t) BgL_hooksz00_41));
-															BgL_test1080z00_162 =
-																CBOOL(
-																(VA_PROCEDUREP(BgL_fun1050z00_50)
-																	? ((obj_t(*)(obj_t,
-																				...))
-																		PROCEDURE_ENTRY(BgL_fun1050z00_50))
-																	(BgL_fun1050z00_50,
-																		BEOA) : ((obj_t(*)(obj_t))
-																		PROCEDURE_ENTRY(BgL_fun1050z00_50))
-																	(BgL_fun1050z00_50)));
+															BgL_fun1049z00_51 =
+																CAR(((obj_t) BgL_hooksz00_42));
+															BgL_test1078z00_165 =
+																CBOOL(BGL_PROCEDURE_CALL0(BgL_fun1049z00_51));
 														}
-														if (BgL_test1080z00_162)
+														if (BgL_test1078z00_165)
 															{	/* Init/extend.scm 37 */
-																obj_t BgL_arg1047z00_47;
-																obj_t BgL_arg1048z00_48;
+																obj_t BgL_arg1046z00_48;
+																obj_t BgL_arg1047z00_49;
 
-																BgL_arg1047z00_47 =
-																	CDR(((obj_t) BgL_hooksz00_41));
-																BgL_arg1048z00_48 =
-																	CDR(((obj_t) BgL_hnamesz00_42));
+																BgL_arg1046z00_48 =
+																	CDR(((obj_t) BgL_hooksz00_42));
+																BgL_arg1047z00_49 =
+																	CDR(((obj_t) BgL_hnamesz00_43));
 																{
-																	obj_t BgL_hnamesz00_174;
-																	obj_t BgL_hooksz00_173;
+																	obj_t BgL_hnamesz00_177;
+																	obj_t BgL_hooksz00_176;
 
-																	BgL_hooksz00_173 = BgL_arg1047z00_47;
-																	BgL_hnamesz00_174 = BgL_arg1048z00_48;
-																	BgL_hnamesz00_42 = BgL_hnamesz00_174;
-																	BgL_hooksz00_41 = BgL_hooksz00_173;
-																	goto BgL_zc3z04anonymousza31042ze3z87_43;
+																	BgL_hooksz00_176 = BgL_arg1046z00_48;
+																	BgL_hnamesz00_177 = BgL_arg1047z00_49;
+																	BgL_hnamesz00_43 = BgL_hnamesz00_177;
+																	BgL_hooksz00_42 = BgL_hooksz00_176;
+																	goto BgL_zc3z04anonymousza31042ze3z87_44;
 																}
 															}
 														else
 															{	/* Init/extend.scm 37 */
-																obj_t BgL_arg1049z00_49;
+																obj_t BgL_arg1048z00_50;
 
-																BgL_arg1049z00_49 =
-																	CAR(((obj_t) BgL_hnamesz00_42));
+																BgL_arg1048z00_50 =
+																	CAR(((obj_t) BgL_hnamesz00_43));
 																BGl_internalzd2errorzd2zztools_errorz00
-																	(BgL_fnamez00_34,
-																	BGl_string1056z00zzinit_extendz00,
-																	BgL_arg1049z00_49);
+																	(BgL_fnamez00_35,
+																	BGl_string1055z00zzinit_extendz00,
+																	BgL_arg1048z00_50);
 															}
 													}
 											}
 										}
 										{	/* Init/extend.scm 38 */
-											obj_t BgL_envz00_54;
+											obj_t BgL_envz00_55;
 
-											BgL_envz00_54 = BGl_defaultzd2environmentzd2zz__evalz00();
+											BgL_envz00_55 = BGl_defaultzd2environmentzd2zz__evalz00();
 											{	/* Init/extend.scm 38 */
 
 												return
-													BGl_loadqz00zz__evalz00(BgL_fnamez00_34,
-													BgL_envz00_54);
+													BGl_loadqz00zz__evalz00(BgL_fnamez00_35,
+													BgL_envz00_55);
 											}
 										}
 									}
@@ -504,8 +488,8 @@ extern "C"
 									{	/* Init/extend.scm 35 */
 										return
 											BGl_errorz00zz__errorz00
-											(BGl_string1058z00zzinit_extendz00,
-											BGl_string1059z00zzinit_extendz00,
+											(BGl_string1057z00zzinit_extendz00,
+											BGl_string1058z00zzinit_extendz00,
 											BgL_extendzd2namezd2_3);
 									}
 							}
@@ -518,11 +502,11 @@ extern "C"
 
 
 /* &load-extend */
-	obj_t BGl_z62loadzd2extendzb0zzinit_extendz00(obj_t BgL_envz00_66,
-		obj_t BgL_extendzd2namezd2_67)
+	obj_t BGl_z62loadzd2extendzb0zzinit_extendz00(obj_t BgL_envz00_67,
+		obj_t BgL_extendzd2namezd2_68)
 	{
 		{	/* Init/extend.scm 25 */
-			return BGl_loadzd2extendzd2zzinit_extendz00(BgL_extendzd2namezd2_67);
+			return BGl_loadzd2extendzd2zzinit_extendz00(BgL_extendzd2namezd2_68);
 		}
 
 	}
@@ -567,14 +551,14 @@ extern "C"
 	{
 		{	/* Init/extend.scm 16 */
 			BGl_modulezd2initializa7ationz75zztools_speekz00(61247943L,
-				BSTRING_TO_STRING(BGl_string1060z00zzinit_extendz00));
+				BSTRING_TO_STRING(BGl_string1059z00zzinit_extendz00));
 			BGl_modulezd2initializa7ationz75zztools_errorz00(300504031L,
-				BSTRING_TO_STRING(BGl_string1060z00zzinit_extendz00));
+				BSTRING_TO_STRING(BGl_string1059z00zzinit_extendz00));
 			BGl_modulezd2initializa7ationz75zzengine_passz00(373082237L,
-				BSTRING_TO_STRING(BGl_string1060z00zzinit_extendz00));
+				BSTRING_TO_STRING(BGl_string1059z00zzinit_extendz00));
 			return
-				BGl_modulezd2initializa7ationz75zzengine_paramz00(517137079L,
-				BSTRING_TO_STRING(BGl_string1060z00zzinit_extendz00));
+				BGl_modulezd2initializa7ationz75zzengine_paramz00(161876678L,
+				BSTRING_TO_STRING(BGl_string1059z00zzinit_extendz00));
 		}
 
 	}
