@@ -1,41 +1,10 @@
-;*---------------------------------------------------------------------*/
-;*   A pratical implementation for the Scheme programming language     */
-;*                                                                     */
-;*                                    ,--^,                            */
-;*                              _ ___/ /|/                             */
-;*                          ,;'( )__, ) '                              */
-;*                         ;;  //   L__.                               */
-;*                         '   \\   /  '                               */
-;*                              ^   ^                                  */
-;*                                                                     */
-;*   Copyright (c) 1992-1999 Manuel Serrano                            */
-;*                                                                     */
-;*     Bug descriptions, use reports, comments or suggestions are      */
-;*     welcome. Send them to                                           */
-;*       bigloo-request@kaolin.unice.fr                                */
-;*       http://kaolin.unice.fr/bigloo                                 */
-;*                                                                     */
-;*   This program is free software; you can redistribute it            */
-;*   and/or modify it under the terms of the GNU General Public        */
-;*   License as published by the Free Software Foundation; either      */
-;*   version 2 of the License, or (at your option) any later version.  */
-;*                                                                     */
-;*   This program is distributed in the hope that it will be useful,   */
-;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
-;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
-;*   GNU General Public License for more details.                      */
-;*                                                                     */
-;*   You should have received a copy of the GNU General Public         */
-;*   License along with this program; if not, write to the Free        */
-;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
-;*   MA 02111-1307, USA.                                               */
-;*---------------------------------------------------------------------*/
 ;*=====================================================================*/
-;*    serrano/prgm/project/bigloo/comptime1.9/Inline/loop.scm          */
+;*    serrano/prgm/project/bigloo/bigloo/comptime/Inline/loop.scm      */
 ;*    -------------------------------------------------------------    */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Thu Jul 11 09:27:29 1996                          */
-;*    Last change :  Thu Sep  5 09:57:21 1996 (serrano)                */
+;*    Last change :  Wed Jun 16 16:03:43 2021 (serrano)                */
+;*    Copyright   :  1996-2021 Manuel Serrano, see LICENSE file        */
 ;*    -------------------------------------------------------------    */
 ;*    The loop unrolling module.                                       */
 ;*=====================================================================*/
@@ -92,6 +61,14 @@
 (define-method (find-let-fun? node::sequence)
    (find-let-fun?* (sequence-nodes node)))
 
+;*---------------------------------------------------------------------*/
+;*    find-let-fun? ::sync ...                                         */
+;*---------------------------------------------------------------------*/
+(define-method (find-let-fun? node::sync)
+   (or (find-let-fun? (sync-mutex node))
+       (find-let-fun? (sync-prelock node))
+       (find-let-fun? (sync-body node))))
+
 ;*---------------------------------------------------------------------*/
 ;*    find-let-fun? ::app ...                                          */
 ;*---------------------------------------------------------------------*/
@@ -115,10 +92,10 @@
 	  (find-let-fun?* args))))
 
 ;*---------------------------------------------------------------------*/
-;*    find-let-fun? ::pragma ...                                       */
+;*    find-let-fun? ::extern ...                                       */
 ;*---------------------------------------------------------------------*/
-(define-method (find-let-fun? node::pragma)
-   (find-let-fun?* (pragma-args node)))
+(define-method (find-let-fun? node::extern)
+   (find-let-fun?* (extern-expr* node)))
 
 ;*---------------------------------------------------------------------*/
 ;*    find-let-fun? ::cast ...                                         */
@@ -151,13 +128,13 @@
 	  (find-let-fun? obj))))
 
 ;*---------------------------------------------------------------------*/
-;*    find-let-fun? ::select ...                                       */
+;*    find-let-fun? ::switch ...                                       */
 ;*---------------------------------------------------------------------*/
-(define-method (find-let-fun? node::select)
-   (let loop ((clauses (select-clauses node)))
+(define-method (find-let-fun? node::switch)
+   (let loop ((clauses (switch-clauses node)))
       (cond
 	 ((null? clauses)
-	  (find-let-fun? (select-test node)))
+	  (find-let-fun? (switch-test node)))
 	 ((find-let-fun? (cdr (car clauses)))
 	  #t)
 	 (else
@@ -186,7 +163,8 @@
 ;*    find-let-fun? ::set-ex-it ...                                    */
 ;*---------------------------------------------------------------------*/
 (define-method (find-let-fun? node::set-ex-it)
-   (find-let-fun? (set-ex-it-body node)))
+   (or (find-let-fun? (set-ex-it-body node))
+       (find-let-fun? (set-ex-it-onexit node))))
 
 ;*---------------------------------------------------------------------*/
 ;*    find-let-fun? ::jump-ex-it ...                                   */
@@ -258,6 +236,16 @@
       (nest-loop!* nodes var nester)
       node))
 
+;*---------------------------------------------------------------------*/
+;*    nest-loop! ::sync ...                                            */
+;*---------------------------------------------------------------------*/
+(define-method (nest-loop! node::sync var nester)
+   (with-access::sync node (body mutex prelock)
+      (set! mutex (nest-loop! mutex var nester))
+      (set! prelock (nest-loop! prelock var nester))
+      (set! body (nest-loop! body var nester))
+      node))
+
 ;*---------------------------------------------------------------------*/
 ;*    nest-loop! ::app ...                                             */
 ;*---------------------------------------------------------------------*/
@@ -287,10 +275,10 @@
       node))
 
 ;*---------------------------------------------------------------------*/
-;*    nest-loop! ::pragma ...                                          */
+;*    nest-loop! ::extern ...                                          */
 ;*---------------------------------------------------------------------*/
-(define-method (nest-loop! node::pragma var nester)
-   (nest-loop!* (pragma-args node) var nester)
+(define-method (nest-loop! node::extern var nester)
+   (nest-loop!* (extern-expr* node) var nester)
    node)
 
 ;*---------------------------------------------------------------------*/
@@ -328,10 +316,10 @@
       node))
 
 ;*---------------------------------------------------------------------*/
-;*    nest-loop! ::select ...                                          */
+;*    nest-loop! ::switch ...                                          */
 ;*---------------------------------------------------------------------*/
-(define-method (nest-loop! node::select var nester)
-   (with-access::select node (test clauses)
+(define-method (nest-loop! node::switch var nester)
+   (with-access::switch node (test clauses)
       (set! test (nest-loop! test var nester))
       (for-each (lambda (clause)
 		   (set-cdr! clause (nest-loop! (cdr clause) var nester)))
@@ -368,8 +356,9 @@
 ;*    nest-loop! ::set-ex-it ...                                       */
 ;*---------------------------------------------------------------------*/
 (define-method (nest-loop! node::set-ex-it var nester)
-   (with-access::set-ex-it node (body)
+   (with-access::set-ex-it node (body onexit)
       (set! body (nest-loop! body var nester))
+      (set! onexit (nest-loop! onexit var nester))
       node))
 
 ;*---------------------------------------------------------------------*/
