@@ -1,10 +1,10 @@
 ;*=====================================================================*/
-;*    serrano/prgm/project/bigloo2.3/comptime/Integrate/node.scm       */
+;*    .../prgm/project/bigloo/bigloo/comptime/Integrate/node.scm       */
 ;*    -------------------------------------------------------------    */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Tue Mar 14 17:30:55 1995                          */
-;*    Last change :  Thu Jul 13 11:25:06 2000 (serrano)                */
-;*    Copyright   :  1995-2000 Manuel Serrano, see LICENSE file        */
+;*    Last change :  Thu Jul  8 11:30:27 2021 (serrano)                */
+;*    Copyright   :  1995-2021 Manuel Serrano, see LICENSE file        */
 ;*    -------------------------------------------------------------    */
 ;*    The computation of K and K* properties.                          */
 ;*=====================================================================*/
@@ -17,38 +17,39 @@
    (import  tools_shape
 	    tools_error
 	    type_type
+	    type_typeof
 	    type_cache
 	    ast_var
 	    ast_node
 	    ast_local
 	    integrate_info
 	    integrate_local->global)
-   (export  (globalize!              ::node ::variable <what/by>*)
+   (export  (integrate-globalize! ::node ::variable <what/by>*)
 	    (integrate-celled?::bool ::local)))
    
 ;*---------------------------------------------------------------------*/
-;*    globalize! ...                                                   */
+;*    integrate-globalize! ...                                         */
 ;*    -------------------------------------------------------------    */
 ;*    This function makes many transformation on the Ast *and*         */
 ;*    returns a free variables list.                                   */
 ;*---------------------------------------------------------------------*/
-(define (globalize! ast integrator what/by*)
+(define (integrate-globalize! ast integrator what/by*)
    (trace integrate "globalize!: " (shape integrator) " " (shape what/by*)
 	  #\Newline "  " (shape ast)
 	  #\Newline)
    ;; for each celled variable, we declare a new local
    ;; variable
-   (let* ((fun      (variable-value integrator))
-	  (celled   (celled-bindings (sfun-args fun)))
+   (let* ((fun (variable-value integrator))
+	  (celled (celled-bindings (sfun-args fun)))
 	  (what/by* (append celled what/by*)))
       ;; we set alpha-fast slot 
-      (for-each (lambda (w.b)
-		   (local-fast-alpha-set! (car w.b) (cdr w.b)))
+      (for-each (lambda (w-b)
+		   (local-fast-alpha-set! (car w-b) (cdr w-b)))
 		what/by*)
       (let ((res (cell-formals celled (glo! ast integrator))))
 	 ;; we remove alpha-fast slots
-	 (for-each (lambda (w.b)
-		      (local-fast-alpha-set! (car w.b) #unspecified))
+	 (for-each (lambda (w-b)
+		      (local-fast-alpha-set! (car w-b) #unspecified))
 		   what/by*)
 	 res)))
 
@@ -64,14 +65,21 @@
 	 ((not (integrate-celled? (car formals)))
 	  (loop celled (cdr formals)))
 	 (else
-	  (let* ((var (make-local-svar (local-id (car formals)) *obj*))
-		 (o.n (cons (car formals) var)))
-	     (local-access-set! var 'cell-integrate)
-	     (widen!::svar/Iinfo (local-value var)
-		(celled? #t)
-		(kaptured? #t))
-	     (loop (cons o.n celled) (cdr formals)))))))
+	  (let* ((ovar (car formals))
+		 (nvar (cell-variable ovar)))
+	     (loop (cons (cons ovar nvar) celled) (cdr formals)))))))
 
+;*---------------------------------------------------------------------*/
+;*    cell-variable ...                                                */
+;*---------------------------------------------------------------------*/
+(define (cell-variable::local local::local)
+   (let ((var (make-local-svar (local-id local) *cell*)))
+      (local-access-set! var 'cell-integrate)
+      (widen!::svar/Iinfo (local-value var)
+	 (celled? #t)
+	 (kaptured? #t))
+      var))
+   
 ;*---------------------------------------------------------------------*/
 ;*    cell-formals ...                                                 */
 ;*---------------------------------------------------------------------*/
@@ -82,32 +90,37 @@
 	  (instantiate::let-var
 	     (loc loc)
 	     (body body)
-	     (type *_*)
-	     (bindings (map (lambda (o.n)
-			       (cons (cdr o.n)
-				     (a-make-cell (instantiate::var
-						     (type *_*)
-						     (loc loc)
-						     (variable (car o.n)))
-						  (car o.n))))
-			    celled))))))
+	     (type (node-type body))
+	     (bindings (map (lambda (o-n)
+			       (cons (cdr o-n)
+				  (a-make-cell (instantiate::ref
+						  (type (variable-type (car o-n)))
+						  (loc loc)
+						  (variable (car o-n)))
+				     (car o-n))))
+			  celled))))))
 
 ;*---------------------------------------------------------------------*/
 ;*    a-make-cell ...                                                  */
 ;*---------------------------------------------------------------------*/
 (define (a-make-cell::make-box node::node variable::variable)
-   (trace (integrate 3) "*** a-make-cell: " (shape node) " " (shape variable)
+   (trace (integrate 5) "*** a-make-cell: " (shape node) " " (shape variable)
 	  #\Newline)
    (with-access::node node (loc)
       (local-access-set! variable 'cell-integrate)
       (svar/Iinfo-celled?-set! (variable-value variable) #t)
-      (instantiate::make-box (type *_*) (loc loc) (value node))))
+      (instantiate::make-box
+	 (type *cell*)
+	 (vtype (get-bigloo-type (variable-type variable)))
+	 (loc loc)
+	 (value node)
+	 (stackable #t))))
     
 ;*---------------------------------------------------------------------*/
 ;*    integrate-celled? ...                                            */
 ;*---------------------------------------------------------------------*/
 (define (integrate-celled?::bool variable::local)
-   (trace (integrate 3) "*** celled?: "
+   (trace (integrate 5) "*** celled?: "
 	  (shape variable) " Iinfo?:"
 	  (svar/Iinfo? (variable-value variable)) " Iinfo-celled?:"
 	  (if (svar/Iinfo? (variable-value variable))
@@ -143,22 +156,30 @@
 ;*    glo! ...                                                         */
 ;*---------------------------------------------------------------------*/
 (define-method (glo! node::var integrator)
-   (let* ((var   (var-variable node))
-	  (alpha (variable-fast-alpha var)))
-      (cond
-	 ((local? alpha)
-	  (var-variable-set! node alpha)
-	  (glo! node integrator))
-	 ((global? var)
-	  node)
-	 ((integrate-celled? var)
-	  (local-access-set! var 'cell-integrate)
-	  (instantiate::box-ref
-	     (loc (node-loc node))
-	     (type (node-type node))
-	     (var node)))
-	 (else
-	  node))))
+   (let* ((variable (var-variable node))
+	  (vtype (variable-type variable)))
+      (let loop ((variable variable))
+	 (let ((alpha (variable-fast-alpha variable)))
+	    (cond
+	       ((local? alpha)
+		(var-variable-set! node alpha)
+		(node-type-set! node (variable-type alpha))
+		(loop alpha))
+	       ((global? variable)
+		node)
+	       ((integrate-celled? variable)
+		;(local-access-set! variable 'cell-integrate)
+		(let ((vtype (get-bigloo-type vtype)))
+		   ;; (node-type-set! node (get-bigloo-type vtype))
+		   (node-type-set! node *cell*)
+		   (instantiate::box-ref
+		      (loc (node-loc node))
+		      ;;(type (get-bigloo-type (node-type node)))
+		      (type vtype)
+		      (vtype vtype)
+		      (var node))))
+	       (else
+		node))))))
 
 ;*---------------------------------------------------------------------*/
 ;*    glo! ::closure ...                                               */
@@ -174,6 +195,16 @@
       (glo*! nodes integrator)
       node))
 
+;*---------------------------------------------------------------------*/
+;*    glo! ::sync ...                                                  */
+;*---------------------------------------------------------------------*/
+(define-method (glo! node::sync integrator)
+   (with-access::sync node (body mutex prelock)
+      (set! mutex (glo! mutex integrator))
+      (set! prelock (glo! prelock integrator))
+      (set! body (glo! body integrator))
+      node))
+
 ;*---------------------------------------------------------------------*/
 ;*    glo! ::app ...                                                   */
 ;*---------------------------------------------------------------------*/
@@ -182,13 +213,13 @@
       (let* ((fun  (var-variable (app-fun node)))
 	     (info (variable-value fun)))
 	 ;; we change the called function if globalized
-	 (if (and (local? fun) (sfun/Iinfo-G? info))
-	     (app-fun-set! node
-			   (instantiate::var
-			      (loc loc)
-			      (type (variable-type (the-global fun)))
-			      (variable (the-global fun)))))
-	 ;; we globalize the actuals before adding new one
+	 (when (and (local? fun) (sfun/Iinfo-G? info))
+	    (app-fun-set! node
+			  (instantiate::ref
+			     (loc loc)
+			     (type (variable-type (the-global fun)))
+			     (variable (the-global fun)))))
+	 ;; we globalize the actuals before adding new ones
 	 ;; otherwise, we could produce illegal `cell-ref'
 	 (let liip ((nodes args))
 	    (if (null? nodes)
@@ -196,25 +227,22 @@
 		(begin
 		   (set-car! nodes (glo! (car nodes) integrator))
 		   (liip (cdr nodes)))))
-	 (cond
-	    ((or (global? fun) (not (sfun/Iinfo-G? info)))
-	     'done)
-	    (else
-	     ;; this is a call to globalized but non escaping
-	     ;; function. We add its kaptured variables
-	     (let loop ((new-actuals args)
-			(kaptured    (sfun/Iinfo-kaptured info)))
-		(if (null? kaptured)
-		    (set! args new-actuals)
-		    (let* ((kap   (car kaptured))
-			   (alpha (local-fast-alpha kap))
-			   (var   (if (local? alpha) alpha kap)))
-		       (loop (cons (instantiate::var
-				      (loc loc)
-				      (type *_*)
-				      (variable var))
-				   new-actuals)
-			     (cdr kaptured)))))))
+	 (unless (or (global? fun) (not (sfun/Iinfo-G? info)))
+	    ;; this is a call to globalized but non escaping
+	    ;; function. We add its kaptured variables
+	    (let loop ((new-actuals args)
+		       (kaptured (sfun/Iinfo-kaptured info)))
+	       (if (null? kaptured)
+		   (set! args new-actuals)
+		   (let* ((kap   (car kaptured))
+			  (alpha (local-fast-alpha kap))
+			  (var   (if (local? alpha) alpha kap)))
+		      (loop (cons (instantiate::ref
+				     (loc loc)
+				     (type (variable-type var))
+				     (variable var))
+				  new-actuals)
+			    (cdr kaptured))))))
 	 node)))
 	  
 ;*---------------------------------------------------------------------*/
@@ -257,7 +285,8 @@
 (define-method (glo! node::setq integrator)
    (with-access::setq node (value)
       (set! value (glo! value integrator))
-      (let ((var (var-variable (setq-var node))))
+      (let* ((var (var-variable (setq-var node)))
+	     (vtype (variable-type var)))
 	 (let loop ((var   var)
 		    (alpha (variable-fast-alpha var)))
 	    (if (local? alpha)
@@ -269,19 +298,21 @@
 		       (let ((a-var (make-local-svar 'aux *obj*))
 			     (loc   (node-loc node)))
 			  (local-access-set! var 'cell-integrate)
+			  (node-type-set! (setq-var node) *obj*)
 			  (widen!::svar/Iinfo (local-value a-var)
 			     (kaptured? #f))
 			  (instantiate::let-var
 			     (loc loc)
-			     (type *_*)
+			     (type *unspec*)
 			     (bindings (list (cons a-var value)))
 			     (body (instantiate::box-set!
 				      (loc loc)
-				      (type *_*)
+				      (type *unspec*)
 				      (var (setq-var node))
-				      (value (instantiate::var
+				      (vtype (get-bigloo-type vtype))
+				      (value (instantiate::ref
 						(loc loc)
-						(type *_*)
+						(type (variable-type a-var))
 						(variable a-var)))))))
 		       node)))))))
 
@@ -306,10 +337,10 @@
       node))
 
 ;*---------------------------------------------------------------------*/
-;*    glo! ::select ...                                                */
+;*    glo! ::switch ...                                                */
 ;*---------------------------------------------------------------------*/
-(define-method (glo! node::select integrator)
-   (with-access::select node (clauses test)
+(define-method (glo! node::switch integrator)
+   (with-access::switch node (clauses test)
       (set! test (glo! test integrator))
       (for-each (lambda (clause)
 		   (set-cdr! clause (glo! (cdr clause) integrator)))
@@ -336,20 +367,28 @@
 		   (let ((var (car binding))
 			 (val (cdr binding)))
 		      (set-cdr! binding (glo! val integrator))
-		      (if (integrate-celled? var)
-			  (begin
-			     (local-type-set! var *obj*)
-			     (set-cdr! binding (a-make-cell (cdr binding)
-							    var))))))
-		bindings)
+		      (when (integrate-celled? var)
+			 (let ((nvar (cell-variable var)))
+			    (local-fast-alpha-set! var nvar)
+			    (set-cdr! binding
+			       (a-make-cell (cdr binding) var))))))
+	 bindings)
       (set! body (glo! body integrator))
+      (for-each (lambda (binding)
+		   (let ((var (car binding)))
+		      (when (integrate-celled? var)
+			 (let ((nvar (cell-variable var)))
+			    (set-car! binding (variable-fast-alpha var))
+			    (local-fast-alpha-set! var #unspecified)))))
+	 bindings)
       node))
 
 ;*---------------------------------------------------------------------*/
 ;*    glo! ::set-ex-it ...                                             */
 ;*---------------------------------------------------------------------*/
 (define-method (glo! node::set-ex-it integrator)
-   (with-access::set-ex-it node (var body)
+   (with-access::set-ex-it node (var body onexit)
+      (set! onexit (glo! onexit integrator))
       (set! body (glo! body integrator))
       node))
 
@@ -376,6 +415,11 @@
 (define-method (glo! node::box-ref integrator)
    (trace (integrate 3) "box-ref: " (shape node) #\Newline)
    (with-access::box-ref node (var)
+      (when (integrate-celled? (var-variable var))
+	 (let ((v (var-variable var)))
+	    (tprint "box-ref=" (shape node))
+	    (tprint "access=" (variable-access v))
+	    (error "integration" "box-ref" (shape node))))
       (set! var (glo! var integrator))
       node))
 
@@ -408,16 +452,20 @@
 	  " integrator: " (shape integrator) #\Newline)
    (let* ((fun   (local-value local))
 	  (obody (sfun-body fun)))
-      (if (eq? local integrator)
-	  (sfun-body-set! fun (glo! obody integrator))
+      (cond
+	 ((eq? local integrator)
+	  (sfun-body-set! fun (glo! obody integrator)))
+	 ((and (sfun/Iinfo? fun) (sfun/Iinfo-G? fun))
+	  #unspecified)
+	 (else
 	  (let ((celled (celled-bindings (sfun-args fun))))
-	     (for-each (lambda (w.b)
-			  (variable-fast-alpha-set! (car w.b) (cdr w.b)))
+	     (for-each (lambda (w-b)
+			  (variable-fast-alpha-set! (car w-b) (cdr w-b)))
 		       celled)
 	     (let* ((nbody1 (glo! obody integrator))
 		    (nbody2 (cell-formals celled nbody1)))
-		(for-each (lambda (w.b)
-			     (variable-fast-alpha-set! (car w.b) #unspecified))
+		(for-each (lambda (w-b)
+			     (variable-fast-alpha-set! (car w-b) #unspecified))
 			  celled)
-		(sfun-body-set! fun nbody2))))))
+		(sfun-body-set! fun nbody2)))))))
 
