@@ -3,8 +3,8 @@
 ;*    -------------------------------------------------------------    */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Tue Feb 21 08:37:48 1995                          */
-;*    Last change :  Sat Jun 12 09:12:43 2021 (serrano)                */
-;*    Copyright   :  1995-2021 Manuel Serrano, see LICENSE file        */
+;*    Last change :  Tue Jun 25 15:02:03 2024 (serrano)                */
+;*    Copyright   :  1995-2024 Manuel Serrano, see LICENSE file        */
 ;*    -------------------------------------------------------------    */
 ;*    The `integration' pass.                                          */
 ;*=====================================================================*/
@@ -37,6 +37,5 @@
 	     (pass-postlude (remove-var '(integrate cfa) vars)))
 	  (let ((global (car old)))
 	     (enter-function (global-id global))
-	     (loop (cdr old)
-		   (append (integrate-definition! global) new))))))
+	     (loop (cdr old) (append (integrate-definition! global) new))))))
 
