@@ -101,15 +101,26 @@
 	  (else (syntax-error classfile cop args)) ))
       ((16 17) ; tIPUSH
        (match-case args
-	  (((? integer?)) (cons cop args))
+	  (((? fixnum?)) (cons cop args))
+	  (((? elong?)) (list cop (elong->fixnum (car args))))
+	  (((? uint32?)) (list cop (uint32->fixnum (car args))))
+	  (((? int32?)) (list cop (int32->fixnum (car args))))
+	  (((? int16?)) (list cop (int16->fixnum (car args))))
+	  (((? uint16?)) (list cop (uint16->fixnum (car args))))
+	  (((? int8?)) (list cop (int8->fixnum (car args))))
+	  (((? uint8?)) (list cop (uint8->fixnum (car args))))
 	  (else (syntax-error classfile cop args)) ))
       ((18 19) ; LDC
        (match-case args
-	  (((or (? integer?) (? flonum?) (? string?))) (cons 18 args))
+	  (((or (? fixnum?) (? flonum?) (? string?))) (cons 18 args))
+	  (((or (? int32?) (? uint32?))) (cons 18 args))
 	  (else (syntax-error classfile cop args)) ))
       ((20) ; LDC2
        (match-case args
-	  (((or (? integer?) (? flonum?))) (cons 20 args))
+	  (((or (? fixnum?) (? flonum?) (? elong?) (? llong?)))
+	   (cons 20 args))
+	  (((or (? uint64?) (? int64?)))
+	   (cons 20 args))
 	  (else (syntax-error classfile cop args)) ))
       ((21 22 23 24 25 54 55 56 57 58 169) ; XLOAD XSTORE RET
        (match-case args
@@ -118,16 +129,16 @@
       ((26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45) ; LOAD_n
        (match-case args
 	  (() (let ( (d (-fx cop 26)) )
-		 (list (+fx 21 (/fx d 4)) (remainder d 4)) ))
+		 (list (+fx 21 (/fx d 4)) (remainderfx d 4)) ))
 	  (else (syntax-error classfile cop args)) ))
       ((59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78) ; STORE_n
        (match-case args
 	  (() (let ( (d (-fx cop 59)) )
-		 (list (+fx 54 (/fx d 4)) (remainder d 4)) ))
+		 (list (+fx 54 (/fx d 4)) (remainderfx d 4)) ))
 	  (else (syntax-error classfile cop args)) ))
       ((132) ; IINC
        (match-case args
-	  (((and ?var (? symbol?)) (and ?n (? integer?)))
+	  (((and ?var (? symbol?)) (and ?n (? fixnum?)))
 	   (list cop (v-index classfile var locals) n) )
 	  (else (syntax-error classfile cop args)) ))
       ((153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168
@@ -137,7 +148,7 @@
 	  (else (syntax-error classfile cop args)) ))
       ((170) ; TABLESWITCH
        (match-case args
-	  (((and ?def (? symbol?)) (and ?beg (? integer?)) .
+	  (((and ?def (? symbol?)) (and ?beg (? fixnum?)) .
 				   (and ?labs ((? symbol?) ...)) )
 	   (cons cop args) )
 	  (else (syntax-error classfile cop args)) ))
@@ -176,7 +187,7 @@
 	  (else (syntax-error classfile cop args)) ))
       ((197) ; MULTINEWARRAY
        (match-case args
-	  ((?type (and ?n (? integer?))) (list cop (as-type classfile type) n))
+	  ((?type (and ?n (? fixnum?))) (list cop (as-type classfile type) n))
 	  (else (syntax-error classfile cop args)) ))
       ((202) ; HANDLER
        (match-case args
@@ -185,7 +196,7 @@
 		 (if (eq? type 0) 0 (pool-class-by-name classfile type)) ))))
       ((203) ; LINE
        (match-case args
-	  (((? integer?)) (cons cop args))
+	  (((? fixnum?) (? fixnum?)) (cons cop args))
 	  (else (syntax-error classfile cop args)) ))
       ((204) ; COMMENT
        (cons cop args) )
@@ -208,7 +219,7 @@
 
 ;; test a slot of a LOOKUPSWITCH
 (define (slot? slot)
-   (and (pair? slot) (integer? (car slot)) (symbol? (cdr slot))) )
+   (and (pair? slot) (fixnum? (car slot)) (symbol? (cdr slot))) )
 
 ;; give the encoded type for NEWARRAY
 (define (get-type-num classfile type)
