@@ -3,8 +3,8 @@
 ;*    -------------------------------------------------------------    */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Tue Jul  9 16:05:09 1996                          */
-;*    Last change :  Tue Jul  3 16:20:31 2001 (serrano)                */
-;*    Copyright   :  1996-2001 Manuel Serrano, see LICENSE file        */
+;*    Last change :  Thu Sep 19 11:52:46 2013 (serrano)                */
+;*    Copyright   :  1996-2013 Manuel Serrano, see LICENSE file        */
 ;*    -------------------------------------------------------------    */
 ;*    Library finalizer                                                */
 ;*=====================================================================*/
@@ -15,13 +15,15 @@
 (module module_library
    (include "Ast/unit.sch")
    (import  type_type
+	    backend_backend
 	    ast_var
 	    ast_env
 	    module_module
 	    module_impuse
 	    engine_param
 	    bdb_setting)
-   (export  (library-finalizer)))
+   (export  (library-finalizer)
+	    (with-library-module! module::symbol)))
 
 ;*---------------------------------------------------------------------*/
 ;*    library-finalizer ...                                            */
@@ -39,32 +41,43 @@
    ;; first, we collect all the needed library modules
    (for-each-global! (lambda (global)
 			(with-access::global global (occurrence module
-								library? value)
-			   (if (and (>fx occurrence 0)
-				    library?
-				    (not (or (cfun? value) (cvar? value))))
-			       (need-library-module! module)))))
+								library value)
+			   (when (and (>fx occurrence 0)
+				      library
+				      (not (or (cfun? value) (cvar? value))))
+			      (need-library-module! module)))))
    ;; when compiling for bdb we must initialize the bdb module
-   (if (>fx *bdb-debug* 0)
-       (need-library-module! *bdb-module*))
+   (if (and (>fx *bdb-debug* 0)
+	    (memq 'bdb (backend-debug-support (the-backend))))
+       (for-each need-library-module! *bdb-module*))
+   (if (and *jvm-debug*
+	    (not *lib-mode*)
+	    (memq 'jvm (backend-debug-support (the-backend))))
+       (for-each need-library-module! *jvm-debug-module*))
+   ;; we mark all the WITH modules (i.e. modules mentionned in a with module
+   ;; clause or in a -with command line option)
+   (for-each need-library-module! *with-library-modules*)
    ;; then we declare a special unit
    (let ((modules *needed-modules*))
       (if (null? modules)
 	  '()
-	  (let loop ((modules      modules)
+	  (let loop ((modules modules)
 		     (init-call* '(#unspecified)))
 	     (if (null? modules)
-		 (let ((body (if (>fx *debug-module* 0)
+		 (let ((body (if (and (>fx *debug-module* 0)
+				      (memq 'module
+					    (backend-debug-support
+					     (the-backend))))
 				 `((begin
-				      (pragma::int
+				      (pragma::void
 				       ,(string-append
-					 "puts(\"   Module init (library): "
+					 "bgl_init_module_debug_library(\""
 					 (symbol->string *module*)
 					 "\")"))
 				      ,@init-call*))
 				 init-call*)))
-		    (unit 'library-modules 2 body #t))
-		 (let* ((id          (car modules))
+		    (unit 'library-modules 2 body #t #f))
+		 (let* ((id (car modules))
 			(init-fun-id (module-initialization-id id)))
 		    (loop (cdr modules)
 			  (cons `((@ ,init-fun-id ,id)
@@ -93,4 +106,21 @@
 	  (putprop! module *key* #t)
 	  (set! *needed-modules* (cons module *needed-modules*)))))
 
+;*---------------------------------------------------------------------*/
+;*    *with-key* ...                                                   */
+;*---------------------------------------------------------------------*/
+(define *with-key* (gensym 'with-key))
+
+;*---------------------------------------------------------------------*/
+;*    *with-library-modules* ...                                       */
+;*---------------------------------------------------------------------*/
+(define *with-library-modules* '())
+
+;*---------------------------------------------------------------------*/
+;*    with-library-module! ...                                         */
+;*---------------------------------------------------------------------*/
+(define (with-library-module! module::symbol)
+   (unless (getprop module *with-key*)
+      (putprop! module *with-key* #t)
+      (set! *with-library-modules* (cons module *with-library-modules*))))
 
