@@ -1,9 +1,9 @@
 /*===========================================================================*/
 /*   (Prof/unit.scm)                                                         */
-/*   Bigloo (4.5b)                                                           */
-/*   Inria -- Sophia Antipolis (c)       Fri Dec 22 05:17:06 PM CET 2023     */
+/*   Bigloo (4.6a)                                                           */
+/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
 /*===========================================================================*/
-/* COMPILATION: (/home/serrano/prgm/project/bigloo/bigloo/bin/bigloo -ldopt -L/home/serrano/prgm/project/bigloo/bigloo/libbacktrace/home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b  -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Prof/unit.scm) */
+/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Prof/unit.scm) */
 /* GC selection */
 #define THE_GC BOEHM_GC
 
@@ -59,6 +59,11 @@ extern "C"
 		bool_t BgL_boundzd2checkzd2;
 		bool_t BgL_typezd2checkzd2;
 		bool_t BgL_typedzd2funcallzd2;
+		bool_t BgL_strictzd2typezd2castz00;
+		bool_t BgL_forcezd2registerzd2gczd2rootszd2;
+		bool_t BgL_stringzd2literalzd2supportz00;
+		bool_t BgL_boxedzd2fixnumszd2;
+		bool_t BgL_typedzd2closureszd2;
 	}                 *BgL_backendz00_bglt;
 
 
@@ -105,6 +110,7 @@ extern "C"
 	BGL_IMPORT obj_t
 		BGl_modulezd2initializa7ationz75zz__r4_pairs_and_lists_6_3z00(long, char *);
 	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__readerz00(long, char *);
+	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__bignumz00(long, char *);
 	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__structurez00(long,
 		char *);
 	BGL_IMPORT obj_t BGl_modulezd2initializa7ationz75zz__biglooz00(long, char *);
@@ -117,26 +123,26 @@ extern "C"
 	extern obj_t BGl_za2currentzd2passza2zd2zzengine_passz00;
 	BGL_EXPORTED_DECL obj_t BGl_makezd2profzd2unitz00zzprof_walkz00(void);
 	extern obj_t BGl_verbosez00zztools_speekz00(obj_t, obj_t);
-	static obj_t __cnst[5];
+	static obj_t __cnst[6];
 
 
 	   
 		 
-		DEFINE_STRING(BGl_string1611z00zzprof_walkz00,
-		BgL_bgl_string1611za700za7za7p1617za7, "Prof", 4);
-	      DEFINE_STRING(BGl_string1612z00zzprof_walkz00,
-		BgL_bgl_string1612za700za7za7p1618za7, "   . ", 5);
-	      DEFINE_STRING(BGl_string1613z00zzprof_walkz00,
-		BgL_bgl_string1613za700za7za7p1619za7, "failure during prelude hook", 27);
-	      DEFINE_STRING(BGl_string1614z00zzprof_walkz00,
-		BgL_bgl_string1614za700za7za7p1620za7, "prof_walk", 9);
-	      DEFINE_STRING(BGl_string1615z00zzprof_walkz00,
-		BgL_bgl_string1615za700za7za7p1621za7,
-		"unit prof begin (begin (pragma \"write_bprof_table()\")) pass-started ",
-		68);
+		DEFINE_STRING(BGl_string1367z00zzprof_walkz00,
+		BgL_bgl_string1367za700za7za7p1377za7, "Prof", 4);
+	      DEFINE_STRING(BGl_string1368z00zzprof_walkz00,
+		BgL_bgl_string1368za700za7za7p1378za7, "   . ", 5);
+	      DEFINE_STRING(BGl_string1369z00zzprof_walkz00,
+		BgL_bgl_string1369za700za7za7p1379za7, "failure during prelude hook", 27);
+	      DEFINE_STRING(BGl_string1370z00zzprof_walkz00,
+		BgL_bgl_string1370za700za7za7p1380za7, "prof_walk", 9);
+	      DEFINE_STRING(BGl_string1371z00zzprof_walkz00,
+		BgL_bgl_string1371za700za7za7p1381za7,
+		"unit prof begin (begin (pragma \"write_bprof_table()\")) #z100 pass-started ",
+		74);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE(BGl_makezd2profzd2unitzd2envzd2zzprof_walkz00,
-		BgL_bgl_za762makeza7d2profza7d1622za7,
+		BgL_bgl_za762makeza7d2profza7d1382za7,
 		BGl_z62makezd2profzd2unitz62zzprof_walkz00, 0L, BUNSPEC, 0);
 
 /* GC roots registration */
@@ -157,7 +163,7 @@ extern "C"
 
 /* module-initialization */
 	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zzprof_walkz00(long
-		BgL_checksumz00_1770, char *BgL_fromz00_1771)
+		BgL_checksumz00_1725, char *BgL_fromz00_1726)
 	{
 		{
 			if (CBOOL(BGl_requirezd2initializa7ationz75zzprof_walkz00))
@@ -187,6 +193,7 @@ extern "C"
 			BGl_modulezd2initializa7ationz75zz__readerz00(0L, "prof_walk");
 			BGl_modulezd2initializa7ationz75zz__r4_ports_6_10_1z00(0L, "prof_walk");
 			BGl_modulezd2initializa7ationz75zz__r4_strings_6_7z00(0L, "prof_walk");
+			BGl_modulezd2initializa7ationz75zz__bignumz00(0L, "prof_walk");
 			BGl_modulezd2initializa7ationz75zz__r4_numbers_6_5_fixnumz00(0L,
 				"prof_walk");
 			BGl_modulezd2initializa7ationz75zz__r4_pairs_and_lists_6_3z00(0L,
@@ -205,71 +212,71 @@ extern "C"
 	{
 		{	/* Prof/unit.scm 15 */
 			{	/* Prof/unit.scm 15 */
-				obj_t BgL_cportz00_1759;
+				obj_t BgL_cportz00_1714;
 
 				{	/* Prof/unit.scm 15 */
-					obj_t BgL_stringz00_1766;
+					obj_t BgL_stringz00_1721;
 
-					BgL_stringz00_1766 = BGl_string1615z00zzprof_walkz00;
+					BgL_stringz00_1721 = BGl_string1371z00zzprof_walkz00;
 					{	/* Prof/unit.scm 15 */
-						obj_t BgL_startz00_1767;
+						obj_t BgL_startz00_1722;
 
-						BgL_startz00_1767 = BINT(0L);
+						BgL_startz00_1722 = BINT(0L);
 						{	/* Prof/unit.scm 15 */
-							obj_t BgL_endz00_1768;
+							obj_t BgL_endz00_1723;
 
-							BgL_endz00_1768 =
-								BINT(STRING_LENGTH(((obj_t) BgL_stringz00_1766)));
+							BgL_endz00_1723 =
+								BINT(STRING_LENGTH(((obj_t) BgL_stringz00_1721)));
 							{	/* Prof/unit.scm 15 */
 
-								BgL_cportz00_1759 =
+								BgL_cportz00_1714 =
 									BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00
-									(BgL_stringz00_1766, BgL_startz00_1767, BgL_endz00_1768);
+									(BgL_stringz00_1721, BgL_startz00_1722, BgL_endz00_1723);
 				}}}}
 				{
-					long BgL_iz00_1760;
+					long BgL_iz00_1715;
 
-					BgL_iz00_1760 = 4L;
-				BgL_loopz00_1761:
-					if ((BgL_iz00_1760 == -1L))
+					BgL_iz00_1715 = 5L;
+				BgL_loopz00_1716:
+					if ((BgL_iz00_1715 == (-1L)))
 						{	/* Prof/unit.scm 15 */
 							return BUNSPEC;
 						}
 					else
 						{	/* Prof/unit.scm 15 */
 							{	/* Prof/unit.scm 15 */
-								obj_t BgL_arg1616z00_1762;
+								obj_t BgL_arg1376z00_1717;
 
 								{	/* Prof/unit.scm 15 */
 
 									{	/* Prof/unit.scm 15 */
-										obj_t BgL_locationz00_1764;
+										obj_t BgL_locationz00_1719;
 
-										BgL_locationz00_1764 = BBOOL(((bool_t) 0));
+										BgL_locationz00_1719 = BBOOL(((bool_t) 0));
 										{	/* Prof/unit.scm 15 */
 
-											BgL_arg1616z00_1762 =
-												BGl_readz00zz__readerz00(BgL_cportz00_1759,
-												BgL_locationz00_1764);
+											BgL_arg1376z00_1717 =
+												BGl_readz00zz__readerz00(BgL_cportz00_1714,
+												BgL_locationz00_1719);
 										}
 									}
 								}
 								{	/* Prof/unit.scm 15 */
-									int BgL_tmpz00_1797;
+									int BgL_tmpz00_1753;
 
-									BgL_tmpz00_1797 = (int) (BgL_iz00_1760);
-									CNST_TABLE_SET(BgL_tmpz00_1797, BgL_arg1616z00_1762);
+									BgL_tmpz00_1753 = (int) (BgL_iz00_1715);
+									CNST_TABLE_SET(BgL_tmpz00_1753, BgL_arg1376z00_1717);
 							}}
 							{	/* Prof/unit.scm 15 */
-								int BgL_auxz00_1765;
+								int BgL_auxz00_1720;
 
-								BgL_auxz00_1765 = (int) ((BgL_iz00_1760 - 1L));
+								BgL_auxz00_1720 = (int) ((BgL_iz00_1715 - 1L));
 								{
-									long BgL_iz00_1802;
+									long BgL_iz00_1758;
 
-									BgL_iz00_1802 = (long) (BgL_auxz00_1765);
-									BgL_iz00_1760 = BgL_iz00_1802;
-									goto BgL_loopz00_1761;
+									BgL_iz00_1758 = (long) (BgL_auxz00_1720);
+									BgL_iz00_1715 = BgL_iz00_1758;
+									goto BgL_loopz00_1716;
 								}
 							}
 						}
@@ -308,198 +315,196 @@ extern "C"
 	{
 		{	/* Prof/unit.scm 31 */
 			{	/* Prof/unit.scm 32 */
-				obj_t BgL_list1331z00_1476;
+				obj_t BgL_list1253z00_1493;
 
 				{	/* Prof/unit.scm 32 */
-					obj_t BgL_arg1332z00_1477;
+					obj_t BgL_arg1254z00_1494;
 
 					{	/* Prof/unit.scm 32 */
-						obj_t BgL_arg1337z00_1478;
+						obj_t BgL_arg1255z00_1495;
 
-						BgL_arg1337z00_1478 =
+						BgL_arg1255z00_1495 =
 							MAKE_YOUNG_PAIR(BCHAR(((unsigned char) 10)), BNIL);
-						BgL_arg1332z00_1477 =
-							MAKE_YOUNG_PAIR(BGl_string1611z00zzprof_walkz00,
-							BgL_arg1337z00_1478);
+						BgL_arg1254z00_1494 =
+							MAKE_YOUNG_PAIR(BGl_string1367z00zzprof_walkz00,
+							BgL_arg1255z00_1495);
 					}
-					BgL_list1331z00_1476 =
-						MAKE_YOUNG_PAIR(BGl_string1612z00zzprof_walkz00,
-						BgL_arg1332z00_1477);
+					BgL_list1253z00_1493 =
+						MAKE_YOUNG_PAIR(BGl_string1368z00zzprof_walkz00,
+						BgL_arg1254z00_1494);
 				}
-				BGl_verbosez00zztools_speekz00(BINT(1L), BgL_list1331z00_1476);
+				BGl_verbosez00zztools_speekz00(BINT(1L), BgL_list1253z00_1493);
 			}
 			BGl_za2nbzd2errorzd2onzd2passza2zd2zztools_errorz00 = BINT(0L);
 			BGl_za2currentzd2passza2zd2zzengine_passz00 =
-				BGl_string1611z00zzprof_walkz00;
+				BGl_string1367z00zzprof_walkz00;
 			{	/* Prof/unit.scm 32 */
-				obj_t BgL_g1107z00_1479;
+				obj_t BgL_g1107z00_1496;
 
-				BgL_g1107z00_1479 = BNIL;
+				BgL_g1107z00_1496 = BNIL;
 				{
-					obj_t BgL_hooksz00_1482;
-					obj_t BgL_hnamesz00_1483;
+					obj_t BgL_hooksz00_1499;
+					obj_t BgL_hnamesz00_1500;
 
-					BgL_hooksz00_1482 = BgL_g1107z00_1479;
-					BgL_hnamesz00_1483 = BNIL;
-				BgL_zc3z04anonymousza31338ze3z87_1484:
-					if (NULLP(BgL_hooksz00_1482))
+					BgL_hooksz00_1499 = BgL_g1107z00_1496;
+					BgL_hnamesz00_1500 = BNIL;
+				BgL_zc3z04anonymousza31256ze3z87_1501:
+					if (NULLP(BgL_hooksz00_1499))
 						{	/* Prof/unit.scm 32 */
-							CNST_TABLE_REF(0L);
+							((obj_t) CNST_TABLE_REF(0));
 						}
 					else
 						{	/* Prof/unit.scm 32 */
-							bool_t BgL_test1626z00_1815;
+							bool_t BgL_test1391z00_1772;
 
 							{	/* Prof/unit.scm 32 */
-								obj_t BgL_fun1347z00_1491;
+								obj_t BgL_fun1270z00_1508;
 
-								BgL_fun1347z00_1491 = CAR(((obj_t) BgL_hooksz00_1482));
-								BgL_test1626z00_1815 =
-									CBOOL(
-									(VA_PROCEDUREP(BgL_fun1347z00_1491) ? ((obj_t(*)(obj_t,
-													...))
-											PROCEDURE_ENTRY(BgL_fun1347z00_1491))
-										(BgL_fun1347z00_1491,
-											BEOA) : ((obj_t(*)(obj_t))
-											PROCEDURE_ENTRY(BgL_fun1347z00_1491))
-										(BgL_fun1347z00_1491)));
+								BgL_fun1270z00_1508 = CAR(((obj_t) BgL_hooksz00_1499));
+								BgL_test1391z00_1772 =
+									CBOOL(BGL_PROCEDURE_CALL0(BgL_fun1270z00_1508));
 							}
-							if (BgL_test1626z00_1815)
+							if (BgL_test1391z00_1772)
 								{	/* Prof/unit.scm 32 */
-									obj_t BgL_arg1343z00_1488;
-									obj_t BgL_arg1344z00_1489;
+									obj_t BgL_arg1260z00_1505;
+									obj_t BgL_arg1262z00_1506;
 
-									BgL_arg1343z00_1488 = CDR(((obj_t) BgL_hooksz00_1482));
-									BgL_arg1344z00_1489 = CDR(((obj_t) BgL_hnamesz00_1483));
+									BgL_arg1260z00_1505 = CDR(((obj_t) BgL_hooksz00_1499));
+									BgL_arg1262z00_1506 = CDR(((obj_t) BgL_hnamesz00_1500));
 									{
-										obj_t BgL_hnamesz00_1827;
-										obj_t BgL_hooksz00_1826;
+										obj_t BgL_hnamesz00_1784;
+										obj_t BgL_hooksz00_1783;
 
-										BgL_hooksz00_1826 = BgL_arg1343z00_1488;
-										BgL_hnamesz00_1827 = BgL_arg1344z00_1489;
-										BgL_hnamesz00_1483 = BgL_hnamesz00_1827;
-										BgL_hooksz00_1482 = BgL_hooksz00_1826;
-										goto BgL_zc3z04anonymousza31338ze3z87_1484;
+										BgL_hooksz00_1783 = BgL_arg1260z00_1505;
+										BgL_hnamesz00_1784 = BgL_arg1262z00_1506;
+										BgL_hnamesz00_1500 = BgL_hnamesz00_1784;
+										BgL_hooksz00_1499 = BgL_hooksz00_1783;
+										goto BgL_zc3z04anonymousza31256ze3z87_1501;
 									}
 								}
 							else
 								{	/* Prof/unit.scm 32 */
-									obj_t BgL_arg1346z00_1490;
+									obj_t BgL_arg1266z00_1507;
 
-									BgL_arg1346z00_1490 = CAR(((obj_t) BgL_hnamesz00_1483));
+									BgL_arg1266z00_1507 = CAR(((obj_t) BgL_hnamesz00_1500));
 									BGl_internalzd2errorzd2zztools_errorz00
-										(BGl_string1611z00zzprof_walkz00,
-										BGl_string1613z00zzprof_walkz00, BgL_arg1346z00_1490);
+										(BGl_string1367z00zzprof_walkz00,
+										BGl_string1369z00zzprof_walkz00, BgL_arg1266z00_1507);
 								}
 						}
 				}
 			}
 			{	/* Prof/unit.scm 34 */
-				obj_t BgL_arg1352z00_1494;
-				obj_t BgL_arg1354z00_1495;
+				obj_t BgL_arg1272z00_1511;
+				obj_t BgL_arg1273z00_1512;
 
 				{	/* Prof/unit.scm 34 */
-					obj_t BgL_b1283z00_1497;
+					obj_t BgL_b1226z00_1513;
 
-					BgL_b1283z00_1497 =
+					BgL_b1226z00_1513 =
 						BGl_getzd2toplevelzd2unitzd2weightzd2zzmodule_includez00();
-					{	/* Prof/unit.scm 34 */
+					if (INTEGERP(BgL_b1226z00_1513))
+						{	/* Prof/unit.scm 34 */
+							obj_t BgL_tmpz00_1696;
 
-						if (INTEGERP(BgL_b1283z00_1497))
+							BgL_tmpz00_1696 = BINT(0L);
 							{	/* Prof/unit.scm 34 */
-								obj_t BgL_za71za7_1737;
+								bool_t BgL_test1393z00_1792;
 
-								BgL_za71za7_1737 = BINT(100L);
 								{	/* Prof/unit.scm 34 */
-									obj_t BgL_tmpz00_1739;
+									obj_t BgL_tmpz00_1793;
 
-									BgL_tmpz00_1739 = BINT(0L);
-									if (BGL_ADDFX_OV(BgL_za71za7_1737, BgL_b1283z00_1497,
-											BgL_tmpz00_1739))
-										{	/* Prof/unit.scm 34 */
-											BgL_arg1352z00_1494 =
-												bgl_bignum_add(bgl_long_to_bignum(
-													(long) CINT(BgL_za71za7_1737)),
-												bgl_long_to_bignum((long) CINT(BgL_b1283z00_1497)));
-										}
-									else
-										{	/* Prof/unit.scm 34 */
-											BgL_arg1352z00_1494 = BgL_tmpz00_1739;
-										}
+									BgL_tmpz00_1793 = BINT(100L);
+									BgL_test1393z00_1792 =
+										BGL_ADDFX_OV(BgL_tmpz00_1793, BgL_b1226z00_1513,
+										BgL_tmpz00_1696);
 								}
+								if (BgL_test1393z00_1792)
+									{	/* Prof/unit.scm 34 */
+										BgL_arg1272z00_1511 =
+											bgl_bignum_add(
+											((obj_t)
+												CNST_TABLE_REF(1)),
+											bgl_long_to_bignum((long) CINT(BgL_b1226z00_1513)));
+									}
+								else
+									{	/* Prof/unit.scm 34 */
+										BgL_arg1272z00_1511 = BgL_tmpz00_1696;
+									}
 							}
-						else
-							{	/* Prof/unit.scm 34 */
-								BgL_arg1352z00_1494 =
-									BGl_2zb2zb2zz__r4_numbers_6_5z00(BINT(100L),
-									BgL_b1283z00_1497);
-							}
-					}
+						}
+					else
+						{	/* Prof/unit.scm 34 */
+							BgL_arg1272z00_1511 =
+								BGl_2zb2zb2zz__r4_numbers_6_5z00(BINT(100L), BgL_b1226z00_1513);
+						}
 				}
 				{	/* Prof/unit.scm 35 */
-					bool_t BgL_test1629z00_1845;
+					bool_t BgL_test1394z00_1803;
 
 					{	/* Prof/unit.scm 35 */
-						obj_t BgL_arg1366z00_1502;
+						obj_t BgL_arg1277z00_1517;
 
-						BgL_arg1366z00_1502 = BGl_thezd2backendzd2zzbackend_backendz00();
-						BgL_test1629z00_1845 =
+						BgL_arg1277z00_1517 = BGl_thezd2backendzd2zzbackend_backendz00();
+						BgL_test1394z00_1803 =
 							(((BgL_backendz00_bglt) COBJECT(
-									((BgL_backendz00_bglt) BgL_arg1366z00_1502)))->
+									((BgL_backendz00_bglt) BgL_arg1277z00_1517)))->
 							BgL_pragmazd2supportzd2);
 					}
-					if (BgL_test1629z00_1845)
+					if (BgL_test1394z00_1803)
 						{	/* Prof/unit.scm 35 */
-							BgL_arg1354z00_1495 = CNST_TABLE_REF(1L);
+							BgL_arg1273z00_1512 = ((obj_t) CNST_TABLE_REF(2));
 						}
 					else
 						{	/* Prof/unit.scm 37 */
-							obj_t BgL_arg1363z00_1501;
+							obj_t BgL_arg1276z00_1516;
 
-							BgL_arg1363z00_1501 = MAKE_YOUNG_PAIR(BUNSPEC, BNIL);
-							BgL_arg1354z00_1495 =
-								MAKE_YOUNG_PAIR(CNST_TABLE_REF(2L), BgL_arg1363z00_1501);
+							BgL_arg1276z00_1516 = MAKE_YOUNG_PAIR(BUNSPEC, BNIL);
+							BgL_arg1273z00_1512 =
+								MAKE_YOUNG_PAIR(
+								((obj_t) CNST_TABLE_REF(3)), BgL_arg1276z00_1516);
 						}
 				}
 				{	/* Prof/unit.scm 33 */
-					obj_t BgL_idz00_1749;
+					obj_t BgL_idz00_1705;
 
-					BgL_idz00_1749 = CNST_TABLE_REF(3L);
+					BgL_idz00_1705 = ((obj_t) CNST_TABLE_REF(4));
 					{	/* Prof/unit.scm 33 */
-						obj_t BgL_newz00_1750;
+						obj_t BgL_newz00_1706;
 
-						BgL_newz00_1750 = create_struct(CNST_TABLE_REF(4L), (int) (5L));
+						BgL_newz00_1706 =
+							create_struct(((obj_t) CNST_TABLE_REF(5)), (int) (5L));
 						{	/* Prof/unit.scm 33 */
-							int BgL_tmpz00_1857;
+							int BgL_tmpz00_1819;
 
-							BgL_tmpz00_1857 = (int) (4L);
-							STRUCT_SET(BgL_newz00_1750, BgL_tmpz00_1857, BFALSE);
+							BgL_tmpz00_1819 = (int) (4L);
+							STRUCT_SET(BgL_newz00_1706, BgL_tmpz00_1819, BFALSE);
 						}
 						{	/* Prof/unit.scm 33 */
-							int BgL_tmpz00_1860;
+							int BgL_tmpz00_1822;
 
-							BgL_tmpz00_1860 = (int) (3L);
-							STRUCT_SET(BgL_newz00_1750, BgL_tmpz00_1860, BTRUE);
+							BgL_tmpz00_1822 = (int) (3L);
+							STRUCT_SET(BgL_newz00_1706, BgL_tmpz00_1822, BTRUE);
 						}
 						{	/* Prof/unit.scm 33 */
-							int BgL_tmpz00_1863;
+							int BgL_tmpz00_1825;
 
-							BgL_tmpz00_1863 = (int) (2L);
-							STRUCT_SET(BgL_newz00_1750, BgL_tmpz00_1863, BgL_arg1354z00_1495);
+							BgL_tmpz00_1825 = (int) (2L);
+							STRUCT_SET(BgL_newz00_1706, BgL_tmpz00_1825, BgL_arg1273z00_1512);
 						}
 						{	/* Prof/unit.scm 33 */
-							int BgL_tmpz00_1866;
+							int BgL_tmpz00_1828;
 
-							BgL_tmpz00_1866 = (int) (1L);
-							STRUCT_SET(BgL_newz00_1750, BgL_tmpz00_1866, BgL_arg1352z00_1494);
+							BgL_tmpz00_1828 = (int) (1L);
+							STRUCT_SET(BgL_newz00_1706, BgL_tmpz00_1828, BgL_arg1272z00_1511);
 						}
 						{	/* Prof/unit.scm 33 */
-							int BgL_tmpz00_1869;
+							int BgL_tmpz00_1831;
 
-							BgL_tmpz00_1869 = (int) (0L);
-							STRUCT_SET(BgL_newz00_1750, BgL_tmpz00_1869, BgL_idz00_1749);
+							BgL_tmpz00_1831 = (int) (0L);
+							STRUCT_SET(BgL_newz00_1706, BgL_tmpz00_1831, BgL_idz00_1705);
 						}
-						return BgL_newz00_1750;
+						return BgL_newz00_1706;
 					}
 				}
 			}
@@ -510,7 +515,7 @@ extern "C"
 
 
 /* &make-prof-unit */
-	obj_t BGl_z62makezd2profzd2unitz62zzprof_walkz00(obj_t BgL_envz00_1757)
+	obj_t BGl_z62makezd2profzd2unitz62zzprof_walkz00(obj_t BgL_envz00_1712)
 	{
 		{	/* Prof/unit.scm 31 */
 			return BGl_makezd2profzd2unitz00zzprof_walkz00();
@@ -558,26 +563,26 @@ extern "C"
 	{
 		{	/* Prof/unit.scm 15 */
 			BGl_modulezd2initializa7ationz75zztools_speekz00(61247943L,
-				BSTRING_TO_STRING(BGl_string1614z00zzprof_walkz00));
+				BSTRING_TO_STRING(BGl_string1370z00zzprof_walkz00));
 			BGl_modulezd2initializa7ationz75zztools_errorz00(300504031L,
-				BSTRING_TO_STRING(BGl_string1614z00zzprof_walkz00));
+				BSTRING_TO_STRING(BGl_string1370z00zzprof_walkz00));
 			BGl_modulezd2initializa7ationz75zzengine_passz00(373082237L,
-				BSTRING_TO_STRING(BGl_string1614z00zzprof_walkz00));
+				BSTRING_TO_STRING(BGl_string1370z00zzprof_walkz00));
 			BGl_modulezd2initializa7ationz75zztools_shapez00(365925558L,
-				BSTRING_TO_STRING(BGl_string1614z00zzprof_walkz00));
-			BGl_modulezd2initializa7ationz75zzengine_paramz00(517137079L,
-				BSTRING_TO_STRING(BGl_string1614z00zzprof_walkz00));
+				BSTRING_TO_STRING(BGl_string1370z00zzprof_walkz00));
+			BGl_modulezd2initializa7ationz75zzengine_paramz00(161876678L,
+				BSTRING_TO_STRING(BGl_string1370z00zzprof_walkz00));
 			BGl_modulezd2initializa7ationz75zztype_typez00(515343395L,
-				BSTRING_TO_STRING(BGl_string1614z00zzprof_walkz00));
+				BSTRING_TO_STRING(BGl_string1370z00zzprof_walkz00));
 			BGl_modulezd2initializa7ationz75zzmodule_includez00(184800657L,
-				BSTRING_TO_STRING(BGl_string1614z00zzprof_walkz00));
+				BSTRING_TO_STRING(BGl_string1370z00zzprof_walkz00));
 			BGl_modulezd2initializa7ationz75zzast_varz00(90839984L,
-				BSTRING_TO_STRING(BGl_string1614z00zzprof_walkz00));
+				BSTRING_TO_STRING(BGl_string1370z00zzprof_walkz00));
 			BGl_modulezd2initializa7ationz75zzast_nodez00(469732712L,
-				BSTRING_TO_STRING(BGl_string1614z00zzprof_walkz00));
+				BSTRING_TO_STRING(BGl_string1370z00zzprof_walkz00));
 			return
 				BGl_modulezd2initializa7ationz75zzbackend_backendz00(216206620L,
-				BSTRING_TO_STRING(BGl_string1614z00zzprof_walkz00));
+				BSTRING_TO_STRING(BGl_string1370z00zzprof_walkz00));
 		}
 
 	}
