@@ -1,9 +1,9 @@
 /*===========================================================================*/
 /*   (Read/load.scm)                                                         */
-/*   Bigloo (4.5b)                                                           */
-/*   Inria -- Sophia Antipolis (c)       Fri Dec 22 05:17:06 PM CET 2023     */
+/*   Bigloo (4.6a)                                                           */
+/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
 /*===========================================================================*/
-/* COMPILATION: (/home/serrano/prgm/project/bigloo/bigloo/bin/bigloo -ldopt -L/home/serrano/prgm/project/bigloo/bigloo/libbacktrace/home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b  -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Read/load.scm) */
+/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Read/load.scm) */
 /* GC selection */
 #define THE_GC BOEHM_GC
 
@@ -32,12 +32,12 @@ extern "C"
 	BGL_IMPORT obj_t BGl_stringzd2copyzd2zz__r4_strings_6_7z00(obj_t);
 	BGL_IMPORT obj_t BGl_readerzd2resetz12zc0zz__readerz00(void);
 	static obj_t BGl_objectzd2initzd2zzread_loadz00(void);
+	static obj_t BGl_z62zc3z04anonymousza31128ze3ze5zzread_loadz00(obj_t);
 	BGL_IMPORT obj_t BGl_readz00zz__readerz00(obj_t, obj_t);
 	BGL_IMPORT obj_t BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00(obj_t,
 		obj_t, obj_t);
 	static obj_t BGl_methodzd2initzd2zzread_loadz00(void);
 	BGL_IMPORT obj_t bgl_close_input_port(obj_t);
-	static obj_t BGl_z62zc3z04anonymousza31095ze3ze5zzread_loadz00(obj_t);
 	BGL_EXPORTED_DECL obj_t BGl_loadzd2modulezd2zzread_loadz00(obj_t, obj_t);
 	BGL_EXPORTED_DECL obj_t BGl_modulezd2initializa7ationz75zzread_loadz00(long,
 		char *);
@@ -78,28 +78,28 @@ extern "C"
 	   
 		 
 		DEFINE_EXPORT_BGL_PROCEDURE(BGl_loadzd2modulezd2envz00zzread_loadz00,
-		BgL_bgl_za762loadza7d2module1135z00, BGl_z62loadzd2modulezb0zzread_loadz00,
+		BgL_bgl_za762loadza7d2module1154z00, BGl_z62loadzd2modulezb0zzread_loadz00,
 		0L, BUNSPEC, 2);
-	      DEFINE_STRING(BGl_string1123z00zzread_loadz00,
-		BgL_bgl_string1123za700za7za7r1136za7, "]", 1);
-	      DEFINE_STRING(BGl_string1124z00zzread_loadz00,
-		BgL_bgl_string1124za700za7za7r1137za7, "      [reading loaded module ", 29);
-	      DEFINE_STRING(BGl_string1125z00zzread_loadz00,
-		BgL_bgl_string1125za700za7za7r1138za7, " vs ", 4);
-	      DEFINE_STRING(BGl_string1126z00zzread_loadz00,
-		BgL_bgl_string1126za700za7za7r1139za7, "conflict in module's name: ", 27);
-	      DEFINE_STRING(BGl_string1127z00zzread_loadz00,
-		BgL_bgl_string1127za700za7za7r1140za7, "load-module", 11);
-	      DEFINE_STRING(BGl_string1128z00zzread_loadz00,
-		BgL_bgl_string1128za700za7za7r1141za7, "Illegal module declaration", 26);
-	      DEFINE_STRING(BGl_string1129z00zzread_loadz00,
-		BgL_bgl_string1129za700za7za7r1142za7, "Can't open such file", 20);
-	      DEFINE_STRING(BGl_string1130z00zzread_loadz00,
-		BgL_bgl_string1130za700za7za7r1143za7, "Can't find file", 15);
-	      DEFINE_STRING(BGl_string1131z00zzread_loadz00,
-		BgL_bgl_string1131za700za7za7r1144za7, "read_load", 9);
-	      DEFINE_STRING(BGl_string1132z00zzread_loadz00,
-		BgL_bgl_string1132za700za7za7r1145za7, "module ", 7);
+	      DEFINE_STRING(BGl_string1140z00zzread_loadz00,
+		BgL_bgl_string1140za700za7za7r1155za7, "]", 1);
+	      DEFINE_STRING(BGl_string1141z00zzread_loadz00,
+		BgL_bgl_string1141za700za7za7r1156za7, "      [reading loaded module ", 29);
+	      DEFINE_STRING(BGl_string1142z00zzread_loadz00,
+		BgL_bgl_string1142za700za7za7r1157za7, " vs ", 4);
+	      DEFINE_STRING(BGl_string1143z00zzread_loadz00,
+		BgL_bgl_string1143za700za7za7r1158za7, "conflict in module's name: ", 27);
+	      DEFINE_STRING(BGl_string1144z00zzread_loadz00,
+		BgL_bgl_string1144za700za7za7r1159za7, "load-module", 11);
+	      DEFINE_STRING(BGl_string1145z00zzread_loadz00,
+		BgL_bgl_string1145za700za7za7r1160za7, "Illegal module declaration", 26);
+	      DEFINE_STRING(BGl_string1146z00zzread_loadz00,
+		BgL_bgl_string1146za700za7za7r1161za7, "Can't open such file", 20);
+	      DEFINE_STRING(BGl_string1147z00zzread_loadz00,
+		BgL_bgl_string1147za700za7za7r1162za7, "Can't find file", 15);
+	      DEFINE_STRING(BGl_string1148z00zzread_loadz00,
+		BgL_bgl_string1148za700za7za7r1163za7, "read_load", 9);
+	      DEFINE_STRING(BGl_string1149z00zzread_loadz00,
+		BgL_bgl_string1149za700za7za7r1164za7, "module ", 7);
 
 /* GC roots registration */
 	static obj_t bgl_gc_roots_register()
@@ -119,7 +119,7 @@ extern "C"
 
 /* module-initialization */
 	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zzread_loadz00(long
-		BgL_checksumz00_166, char *BgL_fromz00_167)
+		BgL_checksumz00_167, char *BgL_fromz00_168)
 	{
 		{
 			if (CBOOL(BGl_requirezd2initializa7ationz75zzread_loadz00))
@@ -166,70 +166,70 @@ extern "C"
 	{
 		{	/* Read/load.scm 15 */
 			{	/* Read/load.scm 15 */
-				obj_t BgL_cportz00_155;
+				obj_t BgL_cportz00_156;
 
 				{	/* Read/load.scm 15 */
-					obj_t BgL_stringz00_162;
+					obj_t BgL_stringz00_163;
 
-					BgL_stringz00_162 = BGl_string1132z00zzread_loadz00;
+					BgL_stringz00_163 = BGl_string1149z00zzread_loadz00;
 					{	/* Read/load.scm 15 */
-						obj_t BgL_startz00_163;
+						obj_t BgL_startz00_164;
 
-						BgL_startz00_163 = BINT(0L);
+						BgL_startz00_164 = BINT(0L);
 						{	/* Read/load.scm 15 */
-							obj_t BgL_endz00_164;
+							obj_t BgL_endz00_165;
 
-							BgL_endz00_164 = BINT(STRING_LENGTH(((obj_t) BgL_stringz00_162)));
+							BgL_endz00_165 = BINT(STRING_LENGTH(((obj_t) BgL_stringz00_163)));
 							{	/* Read/load.scm 15 */
 
-								BgL_cportz00_155 =
+								BgL_cportz00_156 =
 									BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00
-									(BgL_stringz00_162, BgL_startz00_163, BgL_endz00_164);
+									(BgL_stringz00_163, BgL_startz00_164, BgL_endz00_165);
 				}}}}
 				{
-					long BgL_iz00_156;
+					long BgL_iz00_157;
 
-					BgL_iz00_156 = 0L;
-				BgL_loopz00_157:
-					if ((BgL_iz00_156 == -1L))
+					BgL_iz00_157 = 0L;
+				BgL_loopz00_158:
+					if ((BgL_iz00_157 == (-1L)))
 						{	/* Read/load.scm 15 */
 							return BUNSPEC;
 						}
 					else
 						{	/* Read/load.scm 15 */
 							{	/* Read/load.scm 15 */
-								obj_t BgL_arg1134z00_158;
+								obj_t BgL_arg1153z00_159;
 
 								{	/* Read/load.scm 15 */
 
 									{	/* Read/load.scm 15 */
-										obj_t BgL_locationz00_160;
+										obj_t BgL_locationz00_161;
 
-										BgL_locationz00_160 = BBOOL(((bool_t) 0));
+										BgL_locationz00_161 = BBOOL(((bool_t) 0));
 										{	/* Read/load.scm 15 */
 
-											BgL_arg1134z00_158 =
-												BGl_readz00zz__readerz00(BgL_cportz00_155,
-												BgL_locationz00_160);
+											BgL_arg1153z00_159 =
+												BGl_readz00zz__readerz00(BgL_cportz00_156,
+												BgL_locationz00_161);
 										}
 									}
 								}
 								{	/* Read/load.scm 15 */
-									int BgL_tmpz00_193;
+									int BgL_tmpz00_194;
 
-									BgL_tmpz00_193 = (int) (BgL_iz00_156);
-									CNST_TABLE_SET(BgL_tmpz00_193, BgL_arg1134z00_158);
+									BgL_tmpz00_194 = (int) (BgL_iz00_157);
+									CNST_TABLE_SET(BgL_tmpz00_194, BgL_arg1153z00_159);
 							}}
 							{	/* Read/load.scm 15 */
-								int BgL_auxz00_161;
+								int BgL_auxz00_162;
 
-								BgL_auxz00_161 = (int) ((BgL_iz00_156 - 1L));
+								BgL_auxz00_162 = (int) ((BgL_iz00_157 - 1L));
 								{
-									long BgL_iz00_198;
+									long BgL_iz00_199;
 
-									BgL_iz00_198 = (long) (BgL_auxz00_161);
-									BgL_iz00_156 = BgL_iz00_198;
-									goto BgL_loopz00_157;
+									BgL_iz00_199 = (long) (BgL_auxz00_162);
+									BgL_iz00_157 = BgL_iz00_199;
+									goto BgL_loopz00_158;
 								}
 							}
 						}
@@ -258,225 +258,226 @@ extern "C"
 	{
 		{	/* Read/load.scm 26 */
 			{	/* Read/load.scm 27 */
-				obj_t BgL_list1064z00_72;
+				obj_t BgL_list1065z00_73;
 
 				{	/* Read/load.scm 27 */
-					obj_t BgL_arg1066z00_73;
+					obj_t BgL_arg1067z00_74;
 
 					{	/* Read/load.scm 27 */
-						obj_t BgL_arg1067z00_74;
+						obj_t BgL_arg1068z00_75;
 
 						{	/* Read/load.scm 27 */
-							obj_t BgL_arg1068z00_75;
+							obj_t BgL_arg1072z00_76;
 
-							BgL_arg1068z00_75 =
+							BgL_arg1072z00_76 =
 								MAKE_YOUNG_PAIR(BCHAR(((unsigned char) 10)), BNIL);
-							BgL_arg1067z00_74 =
-								MAKE_YOUNG_PAIR(BGl_string1123z00zzread_loadz00,
-								BgL_arg1068z00_75);
+							BgL_arg1068z00_75 =
+								MAKE_YOUNG_PAIR(BGl_string1140z00zzread_loadz00,
+								BgL_arg1072z00_76);
 						}
-						BgL_arg1066z00_73 =
-							MAKE_YOUNG_PAIR(BgL_modulez00_3, BgL_arg1067z00_74);
+						BgL_arg1067z00_74 =
+							MAKE_YOUNG_PAIR(BgL_modulez00_3, BgL_arg1068z00_75);
 					}
-					BgL_list1064z00_72 =
-						MAKE_YOUNG_PAIR(BGl_string1124z00zzread_loadz00, BgL_arg1066z00_73);
+					BgL_list1065z00_73 =
+						MAKE_YOUNG_PAIR(BGl_string1141z00zzread_loadz00, BgL_arg1067z00_74);
 				}
-				BGl_verbosez00zztools_speekz00(BINT(1L), BgL_list1064z00_72);
+				BGl_verbosez00zztools_speekz00(BINT(1L), BgL_list1065z00_73);
 			}
 			{	/* Read/load.scm 28 */
-				obj_t BgL_filez00_76;
+				obj_t BgL_filez00_77;
 
-				BgL_filez00_76 = CAR(BgL_fnamesz00_4);
+				BgL_filez00_77 = CAR(BgL_fnamesz00_4);
 				{	/* Read/load.scm 28 */
-					obj_t BgL_fnamez00_77;
+					obj_t BgL_fnamez00_78;
 
-					BgL_fnamez00_77 =
-						BGl_findzd2filezf2pathz20zz__osz00(BgL_filez00_76,
+					BgL_fnamez00_78 =
+						BGl_findzd2filezf2pathz20zz__osz00(BgL_filez00_77,
 						BGl_za2loadzd2pathza2zd2zz__evalz00);
 					{	/* Read/load.scm 29 */
 
-						if (STRINGP(BgL_fnamez00_77))
+						if (STRINGP(BgL_fnamez00_78))
 							{	/* Read/load.scm 32 */
-								obj_t BgL_portz00_79;
+								obj_t BgL_portz00_80;
 
 								{	/* Read/load.scm 32 */
 
-									BgL_portz00_79 =
+									BgL_portz00_80 =
 										BGl_openzd2inputzd2filez00zz__r4_ports_6_10_1z00
-										(BgL_fnamez00_77, BTRUE, BINT(5000000L));
+										(BgL_fnamez00_78, BTRUE, BINT(5000000L));
 								}
 								BGl_readerzd2resetz12zc0zz__readerz00();
-								if (INPUT_PORTP(BgL_portz00_79))
+								if (INPUT_PORTP(BgL_portz00_80))
 									{	/* Read/load.scm 36 */
-										obj_t BgL_exitd1052z00_81;
+										obj_t BgL_exitd1052z00_82;
 
-										BgL_exitd1052z00_81 = BGL_EXITD_TOP_AS_OBJ();
+										BgL_exitd1052z00_82 = BGL_EXITD_TOP_AS_OBJ();
 										{	/* Read/load.scm 52 */
-											obj_t BgL_zc3z04anonymousza31095ze3z87_149;
+											obj_t BgL_zc3z04anonymousza31128ze3z87_150;
 
-											BgL_zc3z04anonymousza31095ze3z87_149 =
+											BgL_zc3z04anonymousza31128ze3z87_150 =
 												MAKE_FX_PROCEDURE
-												(BGl_z62zc3z04anonymousza31095ze3ze5zzread_loadz00,
+												(BGl_z62zc3z04anonymousza31128ze3ze5zzread_loadz00,
 												(int) (0L), (int) (1L));
-											PROCEDURE_SET(BgL_zc3z04anonymousza31095ze3z87_149,
-												(int) (0L), BgL_portz00_79);
+											PROCEDURE_SET(BgL_zc3z04anonymousza31128ze3z87_150,
+												(int) (0L), BgL_portz00_80);
 											{	/* Read/load.scm 36 */
-												obj_t BgL_arg1820z00_126;
+												obj_t BgL_arg1881z00_127;
 
 												{	/* Read/load.scm 36 */
-													obj_t BgL_arg1821z00_127;
+													obj_t BgL_arg1883z00_128;
 
-													BgL_arg1821z00_127 =
-														BGL_EXITD_PROTECT(BgL_exitd1052z00_81);
-													BgL_arg1820z00_126 =
+													BgL_arg1883z00_128 =
+														BGL_EXITD_PROTECT(BgL_exitd1052z00_82);
+													BgL_arg1881z00_127 =
 														MAKE_YOUNG_PAIR
-														(BgL_zc3z04anonymousza31095ze3z87_149,
-														BgL_arg1821z00_127);
+														(BgL_zc3z04anonymousza31128ze3z87_150,
+														BgL_arg1883z00_128);
 												}
-												BGL_EXITD_PROTECT_SET(BgL_exitd1052z00_81,
-													BgL_arg1820z00_126);
+												BGL_EXITD_PROTECT_SET(BgL_exitd1052z00_82,
+													BgL_arg1881z00_127);
 												BUNSPEC;
 											}
 											{	/* Read/load.scm 36 */
-												obj_t BgL_tmp1054z00_83;
+												obj_t BgL_tmp1054z00_84;
 
 												{	/* Read/load.scm 36 */
-													obj_t BgL_declz00_84;
+													obj_t BgL_declz00_85;
 
 													{	/* Read/load.scm 36 */
 
 														{	/* Read/load.scm 36 */
 
-															BgL_declz00_84 =
-																BGl_readz00zz__readerz00(BgL_portz00_79,
+															BgL_declz00_85 =
+																BGl_readz00zz__readerz00(BgL_portz00_80,
 																BFALSE);
 													}}
 													{	/* Read/load.scm 37 */
-														bool_t BgL_test1150z00_227;
+														bool_t BgL_test1169z00_228;
 
-														if (PAIRP(BgL_declz00_84))
+														if (PAIRP(BgL_declz00_85))
 															{	/* Read/load.scm 37 */
-																BgL_test1150z00_227 =
-																	(CAR(BgL_declz00_84) == CNST_TABLE_REF(0L));
+																BgL_test1169z00_228 =
+																	(CAR(BgL_declz00_85) ==
+																	((obj_t) CNST_TABLE_REF(0)));
 															}
 														else
 															{	/* Read/load.scm 37 */
-																BgL_test1150z00_227 = ((bool_t) 0);
+																BgL_test1169z00_228 = ((bool_t) 0);
 															}
-														if (BgL_test1150z00_227)
+														if (BgL_test1169z00_228)
 															{	/* Read/load.scm 37 */
 																if (
-																	(CAR(CDR(BgL_declz00_84)) == BgL_modulez00_3))
+																	(CAR(CDR(BgL_declz00_85)) == BgL_modulez00_3))
 																	{	/* Read/load.scm 44 */
-																		BgL_tmp1054z00_83 = BFALSE;
+																		BgL_tmp1054z00_84 = BFALSE;
 																	}
 																else
 																	{	/* Read/load.scm 49 */
-																		obj_t BgL_arg1080z00_90;
+																		obj_t BgL_arg1097z00_91;
 
 																		{	/* Read/load.scm 49 */
-																			obj_t BgL_arg1082z00_92;
-																			obj_t BgL_arg1083z00_93;
+																			obj_t BgL_arg1103z00_93;
+																			obj_t BgL_arg1104z00_94;
 
 																			{	/* Read/load.scm 49 */
-																				obj_t BgL_arg1454z00_134;
+																				obj_t BgL_arg1486z00_135;
 
-																				BgL_arg1454z00_134 =
+																				BgL_arg1486z00_135 =
 																					SYMBOL_TO_STRING(BgL_modulez00_3);
-																				BgL_arg1082z00_92 =
+																				BgL_arg1103z00_93 =
 																					BGl_stringzd2copyzd2zz__r4_strings_6_7z00
-																					(BgL_arg1454z00_134);
+																					(BgL_arg1486z00_135);
 																			}
 																			{	/* Read/load.scm 50 */
-																				obj_t BgL_arg1090z00_98;
+																				obj_t BgL_arg1114z00_99;
 
-																				BgL_arg1090z00_98 =
-																					CAR(CDR(BgL_declz00_84));
+																				BgL_arg1114z00_99 =
+																					CAR(CDR(BgL_declz00_85));
 																				{	/* Read/load.scm 50 */
-																					obj_t BgL_arg1454z00_140;
+																					obj_t BgL_arg1486z00_141;
 
-																					BgL_arg1454z00_140 =
+																					BgL_arg1486z00_141 =
 																						SYMBOL_TO_STRING(
-																						((obj_t) BgL_arg1090z00_98));
-																					BgL_arg1083z00_93 =
+																						((obj_t) BgL_arg1114z00_99));
+																					BgL_arg1104z00_94 =
 																						BGl_stringzd2copyzd2zz__r4_strings_6_7z00
-																						(BgL_arg1454z00_140);
+																						(BgL_arg1486z00_141);
 																				}
 																			}
 																			{	/* Read/load.scm 47 */
-																				obj_t BgL_list1084z00_94;
+																				obj_t BgL_list1105z00_95;
 
 																				{	/* Read/load.scm 47 */
-																					obj_t BgL_arg1085z00_95;
+																					obj_t BgL_arg1110z00_96;
 
 																					{	/* Read/load.scm 47 */
-																						obj_t BgL_arg1087z00_96;
+																						obj_t BgL_arg1111z00_97;
 
 																						{	/* Read/load.scm 47 */
-																							obj_t BgL_arg1088z00_97;
+																							obj_t BgL_arg1113z00_98;
 
-																							BgL_arg1088z00_97 =
+																							BgL_arg1113z00_98 =
 																								MAKE_YOUNG_PAIR
-																								(BgL_arg1083z00_93, BNIL);
-																							BgL_arg1087z00_96 =
+																								(BgL_arg1104z00_94, BNIL);
+																							BgL_arg1111z00_97 =
 																								MAKE_YOUNG_PAIR
-																								(BGl_string1125z00zzread_loadz00,
-																								BgL_arg1088z00_97);
+																								(BGl_string1142z00zzread_loadz00,
+																								BgL_arg1113z00_98);
 																						}
-																						BgL_arg1085z00_95 =
-																							MAKE_YOUNG_PAIR(BgL_arg1082z00_92,
-																							BgL_arg1087z00_96);
+																						BgL_arg1110z00_96 =
+																							MAKE_YOUNG_PAIR(BgL_arg1103z00_93,
+																							BgL_arg1111z00_97);
 																					}
-																					BgL_list1084z00_94 =
+																					BgL_list1105z00_95 =
 																						MAKE_YOUNG_PAIR
-																						(BGl_string1126z00zzread_loadz00,
-																						BgL_arg1085z00_95);
+																						(BGl_string1143z00zzread_loadz00,
+																						BgL_arg1110z00_96);
 																				}
-																				BgL_arg1080z00_90 =
+																				BgL_arg1097z00_91 =
 																					BGl_stringzd2appendzd2zz__r4_strings_6_7z00
-																					(BgL_list1084z00_94);
+																					(BgL_list1105z00_95);
 																			}
 																		}
-																		BgL_tmp1054z00_83 =
+																		BgL_tmp1054z00_84 =
 																			BGl_userzd2errorzd2zztools_errorz00
-																			(BGl_string1127z00zzread_loadz00,
-																			BgL_arg1080z00_90, BgL_declz00_84, BNIL);
+																			(BGl_string1144z00zzread_loadz00,
+																			BgL_arg1097z00_91, BgL_declz00_85, BNIL);
 																	}
 															}
 														else
 															{	/* Read/load.scm 37 */
-																BgL_tmp1054z00_83 =
+																BgL_tmp1054z00_84 =
 																	BGl_userzd2errorzd2zztools_errorz00
-																	(BGl_string1127z00zzread_loadz00,
-																	BGl_string1128z00zzread_loadz00,
-																	BgL_declz00_84, BNIL);
+																	(BGl_string1144z00zzread_loadz00,
+																	BGl_string1145z00zzread_loadz00,
+																	BgL_declz00_85, BNIL);
 															}
 													}
 												}
 												{	/* Read/load.scm 36 */
-													bool_t BgL_test1153z00_251;
+													bool_t BgL_test1172z00_253;
 
 													{	/* Read/load.scm 36 */
-														obj_t BgL_arg1819z00_142;
+														obj_t BgL_arg1880z00_143;
 
-														BgL_arg1819z00_142 =
-															BGL_EXITD_PROTECT(BgL_exitd1052z00_81);
-														BgL_test1153z00_251 = PAIRP(BgL_arg1819z00_142);
+														BgL_arg1880z00_143 =
+															BGL_EXITD_PROTECT(BgL_exitd1052z00_82);
+														BgL_test1172z00_253 = PAIRP(BgL_arg1880z00_143);
 													}
-													if (BgL_test1153z00_251)
+													if (BgL_test1172z00_253)
 														{	/* Read/load.scm 36 */
-															obj_t BgL_arg1817z00_143;
+															obj_t BgL_arg1877z00_144;
 
 															{	/* Read/load.scm 36 */
-																obj_t BgL_arg1818z00_144;
+																obj_t BgL_arg1879z00_145;
 
-																BgL_arg1818z00_144 =
-																	BGL_EXITD_PROTECT(BgL_exitd1052z00_81);
-																BgL_arg1817z00_143 =
-																	CDR(((obj_t) BgL_arg1818z00_144));
+																BgL_arg1879z00_145 =
+																	BGL_EXITD_PROTECT(BgL_exitd1052z00_82);
+																BgL_arg1877z00_144 =
+																	CDR(((obj_t) BgL_arg1879z00_145));
 															}
-															BGL_EXITD_PROTECT_SET(BgL_exitd1052z00_81,
-																BgL_arg1817z00_143);
+															BGL_EXITD_PROTECT_SET(BgL_exitd1052z00_82,
+																BgL_arg1877z00_144);
 															BUNSPEC;
 														}
 													else
@@ -484,64 +485,64 @@ extern "C"
 															BFALSE;
 														}
 												}
-												bgl_close_input_port(BgL_portz00_79);
-												BgL_tmp1054z00_83;
+												bgl_close_input_port(BgL_portz00_80);
+												BgL_tmp1054z00_84;
 											}
 										}
 									}
 								else
 									{	/* Read/load.scm 34 */
 										BGl_userzd2errorzd2zztools_errorz00
-											(BGl_string1127z00zzread_loadz00,
-											BGl_string1129z00zzread_loadz00, BgL_filez00_76, BNIL);
+											(BGl_string1144z00zzread_loadz00,
+											BGl_string1146z00zzread_loadz00, BgL_filez00_77, BNIL);
 									}
 							}
 						else
 							{	/* Read/load.scm 30 */
 								BGl_userzd2errorzd2zztools_errorz00
-									(BGl_string1127z00zzread_loadz00,
-									BGl_string1130z00zzread_loadz00, BgL_filez00_76, BNIL);
+									(BGl_string1144z00zzread_loadz00,
+									BGl_string1147z00zzread_loadz00, BgL_filez00_77, BNIL);
 							}
 					}
 				}
 			}
 			{
-				obj_t BgL_l1058z00_113;
+				obj_t BgL_l1058z00_114;
 
 				{	/* Read/load.scm 53 */
-					bool_t BgL_tmpz00_261;
+					bool_t BgL_tmpz00_263;
 
-					BgL_l1058z00_113 = BgL_fnamesz00_4;
-				BgL_zc3z04anonymousza31098ze3z87_114:
-					if (PAIRP(BgL_l1058z00_113))
+					BgL_l1058z00_114 = BgL_fnamesz00_4;
+				BgL_zc3z04anonymousza31131ze3z87_115:
+					if (PAIRP(BgL_l1058z00_114))
 						{	/* Read/load.scm 53 */
 							{	/* Read/load.scm 53 */
-								obj_t BgL_arg1110z00_116;
+								obj_t BgL_arg1134z00_117;
 
-								BgL_arg1110z00_116 = CAR(BgL_l1058z00_113);
+								BgL_arg1134z00_117 = CAR(BgL_l1058z00_114);
 								{	/* Read/load.scm 53 */
-									obj_t BgL_envz00_118;
+									obj_t BgL_envz00_119;
 
-									BgL_envz00_118 = BGl_defaultzd2environmentzd2zz__evalz00();
+									BgL_envz00_119 = BGl_defaultzd2environmentzd2zz__evalz00();
 									{	/* Read/load.scm 53 */
 
-										BGl_loadqz00zz__evalz00(BgL_arg1110z00_116, BgL_envz00_118);
+										BGl_loadqz00zz__evalz00(BgL_arg1134z00_117, BgL_envz00_119);
 									}
 								}
 							}
 							{
-								obj_t BgL_l1058z00_267;
+								obj_t BgL_l1058z00_269;
 
-								BgL_l1058z00_267 = CDR(BgL_l1058z00_113);
-								BgL_l1058z00_113 = BgL_l1058z00_267;
-								goto BgL_zc3z04anonymousza31098ze3z87_114;
+								BgL_l1058z00_269 = CDR(BgL_l1058z00_114);
+								BgL_l1058z00_114 = BgL_l1058z00_269;
+								goto BgL_zc3z04anonymousza31131ze3z87_115;
 							}
 						}
 					else
 						{	/* Read/load.scm 53 */
-							BgL_tmpz00_261 = ((bool_t) 1);
+							BgL_tmpz00_263 = ((bool_t) 1);
 						}
-					return BBOOL(BgL_tmpz00_261);
+					return BBOOL(BgL_tmpz00_263);
 				}
 			}
 		}
@@ -551,28 +552,28 @@ extern "C"
 
 
 /* &load-module */
-	obj_t BGl_z62loadzd2modulezb0zzread_loadz00(obj_t BgL_envz00_150,
-		obj_t BgL_modulez00_151, obj_t BgL_fnamesz00_152)
+	obj_t BGl_z62loadzd2modulezb0zzread_loadz00(obj_t BgL_envz00_151,
+		obj_t BgL_modulez00_152, obj_t BgL_fnamesz00_153)
 	{
 		{	/* Read/load.scm 26 */
 			return
-				BGl_loadzd2modulezd2zzread_loadz00(BgL_modulez00_151,
-				BgL_fnamesz00_152);
+				BGl_loadzd2modulezd2zzread_loadz00(BgL_modulez00_152,
+				BgL_fnamesz00_153);
 		}
 
 	}
 
 
 
-/* &<@anonymous:1095> */
-	obj_t BGl_z62zc3z04anonymousza31095ze3ze5zzread_loadz00(obj_t BgL_envz00_153)
+/* &<@anonymous:1128> */
+	obj_t BGl_z62zc3z04anonymousza31128ze3ze5zzread_loadz00(obj_t BgL_envz00_154)
 	{
 		{	/* Read/load.scm 36 */
 			{	/* Read/load.scm 52 */
-				obj_t BgL_portz00_154;
+				obj_t BgL_portz00_155;
 
-				BgL_portz00_154 = PROCEDURE_REF(BgL_envz00_153, (int) (0L));
-				return bgl_close_input_port(((obj_t) BgL_portz00_154));
+				BgL_portz00_155 = PROCEDURE_REF(BgL_envz00_154, (int) (0L));
+				return bgl_close_input_port(((obj_t) BgL_portz00_155));
 			}
 		}
 
@@ -618,16 +619,16 @@ extern "C"
 	{
 		{	/* Read/load.scm 15 */
 			BGl_modulezd2initializa7ationz75zztools_tracez00(54713316L,
-				BSTRING_TO_STRING(BGl_string1131z00zzread_loadz00));
+				BSTRING_TO_STRING(BGl_string1148z00zzread_loadz00));
 			BGl_modulezd2initializa7ationz75zztools_errorz00(300504031L,
-				BSTRING_TO_STRING(BGl_string1131z00zzread_loadz00));
+				BSTRING_TO_STRING(BGl_string1148z00zzread_loadz00));
 			BGl_modulezd2initializa7ationz75zztools_speekz00(61247943L,
-				BSTRING_TO_STRING(BGl_string1131z00zzread_loadz00));
+				BSTRING_TO_STRING(BGl_string1148z00zzread_loadz00));
 			BGl_modulezd2initializa7ationz75zztype_typez00(515343395L,
-				BSTRING_TO_STRING(BGl_string1131z00zzread_loadz00));
+				BSTRING_TO_STRING(BGl_string1148z00zzread_loadz00));
 			return
 				BGl_modulezd2initializa7ationz75zzast_identz00(174885617L,
-				BSTRING_TO_STRING(BGl_string1131z00zzread_loadz00));
+				BSTRING_TO_STRING(BGl_string1148z00zzread_loadz00));
 		}
 
 	}
