@@ -1,9 +1,9 @@
 /*===========================================================================*/
 /*   (Read/reader.scm)                                                       */
-/*   Bigloo (4.5b)                                                           */
-/*   Inria -- Sophia Antipolis (c)       Fri Dec 22 05:17:06 PM CET 2023     */
+/*   Bigloo (4.6a)                                                           */
+/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
 /*===========================================================================*/
-/* COMPILATION: (/home/serrano/prgm/project/bigloo/bigloo/bin/bigloo -ldopt -L/home/serrano/prgm/project/bigloo/bigloo/libbacktrace/home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b  -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Read/reader.scm) */
+/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Read/reader.scm) */
 /* GC selection */
 #define THE_GC BOEHM_GC
 
@@ -66,24 +66,24 @@ extern "C"
 	   
 		 
 		DEFINE_EXPORT_BGL_PROCEDURE(BGl_compilerzd2readzd2envz00zzread_readerz00,
-		BgL_bgl_za762compilerza7d2re1027z00, va_generic_entry,
+		BgL_bgl_za762compilerza7d2re1028z00, va_generic_entry,
 		BGl_z62compilerzd2readzb0zzread_readerz00, BUNSPEC, -1);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_compilerzd2readzd2srczd2envzd2zzread_readerz00,
-		BgL_bgl_za762compilerza7d2re1028z00, va_generic_entry,
+		BgL_bgl_za762compilerza7d2re1029z00, va_generic_entry,
 		BGl_z62compilerzd2readzd2srcz62zzread_readerz00, BUNSPEC, -1);
 	BGL_IMPORT obj_t BGl_readzd2envzd2zz__readerz00;
 	   
 		 
-		DEFINE_STRING(BGl_string1022z00zzread_readerz00,
-		BgL_bgl_string1022za700za7za7r1029za7, "", 0);
-	      DEFINE_STRING(BGl_string1023z00zzread_readerz00,
-		BgL_bgl_string1023za700za7za7r1030za7, "Illegal intern value", 20);
+		DEFINE_STRING(BGl_string1023z00zzread_readerz00,
+		BgL_bgl_string1023za700za7za7r1030za7, "", 0);
 	      DEFINE_STRING(BGl_string1024z00zzread_readerz00,
-		BgL_bgl_string1024za700za7za7r1031za7, "read_reader", 11);
+		BgL_bgl_string1024za700za7za7r1031za7, "Illegal intern value", 20);
 	      DEFINE_STRING(BGl_string1025z00zzread_readerz00,
-		BgL_bgl_string1025za700za7za7r1032za7, "intern-src intern ", 18);
+		BgL_bgl_string1025za700za7za7r1032za7, "read_reader", 11);
+	      DEFINE_STRING(BGl_string1026z00zzread_readerz00,
+		BgL_bgl_string1026za700za7za7r1033za7, "intern-src intern ", 18);
 
 /* GC roots registration */
 	static obj_t bgl_gc_roots_register()
@@ -104,7 +104,7 @@ extern "C"
 
 /* module-initialization */
 	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zzread_readerz00(long
-		BgL_checksumz00_46, char *BgL_fromz00_47)
+		BgL_checksumz00_47, char *BgL_fromz00_48)
 	{
 		{
 			if (CBOOL(BGl_requirezd2initializa7ationz75zzread_readerz00))
@@ -150,70 +150,70 @@ extern "C"
 	{
 		{	/* Read/reader.scm 16 */
 			{	/* Read/reader.scm 16 */
-				obj_t BgL_cportz00_35;
+				obj_t BgL_cportz00_36;
 
 				{	/* Read/reader.scm 16 */
-					obj_t BgL_stringz00_42;
+					obj_t BgL_stringz00_43;
 
-					BgL_stringz00_42 = BGl_string1025z00zzread_readerz00;
+					BgL_stringz00_43 = BGl_string1026z00zzread_readerz00;
 					{	/* Read/reader.scm 16 */
-						obj_t BgL_startz00_43;
+						obj_t BgL_startz00_44;
 
-						BgL_startz00_43 = BINT(0L);
+						BgL_startz00_44 = BINT(0L);
 						{	/* Read/reader.scm 16 */
-							obj_t BgL_endz00_44;
+							obj_t BgL_endz00_45;
 
-							BgL_endz00_44 = BINT(STRING_LENGTH(((obj_t) BgL_stringz00_42)));
+							BgL_endz00_45 = BINT(STRING_LENGTH(((obj_t) BgL_stringz00_43)));
 							{	/* Read/reader.scm 16 */
 
-								BgL_cportz00_35 =
+								BgL_cportz00_36 =
 									BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00
-									(BgL_stringz00_42, BgL_startz00_43, BgL_endz00_44);
+									(BgL_stringz00_43, BgL_startz00_44, BgL_endz00_45);
 				}}}}
 				{
-					long BgL_iz00_36;
+					long BgL_iz00_37;
 
-					BgL_iz00_36 = 1L;
-				BgL_loopz00_37:
-					if ((BgL_iz00_36 == -1L))
+					BgL_iz00_37 = 1L;
+				BgL_loopz00_38:
+					if ((BgL_iz00_37 == (-1L)))
 						{	/* Read/reader.scm 16 */
 							return BUNSPEC;
 						}
 					else
 						{	/* Read/reader.scm 16 */
 							{	/* Read/reader.scm 16 */
-								obj_t BgL_arg1026z00_38;
+								obj_t BgL_arg1027z00_39;
 
 								{	/* Read/reader.scm 16 */
 
 									{	/* Read/reader.scm 16 */
-										obj_t BgL_locationz00_40;
+										obj_t BgL_locationz00_41;
 
-										BgL_locationz00_40 = BBOOL(((bool_t) 0));
+										BgL_locationz00_41 = BBOOL(((bool_t) 0));
 										{	/* Read/reader.scm 16 */
 
-											BgL_arg1026z00_38 =
-												BGl_readz00zz__readerz00(BgL_cportz00_35,
-												BgL_locationz00_40);
+											BgL_arg1027z00_39 =
+												BGl_readz00zz__readerz00(BgL_cportz00_36,
+												BgL_locationz00_41);
 										}
 									}
 								}
 								{	/* Read/reader.scm 16 */
-									int BgL_tmpz00_72;
+									int BgL_tmpz00_73;
 
-									BgL_tmpz00_72 = (int) (BgL_iz00_36);
-									CNST_TABLE_SET(BgL_tmpz00_72, BgL_arg1026z00_38);
+									BgL_tmpz00_73 = (int) (BgL_iz00_37);
+									CNST_TABLE_SET(BgL_tmpz00_73, BgL_arg1027z00_39);
 							}}
 							{	/* Read/reader.scm 16 */
-								int BgL_auxz00_41;
+								int BgL_auxz00_42;
 
-								BgL_auxz00_41 = (int) ((BgL_iz00_36 - 1L));
+								BgL_auxz00_42 = (int) ((BgL_iz00_37 - 1L));
 								{
-									long BgL_iz00_77;
+									long BgL_iz00_78;
 
-									BgL_iz00_77 = (long) (BgL_auxz00_41);
-									BgL_iz00_36 = BgL_iz00_77;
-									goto BgL_loopz00_37;
+									BgL_iz00_78 = (long) (BgL_auxz00_42);
+									BgL_iz00_37 = BgL_iz00_78;
+									goto BgL_loopz00_38;
 								}
 							}
 						}
@@ -241,12 +241,12 @@ extern "C"
 	{
 		{	/* Read/reader.scm 24 */
 			{	/* Read/reader.scm 25 */
-				obj_t BgL__ortest_1012z00_13;
+				obj_t BgL__ortest_1012z00_14;
 
-				BgL__ortest_1012z00_13 = BGl_bigloozd2loadzd2readerz00zz__paramz00();
-				if (CBOOL(BgL__ortest_1012z00_13))
+				BgL__ortest_1012z00_14 = BGl_bigloozd2loadzd2readerz00zz__paramz00();
+				if (CBOOL(BgL__ortest_1012z00_14))
 					{	/* Read/reader.scm 25 */
-						return BgL__ortest_1012z00_13;
+						return BgL__ortest_1012z00_14;
 					}
 				else
 					{	/* Read/reader.scm 25 */
@@ -265,40 +265,42 @@ extern "C"
 	{
 		{	/* Read/reader.scm 30 */
 			{	/* Read/reader.scm 31 */
-				obj_t BgL_readz00_14;
+				obj_t BgL_readz00_15;
 
-				BgL_readz00_14 = BGl_getzd2compilerzd2readerz00zzread_readerz00();
+				BgL_readz00_15 = BGl_getzd2compilerzd2readerz00zzread_readerz00();
 				{	/* Read/reader.scm 31 */
-					obj_t BgL_valuez00_15;
+					obj_t BgL_valuez00_16;
 
-					BgL_valuez00_15 = apply(BgL_readz00_14, BgL_argsz00_3);
+					BgL_valuez00_16 = apply(BgL_readz00_15, BgL_argsz00_3);
 					{	/* Read/reader.scm 32 */
 
-						if ((BGl_za2readerza2z00zzengine_paramz00 == CNST_TABLE_REF(0L)))
+						if (
+							(BGl_za2readerza2z00zzengine_paramz00 ==
+								((obj_t) CNST_TABLE_REF(0))))
 							{	/* Read/reader.scm 33 */
-								if (EOF_OBJECTP(BgL_valuez00_15))
+								if (EOF_OBJECTP(BgL_valuez00_16))
 									{	/* Read/reader.scm 35 */
-										return BgL_valuez00_15;
+										return BgL_valuez00_16;
 									}
 								else
 									{	/* Read/reader.scm 35 */
-										if (STRINGP(BgL_valuez00_15))
+										if (STRINGP(BgL_valuez00_16))
 											{	/* Read/reader.scm 38 */
 
-												return string_to_obj(BgL_valuez00_15, BFALSE, BFALSE);
+												return string_to_obj(BgL_valuez00_16, BFALSE, BFALSE);
 											}
 										else
 											{	/* Read/reader.scm 37 */
 												return
 													BGl_errorz00zz__errorz00
-													(BGl_string1022z00zzread_readerz00,
-													BGl_string1023z00zzread_readerz00, BgL_valuez00_15);
+													(BGl_string1023z00zzread_readerz00,
+													BGl_string1024z00zzread_readerz00, BgL_valuez00_16);
 											}
 									}
 							}
 						else
 							{	/* Read/reader.scm 33 */
-								return BgL_valuez00_15;
+								return BgL_valuez00_16;
 							}
 					}
 				}
@@ -310,11 +312,11 @@ extern "C"
 
 
 /* &compiler-read */
-	obj_t BGl_z62compilerzd2readzb0zzread_readerz00(obj_t BgL_envz00_31,
-		obj_t BgL_argsz00_32)
+	obj_t BGl_z62compilerzd2readzb0zzread_readerz00(obj_t BgL_envz00_32,
+		obj_t BgL_argsz00_33)
 	{
 		{	/* Read/reader.scm 30 */
-			return BGl_compilerzd2readzd2zzread_readerz00(BgL_argsz00_32);
+			return BGl_compilerzd2readzd2zzread_readerz00(BgL_argsz00_33);
 		}
 
 	}
@@ -327,40 +329,42 @@ extern "C"
 	{
 		{	/* Read/reader.scm 46 */
 			{	/* Read/reader.scm 47 */
-				obj_t BgL_readz00_21;
+				obj_t BgL_readz00_22;
 
-				BgL_readz00_21 = BGl_getzd2compilerzd2readerz00zzread_readerz00();
+				BgL_readz00_22 = BGl_getzd2compilerzd2readerz00zzread_readerz00();
 				{	/* Read/reader.scm 47 */
-					obj_t BgL_valuez00_22;
+					obj_t BgL_valuez00_23;
 
-					BgL_valuez00_22 = apply(BgL_readz00_21, BgL_argsz00_4);
+					BgL_valuez00_23 = apply(BgL_readz00_22, BgL_argsz00_4);
 					{	/* Read/reader.scm 48 */
 
-						if ((BGl_za2readerza2z00zzengine_paramz00 == CNST_TABLE_REF(1L)))
+						if (
+							(BGl_za2readerza2z00zzengine_paramz00 ==
+								((obj_t) CNST_TABLE_REF(1))))
 							{	/* Read/reader.scm 49 */
-								if (EOF_OBJECTP(BgL_valuez00_22))
+								if (EOF_OBJECTP(BgL_valuez00_23))
 									{	/* Read/reader.scm 51 */
-										return BgL_valuez00_22;
+										return BgL_valuez00_23;
 									}
 								else
 									{	/* Read/reader.scm 51 */
-										if (STRINGP(BgL_valuez00_22))
+										if (STRINGP(BgL_valuez00_23))
 											{	/* Read/reader.scm 54 */
 
-												return string_to_obj(BgL_valuez00_22, BFALSE, BFALSE);
+												return string_to_obj(BgL_valuez00_23, BFALSE, BFALSE);
 											}
 										else
 											{	/* Read/reader.scm 53 */
 												return
 													BGl_errorz00zz__errorz00
-													(BGl_string1022z00zzread_readerz00,
-													BGl_string1023z00zzread_readerz00, BgL_valuez00_22);
+													(BGl_string1023z00zzread_readerz00,
+													BGl_string1024z00zzread_readerz00, BgL_valuez00_23);
 											}
 									}
 							}
 						else
 							{	/* Read/reader.scm 49 */
-								return BgL_valuez00_22;
+								return BgL_valuez00_23;
 							}
 					}
 				}
@@ -372,11 +376,11 @@ extern "C"
 
 
 /* &compiler-read-src */
-	obj_t BGl_z62compilerzd2readzd2srcz62zzread_readerz00(obj_t BgL_envz00_33,
-		obj_t BgL_argsz00_34)
+	obj_t BGl_z62compilerzd2readzd2srcz62zzread_readerz00(obj_t BgL_envz00_34,
+		obj_t BgL_argsz00_35)
 	{
 		{	/* Read/reader.scm 46 */
-			return BGl_compilerzd2readzd2srcz00zzread_readerz00(BgL_argsz00_34);
+			return BGl_compilerzd2readzd2srcz00zzread_readerz00(BgL_argsz00_35);
 		}
 
 	}
@@ -421,8 +425,8 @@ extern "C"
 	{
 		{	/* Read/reader.scm 16 */
 			return
-				BGl_modulezd2initializa7ationz75zzengine_paramz00(517137079L,
-				BSTRING_TO_STRING(BGl_string1024z00zzread_readerz00));
+				BGl_modulezd2initializa7ationz75zzengine_paramz00(161876678L,
+				BSTRING_TO_STRING(BGl_string1025z00zzread_readerz00));
 		}
 
 	}
