@@ -3,8 +3,8 @@
 ;*    -------------------------------------------------------------    */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Thu Jul 13 10:25:23 1995                          */
-;*    Last change :  Sun Jan 21 03:41:36 2001 (serrano)                */
-;*    Copyright   :  1995-2001 Manuel Serrano, see LICENSE file        */
+;*    Last change :  Sat Feb 15 14:00:10 2014 (serrano)                */
+;*    Copyright   :  1995-2014 Manuel Serrano, see LICENSE file        */
 ;*    -------------------------------------------------------------    */
 ;*    The Reduction optimizations                                      */
 ;*=====================================================================*/
@@ -24,26 +24,32 @@
 	    reduce_cse
 	    reduce_cond
 	    reduce_typec
+	    reduce_flow-typec
 	    reduce_1occ
 	    reduce_beta
 	    ast_remove)
-   (export  (reduce-walk! globals)))
+   (export  (reduce-walk! globals::pair-nil msg::bstring . obj)))
 
 ;*---------------------------------------------------------------------*/
 ;*    reduce-walk ...                                                  */
 ;*---------------------------------------------------------------------*/
-(define (reduce-walk! globals)
-   (if *optim-dataflow?*
-       (begin
-	  (pass-prelude "Reduction")
-	  (reduce-copy! globals)
-	  (if (>=fx *optim* 2) (reduce-cse! globals))
-	  (reduce-type-check! globals)
-	  (reduce-copy! globals)
-	  (reduce-conditional! globals)
-	  (reduce-1occ! globals)
-	  (if *optim-reduce-beta?* (reduce-beta! globals))
-	  (pass-postlude (remove-var 'reduce globals)))
-       globals))
-  
- 
+(define (reduce-walk! globals msg . type-unsafe)
+   (pass-prelude msg)
+   (cond
+      ((and (pair? type-unsafe) (car type-unsafe))
+       (reduce-1occ! globals)
+       (reduce-type-check! globals)
+       (reduce-conditional! globals)
+       (pass-postlude (remove-var 'reduce globals)))
+      (*optim-dataflow?*
+       (reduce-copy! globals)
+       (when (>=fx *optim* 2) (reduce-cse! globals))
+       (reduce-type-check! globals)
+       (reduce-copy! globals)
+       (reduce-conditional! globals)
+       (reduce-1occ! globals)
+       (when *optim-reduce-beta?* (reduce-beta! globals))
+       (reduce-flow-type-check! globals)
+       (pass-postlude (remove-var 'reduce globals)))
+      (else
+       (remove-var 'reduce globals))))
