@@ -1,9 +1,9 @@
 /*===========================================================================*/
 /*   (SawC/compile.scm)                                                      */
-/*   Bigloo (4.5b)                                                           */
-/*   Inria -- Sophia Antipolis (c)       Fri Dec 22 05:17:06 PM CET 2023     */
+/*   Bigloo (4.6a)                                                           */
+/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
 /*===========================================================================*/
-/* COMPILATION: (/home/serrano/prgm/project/bigloo/bigloo/bin/bigloo -ldopt -L/home/serrano/prgm/project/bigloo/bigloo/libbacktrace/home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b  -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent SawC/compile.scm) */
+/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent SawC/compile.scm) */
 /* GC selection */
 #define THE_GC BOEHM_GC
 
@@ -38,6 +38,7 @@ extern "C"
 		obj_t BgL_parentsz00;
 		bool_t BgL_initzf3zf3;
 		bool_t BgL_magiczf3zf3;
+		obj_t BgL_nullz00;
 		obj_t BgL_z42z42;
 		obj_t BgL_aliasz00;
 		obj_t BgL_pointedzd2tozd2byz00;
@@ -74,7 +75,7 @@ extern "C"
 		obj_t BgL_libraryz00;
 		obj_t BgL_pragmaz00;
 		obj_t BgL_srcz00;
-		obj_t BgL_jvmzd2typezd2namez00;
+		obj_t BgL_qualifiedzd2typezd2namez00;
 		obj_t BgL_initz00;
 		obj_t BgL_aliasz00;
 	}                *BgL_globalz00_bglt;
@@ -112,6 +113,11 @@ extern "C"
 		bool_t BgL_boundzd2checkzd2;
 		bool_t BgL_typezd2checkzd2;
 		bool_t BgL_typedzd2funcallzd2;
+		bool_t BgL_strictzd2typezd2castz00;
+		bool_t BgL_forcezd2registerzd2gczd2rootszd2;
+		bool_t BgL_stringzd2literalzd2supportz00;
+		bool_t BgL_boxedzd2fixnumszd2;
+		bool_t BgL_typedzd2closureszd2;
 	}                 *BgL_backendz00_bglt;
 
 	typedef struct BgL_cvmz00_bgl
@@ -147,6 +153,11 @@ extern "C"
 		bool_t BgL_boundzd2checkzd2;
 		bool_t BgL_typezd2checkzd2;
 		bool_t BgL_typedzd2funcallzd2;
+		bool_t BgL_strictzd2typezd2castz00;
+		bool_t BgL_forcezd2registerzd2gczd2rootszd2;
+		bool_t BgL_stringzd2literalzd2supportz00;
+		bool_t BgL_boxedzd2fixnumszd2;
+		bool_t BgL_typedzd2closureszd2;
 	}             *BgL_cvmz00_bglt;
 
 	typedef struct BgL_sawcz00_bgl
@@ -182,6 +193,11 @@ extern "C"
 		bool_t BgL_boundzd2checkzd2;
 		bool_t BgL_typezd2checkzd2;
 		bool_t BgL_typedzd2funcallzd2;
+		bool_t BgL_strictzd2typezd2castz00;
+		bool_t BgL_forcezd2registerzd2gczd2rootszd2;
+		bool_t BgL_stringzd2literalzd2supportz00;
+		bool_t BgL_boxedzd2fixnumszd2;
+		bool_t BgL_typedzd2closureszd2;
 	}              *BgL_sawcz00_bglt;
 
 
@@ -194,9 +210,9 @@ extern "C"
 	extern obj_t BGl_forzd2eachzd2globalz12z12zzast_envz00(obj_t, obj_t);
 	static obj_t BGl_genericzd2initzd2zzsaw_c_compilez00(void);
 	static obj_t BGl_objectzd2initzd2zzsaw_c_compilez00(void);
-	static obj_t BGl_methodzd2initzd2zzsaw_c_compilez00(void);
-	static obj_t BGl_z62backendzd2compilezd2func1483z62zzsaw_c_compilez00(obj_t,
+	static obj_t BGl_z62backendzd2compilezd2func1425z62zzsaw_c_compilez00(obj_t,
 		obj_t);
+	static obj_t BGl_methodzd2initzd2zzsaw_c_compilez00(void);
 	BGL_EXPORTED_DECL obj_t
 		BGl_modulezd2initializa7ationz75zzsaw_c_compilez00(long, char *);
 	extern obj_t BGl_modulezd2initializa7ationz75zzsaw_c_codez00(long, char *);
@@ -251,13 +267,13 @@ extern "C"
 
 	   
 		 
-		DEFINE_STRING(BGl_string1735z00zzsaw_c_compilez00,
-		BgL_bgl_string1735za700za7za7s1737za7, "backend-compile-functions", 25);
-	      DEFINE_STRING(BGl_string1736z00zzsaw_c_compilez00,
-		BgL_bgl_string1736za700za7za7s1738za7, "saw_c_compile", 13);
-	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1734z00zzsaw_c_compilez00,
-		BgL_bgl_za762backendza7d2com1739z00,
-		BGl_z62backendzd2compilezd2func1483z62zzsaw_c_compilez00, 0L, BUNSPEC, 1);
+		DEFINE_STRING(BGl_string1725z00zzsaw_c_compilez00,
+		BgL_bgl_string1725za700za7za7s1727za7, "backend-compile-functions", 25);
+	      DEFINE_STRING(BGl_string1726z00zzsaw_c_compilez00,
+		BgL_bgl_string1726za700za7za7s1728za7, "saw_c_compile", 13);
+	      DEFINE_STATIC_BGL_PROCEDURE(BGl_proc1724z00zzsaw_c_compilez00,
+		BgL_bgl_za762backendza7d2com1729z00,
+		BGl_z62backendzd2compilezd2func1425z62zzsaw_c_compilez00, 0L, BUNSPEC, 1);
 	extern obj_t BGl_backendzd2compilezd2functionszd2envzd2zzbackend_backendz00;
 	extern obj_t BGl_setzd2variablezd2namez12zd2envzc0zzbackend_cplibz00;
 
@@ -281,7 +297,7 @@ extern "C"
 
 /* module-initialization */
 	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zzsaw_c_compilez00(long
-		BgL_checksumz00_2521, char *BgL_fromz00_2522)
+		BgL_checksumz00_2480, char *BgL_fromz00_2481)
 	{
 		{
 			if (CBOOL(BGl_requirezd2initializa7ationz75zzsaw_c_compilez00))
@@ -371,51 +387,51 @@ extern "C"
 			return
 				BGl_genericzd2addzd2methodz12z12zz__objectz00
 				(BGl_backendzd2compilezd2functionszd2envzd2zzbackend_backendz00,
-				BGl_sawcz00zzbackend_cvmz00, BGl_proc1734z00zzsaw_c_compilez00,
-				BGl_string1735z00zzsaw_c_compilez00);
+				BGl_sawcz00zzbackend_cvmz00, BGl_proc1724z00zzsaw_c_compilez00,
+				BGl_string1725z00zzsaw_c_compilez00);
 		}
 
 	}
 
 
 
-/* &backend-compile-func1483 */
-	obj_t BGl_z62backendzd2compilezd2func1483z62zzsaw_c_compilez00(obj_t
-		BgL_envz00_2511, obj_t BgL_mez00_2512)
+/* &backend-compile-func1425 */
+	obj_t BGl_z62backendzd2compilezd2func1425z62zzsaw_c_compilez00(obj_t
+		BgL_envz00_2470, obj_t BgL_mez00_2471)
 	{
 		{	/* SawC/compile.scm 48 */
 			BGl_forzd2eachzd2globalz12z12zzast_envz00
 				(BGl_setzd2variablezd2namez12zd2envzc0zzbackend_cplibz00, BNIL);
 			{	/* SawC/compile.scm 50 */
-				obj_t BgL_globalsz00_2517;
+				obj_t BgL_globalsz00_2476;
 
-				BgL_globalsz00_2517 =
+				BgL_globalsz00_2476 =
 					(((BgL_backendz00_bglt) COBJECT(
 							((BgL_backendz00_bglt)
-								((BgL_sawcz00_bglt) BgL_mez00_2512))))->BgL_functionsz00);
+								((BgL_sawcz00_bglt) BgL_mez00_2471))))->BgL_functionsz00);
 				BGl_sawzd2cheaderzd2zzsaw_c_codez00();
 				{
-					obj_t BgL_l1480z00_2519;
+					obj_t BgL_l1422z00_2478;
 
-					BgL_l1480z00_2519 = BgL_globalsz00_2517;
-				BgL_zc3z04anonymousza31530ze3z87_2518:
-					if (PAIRP(BgL_l1480z00_2519))
+					BgL_l1422z00_2478 = BgL_globalsz00_2476;
+				BgL_zc3z04anonymousza31491ze3z87_2477:
+					if (PAIRP(BgL_l1422z00_2478))
 						{	/* SawC/compile.scm 53 */
 							{	/* SawC/compile.scm 53 */
-								obj_t BgL_vz00_2520;
+								obj_t BgL_vz00_2479;
 
-								BgL_vz00_2520 = CAR(BgL_l1480z00_2519);
+								BgL_vz00_2479 = CAR(BgL_l1422z00_2478);
 								BGl_sawzd2cgenzd2zzsaw_c_codez00(
 									((BgL_cvmz00_bglt)
-										((BgL_sawcz00_bglt) BgL_mez00_2512)),
-									((BgL_globalz00_bglt) BgL_vz00_2520));
+										((BgL_sawcz00_bglt) BgL_mez00_2471)),
+									((BgL_globalz00_bglt) BgL_vz00_2479));
 							}
 							{
-								obj_t BgL_l1480z00_2549;
+								obj_t BgL_l1422z00_2508;
 
-								BgL_l1480z00_2549 = CDR(BgL_l1480z00_2519);
-								BgL_l1480z00_2519 = BgL_l1480z00_2549;
-								goto BgL_zc3z04anonymousza31530ze3z87_2518;
+								BgL_l1422z00_2508 = CDR(BgL_l1422z00_2478);
+								BgL_l1422z00_2478 = BgL_l1422z00_2508;
+								goto BgL_zc3z04anonymousza31491ze3z87_2477;
 							}
 						}
 					else
@@ -436,60 +452,60 @@ extern "C"
 	{
 		{	/* SawC/compile.scm 15 */
 			BGl_modulezd2initializa7ationz75zztools_speekz00(61247943L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zztools_errorz00(300504031L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zzengine_passz00(373082237L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zztools_tracez00(54713316L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zztools_shapez00(365925558L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
-			BGl_modulezd2initializa7ationz75zzengine_paramz00(517137079L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
+			BGl_modulezd2initializa7ationz75zzengine_paramz00(161876678L,
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zzengine_configurez00(272817175L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zzmodule_modulez00(158397907L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zzmodule_libraryz00(292140514L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zztype_typez00(515343395L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zzast_varz00(90839984L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zzast_nodez00(469732712L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zzast_occurz00(282085879L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zzast_buildz00(428035925L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zzast_envz00(146730773L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zzobject_classz00(502007119L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zzbdb_emitz00(182920176L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zzprof_emitz00(522750846L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zzbackend_backendz00(216206620L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zzbackend_initz00(517592975L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zzbackend_cvmz00(18449009L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
-			BGl_modulezd2initializa7ationz75zzbackend_c_emitz00(14466025L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
+			BGl_modulezd2initializa7ationz75zzbackend_c_emitz00(474089076L,
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zzbackend_c_prototypez00(364917963L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zzbackend_c_mainz00(65542503L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zzbackend_cplibz00(395792377L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			BGl_modulezd2initializa7ationz75zzobject_slotsz00(151271251L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 			return
 				BGl_modulezd2initializa7ationz75zzsaw_c_codez00(317462650L,
-				BSTRING_TO_STRING(BGl_string1736z00zzsaw_c_compilez00));
+				BSTRING_TO_STRING(BGl_string1726z00zzsaw_c_compilez00));
 		}
 
 	}
