@@ -1,9 +1,9 @@
 /*===========================================================================*/
 /*   (SawMill/rtl.scm)                                                       */
-/*   Bigloo (4.5b)                                                           */
-/*   Inria -- Sophia Antipolis (c)       Fri Dec 22 05:17:06 PM CET 2023     */
+/*   Bigloo (4.6a)                                                           */
+/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
 /*===========================================================================*/
-/* COMPILATION: (/home/serrano/prgm/project/bigloo/bigloo/bin/bigloo -ldopt -L/home/serrano/prgm/project/bigloo/bigloo/libbacktrace/home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b  -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent SawMill/rtl.scm) */
+/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent SawMill/rtl.scm) */
 /* GC selection */
 #define THE_GC BOEHM_GC
 
@@ -109,22 +109,22 @@ extern "C"
 	   
 		 
 		DEFINE_EXPORT_BGL_PROCEDURE(BGl_rtl_dfszd2envzd2zzsaw_rtlz00,
-		BgL_bgl_za762rtl_dfsza762za7za7s1831z00, BGl_z62rtl_dfsz62zzsaw_rtlz00, 0L,
+		BgL_bgl_za762rtl_dfsza762za7za7s1830z00, BGl_z62rtl_dfsz62zzsaw_rtlz00, 0L,
 		BUNSPEC, 3);
 	      DEFINE_EXPORT_BGL_PROCEDURE(BGl_namezd2envzd2zzsaw_rtlz00,
-		BgL_bgl_za762nameza762za7za7saw_1832z00, BGl_z62namez62zzsaw_rtlz00, 0L,
+		BgL_bgl_za762nameza762za7za7saw_1831z00, BGl_z62namez62zzsaw_rtlz00, 0L,
 		BUNSPEC, 1);
-	      DEFINE_STRING(BGl_string1827z00zzsaw_rtlz00,
-		BgL_bgl_string1827za700za7za7s1833za7, "must have only one successor", 28);
-	      DEFINE_STRING(BGl_string1828z00zzsaw_rtlz00,
-		BgL_bgl_string1828za700za7za7s1834za7, "saw_rtl", 7);
-	      DEFINE_STRING(BGl_string1829z00zzsaw_rtlz00,
-		BgL_bgl_string1829za700za7za7s1835za7, "unlink! (froms) -> (to) ", 24);
+	      DEFINE_STRING(BGl_string1824z00zzsaw_rtlz00,
+		BgL_bgl_string1824za700za7za7s1832za7, "must have only one successor", 28);
+	      DEFINE_STRING(BGl_string1825z00zzsaw_rtlz00,
+		BgL_bgl_string1825za700za7za7s1833za7, "saw_rtl", 7);
+	      DEFINE_STRING(BGl_string1826z00zzsaw_rtlz00,
+		BgL_bgl_string1826za700za7za7s1834za7, "unlink! (froms) -> (to) ", 24);
 	      DEFINE_EXPORT_BGL_PROCEDURE(BGl_neighbourszd2envzd2zzsaw_rtlz00,
-		BgL_bgl_za762neighboursza7621836z00, BGl_z62neighboursz62zzsaw_rtlz00, 0L,
+		BgL_bgl_za762neighboursza7621835z00, BGl_z62neighboursz62zzsaw_rtlz00, 0L,
 		BUNSPEC, 1);
 	      DEFINE_EXPORT_BGL_PROCEDURE(BGl_unlinkz12zd2envzc0zzsaw_rtlz00,
-		BgL_bgl_za762unlinkza712za770za71837z00, BGl_z62unlinkz12z70zzsaw_rtlz00,
+		BgL_bgl_za762unlinkza712za770za71836z00, BGl_z62unlinkz12z70zzsaw_rtlz00,
 		0L, BUNSPEC, 1);
 
 /* GC roots registration */
@@ -145,7 +145,7 @@ extern "C"
 
 /* module-initialization */
 	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zzsaw_rtlz00(long
-		BgL_checksumz00_2195, char *BgL_fromz00_2196)
+		BgL_checksumz00_2206, char *BgL_fromz00_2207)
 	{
 		{
 			if (CBOOL(BGl_requirezd2initializa7ationz75zzsaw_rtlz00))
@@ -193,71 +193,71 @@ extern "C"
 	{
 		{	/* SawMill/rtl.scm 1 */
 			{	/* SawMill/rtl.scm 1 */
-				obj_t BgL_cportz00_2184;
+				obj_t BgL_cportz00_2195;
 
 				{	/* SawMill/rtl.scm 1 */
-					obj_t BgL_stringz00_2191;
+					obj_t BgL_stringz00_2202;
 
-					BgL_stringz00_2191 = BGl_string1829z00zzsaw_rtlz00;
+					BgL_stringz00_2202 = BGl_string1826z00zzsaw_rtlz00;
 					{	/* SawMill/rtl.scm 1 */
-						obj_t BgL_startz00_2192;
+						obj_t BgL_startz00_2203;
 
-						BgL_startz00_2192 = BINT(0L);
+						BgL_startz00_2203 = BINT(0L);
 						{	/* SawMill/rtl.scm 1 */
-							obj_t BgL_endz00_2193;
+							obj_t BgL_endz00_2204;
 
-							BgL_endz00_2193 =
-								BINT(STRING_LENGTH(((obj_t) BgL_stringz00_2191)));
+							BgL_endz00_2204 =
+								BINT(STRING_LENGTH(((obj_t) BgL_stringz00_2202)));
 							{	/* SawMill/rtl.scm 1 */
 
-								BgL_cportz00_2184 =
+								BgL_cportz00_2195 =
 									BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00
-									(BgL_stringz00_2191, BgL_startz00_2192, BgL_endz00_2193);
+									(BgL_stringz00_2202, BgL_startz00_2203, BgL_endz00_2204);
 				}}}}
 				{
-					long BgL_iz00_2185;
+					long BgL_iz00_2196;
 
-					BgL_iz00_2185 = 3L;
-				BgL_loopz00_2186:
-					if ((BgL_iz00_2185 == -1L))
+					BgL_iz00_2196 = 3L;
+				BgL_loopz00_2197:
+					if ((BgL_iz00_2196 == (-1L)))
 						{	/* SawMill/rtl.scm 1 */
 							return BUNSPEC;
 						}
 					else
 						{	/* SawMill/rtl.scm 1 */
 							{	/* SawMill/rtl.scm 1 */
-								obj_t BgL_arg1830z00_2187;
+								obj_t BgL_arg1829z00_2198;
 
 								{	/* SawMill/rtl.scm 1 */
 
 									{	/* SawMill/rtl.scm 1 */
-										obj_t BgL_locationz00_2189;
+										obj_t BgL_locationz00_2200;
 
-										BgL_locationz00_2189 = BBOOL(((bool_t) 0));
+										BgL_locationz00_2200 = BBOOL(((bool_t) 0));
 										{	/* SawMill/rtl.scm 1 */
 
-											BgL_arg1830z00_2187 =
-												BGl_readz00zz__readerz00(BgL_cportz00_2184,
-												BgL_locationz00_2189);
+											BgL_arg1829z00_2198 =
+												BGl_readz00zz__readerz00(BgL_cportz00_2195,
+												BgL_locationz00_2200);
 										}
 									}
 								}
 								{	/* SawMill/rtl.scm 1 */
-									int BgL_tmpz00_2222;
+									int BgL_tmpz00_2233;
 
-									BgL_tmpz00_2222 = (int) (BgL_iz00_2185);
-									CNST_TABLE_SET(BgL_tmpz00_2222, BgL_arg1830z00_2187);
+									BgL_tmpz00_2233 = (int) (BgL_iz00_2196);
+									CNST_TABLE_SET(BgL_tmpz00_2233, BgL_arg1829z00_2198);
 							}}
 							{	/* SawMill/rtl.scm 1 */
-								int BgL_auxz00_2190;
+								int BgL_auxz00_2201;
 
-								BgL_auxz00_2190 = (int) ((BgL_iz00_2185 - 1L));
+								BgL_auxz00_2201 = (int) ((BgL_iz00_2196 - 1L));
 								{
-									long BgL_iz00_2227;
+									long BgL_iz00_2238;
 
-									BgL_iz00_2227 = (long) (BgL_auxz00_2190);
-									BgL_iz00_2185 = BgL_iz00_2227;
-									goto BgL_loopz00_2186;
+									BgL_iz00_2238 = (long) (BgL_auxz00_2201);
+									BgL_iz00_2196 = BgL_iz00_2238;
+									goto BgL_loopz00_2197;
 								}
 							}
 						}
@@ -286,29 +286,30 @@ extern "C"
 	{
 		{	/* SawMill/rtl.scm 21 */
 			{	/* SawMill/rtl.scm 22 */
-				obj_t BgL_arg1374z00_2140;
+				obj_t BgL_arg1380z00_2149;
 
 				{	/* SawMill/rtl.scm 22 */
-					BgL_rtl_funz00_bglt BgL_arg1375z00_2141;
+					BgL_rtl_funz00_bglt BgL_arg1382z00_2150;
 
-					BgL_arg1375z00_2141 =
+					BgL_arg1382z00_2150 =
 						(((BgL_rtl_insz00_bglt) COBJECT(BgL_insz00_3))->BgL_funz00);
 					{	/* SawMill/rtl.scm 22 */
-						long BgL_arg1808z00_2144;
+						obj_t BgL_arg1866z00_2153;
+						long BgL_arg1867z00_2154;
 
+						BgL_arg1866z00_2153 = (BGl_za2classesza2z00zz__objectz00);
 						{	/* SawMill/rtl.scm 22 */
-							long BgL_arg1809z00_2145;
+							long BgL_arg1869z00_2155;
 
-							BgL_arg1809z00_2145 =
+							BgL_arg1869z00_2155 =
 								BGL_OBJECT_CLASS_NUM(
-								((BgL_objectz00_bglt) BgL_arg1375z00_2141));
-							BgL_arg1808z00_2144 = (BgL_arg1809z00_2145 - OBJECT_TYPE);
+								((BgL_objectz00_bglt) BgL_arg1382z00_2150));
+							BgL_arg1867z00_2154 = (BgL_arg1869z00_2155 - OBJECT_TYPE);
 						}
-						BgL_arg1374z00_2140 =
-							VECTOR_REF(BGl_za2classesza2z00zz__objectz00,
-							BgL_arg1808z00_2144);
+						BgL_arg1380z00_2149 =
+							VECTOR_REF(BgL_arg1866z00_2153, BgL_arg1867z00_2154);
 				}}
-				return BGl_classzd2namezd2zz__objectz00(BgL_arg1374z00_2140);
+				return BGl_classzd2namezd2zz__objectz00(BgL_arg1380z00_2149);
 			}
 		}
 
@@ -317,10 +318,10 @@ extern "C"
 
 
 /* &name */
-	obj_t BGl_z62namez62zzsaw_rtlz00(obj_t BgL_envz00_2174, obj_t BgL_insz00_2175)
+	obj_t BGl_z62namez62zzsaw_rtlz00(obj_t BgL_envz00_2185, obj_t BgL_insz00_2186)
 	{
 		{	/* SawMill/rtl.scm 21 */
-			return BGl_namez00zzsaw_rtlz00(((BgL_rtl_insz00_bglt) BgL_insz00_2175));
+			return BGl_namez00zzsaw_rtlz00(((BgL_rtl_insz00_bglt) BgL_insz00_2186));
 		}
 
 	}
@@ -333,64 +334,67 @@ extern "C"
 	{
 		{	/* SawMill/rtl.scm 27 */
 			{	/* SawMill/rtl.scm 31 */
-				obj_t BgL_arg1376z00_1798;
+				obj_t BgL_arg1383z00_1807;
 
 				{	/* SawMill/rtl.scm 22 */
-					obj_t BgL_arg1374z00_2152;
+					obj_t BgL_arg1380z00_2162;
 
 					{	/* SawMill/rtl.scm 22 */
-						BgL_rtl_funz00_bglt BgL_arg1375z00_2153;
+						BgL_rtl_funz00_bglt BgL_arg1382z00_2163;
 
-						BgL_arg1375z00_2153 =
+						BgL_arg1382z00_2163 =
 							(((BgL_rtl_insz00_bglt) COBJECT(BgL_insz00_4))->BgL_funz00);
 						{	/* SawMill/rtl.scm 22 */
-							long BgL_arg1808z00_2156;
+							obj_t BgL_arg1866z00_2166;
+							long BgL_arg1867z00_2167;
 
+							BgL_arg1866z00_2166 = (BGl_za2classesza2z00zz__objectz00);
 							{	/* SawMill/rtl.scm 22 */
-								long BgL_arg1809z00_2157;
+								long BgL_arg1869z00_2168;
 
-								BgL_arg1809z00_2157 =
+								BgL_arg1869z00_2168 =
 									BGL_OBJECT_CLASS_NUM(
-									((BgL_objectz00_bglt) BgL_arg1375z00_2153));
-								BgL_arg1808z00_2156 = (BgL_arg1809z00_2157 - OBJECT_TYPE);
+									((BgL_objectz00_bglt) BgL_arg1382z00_2163));
+								BgL_arg1867z00_2167 = (BgL_arg1869z00_2168 - OBJECT_TYPE);
 							}
-							BgL_arg1374z00_2152 =
-								VECTOR_REF(BGl_za2classesza2z00zz__objectz00,
-								BgL_arg1808z00_2156);
+							BgL_arg1380z00_2162 =
+								VECTOR_REF(BgL_arg1866z00_2166, BgL_arg1867z00_2167);
 					}}
-					BgL_arg1376z00_1798 =
-						BGl_classzd2namezd2zz__objectz00(BgL_arg1374z00_2152);
+					BgL_arg1383z00_1807 =
+						BGl_classzd2namezd2zz__objectz00(BgL_arg1380z00_2162);
 				}
 				{	/* SawMill/rtl.scm 29 */
-					obj_t BgL_list1377z00_1799;
+					obj_t BgL_list1384z00_1808;
 
 					{	/* SawMill/rtl.scm 29 */
-						obj_t BgL_arg1379z00_1800;
+						obj_t BgL_arg1385z00_1809;
 
 						{	/* SawMill/rtl.scm 29 */
-							obj_t BgL_arg1397z00_1801;
+							obj_t BgL_arg1386z00_1810;
 
 							{	/* SawMill/rtl.scm 29 */
-								obj_t BgL_arg1407z00_1802;
+								obj_t BgL_arg1388z00_1811;
 
 								{	/* SawMill/rtl.scm 29 */
-									obj_t BgL_arg1408z00_1803;
+									obj_t BgL_arg1390z00_1812;
 
-									BgL_arg1408z00_1803 =
-										MAKE_YOUNG_PAIR(CNST_TABLE_REF(0L), BNIL);
-									BgL_arg1407z00_1802 =
-										MAKE_YOUNG_PAIR(CNST_TABLE_REF(1L), BgL_arg1408z00_1803);
+									BgL_arg1390z00_1812 =
+										MAKE_YOUNG_PAIR(((obj_t) CNST_TABLE_REF(0)), BNIL);
+									BgL_arg1388z00_1811 =
+										MAKE_YOUNG_PAIR(
+										((obj_t) CNST_TABLE_REF(1)), BgL_arg1390z00_1812);
 								}
-								BgL_arg1397z00_1801 =
-									MAKE_YOUNG_PAIR(BgL_arg1376z00_1798, BgL_arg1407z00_1802);
+								BgL_arg1386z00_1810 =
+									MAKE_YOUNG_PAIR(BgL_arg1383z00_1807, BgL_arg1388z00_1811);
 							}
-							BgL_arg1379z00_1800 =
-								MAKE_YOUNG_PAIR(CNST_TABLE_REF(1L), BgL_arg1397z00_1801);
+							BgL_arg1385z00_1809 =
+								MAKE_YOUNG_PAIR(
+								((obj_t) CNST_TABLE_REF(1)), BgL_arg1386z00_1810);
 						}
-						BgL_list1377z00_1799 =
-							MAKE_YOUNG_PAIR(CNST_TABLE_REF(2L), BgL_arg1379z00_1800);
+						BgL_list1384z00_1808 =
+							MAKE_YOUNG_PAIR(((obj_t) CNST_TABLE_REF(2)), BgL_arg1385z00_1809);
 					}
-					return BgL_list1377z00_1799;
+					return BgL_list1384z00_1808;
 				}
 			}
 		}
@@ -400,12 +404,12 @@ extern "C"
 
 
 /* &neighbours */
-	obj_t BGl_z62neighboursz62zzsaw_rtlz00(obj_t BgL_envz00_2176,
-		obj_t BgL_insz00_2177)
+	obj_t BGl_z62neighboursz62zzsaw_rtlz00(obj_t BgL_envz00_2187,
+		obj_t BgL_insz00_2188)
 	{
 		{	/* SawMill/rtl.scm 27 */
 			return
-				BGl_neighboursz00zzsaw_rtlz00(((BgL_rtl_insz00_bglt) BgL_insz00_2177));
+				BGl_neighboursz00zzsaw_rtlz00(((BgL_rtl_insz00_bglt) BgL_insz00_2188));
 		}
 
 	}
@@ -418,24 +422,26 @@ extern "C"
 	{
 		{	/* SawMill/rtl.scm 39 */
 			{	/* SawMill/rtl.scm 41 */
-				bool_t BgL_test1840z00_2255;
+				bool_t BgL_test1839z00_2272;
 
 				if (NULLP((((BgL_blockz00_bglt) COBJECT(BgL_bz00_5))->BgL_succsz00)))
 					{	/* SawMill/rtl.scm 41 */
-						BgL_test1840z00_2255 = ((bool_t) 1);
+						BgL_test1839z00_2272 = ((bool_t) 1);
 					}
 				else
 					{	/* SawMill/rtl.scm 41 */
-						obj_t BgL_tmpz00_2259;
+						obj_t BgL_tmpz00_2276;
 
-						BgL_tmpz00_2259 =
+						BgL_tmpz00_2276 =
 							CDR((((BgL_blockz00_bglt) COBJECT(BgL_bz00_5))->BgL_succsz00));
-						BgL_test1840z00_2255 = PAIRP(BgL_tmpz00_2259);
+						BgL_test1839z00_2272 = PAIRP(BgL_tmpz00_2276);
 					}
-				if (BgL_test1840z00_2255)
+				if (BgL_test1839z00_2272)
 					{	/* SawMill/rtl.scm 41 */
-						BGl_errorz00zz__errorz00(CNST_TABLE_REF(3L),
-							BGl_string1827z00zzsaw_rtlz00, ((obj_t) BgL_bz00_5));
+						BGl_errorz00zz__errorz00(
+							((obj_t)
+								CNST_TABLE_REF(3)), BGl_string1824z00zzsaw_rtlz00,
+							((obj_t) BgL_bz00_5));
 					}
 				else
 					{	/* SawMill/rtl.scm 41 */
@@ -443,51 +449,51 @@ extern "C"
 					}
 			}
 			{	/* SawMill/rtl.scm 43 */
-				obj_t BgL_sz00_1815;
+				obj_t BgL_sz00_1824;
 
-				BgL_sz00_1815 =
+				BgL_sz00_1824 =
 					CAR((((BgL_blockz00_bglt) COBJECT(BgL_bz00_5))->BgL_succsz00));
 				{	/* SawMill/rtl.scm 44 */
-					obj_t BgL_g1367z00_1816;
+					obj_t BgL_g1368z00_1825;
 
-					BgL_g1367z00_1816 =
+					BgL_g1368z00_1825 =
 						(((BgL_blockz00_bglt) COBJECT(BgL_bz00_5))->BgL_predsz00);
 					{
-						obj_t BgL_l1365z00_1818;
+						obj_t BgL_l1366z00_1827;
 
-						BgL_l1365z00_1818 = BgL_g1367z00_1816;
-					BgL_zc3z04anonymousza31453ze3z87_1819:
-						if (PAIRP(BgL_l1365z00_1818))
+						BgL_l1366z00_1827 = BgL_g1368z00_1825;
+					BgL_zc3z04anonymousza31416ze3z87_1828:
+						if (PAIRP(BgL_l1366z00_1827))
 							{	/* SawMill/rtl.scm 44 */
 								{	/* SawMill/rtl.scm 44 */
-									obj_t BgL_pz00_1821;
+									obj_t BgL_pz00_1830;
 
-									BgL_pz00_1821 = CAR(BgL_l1365z00_1818);
+									BgL_pz00_1830 = CAR(BgL_l1366z00_1827);
 									{
-										obj_t BgL_auxz00_2272;
+										obj_t BgL_auxz00_2290;
 
 										{	/* SawMill/rtl.scm 45 */
-											obj_t BgL_arg1479z00_1823;
+											obj_t BgL_arg1446z00_1832;
 
-											BgL_arg1479z00_1823 =
+											BgL_arg1446z00_1832 =
 												(((BgL_blockz00_bglt) COBJECT(
-														((BgL_blockz00_bglt) BgL_pz00_1821)))->
+														((BgL_blockz00_bglt) BgL_pz00_1830)))->
 												BgL_succsz00);
-											BgL_auxz00_2272 =
-												BGl_substz00zzsaw_libz00(BgL_arg1479z00_1823,
-												((obj_t) BgL_bz00_5), BgL_sz00_1815);
+											BgL_auxz00_2290 =
+												BGl_substz00zzsaw_libz00(BgL_arg1446z00_1832,
+												((obj_t) BgL_bz00_5), BgL_sz00_1824);
 										}
 										((((BgL_blockz00_bglt) COBJECT(
-														((BgL_blockz00_bglt) BgL_pz00_1821)))->
-												BgL_succsz00) = ((obj_t) BgL_auxz00_2272), BUNSPEC);
+														((BgL_blockz00_bglt) BgL_pz00_1830)))->
+												BgL_succsz00) = ((obj_t) BgL_auxz00_2290), BUNSPEC);
 									}
 								}
 								{
-									obj_t BgL_l1365z00_2279;
+									obj_t BgL_l1366z00_2297;
 
-									BgL_l1365z00_2279 = CDR(BgL_l1365z00_1818);
-									BgL_l1365z00_1818 = BgL_l1365z00_2279;
-									goto BgL_zc3z04anonymousza31453ze3z87_1819;
+									BgL_l1366z00_2297 = CDR(BgL_l1366z00_1827);
+									BgL_l1366z00_1827 = BgL_l1366z00_2297;
+									goto BgL_zc3z04anonymousza31416ze3z87_1828;
 								}
 							}
 						else
@@ -497,25 +503,25 @@ extern "C"
 					}
 				}
 				{	/* SawMill/rtl.scm 47 */
-					obj_t BgL_arg1492z00_1826;
+					obj_t BgL_arg1471z00_1835;
 
 					{	/* SawMill/rtl.scm 47 */
-						obj_t BgL_arg1494z00_1827;
-						obj_t BgL_arg1496z00_1828;
+						obj_t BgL_arg1480z00_1836;
+						obj_t BgL_arg1484z00_1837;
 
-						BgL_arg1494z00_1827 =
+						BgL_arg1480z00_1836 =
 							(((BgL_blockz00_bglt) COBJECT(
-									((BgL_blockz00_bglt) BgL_sz00_1815)))->BgL_predsz00);
-						BgL_arg1496z00_1828 =
+									((BgL_blockz00_bglt) BgL_sz00_1824)))->BgL_predsz00);
+						BgL_arg1484z00_1837 =
 							(((BgL_blockz00_bglt) COBJECT(BgL_bz00_5))->BgL_predsz00);
-						BgL_arg1492z00_1826 =
-							BGl_substzd2appendzd2zzsaw_libz00(BgL_arg1494z00_1827,
-							((obj_t) BgL_bz00_5), BgL_arg1496z00_1828);
+						BgL_arg1471z00_1835 =
+							BGl_substzd2appendzd2zzsaw_libz00(BgL_arg1480z00_1836,
+							((obj_t) BgL_bz00_5), BgL_arg1484z00_1837);
 					}
 					return
 						((((BgL_blockz00_bglt) COBJECT(
-									((BgL_blockz00_bglt) BgL_sz00_1815)))->BgL_predsz00) =
-						((obj_t) BgL_arg1492z00_1826), BUNSPEC);
+									((BgL_blockz00_bglt) BgL_sz00_1824)))->BgL_predsz00) =
+						((obj_t) BgL_arg1471z00_1835), BUNSPEC);
 				}
 			}
 		}
@@ -525,11 +531,11 @@ extern "C"
 
 
 /* &unlink! */
-	obj_t BGl_z62unlinkz12z70zzsaw_rtlz00(obj_t BgL_envz00_2178,
-		obj_t BgL_bz00_2179)
+	obj_t BGl_z62unlinkz12z70zzsaw_rtlz00(obj_t BgL_envz00_2189,
+		obj_t BgL_bz00_2190)
 	{
 		{	/* SawMill/rtl.scm 39 */
-			return BGl_unlinkz12z12zzsaw_rtlz00(((BgL_blockz00_bglt) BgL_bz00_2179));
+			return BGl_unlinkz12z12zzsaw_rtlz00(((BgL_blockz00_bglt) BgL_bz00_2190));
 		}
 
 	}
@@ -541,62 +547,51 @@ extern "C"
 		BgL_bz00_7, obj_t BgL_visitz00_8, obj_t BgL_visitzf3zf3_9)
 	{
 		{	/* SawMill/rtl.scm 89 */
-			(VA_PROCEDUREP(BgL_visitz00_8) ? ((obj_t(*)(obj_t,
-							...)) PROCEDURE_ENTRY(BgL_visitz00_8)) (BgL_visitz00_8,
-					((obj_t) BgL_bz00_7), BEOA) : ((obj_t(*)(obj_t,
-							obj_t)) PROCEDURE_ENTRY(BgL_visitz00_8)) (BgL_visitz00_8,
-					((obj_t) BgL_bz00_7)));
+			BGL_PROCEDURE_CALL1(BgL_visitz00_8, ((obj_t) BgL_bz00_7));
 			{	/* SawMill/rtl.scm 91 */
-				obj_t BgL_g1370z00_1834;
+				obj_t BgL_g1371z00_1843;
 
-				BgL_g1370z00_1834 =
+				BgL_g1371z00_1843 =
 					(((BgL_blockz00_bglt) COBJECT(BgL_bz00_7))->BgL_succsz00);
 				{
-					obj_t BgL_l1368z00_1836;
+					obj_t BgL_l1369z00_1845;
 
 					{	/* SawMill/rtl.scm 93 */
-						bool_t BgL_tmpz00_2296;
+						bool_t BgL_tmpz00_2314;
 
-						BgL_l1368z00_1836 = BgL_g1370z00_1834;
-					BgL_zc3z04anonymousza31520ze3z87_1837:
-						if (PAIRP(BgL_l1368z00_1836))
+						BgL_l1369z00_1845 = BgL_g1371z00_1843;
+					BgL_zc3z04anonymousza31490ze3z87_1846:
+						if (PAIRP(BgL_l1369z00_1845))
 							{	/* SawMill/rtl.scm 93 */
 								{	/* SawMill/rtl.scm 92 */
-									obj_t BgL_succz00_1839;
+									obj_t BgL_succz00_1848;
 
-									BgL_succz00_1839 = CAR(BgL_l1368z00_1836);
-									if (CBOOL(
-											(VA_PROCEDUREP(BgL_visitzf3zf3_9) ? ((obj_t(*)(obj_t,
-															...))
-													PROCEDURE_ENTRY(BgL_visitzf3zf3_9))
-												(BgL_visitzf3zf3_9, BgL_succz00_1839,
-													BEOA) : ((obj_t(*)(obj_t,
-															obj_t))
-													PROCEDURE_ENTRY(BgL_visitzf3zf3_9))
-												(BgL_visitzf3zf3_9, BgL_succz00_1839))))
+									BgL_succz00_1848 = CAR(BgL_l1369z00_1845);
+									if (CBOOL(BGL_PROCEDURE_CALL1(BgL_visitzf3zf3_9,
+												BgL_succz00_1848)))
 										{	/* SawMill/rtl.scm 92 */
 											BFALSE;
 										}
 									else
 										{	/* SawMill/rtl.scm 92 */
 											BGl_rtl_dfsz00zzsaw_rtlz00(
-												((BgL_blockz00_bglt) BgL_succz00_1839), BgL_visitz00_8,
+												((BgL_blockz00_bglt) BgL_succz00_1848), BgL_visitz00_8,
 												BgL_visitzf3zf3_9);
 										}
 								}
 								{
-									obj_t BgL_l1368z00_2308;
+									obj_t BgL_l1369z00_2326;
 
-									BgL_l1368z00_2308 = CDR(BgL_l1368z00_1836);
-									BgL_l1368z00_1836 = BgL_l1368z00_2308;
-									goto BgL_zc3z04anonymousza31520ze3z87_1837;
+									BgL_l1369z00_2326 = CDR(BgL_l1369z00_1845);
+									BgL_l1369z00_1845 = BgL_l1369z00_2326;
+									goto BgL_zc3z04anonymousza31490ze3z87_1846;
 								}
 							}
 						else
 							{	/* SawMill/rtl.scm 93 */
-								BgL_tmpz00_2296 = ((bool_t) 1);
+								BgL_tmpz00_2314 = ((bool_t) 1);
 							}
-						return BBOOL(BgL_tmpz00_2296);
+						return BBOOL(BgL_tmpz00_2314);
 					}
 				}
 			}
@@ -607,14 +602,14 @@ extern "C"
 
 
 /* &rtl_dfs */
-	obj_t BGl_z62rtl_dfsz62zzsaw_rtlz00(obj_t BgL_envz00_2180,
-		obj_t BgL_bz00_2181, obj_t BgL_visitz00_2182, obj_t BgL_visitzf3zf3_2183)
+	obj_t BGl_z62rtl_dfsz62zzsaw_rtlz00(obj_t BgL_envz00_2191,
+		obj_t BgL_bz00_2192, obj_t BgL_visitz00_2193, obj_t BgL_visitzf3zf3_2194)
 	{
 		{	/* SawMill/rtl.scm 89 */
 			return
 				BGl_rtl_dfsz00zzsaw_rtlz00(
-				((BgL_blockz00_bglt) BgL_bz00_2181), BgL_visitz00_2182,
-				BgL_visitzf3zf3_2183);
+				((BgL_blockz00_bglt) BgL_bz00_2192), BgL_visitz00_2193,
+				BgL_visitzf3zf3_2194);
 		}
 
 	}
@@ -659,16 +654,16 @@ extern "C"
 	{
 		{	/* SawMill/rtl.scm 1 */
 			BGl_modulezd2initializa7ationz75zztype_typez00(515343395L,
-				BSTRING_TO_STRING(BGl_string1828z00zzsaw_rtlz00));
+				BSTRING_TO_STRING(BGl_string1825z00zzsaw_rtlz00));
 			BGl_modulezd2initializa7ationz75zzast_varz00(90839984L,
-				BSTRING_TO_STRING(BGl_string1828z00zzsaw_rtlz00));
+				BSTRING_TO_STRING(BGl_string1825z00zzsaw_rtlz00));
 			BGl_modulezd2initializa7ationz75zzast_nodez00(469732712L,
-				BSTRING_TO_STRING(BGl_string1828z00zzsaw_rtlz00));
+				BSTRING_TO_STRING(BGl_string1825z00zzsaw_rtlz00));
 			BGl_modulezd2initializa7ationz75zzsaw_libz00(57049157L,
-				BSTRING_TO_STRING(BGl_string1828z00zzsaw_rtlz00));
+				BSTRING_TO_STRING(BGl_string1825z00zzsaw_rtlz00));
 			return
 				BGl_modulezd2initializa7ationz75zzsaw_defsz00(404844772L,
-				BSTRING_TO_STRING(BGl_string1828z00zzsaw_rtlz00));
+				BSTRING_TO_STRING(BGl_string1825z00zzsaw_rtlz00));
 		}
 
 	}
