@@ -1,9 +1,9 @@
 /*===========================================================================*/
 /*   (SawMill/woodcutter.scm)                                                */
-/*   Bigloo (4.5b)                                                           */
-/*   Inria -- Sophia Antipolis (c)       Fri Dec 22 05:17:06 PM CET 2023     */
+/*   Bigloo (4.6a)                                                           */
+/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
 /*===========================================================================*/
-/* COMPILATION: (/home/serrano/prgm/project/bigloo/bigloo/bin/bigloo -ldopt -L/home/serrano/prgm/project/bigloo/bigloo/libbacktrace/home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b  -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent SawMill/woodcutter.scm) */
+/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent SawMill/woodcutter.scm) */
 /* GC selection */
 #define THE_GC BOEHM_GC
 
@@ -38,6 +38,7 @@ extern "C"
 		obj_t BgL_parentsz00;
 		bool_t BgL_initzf3zf3;
 		bool_t BgL_magiczf3zf3;
+		obj_t BgL_nullz00;
 		obj_t BgL_z42z42;
 		obj_t BgL_aliasz00;
 		obj_t BgL_pointedzd2tozd2byz00;
@@ -90,7 +91,7 @@ extern "C"
 		obj_t BgL_libraryz00;
 		obj_t BgL_pragmaz00;
 		obj_t BgL_srcz00;
-		obj_t BgL_jvmzd2typezd2namez00;
+		obj_t BgL_qualifiedzd2typezd2namez00;
 		obj_t BgL_initz00;
 		obj_t BgL_aliasz00;
 	}                *BgL_globalz00_bglt;
@@ -175,6 +176,11 @@ extern "C"
 		bool_t BgL_boundzd2checkzd2;
 		bool_t BgL_typezd2checkzd2;
 		bool_t BgL_typedzd2funcallzd2;
+		bool_t BgL_strictzd2typezd2castz00;
+		bool_t BgL_forcezd2registerzd2gczd2rootszd2;
+		bool_t BgL_stringzd2literalzd2supportz00;
+		bool_t BgL_boxedzd2fixnumszd2;
+		bool_t BgL_typedzd2closureszd2;
 	}                 *BgL_backendz00_bglt;
 
 	typedef struct BgL_rtl_regz00_bgl
@@ -265,12 +271,12 @@ extern "C"
 
 	   
 		 
-		DEFINE_STRING(BGl_string1835z00zzsaw_woodcutterz00,
-		BgL_bgl_string1835za700za7za7s1836za7, "saw_woodcutter", 14);
+		DEFINE_STRING(BGl_string1819z00zzsaw_woodcutterz00,
+		BgL_bgl_string1819za700za7za7s1820za7, "saw_woodcutter", 14);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_globalzd2ze3blockszd2envze3zzsaw_woodcutterz00,
-		BgL_bgl_za762globalza7d2za7e3b1837za7,
+		BgL_bgl_za762globalza7d2za7e3b1821za7,
 		BGl_z62globalzd2ze3blocksz53zzsaw_woodcutterz00, 0L, BUNSPEC, 2);
 
 /* GC roots registration */
@@ -294,7 +300,7 @@ extern "C"
 /* module-initialization */
 	BGL_EXPORTED_DEF obj_t
 		BGl_modulezd2initializa7ationz75zzsaw_woodcutterz00(long
-		BgL_checksumz00_2532, char *BgL_fromz00_2533)
+		BgL_checksumz00_2495, char *BgL_fromz00_2496)
 	{
 		{
 			if (CBOOL(BGl_requirezd2initializa7ationz75zzsaw_woodcutterz00))
@@ -365,89 +371,89 @@ extern "C"
 	{
 		{	/* SawMill/woodcutter.scm 35 */
 			{	/* SawMill/woodcutter.scm 39 */
-				BgL_blockz00_bglt BgL_bz00_2112;
-				obj_t BgL_argsz00_2113;
+				BgL_blockz00_bglt BgL_bz00_2133;
+				obj_t BgL_argsz00_2134;
 
-				BgL_bz00_2112 = BGl_globalzd2ze3rtlz31zzsaw_node2rtlz00(BgL_vz00_4);
+				BgL_bz00_2133 = BGl_globalzd2ze3rtlz31zzsaw_node2rtlz00(BgL_vz00_4);
 				{	/* SawMill/woodcutter.scm 40 */
-					obj_t BgL_l1434z00_2124;
+					obj_t BgL_l1379z00_2145;
 
-					BgL_l1434z00_2124 =
+					BgL_l1379z00_2145 =
 						(((BgL_sfunz00_bglt) COBJECT(
 								((BgL_sfunz00_bglt)
 									(((BgL_variablez00_bglt) COBJECT(
 												((BgL_variablez00_bglt) BgL_vz00_4)))->
 										BgL_valuez00))))->BgL_argsz00);
-					if (NULLP(BgL_l1434z00_2124))
+					if (NULLP(BgL_l1379z00_2145))
 						{	/* SawMill/woodcutter.scm 40 */
-							BgL_argsz00_2113 = BNIL;
+							BgL_argsz00_2134 = BNIL;
 						}
 					else
 						{	/* SawMill/woodcutter.scm 40 */
-							obj_t BgL_head1436z00_2126;
+							obj_t BgL_head1381z00_2147;
 
 							{	/* SawMill/woodcutter.scm 40 */
-								BgL_rtl_regz00_bglt BgL_arg1528z00_2138;
+								BgL_rtl_regz00_bglt BgL_arg1417z00_2159;
 
 								{	/* SawMill/woodcutter.scm 40 */
-									obj_t BgL_arg1532z00_2139;
+									obj_t BgL_arg1418z00_2160;
 
-									BgL_arg1532z00_2139 = CAR(((obj_t) BgL_l1434z00_2124));
-									BgL_arg1528z00_2138 =
+									BgL_arg1418z00_2160 = CAR(((obj_t) BgL_l1379z00_2145));
+									BgL_arg1417z00_2159 =
 										BGl_localzd2ze3regz31zzsaw_node2rtlz00(
-										((BgL_localz00_bglt) BgL_arg1532z00_2139));
+										((BgL_localz00_bglt) BgL_arg1418z00_2160));
 								}
-								BgL_head1436z00_2126 =
-									MAKE_YOUNG_PAIR(((obj_t) BgL_arg1528z00_2138), BNIL);
+								BgL_head1381z00_2147 =
+									MAKE_YOUNG_PAIR(((obj_t) BgL_arg1417z00_2159), BNIL);
 							}
 							{	/* SawMill/woodcutter.scm 40 */
-								obj_t BgL_g1439z00_2127;
+								obj_t BgL_g1384z00_2148;
 
-								BgL_g1439z00_2127 = CDR(((obj_t) BgL_l1434z00_2124));
+								BgL_g1384z00_2148 = CDR(((obj_t) BgL_l1379z00_2145));
 								{
-									obj_t BgL_l1434z00_2129;
-									obj_t BgL_tail1437z00_2130;
+									obj_t BgL_l1379z00_2150;
+									obj_t BgL_tail1382z00_2151;
 
-									BgL_l1434z00_2129 = BgL_g1439z00_2127;
-									BgL_tail1437z00_2130 = BgL_head1436z00_2126;
-								BgL_zc3z04anonymousza31494ze3z87_2131:
-									if (NULLP(BgL_l1434z00_2129))
+									BgL_l1379z00_2150 = BgL_g1384z00_2148;
+									BgL_tail1382z00_2151 = BgL_head1381z00_2147;
+								BgL_zc3z04anonymousza31405ze3z87_2152:
+									if (NULLP(BgL_l1379z00_2150))
 										{	/* SawMill/woodcutter.scm 40 */
-											BgL_argsz00_2113 = BgL_head1436z00_2126;
+											BgL_argsz00_2134 = BgL_head1381z00_2147;
 										}
 									else
 										{	/* SawMill/woodcutter.scm 40 */
-											obj_t BgL_newtail1438z00_2133;
+											obj_t BgL_newtail1383z00_2154;
 
 											{	/* SawMill/woodcutter.scm 40 */
-												BgL_rtl_regz00_bglt BgL_arg1497z00_2135;
+												BgL_rtl_regz00_bglt BgL_arg1415z00_2156;
 
 												{	/* SawMill/woodcutter.scm 40 */
-													obj_t BgL_arg1519z00_2136;
+													obj_t BgL_arg1416z00_2157;
 
-													BgL_arg1519z00_2136 =
-														CAR(((obj_t) BgL_l1434z00_2129));
-													BgL_arg1497z00_2135 =
+													BgL_arg1416z00_2157 =
+														CAR(((obj_t) BgL_l1379z00_2150));
+													BgL_arg1415z00_2156 =
 														BGl_localzd2ze3regz31zzsaw_node2rtlz00(
-														((BgL_localz00_bglt) BgL_arg1519z00_2136));
+														((BgL_localz00_bglt) BgL_arg1416z00_2157));
 												}
-												BgL_newtail1438z00_2133 =
-													MAKE_YOUNG_PAIR(((obj_t) BgL_arg1497z00_2135), BNIL);
+												BgL_newtail1383z00_2154 =
+													MAKE_YOUNG_PAIR(((obj_t) BgL_arg1415z00_2156), BNIL);
 											}
-											SET_CDR(BgL_tail1437z00_2130, BgL_newtail1438z00_2133);
+											SET_CDR(BgL_tail1382z00_2151, BgL_newtail1383z00_2154);
 											{	/* SawMill/woodcutter.scm 40 */
-												obj_t BgL_arg1496z00_2134;
+												obj_t BgL_arg1414z00_2155;
 
-												BgL_arg1496z00_2134 = CDR(((obj_t) BgL_l1434z00_2129));
+												BgL_arg1414z00_2155 = CDR(((obj_t) BgL_l1379z00_2150));
 												{
-													obj_t BgL_tail1437z00_2572;
-													obj_t BgL_l1434z00_2571;
+													obj_t BgL_tail1382z00_2535;
+													obj_t BgL_l1379z00_2534;
 
-													BgL_l1434z00_2571 = BgL_arg1496z00_2134;
-													BgL_tail1437z00_2572 = BgL_newtail1438z00_2133;
-													BgL_tail1437z00_2130 = BgL_tail1437z00_2572;
-													BgL_l1434z00_2129 = BgL_l1434z00_2571;
-													goto BgL_zc3z04anonymousza31494ze3z87_2131;
+													BgL_l1379z00_2534 = BgL_arg1414z00_2155;
+													BgL_tail1382z00_2535 = BgL_newtail1383z00_2154;
+													BgL_tail1382z00_2151 = BgL_tail1382z00_2535;
+													BgL_l1379z00_2150 = BgL_l1379z00_2534;
+													goto BgL_zc3z04anonymousza31405ze3z87_2152;
 												}
 											}
 										}
@@ -455,44 +461,44 @@ extern "C"
 							}
 						}
 				}
-				BGl_collapsez00zzsaw_collapsez00(BgL_bz00_2112);
-				BgL_bz00_2112 = BGl_removez00zzsaw_removez00(BgL_bz00_2112);
-				BGl_inlinezd2returnszd2zzsaw_inline_returnz00(BgL_bz00_2112);
+				BGl_collapsez00zzsaw_collapsez00(BgL_bz00_2133);
+				BgL_bz00_2133 = BGl_removez00zzsaw_removez00(BgL_bz00_2133);
+				BGl_inlinezd2returnszd2zzsaw_inline_returnz00(BgL_bz00_2133);
 				{	/* SawMill/woodcutter.scm 44 */
-					obj_t BgL_lz00_2114;
+					obj_t BgL_lz00_2135;
 
-					BgL_lz00_2114 =
-						BGl_blockzd2orderingzd2zzsaw_blockorderz00(BgL_bz00_2112);
+					BgL_lz00_2135 =
+						BGl_blockzd2orderingzd2zzsaw_blockorderz00(BgL_bz00_2133);
 					{
-						long BgL_iz00_2116;
-						obj_t BgL_lz00_2117;
+						long BgL_iz00_2137;
+						obj_t BgL_lz00_2138;
 
-						BgL_iz00_2116 = 0L;
-						BgL_lz00_2117 = BgL_lz00_2114;
-					BgL_zc3z04anonymousza31452ze3z87_2118:
-						if (PAIRP(BgL_lz00_2117))
+						BgL_iz00_2137 = 0L;
+						BgL_lz00_2138 = BgL_lz00_2135;
+					BgL_zc3z04anonymousza31391ze3z87_2139:
+						if (PAIRP(BgL_lz00_2138))
 							{	/* SawMill/woodcutter.scm 46 */
 								{	/* SawMill/woodcutter.scm 47 */
-									obj_t BgL_arg1479z00_2120;
+									obj_t BgL_arg1400z00_2141;
 
-									BgL_arg1479z00_2120 = CAR(BgL_lz00_2117);
+									BgL_arg1400z00_2141 = CAR(BgL_lz00_2138);
 									{	/* SawMill/woodcutter.scm 47 */
-										int BgL_vz00_2526;
+										int BgL_vz00_2489;
 
-										BgL_vz00_2526 = (int) (BgL_iz00_2116);
+										BgL_vz00_2489 = (int) (BgL_iz00_2137);
 										((((BgL_blockz00_bglt) COBJECT(
-														((BgL_blockz00_bglt) BgL_arg1479z00_2120)))->
-												BgL_labelz00) = ((int) BgL_vz00_2526), BUNSPEC);
+														((BgL_blockz00_bglt) BgL_arg1400z00_2141)))->
+												BgL_labelz00) = ((int) BgL_vz00_2489), BUNSPEC);
 								}}
 								{
-									obj_t BgL_lz00_2585;
-									long BgL_iz00_2583;
+									obj_t BgL_lz00_2548;
+									long BgL_iz00_2546;
 
-									BgL_iz00_2583 = (BgL_iz00_2116 + 1L);
-									BgL_lz00_2585 = CDR(BgL_lz00_2117);
-									BgL_lz00_2117 = BgL_lz00_2585;
-									BgL_iz00_2116 = BgL_iz00_2583;
-									goto BgL_zc3z04anonymousza31452ze3z87_2118;
+									BgL_iz00_2546 = (BgL_iz00_2137 + 1L);
+									BgL_lz00_2548 = CDR(BgL_lz00_2138);
+									BgL_lz00_2138 = BgL_lz00_2548;
+									BgL_iz00_2137 = BgL_iz00_2546;
+									goto BgL_zc3z04anonymousza31391ze3z87_2139;
 								}
 							}
 						else
@@ -500,9 +506,9 @@ extern "C"
 								((bool_t) 0);
 							}
 					}
-					BGl_addzd2gotoszd2zzsaw_gotosz00(BgL_lz00_2114);
-					BGl_addzd2castszd2zzsaw_castz00(BgL_backz00_3, BgL_lz00_2114);
-					return BgL_lz00_2114;
+					BGl_addzd2gotoszd2zzsaw_gotosz00(BgL_lz00_2135);
+					BGl_addzd2castszd2zzsaw_castz00(BgL_backz00_3, BgL_lz00_2135);
+					return BgL_lz00_2135;
 				}
 			}
 		}
@@ -512,14 +518,14 @@ extern "C"
 
 
 /* &global->blocks */
-	obj_t BGl_z62globalzd2ze3blocksz53zzsaw_woodcutterz00(obj_t BgL_envz00_2529,
-		obj_t BgL_backz00_2530, obj_t BgL_vz00_2531)
+	obj_t BGl_z62globalzd2ze3blocksz53zzsaw_woodcutterz00(obj_t BgL_envz00_2492,
+		obj_t BgL_backz00_2493, obj_t BgL_vz00_2494)
 	{
 		{	/* SawMill/woodcutter.scm 35 */
 			return
 				BGl_globalzd2ze3blocksz31zzsaw_woodcutterz00(
-				((BgL_backendz00_bglt) BgL_backz00_2530),
-				((BgL_globalz00_bglt) BgL_vz00_2531));
+				((BgL_backendz00_bglt) BgL_backz00_2493),
+				((BgL_globalz00_bglt) BgL_vz00_2494));
 		}
 
 	}
@@ -564,42 +570,42 @@ extern "C"
 	{
 		{	/* SawMill/woodcutter.scm 1 */
 			BGl_modulezd2initializa7ationz75zztype_typez00(515343395L,
-				BSTRING_TO_STRING(BGl_string1835z00zzsaw_woodcutterz00));
-			BGl_modulezd2initializa7ationz75zztype_cachez00(346491734L,
-				BSTRING_TO_STRING(BGl_string1835z00zzsaw_woodcutterz00));
+				BSTRING_TO_STRING(BGl_string1819z00zzsaw_woodcutterz00));
+			BGl_modulezd2initializa7ationz75zztype_cachez00(489890788L,
+				BSTRING_TO_STRING(BGl_string1819z00zzsaw_woodcutterz00));
 			BGl_modulezd2initializa7ationz75zzast_envz00(146730773L,
-				BSTRING_TO_STRING(BGl_string1835z00zzsaw_woodcutterz00));
+				BSTRING_TO_STRING(BGl_string1819z00zzsaw_woodcutterz00));
 			BGl_modulezd2initializa7ationz75zzast_varz00(90839984L,
-				BSTRING_TO_STRING(BGl_string1835z00zzsaw_woodcutterz00));
+				BSTRING_TO_STRING(BGl_string1819z00zzsaw_woodcutterz00));
 			BGl_modulezd2initializa7ationz75zzast_nodez00(469732712L,
-				BSTRING_TO_STRING(BGl_string1835z00zzsaw_woodcutterz00));
+				BSTRING_TO_STRING(BGl_string1819z00zzsaw_woodcutterz00));
 			BGl_modulezd2initializa7ationz75zzobject_classz00(502007119L,
-				BSTRING_TO_STRING(BGl_string1835z00zzsaw_woodcutterz00));
-			BGl_modulezd2initializa7ationz75zzengine_paramz00(517137079L,
-				BSTRING_TO_STRING(BGl_string1835z00zzsaw_woodcutterz00));
+				BSTRING_TO_STRING(BGl_string1819z00zzsaw_woodcutterz00));
+			BGl_modulezd2initializa7ationz75zzengine_paramz00(161876678L,
+				BSTRING_TO_STRING(BGl_string1819z00zzsaw_woodcutterz00));
 			BGl_modulezd2initializa7ationz75zzmodule_modulez00(158397907L,
-				BSTRING_TO_STRING(BGl_string1835z00zzsaw_woodcutterz00));
+				BSTRING_TO_STRING(BGl_string1819z00zzsaw_woodcutterz00));
 			BGl_modulezd2initializa7ationz75zztools_shapez00(365925558L,
-				BSTRING_TO_STRING(BGl_string1835z00zzsaw_woodcutterz00));
+				BSTRING_TO_STRING(BGl_string1819z00zzsaw_woodcutterz00));
 			BGl_modulezd2initializa7ationz75zzbackend_backendz00(216206620L,
-				BSTRING_TO_STRING(BGl_string1835z00zzsaw_woodcutterz00));
+				BSTRING_TO_STRING(BGl_string1819z00zzsaw_woodcutterz00));
 			BGl_modulezd2initializa7ationz75zzsaw_defsz00(404844772L,
-				BSTRING_TO_STRING(BGl_string1835z00zzsaw_woodcutterz00));
+				BSTRING_TO_STRING(BGl_string1819z00zzsaw_woodcutterz00));
 			BGl_modulezd2initializa7ationz75zzsaw_node2rtlz00(20930040L,
-				BSTRING_TO_STRING(BGl_string1835z00zzsaw_woodcutterz00));
+				BSTRING_TO_STRING(BGl_string1819z00zzsaw_woodcutterz00));
 			BGl_modulezd2initializa7ationz75zzsaw_collapsez00(236189402L,
-				BSTRING_TO_STRING(BGl_string1835z00zzsaw_woodcutterz00));
+				BSTRING_TO_STRING(BGl_string1819z00zzsaw_woodcutterz00));
 			BGl_modulezd2initializa7ationz75zzsaw_removez00(14643094L,
-				BSTRING_TO_STRING(BGl_string1835z00zzsaw_woodcutterz00));
+				BSTRING_TO_STRING(BGl_string1819z00zzsaw_woodcutterz00));
 			BGl_modulezd2initializa7ationz75zzsaw_inline_returnz00(493879085L,
-				BSTRING_TO_STRING(BGl_string1835z00zzsaw_woodcutterz00));
+				BSTRING_TO_STRING(BGl_string1819z00zzsaw_woodcutterz00));
 			BGl_modulezd2initializa7ationz75zzsaw_blockorderz00(202893895L,
-				BSTRING_TO_STRING(BGl_string1835z00zzsaw_woodcutterz00));
+				BSTRING_TO_STRING(BGl_string1819z00zzsaw_woodcutterz00));
 			BGl_modulezd2initializa7ationz75zzsaw_gotosz00(422998065L,
-				BSTRING_TO_STRING(BGl_string1835z00zzsaw_woodcutterz00));
+				BSTRING_TO_STRING(BGl_string1819z00zzsaw_woodcutterz00));
 			return
 				BGl_modulezd2initializa7ationz75zzsaw_castz00(17912865L,
-				BSTRING_TO_STRING(BGl_string1835z00zzsaw_woodcutterz00));
+				BSTRING_TO_STRING(BGl_string1819z00zzsaw_woodcutterz00));
 		}
 
 	}
