@@ -3,8 +3,8 @@
 ;*    -------------------------------------------------------------    */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Tue Dec 27 09:49:59 1994                          */
-;*    Last change :  Mon May 15 08:01:53 2000 (serrano)                */
-;*    Copyright   :  1994-2000 Manuel Serrano, see LICENSE file        */
+;*    Last change :  Fri Jul  8 08:52:13 2016 (serrano)                */
+;*    Copyright   :  1994-2016 Manuel Serrano, see LICENSE file        */
 ;*    -------------------------------------------------------------    */
 ;*    Tools function for managing parameters.                          */
 ;*=====================================================================*/
@@ -14,7 +14,10 @@
 ;*---------------------------------------------------------------------*/
 (module tools_args
    (import tools_dsssl)
-   (export (arity::int exp)
+   (export (global-arity::long exp)
+	   (local-arity::long exp)
+	   (foreign-arity::long exp)
+	   (dsssl-arity-zero?::bool ::int ::pair-nil)
 	   (make-args-list args nil cons)
 	   (args*->args-list exp)
 	   (args-list->args* list arity)
@@ -23,31 +26,79 @@
 	   (+-arity arity <integer>)))
 
 ;*---------------------------------------------------------------------*/
-;*    arity ...                                                        */
+;*    global-arity ...                                                 */
 ;*    args-list --> int                                                */
 ;*    -------------------------------------------------------------    */
 ;*    (lambda n ..)               --> -1                               */
 ;*    (lambda () ..)              -->  0                               */
 ;*    (lambda (a1 a2 .. an) ..)   -->  n                               */
 ;*    (lambda (a1 a2 .. . an) ..) --> -n                               */
-;*    -------------------------------------------------------------    */
-;*    Any dsssl named constant is equivalent to a `.' expression.      */
-;*    Thus:                                                            */
-;*    (lambda (a1 a2 .. an-1 #!optional ...#!rest ...) ..) --> -n      */
 ;*---------------------------------------------------------------------*/
-(define (arity args)
-   (let loop ((i    0)
-	      (args args))
+(define (global-arity args)
+   (let loop ((i 0)
+	      (a args))
       (cond
-	 ((null? args)
+	 ((null? a)
 	  i)
-	 ((pair? args)
-	  (if (dsssl-named-constant? (car args))
-	      (negfx (+fx i 1))
-	      (loop (+fx i 1) (cdr args))))
+	 ((pair? a)
+	  (if (dsssl-named-constant? (car a))
+	      (dsssl-arity args #t)
+	      (loop (+fx i 1) (cdr a))))
 	 (else
 	  (negfx (+fx i 1))))))
 
+;*---------------------------------------------------------------------*/
+;*    local-arity ...                                                  */
+;*    args-list --> int                                                */
+;*    -------------------------------------------------------------    */
+;*    (lambda n ..)               --> -1                               */
+;*    (lambda () ..)              -->  0                               */
+;*    (lambda (a1 a2 .. an) ..)   -->  n                               */
+;*    (lambda (a1 a2 .. . an) ..) --> -n                               */
+;*---------------------------------------------------------------------*/
+(define (local-arity args)
+   (let loop ((i 0)
+	      (a args))
+      (cond
+	 ((null? a)
+	  i)
+	 ((pair? a)
+	  (if (dsssl-named-constant? (car a))
+	      (dsssl-arity args #f)
+	      (loop (+fx i 1) (cdr a))))
+	 (else
+	  (negfx (+fx i 1))))))
+
+;*---------------------------------------------------------------------*/
+;*    foreign-arity ...                                                */
+;*    args-list --> int                                                */
+;*    -------------------------------------------------------------    */
+;*    (lambda n ..)               --> -1                               */
+;*    (lambda () ..)              -->  0                               */
+;*    (lambda (a1 a2 .. an) ..)   -->  n                               */
+;*    (lambda (a1 a2 .. . an) ..) --> -n                               */
+;*---------------------------------------------------------------------*/
+(define (foreign-arity args)
+   (let loop ((i 0)
+	      (a args))
+      (cond
+	 ((null? a)
+	  i)
+	 ((pair? a)
+	  (if (dsssl-named-constant? (car a))
+	      (error 'foreign-arity
+		     "DSSSL arguments not allowed in foreign"
+		     args)
+	      (loop (+fx i 1) (cdr a))))
+	 (else
+	  (negfx (+fx i 1))))))
+
+;*---------------------------------------------------------------------*/
+;*    dsssl-arity-zero? ...                                            */
+;*---------------------------------------------------------------------*/
+(define (dsssl-arity-zero? arity args)
+   (and (<fx arity 0) (null? args)))
+
 ;*---------------------------------------------------------------------*/
 ;*    args*->args-list ...                                             */
 ;*    cons* --> list                                                   */
@@ -65,18 +116,20 @@
 ;*---------------------------------------------------------------------*/
 ;*    args-list->args* ...                                             */
 ;*---------------------------------------------------------------------*/
-(define (args-list->args* list arity)
+(define (args-list->args* lst arity)
    (cond
       ((>=fx arity 0)
-       list)
+       lst)
       ((=fx arity -1)
-       (car list))
+       (car lst))
       (else
-       (let loop ((list  list)
+       (let loop ((lst  lst)
 		  (arity arity))
-	  (if (=fx arity -1)
-	      (car list)
-	      (cons (car list) (loop (cdr list) (+fx arity 1))))))))
+	  (if (null? (cdr lst))
+	      (if (< arity 0)
+		  (car lst)
+		  (list lst))
+	      (cons (car lst) (loop (cdr lst) (+fx arity 1))))))))
    
 ;*---------------------------------------------------------------------*/
 ;*    sound-arity? ...                                                 */
