@@ -1,9 +1,9 @@
 /*===========================================================================*/
 /*   (Tools/location.scm)                                                    */
-/*   Bigloo (4.5b)                                                           */
-/*   Inria -- Sophia Antipolis (c)       Fri Dec 22 05:17:06 PM CET 2023     */
+/*   Bigloo (4.6a)                                                           */
+/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
 /*===========================================================================*/
-/* COMPILATION: (/home/serrano/prgm/project/bigloo/bigloo/bin/bigloo -ldopt -L/home/serrano/prgm/project/bigloo/bigloo/libbacktrace/home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b  -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Tools/location.scm) */
+/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Tools/location.scm) */
 /* GC selection */
 #define THE_GC BOEHM_GC
 
@@ -46,9 +46,9 @@ extern "C"
 	static obj_t BGl_objectzd2initzd2zztools_locationz00(void);
 	static obj_t BGl_z62findzd2locationzb0zztools_locationz00(obj_t, obj_t);
 	static obj_t BGl_poszd2ze3linez31zztools_locationz00(obj_t, obj_t);
-	BGL_IMPORT obj_t bstring_to_symbol(obj_t);
 	BGL_IMPORT obj_t BGl_makezd2filezd2namez00zz__osz00(obj_t, obj_t);
 	BGL_IMPORT obj_t BGl_readz00zz__readerz00(obj_t, obj_t);
+	BGL_IMPORT obj_t bstring_to_symbol(obj_t);
 	BGL_IMPORT obj_t BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00(obj_t,
 		obj_t, obj_t);
 	static obj_t BGl_getzd2filezd2linesz00zztools_locationz00(obj_t);
@@ -108,45 +108,45 @@ extern "C"
 
 	   
 		 
-		DEFINE_STRING(BGl_string1074z00zztools_locationz00,
-		BgL_bgl_string1074za700za7za7t1081za7, "~~ ", 3);
-	      DEFINE_STRING(BGl_string1075z00zztools_locationz00,
-		BgL_bgl_string1075za700za7za7t1082za7, ": ", 2);
+		DEFINE_STRING(BGl_string1075z00zztools_locationz00,
+		BgL_bgl_string1075za700za7za7t1084za7, "~~ ", 3);
 	      DEFINE_STRING(BGl_string1076z00zztools_locationz00,
-		BgL_bgl_string1076za700za7za7t1083za7, " ", 1);
+		BgL_bgl_string1076za700za7za7t1085za7, ": ", 2);
 	      DEFINE_STRING(BGl_string1077z00zztools_locationz00,
-		BgL_bgl_string1077za700za7za7t1084za7, "____ ", 5);
+		BgL_bgl_string1077za700za7za7t1086za7, " ", 1);
 	      DEFINE_STRING(BGl_string1078z00zztools_locationz00,
-		BgL_bgl_string1078za700za7za7t1085za7, "tools_location", 14);
+		BgL_bgl_string1078za700za7za7t1087za7, "____ ", 5);
 	      DEFINE_STRING(BGl_string1079z00zztools_locationz00,
-		BgL_bgl_string1079za700za7za7t1086za7, "at location ", 12);
+		BgL_bgl_string1079za700za7za7t1088za7, "tools_location", 14);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_locationzd2shapezd2envz00zztools_locationz00,
-		BgL_bgl_za762locationza7d2sh1087z00,
+		BgL_bgl_za762locationza7d2sh1089z00,
 		BGl_z62locationzd2shapezb0zztools_locationz00, 0L, BUNSPEC, 2);
+	      DEFINE_STRING(BGl_string1080z00zztools_locationz00,
+		BgL_bgl_string1080za700za7za7t1090za7, "at location ", 12);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_locationzd2skipzd2forwardzd2envzd2zztools_locationz00,
-		BgL_bgl_za762locationza7d2sk1088z00,
+		BgL_bgl_za762locationza7d2sk1091z00,
 		BGl_z62locationzd2skipzd2forwardz62zztools_locationz00, 0L, BUNSPEC, 2);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE(BGl_findzd2locationzd2envz00zztools_locationz00,
-		BgL_bgl_za762findza7d2locati1089z00,
+		BgL_bgl_za762findza7d2locati1092z00,
 		BGl_z62findzd2locationzb0zztools_locationz00, 0L, BUNSPEC, 1);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE(BGl_dumpzd2locationzd2envz00zztools_locationz00,
-		BgL_bgl_za762dumpza7d2locati1090z00,
+		BgL_bgl_za762dumpza7d2locati1093z00,
 		BGl_z62dumpzd2locationzb0zztools_locationz00, 0L, BUNSPEC, 2);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_findzd2locationzf2loczd2envzf2zztools_locationz00,
-		BgL_bgl_za762findza7d2locati1091z00,
+		BgL_bgl_za762findza7d2locati1094z00,
 		BGl_z62findzd2locationzf2locz42zztools_locationz00, 0L, BUNSPEC, 2);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_locationzd2fullzd2fnamezd2envzd2zztools_locationz00,
-		BgL_bgl_za762locationza7d2fu1092z00,
+		BgL_bgl_za762locationza7d2fu1095z00,
 		BGl_z62locationzd2fullzd2fnamez62zztools_locationz00, 0L, BUNSPEC, 1);
 
 /* GC roots registration */
@@ -172,7 +172,7 @@ extern "C"
 /* module-initialization */
 	BGL_EXPORTED_DEF obj_t
 		BGl_modulezd2initializa7ationz75zztools_locationz00(long
-		BgL_checksumz00_230, char *BgL_fromz00_231)
+		BgL_checksumz00_231, char *BgL_fromz00_232)
 	{
 		{
 			if (CBOOL(BGl_requirezd2initializa7ationz75zztools_locationz00))
@@ -232,70 +232,70 @@ extern "C"
 	{
 		{	/* Tools/location.scm 15 */
 			{	/* Tools/location.scm 15 */
-				obj_t BgL_cportz00_219;
+				obj_t BgL_cportz00_220;
 
 				{	/* Tools/location.scm 15 */
-					obj_t BgL_stringz00_226;
+					obj_t BgL_stringz00_227;
 
-					BgL_stringz00_226 = BGl_string1079z00zztools_locationz00;
+					BgL_stringz00_227 = BGl_string1080z00zztools_locationz00;
 					{	/* Tools/location.scm 15 */
-						obj_t BgL_startz00_227;
+						obj_t BgL_startz00_228;
 
-						BgL_startz00_227 = BINT(0L);
+						BgL_startz00_228 = BINT(0L);
 						{	/* Tools/location.scm 15 */
-							obj_t BgL_endz00_228;
+							obj_t BgL_endz00_229;
 
-							BgL_endz00_228 = BINT(STRING_LENGTH(((obj_t) BgL_stringz00_226)));
+							BgL_endz00_229 = BINT(STRING_LENGTH(((obj_t) BgL_stringz00_227)));
 							{	/* Tools/location.scm 15 */
 
-								BgL_cportz00_219 =
+								BgL_cportz00_220 =
 									BGl_openzd2inputzd2stringz12z12zz__r4_ports_6_10_1z00
-									(BgL_stringz00_226, BgL_startz00_227, BgL_endz00_228);
+									(BgL_stringz00_227, BgL_startz00_228, BgL_endz00_229);
 				}}}}
 				{
-					long BgL_iz00_220;
+					long BgL_iz00_221;
 
-					BgL_iz00_220 = 1L;
-				BgL_loopz00_221:
-					if ((BgL_iz00_220 == -1L))
+					BgL_iz00_221 = 1L;
+				BgL_loopz00_222:
+					if ((BgL_iz00_221 == (-1L)))
 						{	/* Tools/location.scm 15 */
 							return BUNSPEC;
 						}
 					else
 						{	/* Tools/location.scm 15 */
 							{	/* Tools/location.scm 15 */
-								obj_t BgL_arg1080z00_222;
+								obj_t BgL_arg1083z00_223;
 
 								{	/* Tools/location.scm 15 */
 
 									{	/* Tools/location.scm 15 */
-										obj_t BgL_locationz00_224;
+										obj_t BgL_locationz00_225;
 
-										BgL_locationz00_224 = BBOOL(((bool_t) 0));
+										BgL_locationz00_225 = BBOOL(((bool_t) 0));
 										{	/* Tools/location.scm 15 */
 
-											BgL_arg1080z00_222 =
-												BGl_readz00zz__readerz00(BgL_cportz00_219,
-												BgL_locationz00_224);
+											BgL_arg1083z00_223 =
+												BGl_readz00zz__readerz00(BgL_cportz00_220,
+												BgL_locationz00_225);
 										}
 									}
 								}
 								{	/* Tools/location.scm 15 */
-									int BgL_tmpz00_262;
+									int BgL_tmpz00_263;
 
-									BgL_tmpz00_262 = (int) (BgL_iz00_220);
-									CNST_TABLE_SET(BgL_tmpz00_262, BgL_arg1080z00_222);
+									BgL_tmpz00_263 = (int) (BgL_iz00_221);
+									CNST_TABLE_SET(BgL_tmpz00_263, BgL_arg1083z00_223);
 							}}
 							{	/* Tools/location.scm 15 */
-								int BgL_auxz00_225;
+								int BgL_auxz00_226;
 
-								BgL_auxz00_225 = (int) ((BgL_iz00_220 - 1L));
+								BgL_auxz00_226 = (int) ((BgL_iz00_221 - 1L));
 								{
-									long BgL_iz00_267;
+									long BgL_iz00_268;
 
-									BgL_iz00_267 = (long) (BgL_auxz00_225);
-									BgL_iz00_220 = BgL_iz00_267;
-									goto BgL_loopz00_221;
+									BgL_iz00_268 = (long) (BgL_auxz00_226);
+									BgL_iz00_221 = BgL_iz00_268;
+									goto BgL_loopz00_222;
 								}
 							}
 						}
@@ -335,26 +335,26 @@ extern "C"
 	{
 		{	/* Tools/location.scm 33 */
 			{	/* Tools/location.scm 34 */
-				obj_t BgL_linesz00_51;
+				obj_t BgL_linesz00_52;
 
-				BgL_linesz00_51 =
+				BgL_linesz00_52 =
 					BGl_hashtablezd2getzd2zz__hashz00
 					(BGl_za2filezd2lineszd2tableza2z00zztools_locationz00,
 					BgL_filez00_17);
-				if (CBOOL(BgL_linesz00_51))
+				if (CBOOL(BgL_linesz00_52))
 					{	/* Tools/location.scm 35 */
-						return BgL_linesz00_51;
+						return BgL_linesz00_52;
 					}
 				else
 					{	/* Tools/location.scm 36 */
-						obj_t BgL_linesz00_52;
+						obj_t BgL_linesz00_53;
 
-						BgL_linesz00_52 =
+						BgL_linesz00_53 =
 							BGl_filezd2lineszd2zz__r4_input_6_10_2z00(BgL_filez00_17);
 						BGl_hashtablezd2putz12zc0zz__hashz00
 							(BGl_za2filezd2lineszd2tableza2z00zztools_locationz00,
-							BgL_filez00_17, BgL_linesz00_52);
-						return BgL_linesz00_52;
+							BgL_filez00_17, BgL_linesz00_53);
+						return BgL_linesz00_53;
 					}
 			}
 		}
@@ -369,19 +369,19 @@ extern "C"
 	{
 		{	/* Tools/location.scm 44 */
 			{	/* Tools/location.scm 45 */
-				obj_t BgL_linesz00_126;
+				obj_t BgL_linesz00_127;
 
-				BgL_linesz00_126 =
+				BgL_linesz00_127 =
 					BGl_getzd2filezd2linesz00zztools_locationz00(BgL_filez00_18);
 				{	/* Tools/location.scm 46 */
-					obj_t BgL__ortest_1012z00_127;
+					obj_t BgL__ortest_1012z00_128;
 
-					BgL__ortest_1012z00_127 =
+					BgL__ortest_1012z00_128 =
 						BGl_filezd2positionzd2ze3lineze3zz__r4_input_6_10_2z00(CINT
-						(BgL_posz00_19), BgL_linesz00_126);
-					if (CBOOL(BgL__ortest_1012z00_127))
+						(BgL_posz00_19), BgL_linesz00_127);
+					if (CBOOL(BgL__ortest_1012z00_128))
 						{	/* Tools/location.scm 46 */
-							return BgL__ortest_1012z00_127;
+							return BgL__ortest_1012z00_128;
 						}
 					else
 						{	/* Tools/location.scm 46 */
@@ -401,93 +401,97 @@ extern "C"
 	{
 		{	/* Tools/location.scm 51 */
 			{
-				obj_t BgL_locz00_58;
+				obj_t BgL_locz00_59;
 
 				if (EPAIRP(BgL_expz00_20))
 					{	/* Tools/location.scm 63 */
-						obj_t BgL_arg1033z00_57;
+						obj_t BgL_arg1034z00_58;
 
-						BgL_arg1033z00_57 = CER(((obj_t) BgL_expz00_20));
-						BgL_locz00_58 = BgL_arg1033z00_57;
+						BgL_arg1034z00_58 = CER(((obj_t) BgL_expz00_20));
+						BgL_locz00_59 = BgL_arg1034z00_58;
 						{	/* Tools/location.scm 53 */
-							bool_t BgL_test1098z00_286;
+							bool_t BgL_test1101z00_287;
 
-							if (STRUCTP(BgL_locz00_58))
+							if (STRUCTP(BgL_locz00_59))
 								{	/* Tools/location.scm 53 */
-									BgL_test1098z00_286 =
-										(STRUCT_KEY(BgL_locz00_58) == CNST_TABLE_REF(0L));
+									BgL_test1101z00_287 =
+										(STRUCT_KEY(BgL_locz00_59) == ((obj_t) CNST_TABLE_REF(0)));
 								}
 							else
 								{	/* Tools/location.scm 53 */
-									BgL_test1098z00_286 = ((bool_t) 0);
+									BgL_test1101z00_287 = ((bool_t) 0);
 								}
-							if (BgL_test1098z00_286)
+							if (BgL_test1101z00_287)
 								{	/* Tools/location.scm 53 */
-									return BgL_locz00_58;
+									return BgL_locz00_59;
 								}
 							else
 								{	/* Tools/location.scm 53 */
-									if (PAIRP(BgL_locz00_58))
+									if (PAIRP(BgL_locz00_59))
 										{	/* Tools/location.scm 55 */
-											obj_t BgL_cdrzd2109zd2_67;
+											obj_t BgL_cdrzd2109zd2_68;
 
-											BgL_cdrzd2109zd2_67 = CDR(((obj_t) BgL_locz00_58));
-											if ((CAR(((obj_t) BgL_locz00_58)) == CNST_TABLE_REF(1L)))
+											BgL_cdrzd2109zd2_68 = CDR(((obj_t) BgL_locz00_59));
+											if (
+												(CAR(
+														((obj_t) BgL_locz00_59)) ==
+													((obj_t) CNST_TABLE_REF(1))))
 												{	/* Tools/location.scm 55 */
-													if (PAIRP(BgL_cdrzd2109zd2_67))
+													if (PAIRP(BgL_cdrzd2109zd2_68))
 														{	/* Tools/location.scm 55 */
-															obj_t BgL_cdrzd2113zd2_71;
+															obj_t BgL_cdrzd2113zd2_72;
 
-															BgL_cdrzd2113zd2_71 = CDR(BgL_cdrzd2109zd2_67);
-															if (PAIRP(BgL_cdrzd2113zd2_71))
+															BgL_cdrzd2113zd2_72 = CDR(BgL_cdrzd2109zd2_68);
+															if (PAIRP(BgL_cdrzd2113zd2_72))
 																{	/* Tools/location.scm 55 */
-																	if (NULLP(CDR(BgL_cdrzd2113zd2_71)))
+																	if (NULLP(CDR(BgL_cdrzd2113zd2_72)))
 																		{	/* Tools/location.scm 55 */
-																			obj_t BgL_arg1043z00_75;
-																			obj_t BgL_arg1045z00_76;
+																			obj_t BgL_arg1044z00_76;
+																			obj_t BgL_arg1046z00_77;
 
-																			BgL_arg1043z00_75 =
-																				CAR(BgL_cdrzd2109zd2_67);
-																			BgL_arg1045z00_76 =
-																				CAR(BgL_cdrzd2113zd2_71);
+																			BgL_arg1044z00_76 =
+																				CAR(BgL_cdrzd2109zd2_68);
+																			BgL_arg1046z00_77 =
+																				CAR(BgL_cdrzd2113zd2_72);
 																			{	/* Tools/location.scm 57 */
-																				obj_t BgL_arg1048z00_145;
+																				obj_t BgL_arg1049z00_146;
 
-																				BgL_arg1048z00_145 =
+																				BgL_arg1049z00_146 =
 																					BGl_poszd2ze3linez31zztools_locationz00
-																					(BgL_arg1043z00_75,
-																					BgL_arg1045z00_76);
+																					(BgL_arg1044z00_76,
+																					BgL_arg1046z00_77);
 																				{	/* Tools/location.scm 57 */
-																					obj_t BgL_newz00_146;
+																					obj_t BgL_newz00_147;
 
-																					BgL_newz00_146 =
-																						create_struct(CNST_TABLE_REF(0L),
-																						(int) (3L));
+																					BgL_newz00_147 =
+																						create_struct(
+																						((obj_t)
+																							CNST_TABLE_REF(0)), (int) (3L));
 																					{	/* Tools/location.scm 57 */
-																						int BgL_tmpz00_315;
+																						int BgL_tmpz00_319;
 
-																						BgL_tmpz00_315 = (int) (2L);
-																						STRUCT_SET(BgL_newz00_146,
-																							BgL_tmpz00_315,
-																							BgL_arg1048z00_145);
+																						BgL_tmpz00_319 = (int) (2L);
+																						STRUCT_SET(BgL_newz00_147,
+																							BgL_tmpz00_319,
+																							BgL_arg1049z00_146);
 																					}
 																					{	/* Tools/location.scm 57 */
-																						int BgL_tmpz00_318;
+																						int BgL_tmpz00_322;
 
-																						BgL_tmpz00_318 = (int) (1L);
-																						STRUCT_SET(BgL_newz00_146,
-																							BgL_tmpz00_318,
-																							BgL_arg1045z00_76);
+																						BgL_tmpz00_322 = (int) (1L);
+																						STRUCT_SET(BgL_newz00_147,
+																							BgL_tmpz00_322,
+																							BgL_arg1046z00_77);
 																					}
 																					{	/* Tools/location.scm 57 */
-																						int BgL_tmpz00_321;
+																						int BgL_tmpz00_325;
 
-																						BgL_tmpz00_321 = (int) (0L);
-																						STRUCT_SET(BgL_newz00_146,
-																							BgL_tmpz00_321,
-																							BgL_arg1043z00_75);
+																						BgL_tmpz00_325 = (int) (0L);
+																						STRUCT_SET(BgL_newz00_147,
+																							BgL_tmpz00_325,
+																							BgL_arg1044z00_76);
 																					}
-																					return BgL_newz00_146;
+																					return BgL_newz00_147;
 																				}
 																			}
 																		}
@@ -530,11 +534,11 @@ extern "C"
 
 
 /* &find-location */
-	obj_t BGl_z62findzd2locationzb0zztools_locationz00(obj_t BgL_envz00_202,
-		obj_t BgL_expz00_203)
+	obj_t BGl_z62findzd2locationzb0zztools_locationz00(obj_t BgL_envz00_203,
+		obj_t BgL_expz00_204)
 	{
 		{	/* Tools/location.scm 51 */
-			return BGl_findzd2locationzd2zztools_locationz00(BgL_expz00_203);
+			return BGl_findzd2locationzd2zztools_locationz00(BgL_expz00_204);
 		}
 
 	}
@@ -547,25 +551,26 @@ extern "C"
 	{
 		{	/* Tools/location.scm 70 */
 			{	/* Tools/location.scm 71 */
-				obj_t BgL_newzd2loczd2_151;
+				obj_t BgL_newzd2loczd2_152;
 
-				BgL_newzd2loczd2_151 =
+				BgL_newzd2loczd2_152 =
 					BGl_findzd2locationzd2zztools_locationz00(BgL_expz00_21);
 				{	/* Tools/location.scm 72 */
-					bool_t BgL_test1105z00_326;
+					bool_t BgL_test1108z00_330;
 
-					if (STRUCTP(BgL_newzd2loczd2_151))
+					if (STRUCTP(BgL_newzd2loczd2_152))
 						{	/* Tools/location.scm 72 */
-							BgL_test1105z00_326 =
-								(STRUCT_KEY(BgL_newzd2loczd2_151) == CNST_TABLE_REF(0L));
+							BgL_test1108z00_330 =
+								(STRUCT_KEY(BgL_newzd2loczd2_152) ==
+								((obj_t) CNST_TABLE_REF(0)));
 						}
 					else
 						{	/* Tools/location.scm 72 */
-							BgL_test1105z00_326 = ((bool_t) 0);
+							BgL_test1108z00_330 = ((bool_t) 0);
 						}
-					if (BgL_test1105z00_326)
+					if (BgL_test1108z00_330)
 						{	/* Tools/location.scm 72 */
-							return BgL_newzd2loczd2_151;
+							return BgL_newzd2loczd2_152;
 						}
 					else
 						{	/* Tools/location.scm 72 */
@@ -580,13 +585,13 @@ extern "C"
 
 
 /* &find-location/loc */
-	obj_t BGl_z62findzd2locationzf2locz42zztools_locationz00(obj_t BgL_envz00_204,
-		obj_t BgL_expz00_205, obj_t BgL_locz00_206)
+	obj_t BGl_z62findzd2locationzf2locz42zztools_locationz00(obj_t BgL_envz00_205,
+		obj_t BgL_expz00_206, obj_t BgL_locz00_207)
 	{
 		{	/* Tools/location.scm 70 */
 			return
-				BGl_findzd2locationzf2locz20zztools_locationz00(BgL_expz00_205,
-				BgL_locz00_206);
+				BGl_findzd2locationzf2locz20zztools_locationz00(BgL_expz00_206,
+				BgL_locz00_207);
 		}
 
 	}
@@ -599,36 +604,36 @@ extern "C"
 	{
 		{	/* Tools/location.scm 79 */
 			{	/* Tools/location.scm 80 */
-				obj_t BgL_filezd2namezd2_83;
+				obj_t BgL_filezd2namezd2_84;
 
-				BgL_filezd2namezd2_83 = STRUCT_REF(((obj_t) BgL_locz00_23), (int) (0L));
+				BgL_filezd2namezd2_84 = STRUCT_REF(((obj_t) BgL_locz00_23), (int) (0L));
 				{	/* Tools/location.scm 80 */
-					obj_t BgL_fullzd2namezd2_84;
+					obj_t BgL_fullzd2namezd2_85;
 
-					BgL_fullzd2namezd2_84 =
+					BgL_fullzd2namezd2_85 =
 						BGl_makezd2filezd2namez00zz__osz00(BGl_pwdz00zz__osz00(),
-						BgL_filezd2namezd2_83);
+						BgL_filezd2namezd2_84);
 					{	/* Tools/location.scm 81 */
 
-						if (fexists(BSTRING_TO_STRING(BgL_fullzd2namezd2_84)))
+						if (fexists(BSTRING_TO_STRING(BgL_fullzd2namezd2_85)))
 							{	/* Tools/location.scm 82 */
-								return BgL_fullzd2namezd2_84;
+								return BgL_fullzd2namezd2_85;
 							}
 						else
 							{	/* Tools/location.scm 84 */
-								obj_t BgL_libzd2namezd2_86;
+								obj_t BgL_libzd2namezd2_87;
 
-								BgL_libzd2namezd2_86 =
+								BgL_libzd2namezd2_87 =
 									BGl_makezd2filezd2namez00zz__osz00
 									(BGl_za2libzd2srczd2dirza2z00zzengine_paramz00,
-									BgL_filezd2namezd2_83);
-								if (fexists(BSTRING_TO_STRING(BgL_libzd2namezd2_86)))
+									BgL_filezd2namezd2_84);
+								if (fexists(BSTRING_TO_STRING(BgL_libzd2namezd2_87)))
 									{	/* Tools/location.scm 85 */
-										return BgL_libzd2namezd2_86;
+										return BgL_libzd2namezd2_87;
 									}
 								else
 									{	/* Tools/location.scm 85 */
-										return BgL_filezd2namezd2_83;
+										return BgL_filezd2namezd2_84;
 									}
 							}
 					}
@@ -642,10 +647,10 @@ extern "C"
 
 /* &location-full-fname */
 	obj_t BGl_z62locationzd2fullzd2fnamez62zztools_locationz00(obj_t
-		BgL_envz00_207, obj_t BgL_locz00_208)
+		BgL_envz00_208, obj_t BgL_locz00_209)
 	{
 		{	/* Tools/location.scm 79 */
-			return BGl_locationzd2fullzd2fnamez00zztools_locationz00(BgL_locz00_208);
+			return BGl_locationzd2fullzd2fnamez00zztools_locationz00(BgL_locz00_209);
 		}
 
 	}
@@ -658,51 +663,51 @@ extern "C"
 	{
 		{	/* Tools/location.scm 92 */
 			{	/* Tools/location.scm 93 */
-				bool_t BgL_test1109z00_346;
+				bool_t BgL_test1112z00_351;
 
 				if (CBOOL(BGl_za2locationzd2shapezf3za2z21zzengine_paramz00))
 					{	/* Tools/location.scm 93 */
 						if (STRUCTP(BgL_locz00_24))
 							{	/* Tools/location.scm 93 */
-								BgL_test1109z00_346 =
-									(STRUCT_KEY(BgL_locz00_24) == CNST_TABLE_REF(0L));
+								BgL_test1112z00_351 =
+									(STRUCT_KEY(BgL_locz00_24) == ((obj_t) CNST_TABLE_REF(0)));
 							}
 						else
 							{	/* Tools/location.scm 93 */
-								BgL_test1109z00_346 = ((bool_t) 0);
+								BgL_test1112z00_351 = ((bool_t) 0);
 							}
 					}
 				else
 					{	/* Tools/location.scm 93 */
-						BgL_test1109z00_346 = ((bool_t) 0);
+						BgL_test1112z00_351 = ((bool_t) 0);
 					}
-				if (BgL_test1109z00_346)
+				if (BgL_test1112z00_351)
 					{	/* Tools/location.scm 94 */
-						obj_t BgL_arg1054z00_90;
+						obj_t BgL_arg1055z00_91;
 
 						{	/* Tools/location.scm 94 */
-							obj_t BgL_v1013z00_91;
+							obj_t BgL_v1013z00_92;
 
-							BgL_v1013z00_91 = create_vector(3L);
+							BgL_v1013z00_92 = create_vector(3L);
 							{	/* Tools/location.scm 94 */
-								obj_t BgL_arg1055z00_92;
+								obj_t BgL_arg1056z00_93;
 
 								{	/* Tools/location.scm 94 */
-									obj_t BgL_arg1056z00_93;
+									obj_t BgL_arg1057z00_94;
 
-									BgL_arg1056z00_93 = STRUCT_REF(BgL_locz00_24, (int) (0L));
-									BgL_arg1055z00_92 =
-										bstring_to_symbol(((obj_t) BgL_arg1056z00_93));
+									BgL_arg1057z00_94 = STRUCT_REF(BgL_locz00_24, (int) (0L));
+									BgL_arg1056z00_93 =
+										bstring_to_symbol(((obj_t) BgL_arg1057z00_94));
 								}
-								VECTOR_SET(BgL_v1013z00_91, 0L, BgL_arg1055z00_92);
+								VECTOR_SET(BgL_v1013z00_92, 0L, BgL_arg1056z00_93);
 							}
-							VECTOR_SET(BgL_v1013z00_91, 1L,
+							VECTOR_SET(BgL_v1013z00_92, 1L,
 								STRUCT_REF(BgL_locz00_24, (int) (1L)));
-							VECTOR_SET(BgL_v1013z00_91, 2L,
+							VECTOR_SET(BgL_v1013z00_92, 2L,
 								STRUCT_REF(BgL_locz00_24, (int) (2L)));
-							BgL_arg1054z00_90 = BgL_v1013z00_91;
+							BgL_arg1055z00_91 = BgL_v1013z00_92;
 						}
-						return MAKE_YOUNG_PAIR(BgL_arg1054z00_90, BgL_lz00_25);
+						return MAKE_YOUNG_PAIR(BgL_arg1055z00_91, BgL_lz00_25);
 					}
 				else
 					{	/* Tools/location.scm 93 */
@@ -716,13 +721,13 @@ extern "C"
 
 
 /* &location-shape */
-	obj_t BGl_z62locationzd2shapezb0zztools_locationz00(obj_t BgL_envz00_209,
-		obj_t BgL_locz00_210, obj_t BgL_lz00_211)
+	obj_t BGl_z62locationzd2shapezb0zztools_locationz00(obj_t BgL_envz00_210,
+		obj_t BgL_locz00_211, obj_t BgL_lz00_212)
 	{
 		{	/* Tools/location.scm 92 */
 			return
-				BGl_locationzd2shapezd2zztools_locationz00(BgL_locz00_210,
-				BgL_lz00_211);
+				BGl_locationzd2shapezd2zztools_locationz00(BgL_locz00_211,
+				BgL_lz00_212);
 		}
 
 	}
@@ -735,71 +740,71 @@ extern "C"
 	{
 		{	/* Tools/location.scm 104 */
 			{	/* Tools/location.scm 105 */
-				obj_t BgL_port1014z00_96;
+				obj_t BgL_port1014z00_97;
 
 				{	/* Tools/location.scm 105 */
-					obj_t BgL_tmpz00_368;
+					obj_t BgL_tmpz00_374;
 
-					BgL_tmpz00_368 = BGL_CURRENT_DYNAMIC_ENV();
-					BgL_port1014z00_96 = BGL_ENV_CURRENT_OUTPUT_PORT(BgL_tmpz00_368);
+					BgL_tmpz00_374 = BGL_CURRENT_DYNAMIC_ENV();
+					BgL_port1014z00_97 = BGL_ENV_CURRENT_OUTPUT_PORT(BgL_tmpz00_374);
 				}
-				bgl_display_string(BGl_string1074z00zztools_locationz00,
-					BgL_port1014z00_96);
-				bgl_display_obj(BgL_fromz00_26, BgL_port1014z00_96);
 				bgl_display_string(BGl_string1075z00zztools_locationz00,
-					BgL_port1014z00_96);
-				bgl_display_obj(BgL_exprz00_27, BgL_port1014z00_96);
+					BgL_port1014z00_97);
+				bgl_display_obj(BgL_fromz00_26, BgL_port1014z00_97);
 				bgl_display_string(BGl_string1076z00zztools_locationz00,
-					BgL_port1014z00_96);
+					BgL_port1014z00_97);
+				bgl_display_obj(BgL_exprz00_27, BgL_port1014z00_97);
+				bgl_display_string(BGl_string1077z00zztools_locationz00,
+					BgL_port1014z00_97);
 				bgl_display_obj(BGl_findzd2locationzd2zztools_locationz00
-					(BgL_exprz00_27), BgL_port1014z00_96);
-				bgl_display_char(((unsigned char) 10), BgL_port1014z00_96);
+					(BgL_exprz00_27), BgL_port1014z00_97);
+				bgl_display_char(((unsigned char) 10), BgL_port1014z00_97);
 			}
 			{
-				obj_t BgL_exprz00_99;
+				obj_t BgL_exprz00_100;
 
 				{	/* Tools/location.scm 106 */
-					bool_t BgL_tmpz00_379;
+					bool_t BgL_tmpz00_385;
 
-					BgL_exprz00_99 = BgL_exprz00_27;
-				BgL_zc3z04anonymousza31060ze3z87_100:
-					if (PAIRP(BgL_exprz00_99))
+					BgL_exprz00_100 = BgL_exprz00_27;
+				BgL_zc3z04anonymousza31062ze3z87_101:
+					if (PAIRP(BgL_exprz00_100))
 						{	/* Tools/location.scm 107 */
 							{	/* Tools/location.scm 109 */
-								obj_t BgL_port1015z00_102;
+								obj_t BgL_port1015z00_103;
 
 								{	/* Tools/location.scm 109 */
-									obj_t BgL_tmpz00_382;
+									obj_t BgL_tmpz00_388;
 
-									BgL_tmpz00_382 = BGL_CURRENT_DYNAMIC_ENV();
-									BgL_port1015z00_102 =
-										BGL_ENV_CURRENT_OUTPUT_PORT(BgL_tmpz00_382);
+									BgL_tmpz00_388 = BGL_CURRENT_DYNAMIC_ENV();
+									BgL_port1015z00_103 =
+										BGL_ENV_CURRENT_OUTPUT_PORT(BgL_tmpz00_388);
 								}
-								bgl_display_string(BGl_string1077z00zztools_locationz00,
-									BgL_port1015z00_102);
-								bgl_display_obj(BgL_fromz00_26, BgL_port1015z00_102);
-								bgl_display_string(BGl_string1075z00zztools_locationz00,
-									BgL_port1015z00_102);
-								bgl_display_obj(BgL_exprz00_99, BgL_port1015z00_102);
+								bgl_display_string(BGl_string1078z00zztools_locationz00,
+									BgL_port1015z00_103);
+								bgl_display_obj(BgL_fromz00_26, BgL_port1015z00_103);
 								bgl_display_string(BGl_string1076z00zztools_locationz00,
-									BgL_port1015z00_102);
+									BgL_port1015z00_103);
+								bgl_display_obj(BgL_exprz00_100, BgL_port1015z00_103);
+								bgl_display_string(BGl_string1077z00zztools_locationz00,
+									BgL_port1015z00_103);
 								bgl_display_obj(BGl_findzd2locationzd2zztools_locationz00
-									(BgL_exprz00_99), BgL_port1015z00_102);
-								bgl_display_char(((unsigned char) 10), BgL_port1015z00_102);
+									(BgL_exprz00_100), BgL_port1015z00_103);
+								bgl_display_char(((unsigned char) 10), BgL_port1015z00_103);
 							}
 							{
-								obj_t BgL_exprz00_393;
+								obj_t BgL_exprz00_399;
 
-								BgL_exprz00_393 = CDR(BgL_exprz00_99);
-								BgL_exprz00_99 = BgL_exprz00_393;
-								goto BgL_zc3z04anonymousza31060ze3z87_100;
+								BgL_exprz00_399 = CDR(BgL_exprz00_100);
+								BgL_exprz00_100 = BgL_exprz00_399;
+								goto BgL_zc3z04anonymousza31062ze3z87_101;
 							}
 						}
 					else
 						{	/* Tools/location.scm 107 */
-							BgL_tmpz00_379 = ((bool_t) 0);
+							BgL_tmpz00_385 = ((bool_t) 0);
 						}
-					return BBOOL(BgL_tmpz00_379);
+					return BBOOL(BgL_tmpz00_385);
 				}
 			}
 		}
@@ -809,13 +814,13 @@ extern "C"
 
 
 /* &dump-location */
-	obj_t BGl_z62dumpzd2locationzb0zztools_locationz00(obj_t BgL_envz00_212,
-		obj_t BgL_fromz00_213, obj_t BgL_exprz00_214)
+	obj_t BGl_z62dumpzd2locationzb0zztools_locationz00(obj_t BgL_envz00_213,
+		obj_t BgL_fromz00_214, obj_t BgL_exprz00_215)
 	{
 		{	/* Tools/location.scm 104 */
 			return
-				BGl_dumpzd2locationzd2zztools_locationz00(BgL_fromz00_213,
-				BgL_exprz00_214);
+				BGl_dumpzd2locationzd2zztools_locationz00(BgL_fromz00_214,
+				BgL_exprz00_215);
 		}
 
 	}
@@ -829,78 +834,79 @@ extern "C"
 	{
 		{	/* Tools/location.scm 116 */
 			{	/* Tools/location.scm 117 */
-				bool_t BgL_test1113z00_397;
+				bool_t BgL_test1116z00_403;
 
 				if (STRUCTP(BgL_locz00_28))
 					{	/* Tools/location.scm 117 */
-						BgL_test1113z00_397 =
-							(STRUCT_KEY(BgL_locz00_28) == CNST_TABLE_REF(0L));
+						BgL_test1116z00_403 =
+							(STRUCT_KEY(BgL_locz00_28) == ((obj_t) CNST_TABLE_REF(0)));
 					}
 				else
 					{	/* Tools/location.scm 117 */
-						BgL_test1113z00_397 = ((bool_t) 0);
+						BgL_test1116z00_403 = ((bool_t) 0);
 					}
-				if (BgL_test1113z00_397)
+				if (BgL_test1116z00_403)
 					{	/* Tools/location.scm 118 */
-						obj_t BgL_fnamez00_107;
-						long BgL_nposz00_108;
+						obj_t BgL_fnamez00_108;
+						long BgL_nposz00_109;
 
-						BgL_fnamez00_107 = STRUCT_REF(BgL_locz00_28, (int) (0L));
-						BgL_nposz00_108 =
+						BgL_fnamez00_108 = STRUCT_REF(BgL_locz00_28, (int) (0L));
+						BgL_nposz00_109 =
 							(
 							(long) CINT(STRUCT_REF(BgL_locz00_28,
 									(int) (1L))) + (long) (BgL_skipz00_29));
 						{	/* Tools/location.scm 120 */
-							obj_t BgL_arg1066z00_109;
+							obj_t BgL_arg1067z00_110;
 
 							{	/* Tools/location.scm 45 */
-								obj_t BgL_linesz00_196;
+								obj_t BgL_linesz00_197;
 
-								BgL_linesz00_196 =
+								BgL_linesz00_197 =
 									BGl_getzd2filezd2linesz00zztools_locationz00
-									(BgL_fnamez00_107);
+									(BgL_fnamez00_108);
 								{	/* Tools/location.scm 46 */
-									obj_t BgL__ortest_1012z00_197;
+									obj_t BgL__ortest_1012z00_198;
 
-									BgL__ortest_1012z00_197 =
+									BgL__ortest_1012z00_198 =
 										BGl_filezd2positionzd2ze3lineze3zz__r4_input_6_10_2z00(
-										(int) (BgL_nposz00_108), BgL_linesz00_196);
-									if (CBOOL(BgL__ortest_1012z00_197))
+										(int) (BgL_nposz00_109), BgL_linesz00_197);
+									if (CBOOL(BgL__ortest_1012z00_198))
 										{	/* Tools/location.scm 46 */
-											BgL_arg1066z00_109 = BgL__ortest_1012z00_197;
+											BgL_arg1067z00_110 = BgL__ortest_1012z00_198;
 										}
 									else
 										{	/* Tools/location.scm 46 */
-											BgL_arg1066z00_109 = BINT(0L);
+											BgL_arg1067z00_110 = BINT(0L);
 										}
 								}
 							}
 							{	/* Tools/location.scm 120 */
-								obj_t BgL_newz00_198;
+								obj_t BgL_newz00_199;
 
-								BgL_newz00_198 = create_struct(CNST_TABLE_REF(0L), (int) (3L));
-								{	/* Tools/location.scm 120 */
-									int BgL_tmpz00_419;
-
-									BgL_tmpz00_419 = (int) (2L);
-									STRUCT_SET(BgL_newz00_198, BgL_tmpz00_419,
-										BgL_arg1066z00_109);
-								}
-								{	/* Tools/location.scm 120 */
-									obj_t BgL_auxz00_424;
-									int BgL_tmpz00_422;
-
-									BgL_auxz00_424 = BINT(BgL_nposz00_108);
-									BgL_tmpz00_422 = (int) (1L);
-									STRUCT_SET(BgL_newz00_198, BgL_tmpz00_422, BgL_auxz00_424);
-								}
+								BgL_newz00_199 =
+									create_struct(((obj_t) CNST_TABLE_REF(0)), (int) (3L));
 								{	/* Tools/location.scm 120 */
 									int BgL_tmpz00_427;
 
-									BgL_tmpz00_427 = (int) (0L);
-									STRUCT_SET(BgL_newz00_198, BgL_tmpz00_427, BgL_fnamez00_107);
+									BgL_tmpz00_427 = (int) (2L);
+									STRUCT_SET(BgL_newz00_199, BgL_tmpz00_427,
+										BgL_arg1067z00_110);
 								}
-								return BgL_newz00_198;
+								{	/* Tools/location.scm 120 */
+									obj_t BgL_auxz00_432;
+									int BgL_tmpz00_430;
+
+									BgL_auxz00_432 = BINT(BgL_nposz00_109);
+									BgL_tmpz00_430 = (int) (1L);
+									STRUCT_SET(BgL_newz00_199, BgL_tmpz00_430, BgL_auxz00_432);
+								}
+								{	/* Tools/location.scm 120 */
+									int BgL_tmpz00_435;
+
+									BgL_tmpz00_435 = (int) (0L);
+									STRUCT_SET(BgL_newz00_199, BgL_tmpz00_435, BgL_fnamez00_108);
+								}
+								return BgL_newz00_199;
 							}
 						}
 					}
@@ -917,12 +923,12 @@ extern "C"
 
 /* &location-skip-forward */
 	obj_t BGl_z62locationzd2skipzd2forwardz62zztools_locationz00(obj_t
-		BgL_envz00_215, obj_t BgL_locz00_216, obj_t BgL_skipz00_217)
+		BgL_envz00_216, obj_t BgL_locz00_217, obj_t BgL_skipz00_218)
 	{
 		{	/* Tools/location.scm 116 */
 			return
-				BGl_locationzd2skipzd2forwardz00zztools_locationz00(BgL_locz00_216,
-				CINT(BgL_skipz00_217));
+				BGl_locationzd2skipzd2forwardz00zztools_locationz00(BgL_locz00_217,
+				CINT(BgL_skipz00_218));
 		}
 
 	}
@@ -967,8 +973,8 @@ extern "C"
 	{
 		{	/* Tools/location.scm 15 */
 			return
-				BGl_modulezd2initializa7ationz75zzengine_paramz00(517137079L,
-				BSTRING_TO_STRING(BGl_string1078z00zztools_locationz00));
+				BGl_modulezd2initializa7ationz75zzengine_paramz00(161876678L,
+				BSTRING_TO_STRING(BGl_string1079z00zztools_locationz00));
 		}
 
 	}
