@@ -1,9 +1,9 @@
 /*===========================================================================*/
 /*   (Type/pptype.scm)                                                       */
-/*   Bigloo (4.5b)                                                           */
-/*   Inria -- Sophia Antipolis (c)       Fri Dec 22 05:17:06 PM CET 2023     */
+/*   Bigloo (4.6a)                                                           */
+/*   Inria -- Sophia Antipolis (c)       Mon Jan 27 07:45:49 AM CET 2025     */
 /*===========================================================================*/
-/* COMPILATION: (/home/serrano/prgm/project/bigloo/bigloo/bin/bigloo -ldopt -L/home/serrano/prgm/project/bigloo/bigloo/libbacktrace/home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b  -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/bigloo/lib/bigloo/4.5b -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Type/pptype.scm) */
+/* COMPILATION: (/home/serrano/prgm/project/bigloo/4.6a/bin/bigloo -q -afile .afile -fsharing -fno-reflection -cc gcc -lib-dir /home/serrano/prgm/project/bigloo/4.6a/lib/bigloo/4.6a -unsafev -gno-error-localization -no-hello -O2 -rm -unsafe -s -stdc -indent Type/pptype.scm) */
 /* GC selection */
 #define THE_GC BOEHM_GC
 
@@ -38,6 +38,7 @@ extern "C"
 		obj_t BgL_parentsz00;
 		bool_t BgL_initzf3zf3;
 		bool_t BgL_magiczf3zf3;
+		obj_t BgL_nullz00;
 		obj_t BgL_z42z42;
 		obj_t BgL_aliasz00;
 		obj_t BgL_pointedzd2tozd2byz00;
@@ -155,24 +156,23 @@ extern "C"
 
 	   
 		 
-		DEFINE_STRING(BGl_string1162z00zztype_pptypez00,
-		BgL_bgl_string1162za700za7za7t1166za7, " -> ", 4);
-	      DEFINE_STRING(BGl_string1163z00zztype_pptypez00,
-		BgL_bgl_string1163za700za7za7t1167za7, "", 0);
-	      DEFINE_STRING(BGl_string1164z00zztype_pptypez00,
-		BgL_bgl_string1164za700za7za7t1168za7, " x ", 3);
-	      DEFINE_STRING(BGl_string1165z00zztype_pptypez00,
-		BgL_bgl_string1165za700za7za7t1169za7, "type_pptype", 11);
-	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_variablezd2typezd2ze3stringzd2envz31zztype_pptypez00,
-		BgL_bgl_za762variableza7d2ty1170z00,
+		BgL_bgl_za762variableza7d2ty1212z00,
 		BGl_z62variablezd2typezd2ze3stringz81zztype_pptypez00, 0L, BUNSPEC, 1);
 	     
 		DEFINE_EXPORT_BGL_PROCEDURE
 		(BGl_functionzd2typezd2ze3stringzd2envz31zztype_pptypez00,
-		BgL_bgl_za762functionza7d2ty1171z00,
+		BgL_bgl_za762functionza7d2ty1213z00,
 		BGl_z62functionzd2typezd2ze3stringz81zztype_pptypez00, 0L, BUNSPEC, 1);
+	      DEFINE_STRING(BGl_string1208z00zztype_pptypez00,
+		BgL_bgl_string1208za700za7za7t1214za7, " -> ", 4);
+	      DEFINE_STRING(BGl_string1209z00zztype_pptypez00,
+		BgL_bgl_string1209za700za7za7t1215za7, "", 0);
+	      DEFINE_STRING(BGl_string1210z00zztype_pptypez00,
+		BgL_bgl_string1210za700za7za7t1216za7, " x ", 3);
+	      DEFINE_STRING(BGl_string1211z00zztype_pptypez00,
+		BgL_bgl_string1211za700za7za7t1217za7, "type_pptype", 11);
 
 /* GC roots registration */
 	static obj_t bgl_gc_roots_register()
@@ -193,7 +193,7 @@ extern "C"
 
 /* module-initialization */
 	BGL_EXPORTED_DEF obj_t BGl_modulezd2initializa7ationz75zztype_pptypez00(long
-		BgL_checksumz00_534, char *BgL_fromz00_535)
+		BgL_checksumz00_539, char *BgL_fromz00_540)
 	{
 		{
 			if (CBOOL(BGl_requirezd2initializa7ationz75zztype_pptypez00))
@@ -249,47 +249,47 @@ extern "C"
 	{
 		{	/* Type/pptype.scm 32 */
 			{	/* Type/pptype.scm 33 */
-				BgL_valuez00_bglt BgL_sfunz00_448;
+				BgL_valuez00_bglt BgL_sfunz00_453;
 
-				BgL_sfunz00_448 =
+				BgL_sfunz00_453 =
 					(((BgL_variablez00_bglt) COBJECT(BgL_variablez00_4))->BgL_valuez00);
 				{	/* Type/pptype.scm 34 */
-					obj_t BgL_arg1097z00_449;
-					obj_t BgL_arg1098z00_450;
+					obj_t BgL_arg1105z00_454;
+					obj_t BgL_arg1110z00_455;
 
 					{	/* Type/pptype.scm 34 */
-						obj_t BgL_g1060z00_451;
+						obj_t BgL_g1060z00_456;
 
-						BgL_g1060z00_451 =
+						BgL_g1060z00_456 =
 							(((BgL_sfunz00_bglt) COBJECT(
-									((BgL_sfunz00_bglt) BgL_sfunz00_448)))->BgL_argsz00);
-						BgL_arg1097z00_449 =
-							BGl_loopze70ze7zztype_pptypez00(BgL_g1060z00_451);
+									((BgL_sfunz00_bglt) BgL_sfunz00_453)))->BgL_argsz00);
+						BgL_arg1105z00_454 =
+							BGl_loopze70ze7zztype_pptypez00(BgL_g1060z00_456);
 					}
 					{	/* Type/pptype.scm 47 */
-						obj_t BgL_arg1137z00_468;
+						obj_t BgL_arg1146z00_473;
 
 						{	/* Type/pptype.scm 47 */
-							obj_t BgL_arg1140z00_469;
+							obj_t BgL_arg1153z00_474;
 
-							BgL_arg1140z00_469 =
+							BgL_arg1153z00_474 =
 								(((BgL_typez00_bglt) COBJECT(
 										(((BgL_variablez00_bglt) COBJECT(BgL_variablez00_4))->
 											BgL_typez00)))->BgL_idz00);
 							{	/* Type/pptype.scm 47 */
-								obj_t BgL_arg1454z00_525;
+								obj_t BgL_arg1486z00_530;
 
-								BgL_arg1454z00_525 = SYMBOL_TO_STRING(BgL_arg1140z00_469);
-								BgL_arg1137z00_468 =
-									BGl_stringzd2copyzd2zz__r4_strings_6_7z00(BgL_arg1454z00_525);
+								BgL_arg1486z00_530 = SYMBOL_TO_STRING(BgL_arg1153z00_474);
+								BgL_arg1146z00_473 =
+									BGl_stringzd2copyzd2zz__r4_strings_6_7z00(BgL_arg1486z00_530);
 							}
 						}
-						BgL_arg1098z00_450 =
-							BGl_stringzd2downcasezd2zz__r4_strings_6_7z00(BgL_arg1137z00_468);
+						BgL_arg1110z00_455 =
+							BGl_stringzd2downcasezd2zz__r4_strings_6_7z00(BgL_arg1146z00_473);
 					}
 					return
-						string_append_3(BgL_arg1097z00_449,
-						BGl_string1162z00zztype_pptypez00, BgL_arg1098z00_450);
+						string_append_3(BgL_arg1105z00_454,
+						BGl_string1208z00zztype_pptypez00, BgL_arg1110z00_455);
 				}
 			}
 		}
@@ -299,62 +299,62 @@ extern "C"
 
 
 /* loop~0 */
-	obj_t BGl_loopze70ze7zztype_pptypez00(obj_t BgL_argsz00_453)
+	obj_t BGl_loopze70ze7zztype_pptypez00(obj_t BgL_argsz00_458)
 	{
 		{	/* Type/pptype.scm 34 */
-			if (NULLP(BgL_argsz00_453))
+			if (NULLP(BgL_argsz00_458))
 				{	/* Type/pptype.scm 35 */
-					return BGl_string1163z00zztype_pptypez00;
+					return BGl_string1209z00zztype_pptypez00;
 				}
 			else
 				{	/* Type/pptype.scm 40 */
-					obj_t BgL_arg1110z00_456;
-					obj_t BgL_arg1121z00_457;
-					obj_t BgL_arg1122z00_458;
+					obj_t BgL_arg1113z00_461;
+					obj_t BgL_arg1114z00_462;
+					obj_t BgL_arg1115z00_463;
 
 					{	/* Type/pptype.scm 40 */
-						obj_t BgL_arg1123z00_459;
+						obj_t BgL_arg1127z00_464;
 
 						{	/* Type/pptype.scm 40 */
-							obj_t BgL_arg1124z00_460;
+							obj_t BgL_arg1128z00_465;
 
-							BgL_arg1124z00_460 =
+							BgL_arg1128z00_465 =
 								(((BgL_typez00_bglt) COBJECT(
 										(((BgL_variablez00_bglt) COBJECT(
 													((BgL_variablez00_bglt)
 														((BgL_localz00_bglt)
 															CAR(
-																((obj_t) BgL_argsz00_453))))))->BgL_typez00)))->
+																((obj_t) BgL_argsz00_458))))))->BgL_typez00)))->
 								BgL_idz00);
 							{	/* Type/pptype.scm 39 */
-								obj_t BgL_arg1454z00_519;
+								obj_t BgL_arg1486z00_524;
 
-								BgL_arg1454z00_519 = SYMBOL_TO_STRING(BgL_arg1124z00_460);
-								BgL_arg1123z00_459 =
-									BGl_stringzd2copyzd2zz__r4_strings_6_7z00(BgL_arg1454z00_519);
+								BgL_arg1486z00_524 = SYMBOL_TO_STRING(BgL_arg1128z00_465);
+								BgL_arg1127z00_464 =
+									BGl_stringzd2copyzd2zz__r4_strings_6_7z00(BgL_arg1486z00_524);
 							}
 						}
-						BgL_arg1110z00_456 =
-							BGl_stringzd2downcasezd2zz__r4_strings_6_7z00(BgL_arg1123z00_459);
+						BgL_arg1113z00_461 =
+							BGl_stringzd2downcasezd2zz__r4_strings_6_7z00(BgL_arg1127z00_464);
 					}
-					if (NULLP(CDR(((obj_t) BgL_argsz00_453))))
+					if (NULLP(CDR(((obj_t) BgL_argsz00_458))))
 						{	/* Type/pptype.scm 41 */
-							BgL_arg1121z00_457 = BGl_string1163z00zztype_pptypez00;
+							BgL_arg1114z00_462 = BGl_string1209z00zztype_pptypez00;
 						}
 					else
 						{	/* Type/pptype.scm 41 */
-							BgL_arg1121z00_457 = BGl_string1164z00zztype_pptypez00;
+							BgL_arg1114z00_462 = BGl_string1210z00zztype_pptypez00;
 						}
 					{	/* Type/pptype.scm 44 */
-						obj_t BgL_arg1135z00_466;
+						obj_t BgL_arg1145z00_471;
 
-						BgL_arg1135z00_466 = CDR(((obj_t) BgL_argsz00_453));
-						BgL_arg1122z00_458 =
-							BGl_loopze70ze7zztype_pptypez00(BgL_arg1135z00_466);
+						BgL_arg1145z00_471 = CDR(((obj_t) BgL_argsz00_458));
+						BgL_arg1115z00_463 =
+							BGl_loopze70ze7zztype_pptypez00(BgL_arg1145z00_471);
 					}
 					return
-						string_append_3(BgL_arg1110z00_456, BgL_arg1121z00_457,
-						BgL_arg1122z00_458);
+						string_append_3(BgL_arg1113z00_461, BgL_arg1114z00_462,
+						BgL_arg1115z00_463);
 				}
 		}
 
@@ -364,12 +364,12 @@ extern "C"
 
 /* &function-type->string */
 	obj_t BGl_z62functionzd2typezd2ze3stringz81zztype_pptypez00(obj_t
-		BgL_envz00_530, obj_t BgL_variablez00_531)
+		BgL_envz00_535, obj_t BgL_variablez00_536)
 	{
 		{	/* Type/pptype.scm 32 */
 			return
 				BGl_functionzd2typezd2ze3stringze3zztype_pptypez00(
-				((BgL_variablez00_bglt) BgL_variablez00_531));
+				((BgL_variablez00_bglt) BgL_variablez00_536));
 		}
 
 	}
@@ -383,25 +383,25 @@ extern "C"
 	{
 		{	/* Type/pptype.scm 52 */
 			{	/* Type/pptype.scm 53 */
-				obj_t BgL_arg1142z00_471;
+				obj_t BgL_arg1157z00_476;
 
 				{	/* Type/pptype.scm 53 */
-					obj_t BgL_arg1143z00_472;
+					obj_t BgL_arg1158z00_477;
 
-					BgL_arg1143z00_472 =
+					BgL_arg1158z00_477 =
 						(((BgL_typez00_bglt) COBJECT(
 								(((BgL_variablez00_bglt) COBJECT(BgL_variablez00_5))->
 									BgL_typez00)))->BgL_idz00);
 					{	/* Type/pptype.scm 53 */
-						obj_t BgL_arg1454z00_529;
+						obj_t BgL_arg1486z00_534;
 
-						BgL_arg1454z00_529 = SYMBOL_TO_STRING(BgL_arg1143z00_472);
-						BgL_arg1142z00_471 =
-							BGl_stringzd2copyzd2zz__r4_strings_6_7z00(BgL_arg1454z00_529);
+						BgL_arg1486z00_534 = SYMBOL_TO_STRING(BgL_arg1158z00_477);
+						BgL_arg1157z00_476 =
+							BGl_stringzd2copyzd2zz__r4_strings_6_7z00(BgL_arg1486z00_534);
 					}
 				}
 				return
-					BGl_stringzd2downcasezd2zz__r4_strings_6_7z00(BgL_arg1142z00_471);
+					BGl_stringzd2downcasezd2zz__r4_strings_6_7z00(BgL_arg1157z00_476);
 			}
 		}
 
@@ -411,12 +411,12 @@ extern "C"
 
 /* &variable-type->string */
 	obj_t BGl_z62variablezd2typezd2ze3stringz81zztype_pptypez00(obj_t
-		BgL_envz00_532, obj_t BgL_variablez00_533)
+		BgL_envz00_537, obj_t BgL_variablez00_538)
 	{
 		{	/* Type/pptype.scm 52 */
 			return
 				BGl_variablezd2typezd2ze3stringze3zztype_pptypez00(
-				((BgL_variablez00_bglt) BgL_variablez00_533));
+				((BgL_variablez00_bglt) BgL_variablez00_538));
 		}
 
 	}
@@ -461,10 +461,10 @@ extern "C"
 	{
 		{	/* Type/pptype.scm 15 */
 			BGl_modulezd2initializa7ationz75zztype_typez00(515343395L,
-				BSTRING_TO_STRING(BGl_string1165z00zztype_pptypez00));
+				BSTRING_TO_STRING(BGl_string1211z00zztype_pptypez00));
 			return
 				BGl_modulezd2initializa7ationz75zzast_varz00(90839984L,
-				BSTRING_TO_STRING(BGl_string1165z00zztype_pptypez00));
+				BSTRING_TO_STRING(BGl_string1211z00zztype_pptypez00));
 		}
 
 	}
