@@ -3,8 +3,8 @@
 ;*    -------------------------------------------------------------    */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Sun Dec 25 11:32:49 1994                          */
-;*    Last change :  Fri Jul  6 14:03:43 2001 (serrano)                */
-;*    Copyright   :  1994-2001 Manuel Serrano, see LICENSE file        */
+;*    Last change :  Wed May  7 08:42:35 2014 (serrano)                */
+;*    Copyright   :  1994-2014 Manuel Serrano, see LICENSE file        */
 ;*    -------------------------------------------------------------    */
 ;*    The Type environment manipulation                                */
 ;*=====================================================================*/
@@ -17,7 +17,8 @@
    (include "Tools/trace.sch"
 	    "Type/coercer.sch")
    
-   (import  tools_shape
+   (import  init_main
+	    tools_shape
 	    tools_error
 	    tools_location
 	    ast_ident
@@ -30,10 +31,15 @@
 	    type_cache
 	    foreign_ctype
 	    object_class
-	    object_wide-access
-	    object_plain-access
+	    object_predicate
+	    object_creator
+	    object_slots
+	    tvector_tvector
 	    foreign_access
-	    module_foreign)
+	    module_foreign
+	    module_java
+	    module_type
+	    tvector_access)
 
    (static  (bind-type!::type ::symbol ::bool loc)
 	    (uninitialized-types))
@@ -43,6 +49,7 @@
 	    (add-tenv! <Tenv>)
 	    (get-tenv)
 	    (find-type::type ::symbol)
+	    (find-type/location::type ::symbol loc)
 	    (use-type!::type ::symbol loc)
 	    (use-type/import-loc!::type ::symbol loc loci)
 	    (use-foreign-type!::type ::symbol loc)
@@ -62,20 +69,41 @@
 ;*---------------------------------------------------------------------*/
 (define *Tenv* 'the-global-environment)
 
+;*---------------------------------------------------------------------*/
+;*    initialize-Tenv! ...                                             */
+;*---------------------------------------------------------------------*/
+(define (initialize-Tenv!)
+   ;; the global environment
+   (unless (hashtable? *Tenv*)
+      (set! *Tenv* (make-hashtable))))
+
+;*---------------------------------------------------------------------*/
+;*    get-tenv ...                                                     */
+;*---------------------------------------------------------------------*/
+(define (get-tenv)
+   *Tenv*)
+
 ;*---------------------------------------------------------------------*/
 ;*    set-tenv! ...                                                    */
 ;*---------------------------------------------------------------------*/
 (define (set-tenv! Tenv)
-   (set! *Tenv* Tenv))
+   ;; versions 2.6 and smaller used: (set! *Tenv* Tenv)
+   ;; this is nolonger a valid implementation because the standard
+   ;; library of bigloo2.7 provides classes with slots (e.g. &exception).
+   ;; the add-tenv! function takes care of defining the accessors of
+   ;; the classes that are defined in a heap.
+   (initialize-Tenv!)
+   (add-tenv! Tenv))
 
 ;*---------------------------------------------------------------------*/
 ;*    add-tenv! ...                                                    */
 ;*---------------------------------------------------------------------*/
 (define (add-tenv! Tenv)
+   
    (define (adjust-type-coercers! type)
       ;; fix aliased type
-      (if (type? (type-alias type))
-	  (type-alias-set! type (find-type (type-id (type-alias type)))))
+      (when (type? (type-alias type))
+	 (type-alias-set! type (find-type (type-id (type-alias type)))))
       ;; fix subtypes
       (type-parents-set! type
 			 (map (lambda (parent)
@@ -84,35 +112,48 @@
       ;; fix coercers
       (for-each (lambda (coercer)
 		   (let ((from (coercer-from coercer))
-			 (to   (coercer-to coercer)))
+			 (to (coercer-to coercer)))
 		      (coercer-from-set! coercer (find-type (type-id from)))
-		      (coercer-to-set! coercer (find-type (type-id to)))))
+		      (coercer-to-set! coercer (find-type (type-id to)))
+		      (for-each (lambda (co)
+				   (set-cdr! co (find-type (type-id (cdr co)))))
+				(coercer-check-op coercer))
+		      (for-each (lambda (co)
+				   (set-cdr! co (find-type (type-id (cdr co)))))
+				(coercer-coerce-op coercer))))
 		(type-coerce-to type)))
+   
    (define (find-coercer from to)
       (let loop ((coercer (type-coerce-to from)))
 	 (cond
-	    ((null? coercer)
-	     #f)
-	    ((eq? (coercer-to (car coercer)) to)
-	     (car coercer))
-	    (else
-	     (loop (cdr coercer))))))
+	    ((null? coercer) #f)
+	    ((eq? (coercer-to (car coercer)) to) (car coercer))
+	    (else (loop (cdr coercer))))))
+   
    (define (add-type-coercers! old new)
       (for-each (lambda (coercer)
-		   (let* ((from        (coercer-from coercer))
-			  (to          (coercer-to coercer))
-			  (tid         (type-id to))
+		   (let* ((from (coercer-from coercer))
+			  (to (coercer-to coercer))
+			  (tid (type-id to))
 			  (tid-exists? (type-exists? tid)))
-		      (if (or (not tid-exists?)
-			      (not (find-coercer old (find-type tid))))
-			  (type-coerce-to-set! old
-					       (cons coercer
-						     (type-coerce-to old))))))
+		      (when (or (not tid-exists?)
+				(not (find-coercer old (find-type tid))))
+			 (type-coerce-to-set! old
+					      (cons coercer
+						    (type-coerce-to old))))))
 		(type-coerce-to new)))
-   ;; in a first stage, we bind all new types (not rebinding already binded
-   ;; types)
-   (let ((remember-list '()))
-      
+
+   (define (find-new t)
+      (if (isa? t type)
+	  (with-access::type t (id)
+	     (let ((old (hashtable-get *Tenv* id)))
+		(or old t)))
+	  t))
+   
+   ;; in a first stage, we bind all new types
+   ;; (not rebinding already binded types)
+   (let ((remember-list '())
+	 (tvector-list '()))
       ;; the remember list is used to store class type. We have to make
       ;; three traversals over classes. A first one for defining them,
       ;; a second one, when all classes are correctly set up, to
@@ -120,63 +161,74 @@
       ;; classes would have a its-super field that points to the old
       ;; hash table (the one restored, not the current compiler's one).
       ;; The last traversal used to construct the class accessors
+      ;; The same thing apply to tvectors
       (hashtable-for-each Tenv
-			  (lambda (k new)
-			     (let* ((id  (type-id new))
-				    (old (hashtable-get *Tenv* id)))
-				(cond
-				   ((not (type? old))
-				    (hashtable-put! *Tenv* id new)
-				    (if (tclass? new)
-					(begin
-					   (heap-add-class! new)
-					   (set! remember-list
-						 (cons new remember-list)))))
-				   ((not (type-init? old))
-				    (error "add-Tenv!"
-					   "Illegal type heap redefinition"
-					   id)
-				    (exit 255))
-				   (else
-				    ;; we have to store the new coercers 
-				    ;; for the old type
-				    (add-type-coercers! old new))))))
+	 (lambda (k new)
+	    (let* ((id  (type-id new))
+		   (old (hashtable-get *Tenv* id)))
+	       (cond
+		  ((not (type? old))
+		   (hashtable-put! *Tenv* id new)
+		   (when (tclass? new)
+		      (heap-add-class! new)
+		      (set! remember-list
+			 (cons new remember-list)))
+		   (when (jclass? new)
+		      (heap-add-jclass! new))
+		   (when (tvec? new)
+		      (set! tvector-list
+			 (cons new tvector-list))))
+		  ((not (type-init? old))
+		   (error "add-Tenv!"
+		      "Illegal type heap redefinition"
+		      id)
+		   (compiler-exit 55))
+		  (else
+		   ;; we have to store the new coercers 
+		   ;; for the old type
+		   (add-type-coercers! old new))))))
       (hashtable-for-each Tenv
-			  (lambda (k new)
-			     (let* ((id  (type-id new))
-				    (old (hashtable-get *Tenv* id)))
-				(if (ctype? old)
-				    (let ((l (type-location old)))
-				       (foreign-accesses-add!
-					(make-ctype-accesses! old old l)))))))
+	 (lambda (k new)
+	    (let* ((id  (type-id new))
+		   (old (hashtable-get *Tenv* id)))
+	       (when (ctype? old)
+		  (let ((l (type-location old)))
+		     (foreign-accesses-add!
+			(make-ctype-accesses! old old l)))))))
       ;; we have to walk thru the remember list in order to
       ;; setup the correct super class fields
       (for-each (lambda (new)
-		   (if (tclass? new)
-		       (let ((super (tclass-its-super new)))
-			  (if (tclass? super)
-			      (let* ((super-id (tclass-id super))
-				     (old-s    (find-type super-id)))
-				 (if (not (tclass? old-s))
-				     (error "add-Tenv"
-					    "Can't find super class of"
-					    (tclass-name new))
-				     (tclass-its-super-set! new old-s)))))))
-		remember-list)
+		   (when (tclass? new)
+		      ;; super class
+		      (let ((super (tclass-its-super new)))
+			 (when (tclass? super)
+			    (let* ((super-id (tclass-id super))
+				   (old-s (find-type super-id)))
+			       (if (not (tclass? old-s))
+				   (error 'add-Tenv
+				      "Can't find super class of"
+				      (tclass-name new))
+				   (tclass-its-super-set! new old-s)))))))
+	 remember-list)
+      ;; the tvector traversal
+      (for-each (lambda (new)
+		   (delay-tvector! new 'heap #f))
+	 tvector-list)
       ;; the last walk to construct the class accessors
       ;; When we load an additional heap that contains classes
       ;; definition, the accessors are build when compiling the module
       ;; that uses the library. These accessors have to be added to
       ;; the other classes accessors.
-      (for-each (lambda (new)
-		   (if (tclass? new)
+      (for-each (lambda (n)
+		   (if (tclass? n)
 		       (delay-class-accessors!
-			new
-			(delay
-			   (if (tclass-widening new)
-			       (heap-wide-class-accessors! new)
-			       (heap-plain-class-accessors! new))))))
-		remember-list))
+			  n
+			  (delay
+			     ;; The test cannot be lifter out of the delay
+			     ;; scope otherwise it gets evaluated before the
+			     ;; modules options are evaluated.
+			     '()))))
+	 remember-list))
    ;; in a second stage, we have to reset the all coercer for _all_ types.
    ;; This is mandatory because some types have not been rebound and
    ;; then we need to adjust the coercer fields of freshly bound types.
@@ -187,26 +239,22 @@
 		       (lambda (k new)
 			  (adjust-type-coercers! new))))
 		 
-;*---------------------------------------------------------------------*/
-;*    get-tenv ...                                                     */
-;*---------------------------------------------------------------------*/
-(define (get-tenv)
-   *Tenv*)
-
-;*---------------------------------------------------------------------*/
-;*    initialize-Tenv! ...                                             */
-;*---------------------------------------------------------------------*/
-(define (initialize-Tenv!)
-   ;; the global environment
-   (set! *Tenv* (make-hashtable)))
-
 ;*---------------------------------------------------------------------*/
 ;*    find-type ...                                                    */
 ;*---------------------------------------------------------------------*/
 (define (find-type::type id::symbol)
    (let ((type (hashtable-get *Tenv* id)))
       (if (not (type? type))
-	  (error "find-type" "Can't find type" id)
+	  (error 'find-type "Can't find type" id)
+	  type)))
+
+;*---------------------------------------------------------------------*/
+;*    find-type/loc ...                                                */
+;*---------------------------------------------------------------------*/
+(define (find-type/location::type id::symbol loc)
+   (let ((type (hashtable-get *Tenv* id)))
+      (if (not (type? type))
+	  (user-error/location loc 'find-type "Can't find type" id)
 	  type)))
 
 ;*---------------------------------------------------------------------*/
@@ -226,9 +274,18 @@
 (define (bind-type!::type id::symbol init?::bool loc)
    (let ((type (hashtable-get *Tenv* id)))
       (if (type? type)
-	  (if (and (not *lib-mode*) (type-init? type))
-	      (user-error "bind-type!" "Type redefinition" (shape type))
+	  (if (and (not *allow-type-redefinition*)
+		   (not *lib-mode*)
+		   (type-init? type))
+	      (user-error 'bind-type! "Type redefinition" (shape type))
 	      (begin
+		 (when (and (type? type)
+			    (not *lib-mode*)
+			    (type-init? type))
+		    (unless *allow-type-redefinition*
+		       (user-warning 'bind-type!
+				     "Type redefinition"
+				     (shape type))))
 		 ;; the type has already been allocated, we mark it
 		 ;; has initialized.
 		 (if init? (type-init?-set! type #t))
@@ -246,12 +303,15 @@
    (let ((type (hashtable-get *Tenv* id)))
       (cond
 	 ((type? type)
+	  (type-occurrence-increment! type)
 	  type)
 	 (*types-already-checked?*
-	  (user-error/location loc "use-type!" "Can't find type" id))
+	  (user-error/location loc 'use-type! "Can't find type" id))
 	 (else
 	  (trace (ast 3) "    TYPE BOUND " id #\Newline)
-	  (bind-type! id #f loc)))))
+	  (let ((type (bind-type! id #f loc)))
+	     (type-occurrence-increment! type)
+	     type)))))
 
 ;*---------------------------------------------------------------------*/
 ;*    use-type/import-loc! ...                                         */
@@ -263,7 +323,7 @@
 	 ((type? type)
 	  type)
 	 (*types-already-checked?*
-	  (user-error/location loc "use-type!" "Can't find type" id))
+	  (user-error/location loc 'use-type! "Can't find type" id))
 	 (else
 	  (trace (ast 3) "    TYPE BOUND " id #\Newline)
 	  (let ((type (bind-type! id #f loc)))
@@ -274,7 +334,7 @@
 ;*    use-foreign-type! ...                                            */
 ;*    -------------------------------------------------------------    */
 ;*    I have changed the syntax for the foreign declaration. In order  */
-;*    to be consisten now, extern clauses have to be written using     */
+;*    to be consistent now, extern clauses have to be written using    */
 ;*    the :: notation (e.g. (print::int (::string ::int) "printf")).   */
 ;*    Since I also want a backward compatibility Bigloo accepts the    */
 ;*    two syntaxes. This function implement the compatibility.         */
@@ -296,7 +356,7 @@
 ;*    use-foreign-type/import-loc! ...                                 */
 ;*    -------------------------------------------------------------    */
 ;*    I have changed the syntax for the foreign declaration. In order  */
-;*    to be consisten now, extern clauses have to be written using     */
+;*    to be consistent now, extern clauses have to be written using    */
 ;*    the :: notation (e.g. (print::int (::string ::int) "printf")).   */
 ;*    Since I also want a backward compatibility Bigloo accepts the    */
 ;*    two syntaxes. This function implement the compatibility.         */
@@ -336,7 +396,7 @@
 ;*---------------------------------------------------------------------*/
 (define (declare-subtype!::type id::symbol name::bstring parents class::symbol)
    (trace (ast 2) "~~~ declare-subtype!: " id #\Newline)
-   [assert (parents) (list? parents)]
+   (assert (parents) (list? parents))
    (let ((type    (bind-type! id #t #unspecified))
 	 (parents (map find-type parents)))
       (type-name-set!    type name)
@@ -388,39 +448,34 @@
 ;*---------------------------------------------------------------------*/
 (define (check-types)
    (let ((ut (uninitialized-types)))
-      (if (pair? ut)
-	  (begin
-	     (newline (current-error-port))
-	     (fprint (current-error-port)
-		     (length ut)
-		     " type(s) used but not defined.")
-	     (let loop ((ut ut))
-		(cond
-		   ((null? ut)
-		    (fprint (current-error-port) "Stopping compilation...")
-		    (exit -1))
-		   ((type? (car ut))
-		    (try (if (type-import-location (car ut))
-			     (user-error/location (type-import-location (car ut))
-						  *module*
-						  "Undefined type used in export clause"
-						  (shape (car ut)))
-			     (user-error/location (type-location (car ut))
-						  *module*
-						  "Undefined used type"
-						  (shape (car ut))))
-			 (lambda (escape obj proc msg)
-			    (notify-error obj proc msg)
-			    (escape #f)))
-		    (loop (cdr ut)))
-		   (else
-		    (try (error *module*
-				"Undefined type"
-				(shape (car ut)))
-			 (lambda (escape obj proc msg)
-			    (notify-error obj proc msg)
-			    (escape #f)))
-		    (loop (cdr ut)))))))
+      (when (pair? ut)
+	 (newline (current-error-port))
+	 (fprint (current-error-port)
+		 (length ut) " type(s) used but not defined.")
+	 (let loop ((ut ut))
+	    (cond
+	       ((null? ut)
+		(fprint (current-error-port) "Stopping compilation...")
+		(compiler-exit 56))
+	       ((type? (car ut))
+		(with-exception-handler
+		   error-notify
+		   (lambda ()
+		      (if (type-import-location (car ut))
+			  (user-error/location (type-import-location (car ut))
+					       *module*
+					       "Undefined type used in export clause"
+					       (shape (car ut)))
+			  (user-error/location (type-location (car ut))
+					       *module*
+					       "Undefined used type"
+					       (shape (car ut))))))
+		(loop (cdr ut)))
+	       (else
+		(with-exception-handler
+		   error-notify
+		   (lambda ()
+		      (error *module* "Undefined type" (shape (car ut)))))))))
       (set! *types-already-checked?* #t)))
 
 ;*---------------------------------------------------------------------*/
