@@ -189,7 +189,7 @@
     void *base;
 
     GC_print_heap_obj(GC_base(current));
-
+    GC_err_printf("\n");
     for (i = 0; ; ++i) {
       source = GC_get_back_ptr_info(current, &base, &offset);
       if (GC_UNREFERENCED == source) {
@@ -215,6 +215,7 @@
           GC_err_printf("offset %ld in object:\n", (long)offset);
           /* Take GC_base(base) to get real base, i.e. header. */
           GC_print_heap_obj(GC_base(base));
+          GC_err_printf("\n");
           break;
         default:
           GC_err_printf("INTERNAL ERROR: UNEXPECTED SOURCE!!!!\n");
@@ -225,8 +226,8 @@
     out:;
   }
 
-  /* Force a garbage collection and generate/print a backtrace  */
-  /* from a random heap address.                                */
+  /* Force a garbage collection and generate a backtrace from a */
+  /* random heap address.                                       */
   GC_INNER void GC_generate_random_backtrace_no_gc(void)
   {
     void * current;
@@ -321,83 +322,69 @@ GC_API void GC_CALL GC_register_describe_type_fn(int kind,
   GC_describe_type_fns[kind] = fn;
 }
 
+/* Print a type description for the object whose client-visible address */
+/* is p.                                                                */
+STATIC void GC_print_type(ptr_t p)
+{
+    hdr * hhdr = GC_find_header(p);
+    char buffer[GC_TYPE_DESCR_LEN + 1];
+    int kind = hhdr -> hb_obj_kind;
+
+    if (0 != GC_describe_type_fns[kind] && GC_is_marked(GC_base(p))) {
+        /* This should preclude free list objects except with   */
+        /* thread-local allocation.                             */
+        buffer[GC_TYPE_DESCR_LEN] = 0;
+        (GC_describe_type_fns[kind])(p, buffer);
+        GC_ASSERT(buffer[GC_TYPE_DESCR_LEN] == 0);
+        GC_err_puts(buffer);
+    } else {
+        switch(kind) {
+          case PTRFREE:
+            GC_err_puts("PTRFREE");
+            break;
+          case NORMAL:
+            GC_err_puts("NORMAL");
+            break;
+          case UNCOLLECTABLE:
+            GC_err_puts("UNCOLLECTABLE");
+            break;
+#         ifdef ATOMIC_UNCOLLECTABLE
+            case AUNCOLLECTABLE:
+              GC_err_puts("ATOMIC UNCOLLECTABLE");
+              break;
+#         endif
+          case STUBBORN:
+            GC_err_puts("STUBBORN");
+            break;
+          default:
+            GC_err_printf("kind=%d descr=0x%lx", kind,
+                          (unsigned long)(hhdr -> hb_descr));
+        }
+    }
+}
+
 #define GET_OH_LINENUM(ohdr) ((int)(ohdr)->oh_int)
 
-#ifndef SHORT_DBG_HDRS
-# define IF_NOT_SHORTDBG_HDRS(x) x
-# define COMMA_IFNOT_SHORTDBG_HDRS(x) /* comma */, x
-#else
-# define IF_NOT_SHORTDBG_HDRS(x) /* empty */
-# define COMMA_IFNOT_SHORTDBG_HDRS(x) /* empty */
-#endif
-
-/* Print a human-readable description of the object to stderr.          */
-/* p points to somewhere inside an object with the debugging info.      */
+/* Print a human-readable description of the object to stderr. p points */
+/* to somewhere inside an object with the debugging info.               */
 STATIC void GC_print_obj(ptr_t p)
 {
     oh * ohdr = (oh *)GC_base(p);
-    ptr_t q;
-    hdr * hhdr;
-    int kind;
-    char *kind_str;
-    char buffer[GC_TYPE_DESCR_LEN + 1];
 
     GC_ASSERT(I_DONT_HOLD_LOCK());
 #   ifdef LINT2
       if (!ohdr) ABORT("Invalid GC_print_obj argument");
 #   endif
-
-    q = (ptr_t)(ohdr + 1);
-    /* Print a type description for the object whose client-visible     */
-    /* address is q.                                                    */
-    hhdr = GC_find_header(q);
-    kind = hhdr -> hb_obj_kind;
-    if (0 != GC_describe_type_fns[kind] && GC_is_marked(ohdr)) {
-        /* This should preclude free list objects except with   */
-        /* thread-local allocation.                             */
-        buffer[GC_TYPE_DESCR_LEN] = 0;
-        (GC_describe_type_fns[kind])(q, buffer);
-        GC_ASSERT(buffer[GC_TYPE_DESCR_LEN] == 0);
-        kind_str = buffer;
-    } else {
-        switch(kind) {
-          case PTRFREE:
-            kind_str = "PTRFREE";
-            break;
-          case NORMAL:
-            kind_str = "NORMAL";
-            break;
-          case UNCOLLECTABLE:
-            kind_str = "UNCOLLECTABLE";
-            break;
-#         ifdef ATOMIC_UNCOLLECTABLE
-            case AUNCOLLECTABLE:
-              kind_str = "ATOMIC_UNCOLLECTABLE";
-              break;
-#         endif
-          case STUBBORN:
-            kind_str = "STUBBORN";
-            break;
-          default:
-            kind_str = NULL;
-                /* The alternative is to use snprintf(buffer) but it is */
-                /* not quite portable (see vsnprintf in misc.c).        */
-        }
-    }
-
-    if (NULL != kind_str) {
-        GC_err_printf("%p (%s:%d," IF_NOT_SHORTDBG_HDRS(" sz=%lu,") " %s)\n",
-                      (ptr_t)ohdr + sizeof(oh),
-                      ohdr->oh_string, GET_OH_LINENUM(ohdr) /*, */
-                      COMMA_IFNOT_SHORTDBG_HDRS((unsigned long)ohdr->oh_sz),
-                      kind_str);
-    } else {
-        GC_err_printf("%p (%s:%d," IF_NOT_SHORTDBG_HDRS(" sz=%lu,")
-                      " kind=%d descr=0x%lx)\n", (ptr_t)ohdr + sizeof(oh),
-                      ohdr->oh_string, GET_OH_LINENUM(ohdr) /*, */
-                      COMMA_IFNOT_SHORTDBG_HDRS((unsigned long)ohdr->oh_sz),
-                      kind, (unsigned long)hhdr->hb_descr);
-    }
+    GC_err_printf("%p (", ((ptr_t)ohdr + sizeof(oh)));
+    GC_err_puts(ohdr -> oh_string);
+#   ifdef SHORT_DBG_HDRS
+      GC_err_printf(":%d, ", GET_OH_LINENUM(ohdr));
+#   else
+      GC_err_printf(":%d, sz=%lu, ",
+                    GET_OH_LINENUM(ohdr), (unsigned long)(ohdr -> oh_sz));
+#   endif
+    GC_print_type((ptr_t)(ohdr + 1));
+    GC_err_puts(")\n");
     PRINT_CALL_CHAIN(ohdr);
 }
 
@@ -449,9 +436,8 @@ STATIC void GC_debug_print_heap_obj_proc(ptr_t p)
   STATIC void GC_do_nothing(void) {}
 #endif
 
-STATIC void GC_start_debugging_inner(void)
+GC_INNER void GC_start_debugging(void)
 {
-  GC_ASSERT(I_HOLD_LOCK());
 # ifndef SHORT_DBG_HDRS
     GC_check_heap = GC_check_heap_proc;
     GC_print_all_smashed = GC_print_all_smashed_proc;
@@ -461,28 +447,15 @@ STATIC void GC_start_debugging_inner(void)
 # endif
   GC_print_heap_obj = GC_debug_print_heap_obj_proc;
   GC_debugging_started = TRUE;
-  GC_register_displacement_inner((word)sizeof(oh));
-}
-
-GC_INNER void GC_start_debugging(void)
-{
-  DCL_LOCK_STATE;
-
-  LOCK();
-  GC_start_debugging_inner();
-  UNLOCK();
+  GC_register_displacement((word)sizeof(oh));
 }
 
 size_t GC_debug_header_size = sizeof(oh);
 
 GC_API void GC_CALL GC_debug_register_displacement(size_t offset)
 {
-  DCL_LOCK_STATE;
-
-  LOCK();
-  GC_register_displacement_inner(offset);
-  GC_register_displacement_inner((word)sizeof(oh) + offset);
-  UNLOCK();
+    GC_register_displacement(offset);
+    GC_register_displacement((word)sizeof(oh) + offset);
 }
 
 GC_API void * GC_CALL GC_debug_malloc(size_t lb, GC_EXTRA_PARAMS)
@@ -494,8 +467,10 @@ GC_API void * GC_CALL GC_debug_malloc(size_t lb, GC_EXTRA_PARAMS)
     result = GC_malloc(lb + DEBUG_BYTES);
 
     if (result == 0) {
-        GC_err_printf("GC_debug_malloc(%lu) returning NULL (%s:%d)\n",
-                      (unsigned long)lb, s, i);
+        GC_err_printf("GC_debug_malloc(%lu) returning NULL (",
+                      (unsigned long) lb);
+        GC_err_puts(s);
+        GC_err_printf(":%d)\n", i);
         return(0);
     }
     if (!GC_debugging_started) {
@@ -511,8 +486,10 @@ GC_API void * GC_CALL GC_debug_malloc_ignore_off_page(size_t lb,
     void * result = GC_malloc_ignore_off_page(lb + DEBUG_BYTES);
 
     if (result == 0) {
-        GC_err_printf("GC_debug_malloc_ignore_off_page(%lu)"
-                      " returning NULL (%s:%d)\n", (unsigned long)lb, s, i);
+        GC_err_printf("GC_debug_malloc_ignore_off_page(%lu) returning NULL (",
+                       (unsigned long) lb);
+        GC_err_puts(s);
+        GC_err_printf(":%d)\n", i);
         return(0);
     }
     if (!GC_debugging_started) {
@@ -529,7 +506,9 @@ GC_API void * GC_CALL GC_debug_malloc_atomic_ignore_off_page(size_t lb,
 
     if (result == 0) {
         GC_err_printf("GC_debug_malloc_atomic_ignore_off_page(%lu)"
-                      " returning NULL (%s:%d)\n", (unsigned long)lb, s, i);
+                      " returning NULL (", (unsigned long)lb);
+        GC_err_puts(s);
+        GC_err_printf(":%d)\n", i);
         return(0);
     }
     if (!GC_debugging_started) {
@@ -554,9 +533,6 @@ GC_API void * GC_CALL GC_debug_malloc_atomic_ignore_off_page(size_t lb,
                        (unsigned long) lb);
         return(0);
     }
-    if (!GC_debugging_started) {
-        GC_start_debugging_inner();
-    }
     ADD_CALL_CHAIN(result, GC_RETURN_ADDR);
     return (GC_store_debug_info_inner(result, (word)lb, "INTERNAL", 0));
   }
@@ -572,9 +548,6 @@ GC_API void * GC_CALL GC_debug_malloc_atomic_ignore_off_page(size_t lb,
                        (unsigned long) lb);
         return(0);
     }
-    if (!GC_debugging_started) {
-        GC_start_debugging_inner();
-    }
     ADD_CALL_CHAIN(result, GC_RETURN_ADDR);
     return (GC_store_debug_info_inner(result, (word)lb, "INTERNAL", 0));
   }
@@ -586,8 +559,10 @@ GC_API void * GC_CALL GC_debug_malloc_atomic_ignore_off_page(size_t lb,
     void * result = GC_malloc_stubborn(lb + DEBUG_BYTES);
 
     if (result == 0) {
-        GC_err_printf("GC_debug_malloc_stubborn(%lu)"
-                      " returning NULL (%s:%d)\n", (unsigned long)lb, s, i);
+        GC_err_printf("GC_debug_malloc(%lu) returning NULL (",
+                      (unsigned long) lb);
+        GC_err_puts(s);
+        GC_err_printf(":%d)\n", i);
         return(0);
     }
     if (!GC_debugging_started) {
@@ -603,11 +578,13 @@ GC_API void * GC_CALL GC_debug_malloc_atomic_ignore_off_page(size_t lb,
     hdr * hhdr;
 
     if (q == 0) {
-        ABORT_ARG1("GC_debug_change_stubborn: bad arg", ": %p", p);
+        GC_err_printf("Bad argument: %p to GC_debug_change_stubborn\n", p);
+        ABORT("GC_debug_change_stubborn: bad arg");
     }
     hhdr = HDR(q);
     if (hhdr -> hb_obj_kind != STUBBORN) {
-        ABORT_ARG1("GC_debug_change_stubborn: arg not stubborn", ": %p", p);
+        GC_err_printf("GC_debug_change_stubborn arg not stubborn: %p\n", p);
+        ABORT("GC_debug_change_stubborn: arg not stubborn");
     }
     GC_change_stubborn(q);
   }
@@ -618,12 +595,13 @@ GC_API void * GC_CALL GC_debug_malloc_atomic_ignore_off_page(size_t lb,
     hdr * hhdr;
 
     if (q == 0) {
-        ABORT_ARG1("GC_debug_end_stubborn_change: bad arg", ": %p", p);
+        GC_err_printf("Bad argument: %p to GC_debug_end_stubborn_change\n", p);
+        ABORT("GC_debug_end_stubborn_change: bad arg");
     }
     hhdr = HDR(q);
     if (hhdr -> hb_obj_kind != STUBBORN) {
-        ABORT_ARG1("GC_debug_end_stubborn_change: arg not stubborn",
-                   ": %p", p);
+        GC_err_printf("debug_end_stubborn_change arg not stubborn: %p\n", p);
+        ABORT("GC_debug_end_stubborn_change: arg not stubborn");
     }
     GC_end_stubborn_change(q);
   }
@@ -647,8 +625,10 @@ GC_API void * GC_CALL GC_debug_malloc_atomic(size_t lb, GC_EXTRA_PARAMS)
     void * result = GC_malloc_atomic(lb + DEBUG_BYTES);
 
     if (result == 0) {
-        GC_err_printf("GC_debug_malloc_atomic(%lu) returning NULL (%s:%d)\n",
-                      (unsigned long)lb, s, i);
+        GC_err_printf("GC_debug_malloc_atomic(%lu) returning NULL (",
+                      (unsigned long) lb);
+        GC_err_puts(s);
+        GC_err_printf(":%d)\n", i);
         return(0);
     }
     if (!GC_debugging_started) {
@@ -676,7 +656,12 @@ GC_API char * GC_CALL GC_debug_strdup(const char *str, GC_EXTRA_PARAMS)
 #   endif
     return NULL;
   }
-  BCOPY(str, copy, lb);
+# ifndef MSWINCE
+    strcpy(copy, str);
+# else
+    /* strcpy() is deprecated in WinCE */
+    memcpy(copy, str, lb);
+# endif
   return copy;
 }
 
@@ -723,8 +708,10 @@ GC_API void * GC_CALL GC_debug_malloc_uncollectable(size_t lb,
     void * result = GC_malloc_uncollectable(lb + UNCOLLECTABLE_DEBUG_BYTES);
 
     if (result == 0) {
-        GC_err_printf("GC_debug_malloc_uncollectable(%lu)"
-                      " returning NULL (%s:%d)\n", (unsigned long)lb, s, i);
+        GC_err_printf("GC_debug_malloc_uncollectable(%lu) returning NULL (",
+                      (unsigned long) lb);
+        GC_err_puts(s);
+        GC_err_printf(":%d)\n", i);
         return(0);
     }
     if (!GC_debugging_started) {
@@ -742,8 +729,11 @@ GC_API void * GC_CALL GC_debug_malloc_uncollectable(size_t lb,
         GC_malloc_atomic_uncollectable(lb + UNCOLLECTABLE_DEBUG_BYTES);
 
     if (result == 0) {
-        GC_err_printf("GC_debug_malloc_atomic_uncollectable(%lu)"
-                      " returning NULL (%s:%d)\n", (unsigned long)lb, s, i);
+        GC_err_printf(
+                "GC_debug_malloc_atomic_uncollectable(%lu) returning NULL (",
+                (unsigned long) lb);
+        GC_err_puts(s);
+        GC_err_printf(":%d)\n", i);
         return(0);
     }
     if (!GC_debugging_started) {
@@ -769,7 +759,8 @@ GC_API void GC_CALL GC_debug_free(void * p)
 
     base = GC_base(p);
     if (base == 0) {
-      ABORT_ARG1("Invalid pointer passed to free()", ": %p", p);
+      GC_err_printf("Attempt to free invalid pointer %p\n", p);
+      ABORT("Invalid pointer passed to free()");
     }
     if ((ptr_t)p - (ptr_t)base != sizeof(oh)) {
       GC_err_printf(
@@ -846,7 +837,8 @@ GC_API void * GC_CALL GC_debug_realloc(void * p, size_t lb, GC_EXTRA_PARAMS)
 
     base = GC_base(p);
     if (base == 0) {
-        ABORT_ARG1("Invalid pointer passed to realloc()", ": %p", p);
+        GC_err_printf("Attempt to reallocate invalid pointer %p\n", p);
+        ABORT("Invalid pointer passed to realloc()");
     }
     if ((ptr_t)p - (ptr_t)base != sizeof(oh)) {
         GC_err_printf(
@@ -876,7 +868,8 @@ GC_API void * GC_CALL GC_debug_realloc(void * p, size_t lb, GC_EXTRA_PARAMS)
 #    endif
       default:
         result = NULL; /* initialized to prevent warning. */
-        ABORT_RET("GC_debug_realloc: encountered bad kind");
+        GC_err_printf("GC_debug_realloc: encountered bad kind\n");
+        ABORT_RET("Bad kind");
     }
 
     if (result != NULL) {
@@ -922,18 +915,14 @@ STATIC void GC_print_all_smashed_proc(void)
 
     GC_ASSERT(I_DONT_HOLD_LOCK());
     if (GC_n_smashed == 0) return;
-    GC_err_printf("GC_check_heap_block: found %u smashed heap objects:\n",
-                  GC_n_smashed);
+    GC_err_printf("GC_check_heap_block: found smashed heap objects:\n");
     for (i = 0; i < GC_n_smashed; ++i) {
-        ptr_t base = (ptr_t)GC_base(GC_smashed[i]);
-
-#       ifdef LINT2
-          if (!base) ABORT("Invalid GC_smashed element");
-#       endif
-        GC_print_smashed_obj("", base + sizeof(oh), GC_smashed[i]);
+        GC_print_smashed_obj("", (ptr_t)GC_base(GC_smashed[i]) + sizeof(oh),
+                             GC_smashed[i]);
         GC_smashed[i] = 0;
     }
     GC_n_smashed = 0;
+    GC_err_printf("\n");
 }
 
 /* Check all marked objects in the given block for validity     */
@@ -1072,8 +1061,9 @@ GC_API void GC_CALL GC_debug_register_finalizer(void * obj,
         return;
     }
     if ((ptr_t)obj - base != sizeof(oh)) {
-        GC_err_printf("GC_debug_register_finalizer called with"
-                      " non-base-pointer %p\n", obj);
+        GC_err_printf(
+            "GC_debug_register_finalizer called with non-base-pointer %p\n",
+            obj);
     }
     if (0 == fn) {
       GC_register_finalizer(base, 0, 0, &my_old_fn, &my_old_cd);
@@ -1101,8 +1091,10 @@ GC_API void GC_CALL GC_debug_register_finalizer_no_order
         return;
     }
     if ((ptr_t)obj - base != sizeof(oh)) {
-        GC_err_printf("GC_debug_register_finalizer_no_order called with"
-                      " non-base-pointer %p\n", obj);
+        GC_err_printf(
+          "GC_debug_register_finalizer_no_order called with "
+          "non-base-pointer %p\n",
+          obj);
     }
     if (0 == fn) {
       GC_register_finalizer_no_order(base, 0, 0, &my_old_fn, &my_old_cd);
@@ -1130,8 +1122,10 @@ GC_API void GC_CALL GC_debug_register_finalizer_unreachable
         return;
     }
     if ((ptr_t)obj - base != sizeof(oh)) {
-        GC_err_printf("GC_debug_register_finalizer_unreachable called with"
-                      " non-base-pointer %p\n", obj);
+        GC_err_printf(
+            "GC_debug_register_finalizer_unreachable called with "
+            "non-base-pointer %p\n",
+            obj);
     }
     if (0 == fn) {
       GC_register_finalizer_unreachable(base, 0, 0, &my_old_fn, &my_old_cd);
@@ -1159,8 +1153,9 @@ GC_API void GC_CALL GC_debug_register_finalizer_ignore_self
         return;
     }
     if ((ptr_t)obj - base != sizeof(oh)) {
-        GC_err_printf("GC_debug_register_finalizer_ignore_self called with"
-                      " non-base-pointer %p\n", obj);
+        GC_err_printf(
+            "GC_debug_register_finalizer_ignore_self called with "
+            "non-base-pointer %p\n", obj);
     }
     if (0 == fn) {
       GC_register_finalizer_ignore_self(base, 0, 0, &my_old_fn, &my_old_cd);
