@@ -3,8 +3,8 @@
 ;*    -------------------------------------------------------------    */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Thu Feb  1 13:18:41 2001                          */
-;*    Last change :  Thu Feb  1 13:36:15 2001 (serrano)                */
-;*    Copyright   :  2001 Manuel Serrano                               */
+;*    Last change :  Thu Sep 25 18:11:12 2008 (serrano)                */
+;*    Copyright   :  2001-08 Manuel Serrano                            */
 ;*    -------------------------------------------------------------    */
 ;*    The C demangler                                                  */
 ;*=====================================================================*/
@@ -20,38 +20,37 @@
 ;*---------------------------------------------------------------------*/
 (define *demangle-grammar*
    (regular-grammar ((id (: (or alpha #\_) (* (or alpha digit #\_))))
-		     (rest (in "<>/:;'~`!@#$%^&*()_-+=\|]}[{\\\"")))
-      ((: id "_bglt")
-       ;; this is a Bigloo type
-       (let ((str (the-substring 0 (-fx (the-length) 5))))
-	  (if (bigloo-mangled? str)
-	      (display (bigloo-demangle str))
-	      (display (the-string))))
-       (ignore))
+		     (rest (in "<>/:;'~`@#$%^&*()_-+=\|]}[{\\\"")))
       ((: id #\_ (+ (in digit)))
-       ;; this is likely to be a Bigloo local vaiable
+       ;; this is likely to be a Bigloo local variable
        (let ((len (the-length))
 	     (str (the-string)))
 	  (let loop ((i (-fx len 1)))
 	     (if (char=? (string-ref str i) #\_)
 		 (let ((substr (substring str 0 i)))
-		    (if (bigloo-mangled? substr)
-			(display (bigloo-demangle substr))
-			(display (the-string))))
+		    (cond
+		       ((bigloo-mangled? substr)
+			(display (bigloo-demangle substr)))
+		       (else
+			(display (the-string)))))
 		 (loop (-fx i 1)))))
        (ignore))
       (id
        ;; a plain identifier
        (let ((str (the-string)))
-	  (if (bigloo-mangled? str)
+	  (cond
+	     ((bigloo-mangled? str)
 	      (multiple-value-bind (id module)
 		 (bigloo-demangle str)
 		 (display id)
 		 (if (string? module)
-		     (display* "@" module)))
-	      (display str)))
+		     (display* "@" module))))
+	     ((bigloo-class-mangled? str)
+	      (display (bigloo-class-demangle str)))
+	     (else
+	      (display str))))
        (ignore))
-      ((+ blank)
+      (blank
        (display (the-string))
        (ignore))
       ((+ (or digit punct rest))
