@@ -3,7 +3,7 @@
 ;*                                                                     */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Wed Mar 18 15:32:05 1992                          */
-;*    Last change :  Sat Nov 13 09:24:05 1999 (serrano)                */
+;*    Last change :  Sun Dec 18 07:28:10 2005 (serrano)                */
 ;*                                                                     */
 ;*    Les tests sur les aritees variables                              */
 ;*---------------------------------------------------------------------*/
@@ -14,7 +14,9 @@
 (module vararity
    (import  (main "main.scm"))
    (include "test.sch")
-   (export  (test-vararity)))
+   (export  (test-vararity)
+	    (dsssl3 a #!optional b (c 'c) (d 'd))
+	    (dsssl3b a #!key b (c 'c) (d 'd))))
 
 ;*---------------------------------------------------------------------*/
 ;*    test 1.                                                          */
@@ -36,6 +38,18 @@
 (define (test3 . c)
    c)
 
+;*---------------------------------------------------------------------*/
+;*    dsssl3                                                           */
+;*---------------------------------------------------------------------*/
+(define (dsssl3 a #!optional b (c 'c) (d 'd))
+   (list a b c d))
+
+;*---------------------------------------------------------------------*/
+;*    dsssl3b                                                          */
+;*---------------------------------------------------------------------*/
+(define (dsssl3b a #!key b (c 'c) (d 'd))
+   (list a b c d))
+
 ;*---------------------------------------------------------------------*/
 ;*    test-vararity ...                                                */
 ;*---------------------------------------------------------------------*/
