@@ -3,7 +3,7 @@
 ;*    -------------------------------------------------------------    */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Fri Mar 24 09:59:43 1995                          */
-;*    Last change :  Tue Oct 25 07:54:25 2022 (serrano)                */
+;*    Last change :  Thu Dec 12 08:42:06 2024 (serrano)                */
 ;*    -------------------------------------------------------------    */
 ;*    6.5. Numbers (page 18, r4)                                       */
 ;*    -------------------------------------------------------------    */
@@ -18,11 +18,14 @@
 (module __r4_numbers_6_5
    
    (import  __error
-	    __param)
+	    __param
+	    __bignum)
 
    (use     __type
 	    __bigloo
 	    __tvector
+	    __evenv
+	    
 	    __r4_equivalence_6_2
 	    __r4_numbers_6_5_fixnum
 	    __r4_booleans_6_1
@@ -33,13 +36,8 @@
 	    __r4_numbers_6_5_flonum_dtoa
 	    __r4_symbols_6_4
 	    __r4_strings_6_7
-	    __r5_control_features_6_4
-	    __bignum
-	    
-	    __evenv)
+	    __r5_control_features_6_4)
 
-   (include "Ieee/bignum.sch")
-   
    (extern  (macro $fixnum->flonum::double (::long)   "(double)")
 	    (macro $flonum->fixnum::long (::double) "(long)")
 	    
@@ -419,7 +417,7 @@
 	 (oppost 'begin))
       (case op
 	 ((+ - * /)
-	  (set! opfx (symbol-append opfx '-safe))
+	  (set! opfx (symbol-append opfx '/ov))
 	  (set! opelong (symbol-append opelong '-safe))
 	  (set! opllong (symbol-append opllong '-safe))
 	  (set! oppost '$bignum->fixnum-safe)))
@@ -1129,7 +1127,7 @@
       ((and (flonum? x) (flonum? y) (=fl x 0.0) (=fl y 0.0))
        1.0)
       ((and (fixnum? x) (fixnum? y) (>=fx y 0))
-       (exptfx x y))
+       (exptfx/ov x y))
       ((and (bignum? x) (bignum? y) (positivebx? y))
        (exptbx x y))
       ((bignum? x)
