@@ -1,66 +1,43 @@
-;*---------------------------------------------------------------------*/
-;*   A pratical implementation for the Scheme programming language     */
-;*                                                                     */
-;*                                    ,--^,                            */
-;*                              _ ___/ /|/                             */
-;*                          ,;'( )__, ) '                              */
-;*                         ;;  //   L__.                               */
-;*                         '   \\   /  '                               */
-;*                              ^   ^                                  */
-;*                                                                     */
-;*   Copyright (c) 1992-1999 Manuel Serrano                            */
-;*                                                                     */
-;*     Bug descriptions, use reports, comments or suggestions are      */
-;*     welcome. Send them to                                           */
-;*       bigloo-request@kaolin.unice.fr                                */
-;*       http://kaolin.unice.fr/bigloo                                 */
-;*                                                                     */
-;*   This program is free software; you can redistribute it            */
-;*   and/or modify it under the terms of the GNU General Public        */
-;*   License as published by the Free Software Foundation; either      */
-;*   version 2 of the License, or (at your option) any later version.  */
-;*                                                                     */
-;*   This program is distributed in the hope that it will be useful,   */
-;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
-;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
-;*   GNU General Public License for more details.                      */
-;*                                                                     */
-;*   You should have received a copy of the GNU General Public         */
-;*   License along with this program; if not, write to the Free        */
-;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
-;*   MA 02111-1307, USA.                                               */
-;*---------------------------------------------------------------------*/
 
 (module __match_normalize
 
-   (import  (__error                   "Llib/error.scm")
-	    (__match_s2cfun            "Match/s2cfun.scm"))
+   (import  __error
+	    __match_s2cfun
+	    __param
+	    __bexit
+	    __object
+	    __thread)
    
-   (use     (__type                    "Llib/type.scm")
-	    (__bigloo                  "Llib/bigloo.scm")
-	    (__tvector                 "Llib/tvector.scm")
-	    (__structure               "Llib/struct.scm")
-	    (__tvector                 "Llib/tvector.scm")
-
-	    (__r4_numbers_6_5          "Ieee/number.scm")
-	    (__r4_numbers_6_5_fixnum   "Ieee/fixnum.scm")
-	    (__r4_numbers_6_5_flonum   "Ieee/flonum.scm")
-	    (__r4_characters_6_6       "Ieee/char.scm")
-	    (__r4_equivalence_6_2      "Ieee/equiv.scm")
-	    (__r4_booleans_6_1         "Ieee/boolean.scm")
-	    (__r4_symbols_6_4          "Ieee/symbol.scm")
-	    (__r4_strings_6_7          "Ieee/string.scm")
-	    (__r4_pairs_and_lists_6_3  "Ieee/pair-list.scm")
-	    (__r4_input_6_10_2         "Ieee/input.scm")
-	    (__r4_control_features_6_9 "Ieee/control.scm")
-	    (__r4_vectors_6_8          "Ieee/vector.scm")
-	    (__r4_ports_6_10_1         "Ieee/port.scm")
-	    (__r4_output_6_10_3        "Ieee/output.scm")
-	    (__evenv                   "Eval/evenv.scm"))
+   (use     __type
+	    __bigloo
+	    __tvector
+	    __structure
+	    __tvector
+	    __bignum
+	    __rgc
+	    __bit
+	    
+	    __r4_numbers_6_5
+	    __r4_numbers_6_5_fixnum
+	    __r4_numbers_6_5_flonum
+	    __r4_numbers_6_5_flonum_dtoa
+	    __r4_characters_6_6
+	    __r4_equivalence_6_2
+	    __r4_booleans_6_1
+	    __r4_symbols_6_4
+	    __r4_strings_6_7
+	    __r4_pairs_and_lists_6_3
+	    __r4_input_6_10_2
+	    __r4_control_features_6_9
+	    __r4_vectors_6_8
+	    __r4_ports_6_10_1
+	    __r4_output_6_10_3
+	    __evenv)
    
    (export  (normalize-pattern pat)
 	    (match-define-structure! exp)
-	    (extend.r.macro-env name fun)))
+	    (match-define-record-type! exp)
+	    (extend-r-macro-env name fun)))
  
 ;;;===========================================================4
 ;;; The standardizer converts patterns with an 
@@ -94,50 +71,50 @@
 
 (define (term-variable? e)
   (and (symbol? e)
-       (> (string-length (symbol->string e)) 1)
-       (char=? (string-ref (symbol->string e) 0) #\?) ) )
+       (> (string-length (symbol->string! e)) 1)
+       (char=? (string-ref (symbol->string! e) 0) #\?) ) )
 
 (define (segment-variable? e)
   (and (symbol? e)
-       (> (string-length (symbol->string e)) 2)
-       (char=? (string-ref (symbol->string e) 0) #\?)
-       (char=? (string-ref (symbol->string e) 1) #\?) ) )
+       (> (string-length (symbol->string! e)) 2)
+       (char=? (string-ref (symbol->string! e) 0) #\?)
+       (char=? (string-ref (symbol->string! e) 1) #\?) ) )
 
 (define (lispish-segment-variable? e)
   (and (symbol? e)
-       (> (string-length (symbol->string e)) 3)
-       (char=? (string-ref (symbol->string e) 0) #\?)
-       (char=? (string-ref (symbol->string e) 1) #\?)
-       (char=? (string-ref (symbol->string e) 2) #\?) ) )
+       (> (string-length (symbol->string! e)) 3)
+       (char=? (string-ref (symbol->string! e) 0) #\?)
+       (char=? (string-ref (symbol->string! e) 1) #\?)
+       (char=? (string-ref (symbol->string! e) 2) #\?) ) )
 
 (define (tree-variable? e)
   (and (symbol? e)
-       (> (string-length (symbol->string e)) 1)
-       (char=? (string-ref (symbol->string e) 0) #\!) ) )
+       (> (string-length (symbol->string! e)) 1)
+       (char=? (string-ref (symbol->string! e) 0) #\!) ) )
 
 (define (hole-variable? e)
   (and (symbol? e)
-       (> (string-length (symbol->string e)) 1)
-       (char=? (string-ref (symbol->string e) 0) #\^) ) )
+       (> (string-length (symbol->string! e)) 1)
+       (char=? (string-ref (symbol->string! e) 0) #\^) ) )
 
 (define (term-variable-true-name e)
-  (let ((s (symbol->string e)))
+  (let ((s (symbol->string! e)))
     (string->symbol (substring s 1 (string-length s))) ) )
 
 (define (segment-variable-true-name e)
-  (let ((s (symbol->string e)))
+  (let ((s (symbol->string! e)))
     (string->symbol (substring s 2 (string-length s))) ) )
 
 (define (tree-variable-true-name e)
-  (let ((s (symbol->string e)))
+  (let ((s (symbol->string! e)))
     (string->symbol (substring s 1 (string-length s))) ) )
 
 (define (hole-variable-true-name e)
-  (let ((s (symbol->string e)))
+  (let ((s (symbol->string! e)))
     (string->symbol (substring s 1 (string-length s))) ) )
 
 (define (lispish-segment-variable-true-name e)
-  (let ((s (symbol->string e)))
+  (let ((s (symbol->string! e)))
     (string->symbol (substring s 3 (string-length s))) ) )
 
 ;;;===============================================================6
@@ -145,7 +122,7 @@
 
 (define (normalize-pattern e)
   ((standardize-pattern e) 
-   r.macro-pattern
+   r-macro-pattern
    (lambda (pattern rr) pattern) ) )
 
 ;(define (standardize-pattern e)
@@ -157,11 +134,12 @@
 ;    ( (any) (standardize-patterns e) ) ) )
 
 (define (standardize-pattern e)
-  (cond ((macro-pattern? e) (standardize-macro-pattern e))
+  (cond ((macro-pattern? e) => (lambda (p) (standardize-macro-pattern e p)))
         ((eq? e '?-) (standardize-sexp))
         ((term-variable? e) (standardize-term-variable e))
         ((hole-variable? e) (standardize-hole-variable e))
         ((vector? e) (standardize-vector e))
+        ((struct? e) (standardize-struct e))
         ((atom? e) (standardize-quote e))
         (else (standardize-patterns e)) ) )
 
@@ -175,7 +153,7 @@
 
 (define (standardize-patterns e*)
   (if (pair? e*)
-      (cond ((macro-pattern? e*) (standardize-macro-pattern e*))
+      (cond ((macro-pattern? e*) => (lambda (p) (standardize-macro-pattern e* p)))
 	    ((eq? (car e*) '??-) (standardize-any (cdr e*)))
 	    ((eq? (car e*) '???-) (standardize-lispish-any (cdr e*)))
 	    ((lispish-segment-variable? (car e*))
@@ -340,17 +318,17 @@
       (lambda (r c) (c `(any) r))
       (standardize-any f*) ) )
 
-(define (standardize-macro-pattern e)
-  (apply (lookup r.macro-pattern (car e)) (cdr e)) )
+(define (standardize-macro-pattern e p)
+  (apply p (cdr e)) )
 
 ;;;--------------------------------------------------------------------*/
 ;;;   Macro-patterns                                                   */
 ;;;--------------------------------------------------------------------*/
 
 ;;; The environment binding name to macro-pattern
-(define r.macro-pattern.init '())
+(define r-macro-pattern-init '())
 
-(define r.macro-pattern r.macro-pattern.init)
+(define r-macro-pattern r-macro-pattern-init)
 
 (define (extend-alist fn pt im)
   (cons (cons pt im) fn) )
@@ -360,38 +338,46 @@
        (cdr (assq n r))
        #f))
 
-(define (extend.r.macro-env name fun)
-   (set! r.macro-pattern
-	 (extend-alist r.macro-pattern
+(define (extend-r-macro-env name fun)
+   (set! r-macro-pattern
+	 (extend-alist r-macro-pattern
 		       name
 		       fun)))
 
 (define-macro (defmacro-pattern name variables body)
   `(begin
-;*     (set! r.macro-pattern  */
-;*          (extend-alist r.macro-pattern  */
+;*     (set! r-macro-pattern  */
+;*          (extend-alist r-macro-pattern  */
 ;* 		       ',name  */
 ;* 		       (lambda ,variables ,body) ) )  */
-      (extend.r.macro-env ',name (lambda ,variables ,body))
+      (extend-r-macro-env ',name (lambda ,variables ,body))
     ',name ) )
 
 (define (macro-pattern? e)
   (and (pair? e)
-       (lookup r.macro-pattern (car e)) ) )
+       (lookup r-macro-pattern (car e)) ) )
 
-(defmacro-pattern atom (e . e*)
-   (lambda (r c)
-      (if (pair? e*)
-	  (match-wrong "Too many patterns provided for atom")
-	  ((standardize-pattern e)
-	   r
-	   (lambda (pattern rr)
-	      (c `(and (not (cons (any) (any)))
-		       ,pattern)
-		 rr))))))
+(defmacro-pattern atom l
+   (if (null? l)
+       (match-wrong "Illegal `atom' form" l)
+       (let ((e (car l))
+	     (e* (cdr l)))
+	  (lambda (r c)
+	     (if (pair? e*)
+		 (match-wrong "Too many patterns provided for atom" e*)
+		 ((standardize-pattern e)
+		  r
+		  (lambda (pattern rr)
+		     (c `(and (not (cons (any) (any)))
+			      ,pattern)
+			rr))))))))
 
-(defmacro-pattern or (e . e*)
-   (lambda (r c)
+(defmacro-pattern or l
+   (if (null? l)
+       (match-wrong "Illegal `or' form" l)
+       (let ((e (car l))
+	     (e* (cdr l)))
+	  (lambda (r c)
 	     (if (pair? e*)
 		 ((standardize-pattern e)
 		  r
@@ -402,8 +388,8 @@
 			 (if (and (coherent-environment? rr rrr)
 				  (coherent-environment? rrr rr))
 			     (c `(or ,pattern1 ,pattern2) rrr)
-			     (match-wrong "Incompatible alternative"))))))
-		 ((standardize-pattern e) r c))))
+			     (match-wrong "Incompatible alternative" l))))))
+		 ((standardize-pattern e) r c))))))
 
 ;;; (defmacro-pattern tagged-or (e l . e*)  */
 ;;;    (lambda (r c)  */
@@ -420,8 +406,12 @@
 ;;; 			     (match-wrong "Incompatible alternative"))))))  */
 ;;; 		 ((standardize-pattern e) r c) ) ) )  */
 
-(defmacro-pattern t-or (e . e*)
-   (lambda (r c)
+(defmacro-pattern t-or l
+   (if (null? l)
+       (match-wrong "Illegal `t-or' form" l)
+       (let ((e (car l))
+	     (e* (cdr l)))
+	  (lambda (r c)
 	     (if (pair? e*)
 		 ((standardize-pattern e)
 		  r
@@ -432,35 +422,46 @@
 			 (if (and (coherent-environment? rr rrr)
 				  (coherent-environment? rrr rr))
 			     (c `(t-or ,pattern1 ,pattern2) rrr)
-			     (match-wrong "Incompatible alternative"))))))
-		 ((standardize-pattern e) r c) ) ) )
+			     (match-wrong "Incompatible alternative" l))))))
+		 ((standardize-pattern e) r c) ) ) ) ) )
 
-(defmacro-pattern and (e . e*)
-   (lambda (r c)
-	   (if (pair? e*)
-	       ((standardize-pattern e)
-		r
-		(lambda (pattern1 rr)
-		   ((standardize-pattern `(and . ,e*))
-	 	    rr
-		    (lambda (pattern2 rrr)
-		       (c `(and ,pattern1 ,pattern2) rrr) ) ) ) )
-	       ((standardize-pattern e) r c))))
+(defmacro-pattern and l
+   (if (null? l)
+       (match-wrong "Illegal `and' form" l)
+       (let ((e (car l))
+	     (e* (cdr l)))
+	  (lambda (r c)
+	     (if (pair? e*)
+		 ((standardize-pattern e)
+		  r
+		  (lambda (pattern1 rr)
+		     ((standardize-pattern `(and . ,e*))
+		      rr
+		      (lambda (pattern2 rrr)
+			 (c `(and ,pattern1 ,pattern2) rrr) ) ) ) )
+		 ((standardize-pattern e) r c))))))
 
-(defmacro-pattern not (e)
-   (lambda (r c)
-	  ((standardize-pattern e)  
-	   r
-	   (lambda (pattern rr)
-	      (c `(not ,pattern) r) ) ) ) )
+(defmacro-pattern not l
+   (if (or (null? l) (pair? (cdr l)))
+       (match-wrong "Illegal `not'" l)
+       (let ((e (car l)))
+	  (lambda (r c)
+	     ((standardize-pattern e)  
+	      r
+	      (lambda (pattern rr)
+		 (c `(not ,pattern) r) ) ) ) ) ) )
 
-(defmacro-pattern ? (e)
-   (lambda (r c)
-      (c `(check ,e) r)))
+(defmacro-pattern ? l
+   (if (or (null? l) (pair? (cdr l)))
+       (match-wrong "Illegal `?' form" l)
+       (lambda (r c)
+	  (c `(check ,(car l)) r))))
 
-(defmacro-pattern kwote (e)
-   (lambda (r c)
-      (c `(quote ,e) r)))
+(defmacro-pattern kwote l
+   (if (or (null? l) (pair? (cdr l)))
+       (match-wrong "Illegal `kwote' form" l)
+       (lambda (r c)
+	  (c `(quote ,(car l)) r))))
 
 ;;; check coherency between arms of alternative patterns:
 ;;; For instance (match-lambda (or ?x ?y) t) is not coherent
@@ -480,10 +481,10 @@
 
 (define unbound-pattern '**Bad-Luck096561123523452**)
 
-(define (match-wrong . args)
-  (error 'Pattern-Matching "ERREUR: "args))
+(define (match-wrong msg arg)
+  (error 'Pattern-Matching msg arg))
 
-(define (r9.init n)
+(define (r9-init n)
   unbound-pattern)
 
 (define n normalize-pattern)
@@ -525,14 +526,20 @@
       ((eq? (car p) 'not) 1)
       ((tree-variable? (car p)) 0)
       ((memq (car p) '(??- ???-)) 0)
-      ((memq (car p) '(or and t-or tagged-or))
-       (pattern-length (cadr p)))
+      ((memq (car p) '(or and t-or tagged-or)) (pattern-length (cadr p)))
       (else (+ 1 (pattern-length (cdr p))))))
       
 ;*---------------------------------------------------------------------*/
 ;*    XXX-match-define-structure! updates a global environment         */
 ;*    mapping structure names to their lists of fields:                */
 ;*    ((2D-point x y) (3D-point x y z))                                */
+;*                                                                     */
+;*    Modified by Will M. Farr 28 Sept 2006 to support pattern         */
+;*    matching on define-record-type structures.  This requires        */
+;*    changing the *Match-Structures* environment to store the         */
+;*    predicate in addition to the structure name (because the         */
+;*    define-record-type from allows the user to specify the predicate */
+;*    name): ((2D-point 2D-point? x y) (3D-point 3D-point? x y z)).    */
 ;*---------------------------------------------------------------------*/
 (define *Match-Structures* '())
 
@@ -540,16 +547,24 @@
    (match-case exp
       ((define-struct ?name . ?fields)
        (set! *Match-Structures*
-             (cons (cdr exp) *Match-Structures*)))
+             (cons `(,name ,(symbol-append name '?) ,@fields)
+		   *Match-Structures*)))
       (else (error "Incorrect declaration: " exp 'Aborted))))
 
-(defmacro-pattern struct-pat (name . e*)
-   (lambda (r c)
-      (c `(struct-pat ,name
-                      ,@(map normalize-pattern e*))
-         r)))
+(define (match-define-record-type! exp)
+  (match-case exp
+    ((define-record-type ?name ?constr ?pred . ?fields)
+     (let ((really-fields (map car fields)))
+       (set! *Match-Structures*
+	     (cons `(,name ,pred ,@fields)
+		   *Match-Structures*))))
+    (else (error "Incorrect declaration: " exp 'Aborted))))
 
-(defmacro-pattern _structure_ f              
+(defmacro-pattern struct-pat (name pred . e*)
+   (lambda (r c)
+      (c `(struct-pat ,name ,pred ,@(map normalize-pattern e*)) r)))
+
+(define (standardize-struct e)
    (lambda (r c)
       (define (look-for-structure provided-fields)
          (let loop1 ((S *Match-Structures*))
@@ -563,15 +578,17 @@
                            (loop1 (cdr S))))))))
       (let* (;; On recupere le nom et la liste des champs
              ;; dans le bon ordre
+	     (f (struct->list e))
              (structure (if (pair? (car f))
-                            (look-for-structure
-                             (map car (cdr f)))
+                            (look-for-structure (map car (cdr f)))
                             (if (assoc (car f) *Match-Structures*)
                                 (assoc (car f) *Match-Structures*)
-                                (error "No such structure "
-                                       f *Match-Structures*))))
+                                (error 'match-case
+				       "No such structure "
+				       (car f)))))
              (name (car structure))
-             (fields (cdr structure))
+	     (pred (cadr structure))
+             (fields (cddr structure))
              (provided-fields (if (pair? (car f))
                                   f
                                   (cdr f)))
@@ -583,11 +600,11 @@
              (pattern
               `(struct-pat
                 ,name
+		,pred
                 ,@(if (pair? (car f))
                       (map (lambda (field)
                               (if (assoc field provided-fields)
-                                  (cadr (assoc field
-                                               provided-fields))
+                                  (cadr (assoc field provided-fields))
                                   '?-))
                            fields)
                       (cdr f)))))
