@@ -1,9 +1,9 @@
 ;*=====================================================================*/
-;*    serrano/prgm/project/bigloo/runtime/Pp/pp.scm                    */
+;*    serrano/prgm/project/bigloo/bigloo/runtime/Pp/pp.scm             */
 ;*    -------------------------------------------------------------    */
 ;*    Author      :  Manuel Serrano                                    */
 ;*    Creation    :  Sat Nov 27 14:10:31 1993                          */
-;*    Last change :  Mon Nov 19 15:10:39 2001 (serrano)                */
+;*    Last change :  Fri Jun 25 14:14:12 2021 (serrano)                */
 ;*    -------------------------------------------------------------    */
 ;*    Le pretty-printer de Marc Feeley.                                */
 ;*=====================================================================*/
@@ -18,13 +18,21 @@
    
    (use     __type
 	    __bigloo
+	    __param
+	    __object
+	    __thread
+	    __bexit
+	    __bignum
 	    __tvector
 	    __structure
 	    __tvector
-
+	    __rgc
+	    __bit
+	    
 	    __r4_numbers_6_5
 	    __r4_numbers_6_5_fixnum
 	    __r4_numbers_6_5_flonum
+	    __r4_numbers_6_5_flonum_dtoa
 	    __r4_characters_6_6
 	    __r4_equivalence_6_2
 	    __r4_booleans_6_1
@@ -141,7 +149,7 @@
 	    (out "()" col)))
      
      (cond ((match-case obj
-	       ((comment (? integer?) (? string?))
+	       ((comment (? fixnum?) (? string?))
 		#t)
 	       (else
 		#f))
@@ -160,7 +168,27 @@
 	   ((boolean? obj)
 	    (out (if obj "#t" "#f") col))
 	   ((number? obj)
-	    (out (number->string obj) col))
+	    (cond
+	       ((elong? obj)
+		(out (string-append "#e" (number->string obj)) col))
+	       ((llong? obj)
+		(out (string-append "#l" (number->string obj)) col))
+	       ((uint8? obj)
+		(out (string-append "#u8:" (number->string obj)) col))
+	       ((uint16? obj)
+		(out (string-append "#u16:" (number->string obj)) col))
+	       ((uint32? obj)
+		(out (string-append "#u32:" (number->string obj)) col))
+	       ((int8? obj)
+		(out (string-append "#s8:" (number->string obj)) col))
+	       ((int16? obj)
+		(out (string-append "#s16:" (number->string obj)) col))
+	       ((int32? obj)
+		(out (string-append "#s32:" (number->string obj)) col))
+	       ((bignum? obj)
+		(out (string-append "#z" (number->string obj)) col))
+	       (else
+		(out (number->string obj) col))))
 	   ((symbol? obj)
 	    (let ((p (open-output-string)))
 	       (if display?
@@ -176,14 +204,16 @@
 		   (out (string-downcase (close-output-port p))
 			col)))))
 	   ((procedure? obj)
-	    (out "#<procedure>" col))
+	    (out (with-output-to-string (lambda () (display obj))) col))
 	   ((string? obj)
 	    (let ((obj (string-for-read obj)))
 	       (if display?
 		   (out obj col)
 		   (let loop ((i 0)
 			      (j 0) 
-			      (col (out (if *bigloo-strict-r5rs-strings* "#\"" "\"")
+			      (col (out (if (bigloo-strict-r5rs-strings)
+					    "#\""
+					    "\"")
 					col)))
 		      (if (and col (<fx j (string-length obj)))
 			  (let ((c (string-ref obj j)))
@@ -203,6 +233,10 @@
 	    (out "#[output-port]" col))
 	   ((eof-object? obj)
 	    (out "#[eof-object]" col))
+	   ((object? obj)
+	    (out (string-append "#|"
+		    (symbol->string (class-name (object-class obj)))
+		    "|") col))
 	   (else
 	    (out (let ((p (open-output-string)))
 		    (write obj p)
@@ -253,7 +287,7 @@
             (let ((proc (style head)))
               (if proc
                 (proc expr col extra)
-                (if (>fx (string-length (symbol->string head))
+                (if (>fx (string-length (symbol->string! head))
                        max-call-head-width)
                   (pp-general expr col extra #f #f #f pp-expr)
                   (pp-call expr col extra pp-expr))))
@@ -343,13 +377,23 @@
     (define (pp-defun expr col extra)
       (pp-general expr col extra #t pp-expr-defun #f pp-expr)
       (out #"\n" 0))
-      
-    (define (pp-lambda expr col extra)
-      (pp-general expr col extra #f pp-expr-list #f pp-expr))
 
+    (define (pp-let expr col extra)
+       (pp-general expr col extra #f pp-expr-list #f pp-expr))
+    
+    ; (item1 item2
+    ;     item3
+    ;     item4)
+    (define (pp-lambda expr col extra)
+       (let* ((col (out "(" col))
+	      (col2 (wr (car expr) col))
+	      (col3 (out " " col2))
+	      (col4 (wr (cadr expr) col3)))
+	 (pp-down (cddr expr) col3 (+fx col 2) extra pp-expr)))
+   
     (define (pp-comment expr col extra)
        (match-case expr
-	  ((comment (and (? integer?) ?column) (and (? string?) ?string))
+	  ((comment (and (? fixnum?) ?column) (and (? string?) ?string))
 	   (let ((add (- *pp-width* (string-length string) 3)))
 	      (if (=fx column 0)
 		  (if (>fx add 0)
@@ -396,10 +440,12 @@
 
     (define (style head)
       (case (if (eq? *pp-case* 'respect)
-		(string->symbol (string-upcase (symbol->string head)))
+		(string->symbol (symbol->string! head))
 		head)
-        ((lambda let* letrec)                                pp-lambda)
+        ((lambda)                                            pp-lambda)
+        ((let* letrec)                                       pp-let)
 	((define define-inline define-method define-generic) pp-define)
+	((module)                                            pp-define)
 	((defun de)                                          pp-defun)
         ((if set!)                                           pp-if)
         ((cond)                                              pp-cond)
